@@ -16,19 +16,22 @@
 */
 
 #include <gtest/gtest.h>
-#include "gz/sim/test_config.hh"
-#include "gz/sim/components/Component.hh"
-#include "gz/sim/components/Factory.hh"
-#include "gz/sim/components/Pose.hh"
+#include "ignition/gazebo/test_config.hh"
+#include "ignition/gazebo/components/Component.hh"
+#include "ignition/gazebo/components/Factory.hh"
+#include "ignition/gazebo/components/Pose.hh"
 
-#include "../test/helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
-class ComponentFactoryTest : public InternalFixture<::testing::Test>
+class ComponentFactoryTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+  }
 };
 
 /////////////////////////////////////////////////
