@@ -15,29 +15,32 @@
  *
 */
 
-#include <gz/msgs/atmosphere.pb.h>
-#include <gz/msgs/axis_aligned_box.pb.h>
-#include <gz/msgs/boxgeom.pb.h>
-#include <gz/msgs/cylindergeom.pb.h>
-#include <gz/msgs/entity.pb.h>
-#include <gz/msgs/geometry.pb.h>
-#include <gz/msgs/gui.pb.h>
-#include <gz/msgs/imu_sensor.pb.h>
-#include <gz/msgs/lidar_sensor.pb.h>
-#include <gz/msgs/actor.pb.h>
-#include <gz/msgs/light.pb.h>
-#include <gz/msgs/material.pb.h>
-#include <gz/msgs/planegeom.pb.h>
-#include <gz/msgs/plugin.pb.h>
-#include <gz/msgs/spheregeom.pb.h>
-#include <gz/msgs/Utility.hh>
+#include <ignition/msgs/atmosphere.pb.h>
+#include <ignition/msgs/axis_aligned_box.pb.h>
+#include <ignition/msgs/boxgeom.pb.h>
+#include <ignition/msgs/capsulegeom.pb.h>
+#include <ignition/msgs/cylindergeom.pb.h>
+#include <ignition/msgs/entity.pb.h>
+#include <ignition/msgs/ellipsoidgeom.pb.h>
+#include <ignition/msgs/geometry.pb.h>
+#include <ignition/msgs/gui.pb.h>
+#include <ignition/msgs/heightmapgeom.pb.h>
+#include <ignition/msgs/imu_sensor.pb.h>
+#include <ignition/msgs/lidar_sensor.pb.h>
+#include <ignition/msgs/actor.pb.h>
+#include <ignition/msgs/light.pb.h>
+#include <ignition/msgs/material.pb.h>
+#include <ignition/msgs/planegeom.pb.h>
+#include <ignition/msgs/plugin.pb.h>
+#include <ignition/msgs/spheregeom.pb.h>
+#include <ignition/msgs/Utility.hh>
 
-#include <gz/math/Angle.hh>
-#include <gz/math/AxisAlignedBox.hh>
-#include <gz/math/Helpers.hh>
-#include <gz/math/Temperature.hh>
+#include <ignition/math/Angle.hh>
+#include <ignition/math/AxisAlignedBox.hh>
+#include <ignition/math/Helpers.hh>
+#include <ignition/math/Temperature.hh>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include <sdf/Actor.hh>
 #include <sdf/Atmosphere.hh>
@@ -45,9 +48,12 @@
 #include <sdf/Altimeter.hh>
 #include <sdf/Box.hh>
 #include <sdf/Camera.hh>
+#include <sdf/Capsule.hh>
 #include <sdf/Cylinder.hh>
+#include <sdf/Ellipsoid.hh>
 #include <sdf/Geometry.hh>
 #include <sdf/Gui.hh>
+#include <sdf/Heightmap.hh>
 #include <sdf/Imu.hh>
 #include <sdf/Lidar.hh>
 #include <sdf/Light.hh>
@@ -56,21 +62,21 @@
 #include <sdf/Mesh.hh>
 #include <sdf/Pbr.hh>
 #include <sdf/Plane.hh>
-#include <sdf/Polyline.hh>
 #include <sdf/Sphere.hh>
 
+#include <algorithm>
 #include <string>
 
-#include "gz/sim/Conversions.hh"
-#include "gz/sim/Export.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/Conversions.hh"
+#include "ignition/gazebo/Export.hh"
+#include "ignition/gazebo/Util.hh"
 
-using namespace gz;
+using namespace ignition;
 
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Entity_Type gazebo::convert(const std::string &_in)
+msgs::Entity_Type ignition::gazebo::convert(const std::string &_in)
 {
   msgs::Entity_Type out = msgs::Entity_Type_NONE;
 
@@ -108,7 +114,7 @@ msgs::Entity_Type gazebo::convert(const std::string &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Pose3d gazebo::convert(const msgs::Pose &_in)
+math::Pose3d ignition::gazebo::convert(const msgs::Pose &_in)
 {
   math::Pose3d out(_in.position().x(),
                    _in.position().y(),
@@ -125,7 +131,7 @@ math::Pose3d gazebo::convert(const msgs::Pose &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Collision gazebo::convert(const sdf::Collision &_in)
+msgs::Collision ignition::gazebo::convert(const sdf::Collision &_in)
 {
   msgs::Collision out;
   out.set_name(_in.Name());
@@ -138,7 +144,7 @@ msgs::Collision gazebo::convert(const sdf::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Collision gazebo::convert(const msgs::Collision &_in)
+sdf::Collision ignition::gazebo::convert(const msgs::Collision &_in)
 {
   sdf::Collision out;
   out.SetName(_in.name());
@@ -150,7 +156,7 @@ sdf::Collision gazebo::convert(const msgs::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
+msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
 {
   msgs::Geometry out;
   if (_in.Type() == sdf::GeometryType::BOX && _in.BoxShape())
@@ -158,12 +164,24 @@ msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
     out.set_type(msgs::Geometry::BOX);
     msgs::Set(out.mutable_box()->mutable_size(), _in.BoxShape()->Size());
   }
+  else if (_in.Type() == sdf::GeometryType::CAPSULE && _in.CapsuleShape())
+  {
+    out.set_type(msgs::Geometry::CAPSULE);
+    out.mutable_capsule()->set_radius(_in.CapsuleShape()->Radius());
+    out.mutable_capsule()->set_length(_in.CapsuleShape()->Length());
+  }
   else if (_in.Type() == sdf::GeometryType::CYLINDER && _in.CylinderShape())
   {
     out.set_type(msgs::Geometry::CYLINDER);
     out.mutable_cylinder()->set_radius(_in.CylinderShape()->Radius());
     out.mutable_cylinder()->set_length(_in.CylinderShape()->Length());
   }
+  else if (_in.Type() == sdf::GeometryType::ELLIPSOID && _in.EllipsoidShape())
+  {
+    out.set_type(msgs::Geometry::ELLIPSOID);
+    msgs::Set(out.mutable_ellipsoid()->mutable_radii(),
+             _in.EllipsoidShape()->Radii());
+  }
   else if (_in.Type() == sdf::GeometryType::PLANE && _in.PlaneShape())
   {
     out.set_type(msgs::Geometry::PLANE);
@@ -189,18 +207,37 @@ msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
     meshMsg->set_submesh(meshSdf->Submesh());
     meshMsg->set_center_submesh(meshSdf->CenterSubmesh());
   }
-  else if (_in.Type() == sdf::GeometryType::POLYLINE &&
-      !_in.PolylineShape().empty())
+  else if (_in.Type() == sdf::GeometryType::HEIGHTMAP && _in.HeightmapShape())
   {
-    out.set_type(msgs::Geometry::POLYLINE);
-    for (const auto &polyline : _in.PolylineShape())
+    auto heightmapSdf = _in.HeightmapShape();
+
+    out.set_type(msgs::Geometry::HEIGHTMAP);
+    auto heightmapMsg = out.mutable_heightmap();
+
+    heightmapMsg->set_filename(asFullPath(heightmapSdf->Uri(),
+        heightmapSdf->FilePath()));
+    msgs::Set(heightmapMsg->mutable_size(), heightmapSdf->Size());
+    msgs::Set(heightmapMsg->mutable_origin(), heightmapSdf->Position());
+    heightmapMsg->set_use_terrain_paging(heightmapSdf->UseTerrainPaging());
+    heightmapMsg->set_sampling(heightmapSdf->Sampling());
+
+    for (auto i = 0u; i < heightmapSdf->TextureCount(); ++i)
     {
-      auto polylineMsg = out.add_polyline();
-      polylineMsg->set_height(polyline.Height());
-      for (const auto &point : polyline.Points())
-      {
-        msgs::Set(polylineMsg->add_point(), point);
-      }
+      auto textureSdf = heightmapSdf->TextureByIndex(i);
+      auto textureMsg = heightmapMsg->add_texture();
+      textureMsg->set_size(textureSdf->Size());
+      textureMsg->set_diffuse(asFullPath(textureSdf->Diffuse(),
+          heightmapSdf->FilePath()));
+      textureMsg->set_normal(asFullPath(textureSdf->Normal(),
+          heightmapSdf->FilePath()));
+    }
+
+    for (auto i = 0u; i < heightmapSdf->BlendCount(); ++i)
+    {
+      auto blendSdf = heightmapSdf->BlendByIndex(i);
+      auto blendMsg = heightmapMsg->add_blend();
+      blendMsg->set_min_height(blendSdf->MinHeight());
+      blendMsg->set_fade_dist(blendSdf->FadeDistance());
     }
   }
   else
@@ -214,7 +251,7 @@ msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
+sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
 {
   sdf::Geometry out;
   if (_in.type() == msgs::Geometry::BOX && _in.has_box())
@@ -226,6 +263,16 @@ sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 
     out.SetBoxShape(boxShape);
   }
+  else if (_in.type() == msgs::Geometry::CAPSULE && _in.has_capsule())
+  {
+    out.SetType(sdf::GeometryType::CAPSULE);
+
+    sdf::Capsule capsuleShape;
+    capsuleShape.SetRadius(_in.capsule().radius());
+    capsuleShape.SetLength(_in.capsule().length());
+
+    out.SetCapsuleShape(capsuleShape);
+  }
   else if (_in.type() == msgs::Geometry::CYLINDER && _in.has_cylinder())
   {
     out.SetType(sdf::GeometryType::CYLINDER);
@@ -236,6 +283,15 @@ sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 
     out.SetCylinderShape(cylinderShape);
   }
+  else if (_in.type() == msgs::Geometry::ELLIPSOID && _in.has_ellipsoid())
+  {
+    out.SetType(sdf::GeometryType::ELLIPSOID);
+
+    sdf::Ellipsoid ellipsoidShape;
+    ellipsoidShape.SetRadii(msgs::Convert(_in.ellipsoid().radii()));
+
+    out.SetEllipsoidShape(ellipsoidShape);
+  }
   else if (_in.type() == msgs::Geometry::PLANE && _in.has_plane())
   {
     out.SetType(sdf::GeometryType::PLANE);
@@ -267,27 +323,37 @@ sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 
     out.SetMeshShape(meshShape);
   }
-  else if (_in.type() == msgs::Geometry::POLYLINE && _in.polyline_size() > 0)
+  else if (_in.type() == msgs::Geometry::HEIGHTMAP && _in.has_heightmap())
   {
-    out.SetType(sdf::GeometryType::POLYLINE);
+    out.SetType(sdf::GeometryType::HEIGHTMAP);
+    sdf::Heightmap heightmapShape;
 
-    std::vector<sdf::Polyline> polylines;
+    heightmapShape.SetUri(_in.heightmap().filename());
+    heightmapShape.SetSize(msgs::Convert(_in.heightmap().size()));
+    heightmapShape.SetPosition(msgs::Convert(_in.heightmap().origin()));
+    heightmapShape.SetUseTerrainPaging(_in.heightmap().use_terrain_paging());
+    heightmapShape.SetSampling(_in.heightmap().sampling());
 
-    for (auto i = 0; i < _in.polyline().size(); ++i)
+    for (int i = 0; i < _in.heightmap().texture_size(); ++i)
     {
-      auto polylineMsg = _in.polyline(i);
-      sdf::Polyline polylineShape;
-      polylineShape.SetHeight(polylineMsg.height());
-
-      for (auto j = 0; j < polylineMsg.point().size(); ++j)
-      {
-        polylineShape.AddPoint(msgs::Convert(polylineMsg.point(j)));
-      }
-
-      polylines.push_back(polylineShape);
+      auto textureMsg = _in.heightmap().texture(i);
+      sdf::HeightmapTexture textureSdf;
+      textureSdf.SetSize(textureMsg.size());
+      textureSdf.SetDiffuse(textureMsg.diffuse());
+      textureSdf.SetNormal(textureMsg.normal());
+      heightmapShape.AddTexture(textureSdf);
     }
 
-    out.SetPolylineShape(polylines);
+    for (int i = 0; i < _in.heightmap().blend_size(); ++i)
+    {
+      auto blendMsg = _in.heightmap().blend(i);
+      sdf::HeightmapBlend blendSdf;
+      blendSdf.SetMinHeight(blendMsg.min_height());
+      blendSdf.SetFadeDistance(blendMsg.fade_dist());
+      heightmapShape.AddBlend(blendSdf);
+    }
+
+    out.SetHeightmapShape(heightmapShape);
   }
   else
   {
@@ -300,20 +366,22 @@ sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Material gazebo::convert(const sdf::Material &_in)
+msgs::Material ignition::gazebo::convert(const sdf::Material &_in)
 {
   msgs::Material out;
   msgs::Set(out.mutable_ambient(), _in.Ambient());
   msgs::Set(out.mutable_diffuse(), _in.Diffuse());
   msgs::Set(out.mutable_specular(), _in.Specular());
   msgs::Set(out.mutable_emissive(), _in.Emissive());
+  out.set_render_order(_in.RenderOrder());
   out.set_lighting(_in.Lighting());
+  out.set_double_sided(_in.DoubleSided());
 
-  sdf::Pbr *pbr = _in.PbrMaterial();
+  auto pbr = _in.PbrMaterial();
   if (pbr)
   {
-    msgs::Material::PBR *pbrMsg = out.mutable_pbr();
-    sdf::PbrWorkflow *workflow = pbr->Workflow(sdf::PbrWorkflowType::METAL);
+    auto pbrMsg = out.mutable_pbr();
+    auto workflow = pbr->Workflow(sdf::PbrWorkflowType::METAL);
     if (workflow)
       pbrMsg->set_type(msgs::Material_PBR_WorkflowType_METAL);
     else
@@ -346,6 +414,9 @@ msgs::Material gazebo::convert(const sdf::Material &_in)
           asFullPath(workflow->EnvironmentMap(), _in.FilePath()));
       pbrMsg->set_emissive_map(workflow->EmissiveMap().empty() ? "" :
           asFullPath(workflow->EmissiveMap(), _in.FilePath()));
+      pbrMsg->set_light_map(workflow->LightMap().empty() ? "" :
+          asFullPath(workflow->LightMap(), _in.FilePath()));
+      pbrMsg->set_light_map_texcoord_set(workflow->LightMapTexCoordSet());
     }
   }
   return out;
@@ -354,14 +425,16 @@ msgs::Material gazebo::convert(const sdf::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Material gazebo::convert(const msgs::Material &_in)
+sdf::Material ignition::gazebo::convert(const msgs::Material &_in)
 {
   sdf::Material out;
   out.SetAmbient(msgs::Convert(_in.ambient()));
   out.SetDiffuse(msgs::Convert(_in.diffuse()));
   out.SetSpecular(msgs::Convert(_in.specular()));
   out.SetEmissive(msgs::Convert(_in.emissive()));
+  out.SetRenderOrder(_in.render_order());
   out.SetLighting(_in.lighting());
+  out.SetDoubleSided(_in.double_sided());
 
   if (_in.has_pbr())
   {
@@ -384,6 +457,8 @@ sdf::Material gazebo::convert(const msgs::Material &_in)
     workflow.SetEnvironmentMap(pbrMsg.environment_map());
     workflow.SetAmbientOcclusionMap(pbrMsg.ambient_occlusion_map());
     workflow.SetEmissiveMap(pbrMsg.emissive_map());
+    workflow.SetLightMap(pbrMsg.light_map(), pbrMsg.light_map_texcoord_set());
+
     pbr.SetWorkflow(workflow.Type(), workflow);
     out.SetPbrMaterial(pbr);
   }
@@ -393,7 +468,7 @@ sdf::Material gazebo::convert(const msgs::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Actor gazebo::convert(const sdf::Actor &_in)
+msgs::Actor ignition::gazebo::convert(const sdf::Actor &_in)
 {
   msgs::Actor out;
   out.mutable_entity()->set_name(_in.Name());
@@ -433,7 +508,7 @@ msgs::Actor gazebo::convert(const sdf::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Actor gazebo::convert(const msgs::Actor &_in)
+sdf::Actor ignition::gazebo::convert(const msgs::Actor &_in)
 {
   sdf::Actor out;
   out.SetName(_in.entity().name());
@@ -476,7 +551,7 @@ sdf::Actor gazebo::convert(const msgs::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Light gazebo::convert(const sdf::Light &_in)
+msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
 {
   msgs::Light out;
   out.set_name(_in.Name());
@@ -487,6 +562,7 @@ msgs::Light gazebo::convert(const sdf::Light &_in)
   out.set_attenuation_linear(_in.LinearAttenuationFactor());
   out.set_attenuation_quadratic(_in.QuadraticAttenuationFactor());
   out.set_range(_in.AttenuationRange());
+  out.set_intensity(_in.Intensity());
   msgs::Set(out.mutable_direction(), _in.Direction());
   out.set_cast_shadows(_in.CastShadows());
   out.set_spot_inner_angle(_in.SpotInnerAngle().Radian());
@@ -504,7 +580,7 @@ msgs::Light gazebo::convert(const sdf::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Light gazebo::convert(const msgs::Light &_in)
+sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
 {
   sdf::Light out;
   out.SetName(_in.name());
@@ -516,6 +592,7 @@ sdf::Light gazebo::convert(const msgs::Light &_in)
   out.SetQuadraticAttenuationFactor(_in.attenuation_quadratic());
   out.SetAttenuationRange(_in.range());
   out.SetDirection(msgs::Convert(_in.direction()));
+  out.SetIntensity(_in.intensity());
   out.SetCastShadows(_in.cast_shadows());
   out.SetSpotInnerAngle(math::Angle(_in.spot_inner_angle()));
   out.SetSpotOuterAngle(math::Angle(_in.spot_outer_angle()));
@@ -532,7 +609,7 @@ sdf::Light gazebo::convert(const msgs::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::GUI gazebo::convert(const sdf::Gui &_in)
+msgs::GUI ignition::gazebo::convert(const sdf::Gui &_in)
 {
   msgs::GUI out;
 
@@ -571,12 +648,12 @@ msgs::GUI gazebo::convert(const sdf::Gui &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Time gazebo::convert(
+msgs::Time ignition::gazebo::convert(
     const std::chrono::steady_clock::duration &_in)
 {
   msgs::Time out;
 
-  auto secNsec = math::durationToSecNsec(_in);
+  auto secNsec = ignition::math::durationToSecNsec(_in);
 
   out.set_sec(secNsec.first);
   out.set_nsec(secNsec.second);
@@ -587,7 +664,7 @@ msgs::Time gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-std::chrono::steady_clock::duration gazebo::convert(
+std::chrono::steady_clock::duration ignition::gazebo::convert(
     const msgs::Time &_in)
 {
   return std::chrono::seconds(_in.sec()) + std::chrono::nanoseconds(_in.nsec());
@@ -596,7 +673,7 @@ std::chrono::steady_clock::duration gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Inertial gazebo::convert(const math::Inertiald &_in)
+msgs::Inertial ignition::gazebo::convert(const math::Inertiald &_in)
 {
   msgs::Inertial out;
   msgs::Set(out.mutable_pose(), _in.Pose());
@@ -613,7 +690,7 @@ msgs::Inertial gazebo::convert(const math::Inertiald &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Inertiald gazebo::convert(const msgs::Inertial &_in)
+math::Inertiald ignition::gazebo::convert(const msgs::Inertial &_in)
 {
   math::MassMatrix3d massMatrix;
   massMatrix.SetMass(_in.mass());
@@ -633,18 +710,10 @@ math::Inertiald gazebo::convert(const msgs::Inertial &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Axis gazebo::convert(const sdf::JointAxis &_in)
+msgs::Axis ignition::gazebo::convert(const sdf::JointAxis &_in)
 {
   msgs::Axis out;
   msgs::Set(out.mutable_xyz(), _in.Xyz());
-#ifndef _WIN32
-# pragma GCC diagnostic push
-# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-  out.set_use_parent_model_frame(_in.UseParentModelFrame());
-#ifndef _WIN32
-# pragma GCC diagnostic pop
-#endif
   out.set_xyz_expressed_in(_in.XyzExpressedIn());
   out.set_damping(_in.Damping());
   out.set_friction(_in.Friction());
@@ -671,18 +740,13 @@ msgs::Axis gazebo::convert(const sdf::JointAxis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::JointAxis gazebo::convert(const msgs::Axis &_in)
+sdf::JointAxis ignition::gazebo::convert(const msgs::Axis &_in)
 {
   sdf::JointAxis out;
-  out.SetXyz(msgs::Convert(_in.xyz()));
-#ifndef _WIN32
-# pragma GCC diagnostic push
-# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-  out.SetUseParentModelFrame(_in.use_parent_model_frame());
-#ifndef _WIN32
-# pragma GCC diagnostic pop
-#endif
+  sdf::Errors errors = out.SetXyz(msgs::Convert(_in.xyz()));
+  for (const auto &err : errors) {
+    ignerr << err.Message() << std::endl;
+  }
   out.SetXyzExpressedIn(_in.xyz_expressed_in());
   out.SetDamping(_in.damping());
   out.SetFriction(_in.friction());
@@ -696,7 +760,7 @@ sdf::JointAxis gazebo::convert(const msgs::Axis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Scene gazebo::convert(const sdf::Scene &_in)
+msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
 {
   msgs::Scene out;
   // todo(anyone) add Name to sdf::Scene?
@@ -706,13 +770,28 @@ msgs::Scene gazebo::convert(const sdf::Scene &_in)
   out.set_shadows(_in.Shadows());
   out.set_grid(_in.Grid());
   out.set_origin_visual(_in.OriginVisual());
+
+  if (_in.Sky())
+  {
+    msgs::Sky *skyMsg = out.mutable_sky();
+    skyMsg->set_time(_in.Sky()->Time());
+    skyMsg->set_sunrise(_in.Sky()->Sunrise());
+    skyMsg->set_sunset(_in.Sky()->Sunset());
+    skyMsg->set_wind_speed(_in.Sky()->CloudSpeed());
+    skyMsg->set_wind_direction(_in.Sky()->CloudDirection().Radian());
+    skyMsg->set_humidity(_in.Sky()->CloudHumidity());
+    skyMsg->set_mean_cloud_size(_in.Sky()->CloudMeanSize());
+    msgs::Set(skyMsg->mutable_cloud_ambient(),
+        _in.Sky()->CloudAmbient());
+  }
+
   return out;
 }
 
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Scene gazebo::convert(const msgs::Scene &_in)
+sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
 {
   sdf::Scene out;
   // todo(anyone) add SetName to sdf::Scene?
@@ -722,13 +801,27 @@ sdf::Scene gazebo::convert(const msgs::Scene &_in)
   out.SetShadows(_in.shadows());
   out.SetGrid(_in.grid());
   out.SetOriginVisual(_in.origin_visual());
+
+  if (_in.has_sky())
+  {
+    sdf::Sky sky;
+    sky.SetTime(_in.sky().time());
+    sky.SetSunrise(_in.sky().sunrise());
+    sky.SetSunset(_in.sky().sunset());
+    sky.SetCloudSpeed(_in.sky().wind_speed());
+    sky.SetCloudDirection(math::Angle(_in.sky().wind_direction()));
+    sky.SetCloudHumidity(_in.sky().humidity());
+    sky.SetCloudMeanSize(_in.sky().mean_cloud_size());
+    sky.SetCloudAmbient(msgs::Convert(_in.sky().cloud_ambient()));
+    out.SetSky(sky);
+  }
   return out;
 }
 
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Atmosphere gazebo::convert(const sdf::Atmosphere &_in)
+msgs::Atmosphere ignition::gazebo::convert(const sdf::Atmosphere &_in)
 {
   msgs::Atmosphere out;
   out.set_temperature(_in.Temperature().Kelvin());
@@ -746,7 +839,7 @@ msgs::Atmosphere gazebo::convert(const sdf::Atmosphere &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Atmosphere gazebo::convert(const msgs::Atmosphere &_in)
+sdf::Atmosphere ignition::gazebo::convert(const msgs::Atmosphere &_in)
 {
   sdf::Atmosphere out;
   out.SetTemperature(math::Temperature(_in.temperature()));
@@ -762,16 +855,16 @@ sdf::Atmosphere gazebo::convert(const msgs::Atmosphere &_in)
 }
 
 //////////////////////////////////////////////////
-void gazebo::set(msgs::Time *_msg,
+void ignition::gazebo::set(msgs::Time *_msg,
     const std::chrono::steady_clock::duration &_in)
 {
-  auto secNsec = math::durationToSecNsec(_in);
+  auto secNsec = ignition::math::durationToSecNsec(_in);
   _msg->set_sec(secNsec.first);
   _msg->set_nsec(secNsec.second);
 }
 
 //////////////////////////////////////////////////
-void gazebo::set(msgs::WorldStatistics *_msg,
+void ignition::gazebo::set(msgs::WorldStatistics *_msg,
     const gazebo::UpdateInfo &_in)
 {
   set(_msg->mutable_sim_time(), _in.simTime);
@@ -783,7 +876,8 @@ void gazebo::set(msgs::WorldStatistics *_msg,
 
 //////////////////////////////////////////////////
 template<>
-msgs::Physics gazebo::convert(const sdf::Physics &_in)
+IGNITION_GAZEBO_VISIBLE
+msgs::Physics ignition::gazebo::convert(const sdf::Physics &_in)
 {
   msgs::Physics out;
   out.set_max_step_size(_in.MaxStepSize());
@@ -793,7 +887,8 @@ msgs::Physics gazebo::convert(const sdf::Physics &_in)
 
 //////////////////////////////////////////////////
 template<>
-sdf::Physics gazebo::convert(const msgs::Physics &_in)
+IGNITION_GAZEBO_VISIBLE
+sdf::Physics ignition::gazebo::convert(const msgs::Physics &_in)
 {
   sdf::Physics out;
   out.SetRealTimeFactor(_in.real_time_factor());
@@ -802,7 +897,7 @@ sdf::Physics gazebo::convert(const msgs::Physics &_in)
 }
 
 //////////////////////////////////////////////////
-void gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
+void ignition::gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
 {
   switch (_sdf.Type())
   {
@@ -828,10 +923,48 @@ void gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
   _msg->set_dynamic_bias_correlation_time(_sdf.DynamicBiasCorrelationTime());
 }
 
+//////////////////////////////////////////////////
+std::string ignition::gazebo::convert(const sdf::LightType &_in)
+{
+  if (_in == sdf::LightType::POINT)
+  {
+    return std::string("point");
+  }
+  else if (_in == sdf::LightType::DIRECTIONAL)
+  {
+    return std::string("directional");
+  }
+  else if (_in == sdf::LightType::SPOT)
+  {
+    return std::string("spot");
+  }
+  return std::string("");
+}
+
+//////////////////////////////////////////////////
+sdf::LightType ignition::gazebo::convert(const std::string &_in)
+{
+  std::string inLowerCase = _in;
+  std::transform(_in.begin(), _in.end(), inLowerCase.begin(), ::tolower);
+  if (inLowerCase == "point")
+  {
+    return sdf::LightType::POINT;
+  }
+  else if (inLowerCase == "directional")
+  {
+    return sdf::LightType::DIRECTIONAL;
+  }
+  else if (inLowerCase == "spot")
+  {
+    return sdf::LightType::SPOT;
+  }
+  return sdf::LightType::INVALID;
+}
+
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Noise gazebo::convert(const msgs::SensorNoise &_in)
+sdf::Noise ignition::gazebo::convert(const msgs::SensorNoise &_in)
 {
   sdf::Noise out;
 
@@ -864,7 +997,7 @@ sdf::Noise gazebo::convert(const msgs::SensorNoise &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
+msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 {
   msgs::Sensor out;
   out.set_name(_in.Name());
@@ -880,17 +1013,17 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
       msgs::MagnetometerSensor *sensor = out.mutable_magnetometer();
       if (_in.MagnetometerSensor()->XNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_x_noise(),
+        ignition::gazebo::set(sensor->mutable_x_noise(),
             _in.MagnetometerSensor()->XNoise());
       }
       if (_in.MagnetometerSensor()->YNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_y_noise(),
+        ignition::gazebo::set(sensor->mutable_y_noise(),
             _in.MagnetometerSensor()->YNoise());
       }
       if (_in.MagnetometerSensor()->ZNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_z_noise(),
+        ignition::gazebo::set(sensor->mutable_z_noise(),
             _in.MagnetometerSensor()->ZNoise());
       }
     }
@@ -940,13 +1073,13 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
       if (_in.AltimeterSensor()->VerticalPositionNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_vertical_position_noise(),
+        ignition::gazebo::set(sensor->mutable_vertical_position_noise(),
             _in.AltimeterSensor()->VerticalPositionNoise());
       }
       if (_in.AltimeterSensor()->VerticalVelocityNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_vertical_velocity_noise(),
+        ignition::gazebo::set(sensor->mutable_vertical_velocity_noise(),
             _in.AltimeterSensor()->VerticalVelocityNoise());
       }
     }
@@ -965,7 +1098,7 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
       if (_in.AirPressureSensor()->PressureNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_pressure_noise(),
+        ignition::gazebo::set(sensor->mutable_pressure_noise(),
             _in.AirPressureSensor()->PressureNoise());
       }
       sensor->set_reference_altitude(
@@ -986,38 +1119,38 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfImu->LinearAccelerationXNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_x_noise(),
             sdfImu->LinearAccelerationXNoise());
       }
       if (sdfImu->LinearAccelerationYNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_y_noise(),
             sdfImu->LinearAccelerationYNoise());
       }
       if (sdfImu->LinearAccelerationZNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_z_noise(),
             sdfImu->LinearAccelerationZNoise());
       }
 
       if (sdfImu->AngularVelocityXNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_angular_velocity()->mutable_x_noise(),
             sdfImu->AngularVelocityXNoise());
       }
       if (sdfImu->AngularVelocityYNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_angular_velocity()->mutable_y_noise(),
             sdfImu->AngularVelocityYNoise());
       }
       if (sdfImu->AngularVelocityZNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(
+        ignition::gazebo::set(
             sensor->mutable_angular_velocity()->mutable_z_noise(),
             sdfImu->AngularVelocityZNoise());
       }
@@ -1051,7 +1184,7 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfLidar->LidarNoise().Type() != sdf::NoiseType::NONE)
       {
-        gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
+        ignition::gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
       }
       sensor->set_horizontal_samples(sdfLidar->HorizontalScanSamples());
       sensor->set_horizontal_resolution(sdfLidar->HorizontalScanResolution());
@@ -1081,7 +1214,7 @@ msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
+sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
 {
   sdf::Sensor out;
   out.SetName(_in.name());
@@ -1098,17 +1231,17 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.magnetometer().has_x_noise())
       {
-        sensor.SetXNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetXNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.magnetometer().x_noise()));
       }
       if (_in.magnetometer().has_y_noise())
       {
-        sensor.SetYNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetYNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.magnetometer().y_noise()));
       }
       if (_in.magnetometer().has_z_noise())
       {
-        sensor.SetZNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetZNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.magnetometer().z_noise()));
       }
     }
@@ -1163,13 +1296,13 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.altimeter().has_vertical_position_noise())
       {
-        sensor.SetVerticalPositionNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalPositionNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_position_noise()));
       }
 
       if (_in.altimeter().has_vertical_velocity_noise())
       {
-        sensor.SetVerticalVelocityNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalVelocityNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_velocity_noise()));
       }
     }
@@ -1188,7 +1321,7 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.air_pressure().has_pressure_noise())
       {
-        sensor.SetPressureNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetPressureNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.air_pressure().pressure_noise()));
       }
 
@@ -1212,19 +1345,19 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().linear_acceleration().has_x_noise())
         {
           sensor.SetLinearAccelerationXNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().x_noise()));
         }
         if (_in.imu().linear_acceleration().has_y_noise())
         {
           sensor.SetLinearAccelerationYNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().y_noise()));
         }
         if (_in.imu().linear_acceleration().has_z_noise())
         {
           sensor.SetLinearAccelerationZNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().z_noise()));
         }
       }
@@ -1234,19 +1367,19 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().angular_velocity().has_x_noise())
         {
           sensor.SetAngularVelocityXNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().x_noise()));
         }
         if (_in.imu().angular_velocity().has_y_noise())
         {
           sensor.SetAngularVelocityYNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().y_noise()));
         }
         if (_in.imu().angular_velocity().has_z_noise())
         {
           sensor.SetAngularVelocityZNoise(
-              gazebo::convert<sdf::Noise>(
+              ignition::gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().z_noise()));
         }
       }
@@ -1303,7 +1436,7 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
 
       if (_in.lidar().has_noise())
       {
-        sensor.SetLidarNoise(gazebo::convert<sdf::Noise>(
+        sensor.SetLidarNoise(ignition::gazebo::convert<sdf::Noise>(
               _in.lidar().noise()));
       }
     }
@@ -1321,7 +1454,7 @@ sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::WorldStatistics gazebo::convert(const gazebo::UpdateInfo &_in)
+msgs::WorldStatistics ignition::gazebo::convert(const gazebo::UpdateInfo &_in)
 {
   msgs::WorldStatistics out;
   set(&out, _in);
@@ -1331,7 +1464,7 @@ msgs::WorldStatistics gazebo::convert(const gazebo::UpdateInfo &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-gazebo::UpdateInfo gazebo::convert(const msgs::WorldStatistics &_in)
+gazebo::UpdateInfo ignition::gazebo::convert(const msgs::WorldStatistics &_in)
 {
   gazebo::UpdateInfo out;
   out.iterations = _in.iterations();
@@ -1345,7 +1478,7 @@ gazebo::UpdateInfo gazebo::convert(const msgs::WorldStatistics &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::AxisAlignedBox gazebo::convert(const math::AxisAlignedBox &_in)
+msgs::AxisAlignedBox ignition::gazebo::convert(const math::AxisAlignedBox &_in)
 {
   msgs::AxisAlignedBox out;
   msgs::Set(out.mutable_min_corner(), _in.Min());
@@ -1356,7 +1489,7 @@ msgs::AxisAlignedBox gazebo::convert(const math::AxisAlignedBox &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::AxisAlignedBox gazebo::convert(const msgs::AxisAlignedBox &_in)
+math::AxisAlignedBox ignition::gazebo::convert(const msgs::AxisAlignedBox &_in)
 {
   math::AxisAlignedBox out;
   out.Min() = msgs::Convert(_in.min_corner());
