@@ -22,26 +22,28 @@
 #include <sdf/Altimeter.hh>
 #include <sdf/Atmosphere.hh>
 #include <sdf/Box.hh>
+#include <sdf/Capsule.hh>
 #include <sdf/Cylinder.hh>
+#include <sdf/Ellipsoid.hh>
 #include <sdf/Gui.hh>
+#include <sdf/Heightmap.hh>
 #include <sdf/Light.hh>
 #include <sdf/Magnetometer.hh>
 #include <sdf/Mesh.hh>
 #include <sdf/Pbr.hh>
 #include <sdf/Physics.hh>
 #include <sdf/Plane.hh>
-#include <sdf/Polyline.hh>
 #include <sdf/Root.hh>
 #include <sdf/Scene.hh>
 #include <sdf/Sphere.hh>
 #include <sdf/World.hh>
 
-#include <gz/msgs/Utility.hh>
+#include <ignition/msgs/Utility.hh>
 
-#include "gz/sim/Conversions.hh"
+#include "ignition/gazebo/Conversions.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace std::chrono_literals;
 
 /////////////////////////////////////////////////
@@ -53,8 +55,8 @@ TEST(Conversions, Light)
   light.SetRawPose({3, 2, 1, 0, IGN_PI, 0});
   light.SetPoseRelativeTo("world");
   light.SetCastShadows(true);
-  light.SetDiffuse(math::Color(0.4f, 0.5f, 0.6f, 1.0));
-  light.SetSpecular(math::Color(0.8f, 0.9f, 0.1f, 1.0));
+  light.SetDiffuse(ignition::math::Color(0.4f, 0.5f, 0.6f, 1.0));
+  light.SetSpecular(ignition::math::Color(0.8f, 0.9f, 0.1f, 1.0));
   light.SetAttenuationRange(3.2);
   light.SetConstantAttenuationFactor(0.5);
   light.SetLinearAttenuationFactor(0.1);
@@ -63,6 +65,7 @@ TEST(Conversions, Light)
   light.SetSpotInnerAngle(1.9);
   light.SetSpotOuterAngle(3.3);
   light.SetSpotFalloff(0.9);
+  light.SetIntensity(1.7);
 
   msgs::Light lightMsg;
   lightMsg = convert<msgs::Light>(light);
@@ -85,6 +88,7 @@ TEST(Conversions, Light)
   EXPECT_EQ(math::Angle(1.9), lightMsg.spot_inner_angle());
   EXPECT_EQ(math::Angle(3.3), lightMsg.spot_outer_angle());
   EXPECT_FLOAT_EQ(0.9, lightMsg.spot_falloff());
+  EXPECT_FLOAT_EQ(1.7, lightMsg.intensity());
 
   auto newLight = convert<sdf::Light>(lightMsg);
   EXPECT_EQ("test_convert_light", newLight.Name());
@@ -103,6 +107,17 @@ TEST(Conversions, Light)
   EXPECT_EQ(math::Angle(1.9), newLight.SpotInnerAngle());
   EXPECT_EQ(math::Angle(3.3), newLight.SpotOuterAngle());
   EXPECT_FLOAT_EQ(0.9, newLight.SpotFalloff());
+  EXPECT_FLOAT_EQ(1.7, newLight.Intensity());
+
+  EXPECT_EQ("", convert(sdf::LightType::INVALID));
+  EXPECT_EQ("point", convert(sdf::LightType::POINT));
+  EXPECT_EQ("directional", convert(sdf::LightType::DIRECTIONAL));
+  EXPECT_EQ("spot", convert(sdf::LightType::SPOT));
+
+  EXPECT_EQ(sdf::LightType::POINT, convert("POINT"));
+  EXPECT_EQ(sdf::LightType::DIRECTIONAL, convert("DireCtiOnal"));
+  EXPECT_EQ(sdf::LightType::SPOT, convert("spot"));
+  EXPECT_EQ(sdf::LightType::INVALID, convert("gazebo"));
 }
 
 /////////////////////////////////////////////////
@@ -224,11 +239,13 @@ TEST(Conversions, Time)
 TEST(Conversions, Material)
 {
   sdf::Material material;
-  material.SetDiffuse(math::Color(0.1f, 0.2f, 0.3f, 0.4f));
-  material.SetSpecular(math::Color(0.5f, 0.6f, 0.7f, 0.8f));
-  material.SetAmbient(math::Color(0.9f, 1.0f, 1.1f, 1.2f));
-  material.SetEmissive(math::Color(1.3f, 1.4f, 1.5f, 1.6f));
+  material.SetDiffuse(ignition::math::Color(0.1f, 0.2f, 0.3f, 0.4f));
+  material.SetSpecular(ignition::math::Color(0.5f, 0.6f, 0.7f, 0.8f));
+  material.SetAmbient(ignition::math::Color(0.9f, 1.0f, 1.1f, 1.2f));
+  material.SetEmissive(ignition::math::Color(1.3f, 1.4f, 1.5f, 1.6f));
   material.SetLighting(true);
+  material.SetRenderOrder(2.5);
+  material.SetDoubleSided(true);
 
   sdf::Pbr pbr;
   sdf::PbrWorkflow workflow;
@@ -242,6 +259,7 @@ TEST(Conversions, Material)
   workflow.SetEmissiveMap("emissive_map.png");
   workflow.SetGlossinessMap("dummy_glossiness_map.png");
   workflow.SetSpecularMap("dummy_specular_map.png");
+  workflow.SetLightMap("light_map.png", 1u);
   workflow.SetMetalness(0.3);
   workflow.SetRoughness(0.9);
   workflow.SetGlossiness(0.1);
@@ -258,6 +276,8 @@ TEST(Conversions, Material)
   EXPECT_EQ(math::Color(1.3f, 1.4f, 1.5f, 1.6f),
       msgs::Convert(materialMsg.emissive()));
   EXPECT_TRUE(materialMsg.lighting());
+  EXPECT_DOUBLE_EQ(2.5, materialMsg.render_order());
+  EXPECT_TRUE(materialMsg.double_sided());
 
   EXPECT_TRUE(materialMsg.has_pbr());
   const auto &pbrMsg = materialMsg.pbr();
@@ -271,6 +291,9 @@ TEST(Conversions, Material)
   EXPECT_EQ("ambient_occlusion_map.png", pbrMsg.ambient_occlusion_map());
   EXPECT_EQ("dummy_glossiness_map.png", pbrMsg.glossiness_map());
   EXPECT_EQ("dummy_specular_map.png", pbrMsg.specular_map());
+  EXPECT_EQ("light_map.png", pbrMsg.light_map());
+  EXPECT_EQ(1u, pbrMsg.light_map_texcoord_set());
+
   EXPECT_DOUBLE_EQ(0.3, pbrMsg.metalness());
   EXPECT_DOUBLE_EQ(0.9, pbrMsg.roughness());
   EXPECT_DOUBLE_EQ(0.1, pbrMsg.glossiness());
@@ -281,11 +304,12 @@ TEST(Conversions, Material)
   EXPECT_EQ(math::Color(0.9f, 1.0f, 1.1f, 1.2f), newMaterial.Ambient());
   EXPECT_EQ(math::Color(1.3f, 1.4f, 1.5f, 1.6f), newMaterial.Emissive());
   EXPECT_TRUE(newMaterial.Lighting());
+  EXPECT_TRUE(newMaterial.DoubleSided());
+  EXPECT_DOUBLE_EQ(2.5, newMaterial.RenderOrder());
 
-  sdf::Pbr *newPbrMaterial = newMaterial.PbrMaterial();
+  auto newPbrMaterial = newMaterial.PbrMaterial();
   ASSERT_NE(nullptr, newPbrMaterial);
-  sdf::PbrWorkflow *newWorkflow =
-      newPbrMaterial->Workflow(sdf::PbrWorkflowType::METAL);
+  auto newWorkflow = newPbrMaterial->Workflow(sdf::PbrWorkflowType::METAL);
   ASSERT_NE(nullptr, newWorkflow);
   EXPECT_EQ("albedo_map.png", newWorkflow->AlbedoMap());
   EXPECT_EQ("normal_map.png", newWorkflow->NormalMap());
@@ -296,6 +320,8 @@ TEST(Conversions, Material)
   EXPECT_EQ("ambient_occlusion_map.png", newWorkflow->AmbientOcclusionMap());
   EXPECT_EQ("dummy_glossiness_map.png", newWorkflow->GlossinessMap());
   EXPECT_EQ("dummy_specular_map.png", newWorkflow->SpecularMap());
+  EXPECT_EQ("light_map.png", newWorkflow->LightMap());
+  EXPECT_EQ(1u, newWorkflow->LightMapTexCoordSet());
   EXPECT_DOUBLE_EQ(0.3, newWorkflow->Metalness());
   EXPECT_DOUBLE_EQ(0.9, newWorkflow->Roughness());
   EXPECT_DOUBLE_EQ(0.1, newWorkflow->Glossiness());
@@ -308,7 +334,7 @@ TEST(Conversions, GeometryBox)
   geometry.SetType(sdf::GeometryType::BOX);
 
   sdf::Box boxShape;
-  boxShape.SetSize(math::Vector3d(1, 2, 3));
+  boxShape.SetSize(ignition::math::Vector3d(1, 2, 3));
   geometry.SetBoxShape(boxShape);
 
   auto geometryMsg = convert<msgs::Geometry>(geometry);
@@ -344,6 +370,30 @@ TEST(Conversions, GeometrySphere)
   EXPECT_DOUBLE_EQ(1.23, newGeometry.SphereShape()->Radius());
 }
 
+/////////////////////////////////////////////////
+TEST(Conversions, GeometryCapsule)
+{
+  sdf::Geometry geometry;
+  geometry.SetType(sdf::GeometryType::CAPSULE);
+
+  sdf::Capsule capsuleShape;
+  capsuleShape.SetRadius(1.23);
+  capsuleShape.SetLength(4.56);
+  geometry.SetCapsuleShape(capsuleShape);
+
+  auto geometryMsg = convert<msgs::Geometry>(geometry);
+  EXPECT_EQ(msgs::Geometry::CAPSULE, geometryMsg.type());
+  EXPECT_TRUE(geometryMsg.has_capsule());
+  EXPECT_DOUBLE_EQ(1.23, geometryMsg.capsule().radius());
+  EXPECT_DOUBLE_EQ(4.56, geometryMsg.capsule().length());
+
+  auto newGeometry = convert<sdf::Geometry>(geometryMsg);
+  EXPECT_EQ(sdf::GeometryType::CAPSULE, newGeometry.Type());
+  ASSERT_NE(nullptr, newGeometry.CapsuleShape());
+  EXPECT_DOUBLE_EQ(1.23, newGeometry.CapsuleShape()->Radius());
+  EXPECT_DOUBLE_EQ(4.56, newGeometry.CapsuleShape()->Length());
+}
+
 /////////////////////////////////////////////////
 TEST(Conversions, GeometryCylinder)
 {
@@ -368,6 +418,29 @@ TEST(Conversions, GeometryCylinder)
   EXPECT_DOUBLE_EQ(4.56, newGeometry.CylinderShape()->Length());
 }
 
+/////////////////////////////////////////////////
+TEST(Conversions, GeometryEllipsoid)
+{
+  sdf::Geometry geometry;
+  geometry.SetType(sdf::GeometryType::ELLIPSOID);
+
+  sdf::Ellipsoid ellipsoidShape;
+  ellipsoidShape.SetRadii(ignition::math::Vector3d(1.2, 3.2, 2.4));
+  geometry.SetEllipsoidShape(ellipsoidShape);
+
+  auto geometryMsg = convert<msgs::Geometry>(geometry);
+  EXPECT_EQ(msgs::Geometry::ELLIPSOID, geometryMsg.type());
+  EXPECT_TRUE(geometryMsg.has_ellipsoid());
+  EXPECT_EQ(ignition::math::Vector3d(1.2, 3.2, 2.4),
+    msgs::Convert(geometryMsg.ellipsoid().radii()));
+
+  auto newGeometry = convert<sdf::Geometry>(geometryMsg);
+  EXPECT_EQ(sdf::GeometryType::ELLIPSOID, newGeometry.Type());
+  ASSERT_NE(nullptr, newGeometry.EllipsoidShape());
+  EXPECT_EQ(ignition::math::Vector3d(1.2, 3.2, 2.4),
+    newGeometry.EllipsoidShape()->Radii());
+}
+
 /////////////////////////////////////////////////
 TEST(Conversions, GeometryMesh)
 {
@@ -375,7 +448,7 @@ TEST(Conversions, GeometryMesh)
   geometry.SetType(sdf::GeometryType::MESH);
 
   sdf::Mesh meshShape;
-  meshShape.SetScale(math::Vector3d(1, 2, 3));
+  meshShape.SetScale(ignition::math::Vector3d(1, 2, 3));
   meshShape.SetUri("file://watermelon");
   meshShape.SetSubmesh("grape");
   meshShape.SetCenterSubmesh(true);
@@ -406,8 +479,8 @@ TEST(Conversions, GeometryPlane)
   geometry.SetType(sdf::GeometryType::PLANE);
 
   sdf::Plane planeShape;
-  planeShape.SetSize(math::Vector2d(1, 2));
-  planeShape.SetNormal(math::Vector3d::UnitY);
+  planeShape.SetSize(ignition::math::Vector2d(1, 2));
+  planeShape.SetNormal(ignition::math::Vector3d::UnitY);
   geometry.SetPlaneShape(planeShape);
 
   auto geometryMsg = convert<msgs::Geometry>(geometry);
@@ -426,37 +499,69 @@ TEST(Conversions, GeometryPlane)
 }
 
 /////////////////////////////////////////////////
-TEST(Conversions, GeometryPolyline)
+TEST(Conversions, GeometryHeightmap)
 {
   sdf::Geometry geometry;
-  geometry.SetType(sdf::GeometryType::POLYLINE);
+  geometry.SetType(sdf::GeometryType::HEIGHTMAP);
 
-  sdf::Polyline polylineShape;
-  polylineShape.SetHeight(1.23);
-  polylineShape.AddPoint({4.5, 6.7});
-  polylineShape.AddPoint({8.9, 10.11});
-  geometry.SetPolylineShape({polylineShape});
+  sdf::Heightmap heightmap;
+  heightmap.SetUri("file://heights.png");
+  heightmap.SetSize(ignition::math::Vector3d(1, 2, 3));
+  heightmap.SetPosition(ignition::math::Vector3d(4, 5, 6));
+  heightmap.SetUseTerrainPaging(true);
+  heightmap.SetSampling(16u);
+
+  sdf::HeightmapTexture texture;
+  texture.SetDiffuse("file://diffuse.png");
+  texture.SetNormal("file://normal.png");
+  texture.SetSize(1.23);
+  heightmap.AddTexture(texture);
+
+  sdf::HeightmapBlend blend;
+  blend.SetMinHeight(123.456);
+  blend.SetFadeDistance(456.789);
+  heightmap.AddBlend(blend);
+
+  geometry.SetHeightmapShape(heightmap);
 
   auto geometryMsg = convert<msgs::Geometry>(geometry);
-  EXPECT_EQ(msgs::Geometry::POLYLINE, geometryMsg.type());
-  ASSERT_EQ(1, geometryMsg.polyline_size());
-  EXPECT_DOUBLE_EQ(1.23, geometryMsg.polyline(0).height());
-  ASSERT_EQ(2, geometryMsg.polyline(0).point_size());
-  EXPECT_DOUBLE_EQ(4.5, geometryMsg.polyline(0).point(0).x());
-  EXPECT_DOUBLE_EQ(6.7, geometryMsg.polyline(0).point(0).y());
-  EXPECT_DOUBLE_EQ(8.9, geometryMsg.polyline(0).point(1).x());
-  EXPECT_DOUBLE_EQ(10.11, geometryMsg.polyline(0).point(1).y());
+
+  EXPECT_EQ(msgs::Geometry::HEIGHTMAP, geometryMsg.type());
+  EXPECT_TRUE(geometryMsg.has_heightmap());
+  EXPECT_EQ(math::Vector3d(1, 2, 3),
+      msgs::Convert(geometryMsg.heightmap().size()));
+  EXPECT_EQ("file://heights.png", geometryMsg.heightmap().filename());
+  EXPECT_TRUE(geometryMsg.heightmap().use_terrain_paging());
+  EXPECT_EQ(16u, geometryMsg.heightmap().sampling());
+
+  ASSERT_EQ(1, geometryMsg.heightmap().texture().size());
+  EXPECT_DOUBLE_EQ(1.23, geometryMsg.heightmap().texture(0).size());
+  EXPECT_EQ("file://diffuse.png", geometryMsg.heightmap().texture(0).diffuse());
+  EXPECT_EQ("file://normal.png", geometryMsg.heightmap().texture(0).normal());
+
+  ASSERT_EQ(1, geometryMsg.heightmap().blend().size());
+  EXPECT_DOUBLE_EQ(123.456, geometryMsg.heightmap().blend(0).min_height());
+  EXPECT_DOUBLE_EQ(456.789, geometryMsg.heightmap().blend(0).fade_dist());
 
   auto newGeometry = convert<sdf::Geometry>(geometryMsg);
-  EXPECT_EQ(sdf::GeometryType::POLYLINE, newGeometry.Type());
-  ASSERT_FALSE(newGeometry.PolylineShape().empty());
-  ASSERT_EQ(1u, newGeometry.PolylineShape().size());
-  EXPECT_DOUBLE_EQ(1.23, newGeometry.PolylineShape()[0].Height());
-  ASSERT_EQ(2u, newGeometry.PolylineShape()[0].PointCount());
-  EXPECT_DOUBLE_EQ(4.5, newGeometry.PolylineShape()[0].PointByIndex(0)->X());
-  EXPECT_DOUBLE_EQ(6.7, newGeometry.PolylineShape()[0].PointByIndex(0)->Y());
-  EXPECT_DOUBLE_EQ(8.9, newGeometry.PolylineShape()[0].PointByIndex(1)->X());
-  EXPECT_DOUBLE_EQ(10.11, newGeometry.PolylineShape()[0].PointByIndex(1)->Y());
+
+  EXPECT_EQ(sdf::GeometryType::HEIGHTMAP, newGeometry.Type());
+
+  auto newHeightmap = newGeometry.HeightmapShape();
+  ASSERT_NE(nullptr, newHeightmap);
+  EXPECT_EQ(math::Vector3d(1, 2, 3), newHeightmap->Size());
+  EXPECT_EQ("file://heights.png", newHeightmap->Uri());
+  EXPECT_TRUE(newHeightmap->UseTerrainPaging());
+  EXPECT_EQ(16u, newHeightmap->Sampling());
+
+  ASSERT_EQ(1u, newHeightmap->TextureCount());
+  EXPECT_DOUBLE_EQ(1.23, newHeightmap->TextureByIndex(0)->Size());
+  EXPECT_EQ("file://diffuse.png", newHeightmap->TextureByIndex(0)->Diffuse());
+  EXPECT_EQ("file://normal.png", newHeightmap->TextureByIndex(0)->Normal());
+
+  ASSERT_EQ(1u, newHeightmap->BlendCount());
+  EXPECT_DOUBLE_EQ(123.456, newHeightmap->BlendByIndex(0)->MinHeight());
+  EXPECT_DOUBLE_EQ(456.789, newHeightmap->BlendByIndex(0)->FadeDistance());
 }
 
 /////////////////////////////////////////////////
@@ -501,7 +606,7 @@ TEST(Conversions, Inertial)
 TEST(Conversions, JointAxis)
 {
   sdf::JointAxis jointAxis;
-  jointAxis.SetXyz(math::Vector3d(1, 2, 3));
+  EXPECT_TRUE(jointAxis.SetXyz(math::Vector3d(1, 2, 3)).empty());
   jointAxis.SetXyzExpressedIn("__model__");
   jointAxis.SetDamping(0.1);
   jointAxis.SetFriction(0.2);
@@ -511,7 +616,7 @@ TEST(Conversions, JointAxis)
   jointAxis.SetMaxVelocity(0.6);
 
   auto axisMsg = convert<msgs::Axis>(jointAxis);
-  EXPECT_EQ(math::Vector3d(1, 2, 3), msgs::Convert(axisMsg.xyz()));
+  EXPECT_EQ(math::Vector3d(1, 2, 3).Normalized(), msgs::Convert(axisMsg.xyz()));
   EXPECT_DOUBLE_EQ(0.1, axisMsg.damping());
   EXPECT_DOUBLE_EQ(0.2, axisMsg.friction());
   EXPECT_DOUBLE_EQ(0.3, axisMsg.limit_lower());
@@ -521,7 +626,7 @@ TEST(Conversions, JointAxis)
   EXPECT_EQ(axisMsg.xyz_expressed_in(), "__model__");
 
   auto newJointAxis = convert<sdf::JointAxis>(axisMsg);
-  EXPECT_EQ(math::Vector3d(1, 2, 3), newJointAxis.Xyz());
+  EXPECT_EQ(math::Vector3d(1, 2, 3).Normalized(), newJointAxis.Xyz());
   EXPECT_DOUBLE_EQ(0.1, newJointAxis.Damping());
   EXPECT_DOUBLE_EQ(0.2, newJointAxis.Friction());
   EXPECT_DOUBLE_EQ(0.3, newJointAxis.Lower());
@@ -535,8 +640,8 @@ TEST(Conversions, JointAxis)
 TEST(Conversions, Scene)
 {
   sdf::Scene scene;
-  scene.SetAmbient(math::Color(0.1f, 0.2f, 0.3f, 0.4f));
-  scene.SetBackground(math::Color(0.5f, 0.6f, 0.7f, 0.8f));
+  scene.SetAmbient(ignition::math::Color(0.1f, 0.2f, 0.3f, 0.4f));
+  scene.SetBackground(ignition::math::Color(0.5f, 0.6f, 0.7f, 0.8f));
   scene.SetShadows(true);
   scene.SetGrid(true);
   scene.SetOriginVisual(true);
@@ -549,6 +654,7 @@ TEST(Conversions, Scene)
   EXPECT_TRUE(sceneMsg.shadows());
   EXPECT_TRUE(sceneMsg.grid());
   EXPECT_TRUE(sceneMsg.origin_visual());
+  EXPECT_FALSE(sceneMsg.has_sky());
 
   auto newScene = convert<sdf::Scene>(sceneMsg);
   EXPECT_EQ(math::Color(0.1f, 0.2f, 0.3f, 0.4f), newScene.Ambient());
@@ -556,6 +662,42 @@ TEST(Conversions, Scene)
   EXPECT_TRUE(newScene.Shadows());
   EXPECT_TRUE(newScene.Grid());
   EXPECT_TRUE(newScene.OriginVisual());
+  EXPECT_EQ(nullptr, newScene.Sky());
+
+  // sky
+  sdf::Sky sky;
+  sky.SetTime(10);
+  sky.SetSunrise(4.0);
+  sky.SetSunset(15.0);
+  sky.SetCloudSpeed(5.0);
+  sky.SetCloudDirection(math::Angle(3.14));
+  sky.SetCloudHumidity(0.11);
+  sky.SetCloudMeanSize(0.88);
+  sky.SetCloudAmbient(math::Color::Red);
+  scene.SetSky(sky);
+
+  auto sceneSkyMsg = convert<msgs::Scene>(scene);
+  EXPECT_TRUE(sceneSkyMsg.has_sky());
+  EXPECT_DOUBLE_EQ(10.0, sceneSkyMsg.sky().time());
+  EXPECT_DOUBLE_EQ(4.0, sceneSkyMsg.sky().sunrise());
+  EXPECT_DOUBLE_EQ(15.0, sceneSkyMsg.sky().sunset());
+  EXPECT_DOUBLE_EQ(5.0, sceneSkyMsg.sky().wind_speed());
+  EXPECT_DOUBLE_EQ(3.14, sceneSkyMsg.sky().wind_direction());
+  EXPECT_DOUBLE_EQ(0.11, sceneSkyMsg.sky().humidity());
+  EXPECT_DOUBLE_EQ(0.88, sceneSkyMsg.sky().mean_cloud_size());
+  EXPECT_EQ(math::Color::Red,
+      msgs::Convert(sceneSkyMsg.sky().cloud_ambient()));
+
+  auto newSceneSky = convert<sdf::Scene>(sceneSkyMsg);
+  ASSERT_NE(nullptr, newSceneSky.Sky());
+  EXPECT_DOUBLE_EQ(10.0, newSceneSky.Sky()->Time());
+  EXPECT_DOUBLE_EQ(4.0, newSceneSky.Sky()->Sunrise());
+  EXPECT_DOUBLE_EQ(15.0, newSceneSky.Sky()->Sunset());
+  EXPECT_DOUBLE_EQ(5.0, newSceneSky.Sky()->CloudSpeed());
+  EXPECT_EQ(math::Angle(3.14), newSceneSky.Sky()->CloudDirection());
+  EXPECT_DOUBLE_EQ(0.11, newSceneSky.Sky()->CloudHumidity());
+  EXPECT_DOUBLE_EQ(0.88, newSceneSky.Sky()->CloudMeanSize());
+  EXPECT_EQ(math::Color::Red, newSceneSky.Sky()->CloudAmbient());
 }
 
 /////////////////////////////////////////////////
@@ -578,14 +720,14 @@ TEST(Conversions, Atmosphere)
 }
 
 /////////////////////////////////////////////////
-TEST(Conversions, MagnetometerSensor)
+TEST(CONVERSIONS, MagnetometerSensor)
 {
   sdf::Sensor sensor;
   sensor.SetName("my_sensor");
   sensor.SetType(sdf::SensorType::MAGNETOMETER);
   sensor.SetUpdateRate(12.4);
   sensor.SetTopic("my_topic");
-  sensor.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
+  sensor.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Noise noise;
   noise.SetType(sdf::NoiseType::GAUSSIAN);
@@ -618,14 +760,14 @@ TEST(Conversions, MagnetometerSensor)
 }
 
 /////////////////////////////////////////////////
-TEST(Conversions, AltimeterSensor)
+TEST(CONVERSIONS, AltimeterSensor)
 {
   sdf::Sensor sensor;
   sensor.SetName("my_sensor");
   sensor.SetType(sdf::SensorType::ALTIMETER);
   sensor.SetUpdateRate(12.4);
   sensor.SetTopic("my_topic");
-  sensor.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
+  sensor.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Noise noise;
   noise.SetType(sdf::NoiseType::GAUSSIAN);
