@@ -17,20 +17,18 @@
 
 #include <map>
 #include <set>
-#include <sstream>
-#include <string>
 #include <unordered_map>
 #include <unordered_set>
 #include <vector>
 
-#include <gz/common/Profiler.hh>
-#include <gz/math/graph/GraphAlgorithms.hh>
-#include "gz/sim/components/Component.hh"
-#include "gz/sim/components/Factory.hh"
-#include "gz/sim/EntityComponentManager.hh"
+#include <ignition/common/Profiler.hh>
+#include <ignition/math/graph/GraphAlgorithms.hh>
+#include "ignition/gazebo/components/Component.hh"
+#include "ignition/gazebo/components/Factory.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 class ignition::gazebo::EntityComponentManagerPrivate
 {
@@ -56,6 +54,24 @@ class ignition::gazebo::EntityComponentManagerPrivate
   /// `AddEntityToMessage`.
   public: void CalculateStateThreadLoad();
 
+  /// \brief Create a message for the removed components
+  /// \param[in] _entity Entity with the removed components
+  /// \param[in, out] _msg Entity message
+  /// \param[in] _types _types Type IDs of components to be serialized. Leave
+  /// empty to get all removed components.
+  public: void SetRemovedComponentsMsgs(Entity &_entity,
+      msgs::SerializedEntity *_msg,
+      const std::unordered_set<ComponentTypeId> &_types = {});
+
+  /// \brief Create a message for the removed components
+  /// \param[in] _entity Entity with the removed components
+  /// \param[in, out] _msg State message
+  /// \param[in] _types _types Type IDs of components to be serialized. Leave
+  /// empty to get all removed components.
+  public: void SetRemovedComponentsMsgs(Entity &_entity,
+      msgs::SerializedStateMap &_msg,
+      const std::unordered_set<ComponentTypeId> &_types = {});
+
   /// \brief Map of component storage classes. The key is a component
   /// type id, and the value is a pointer to the component storage.
   public: std::unordered_map<ComponentTypeId,
@@ -89,7 +105,7 @@ class ignition::gazebo::EntityComponentManagerPrivate
   /// NOTE: Any modification of this data structure must be followed
   /// by setting `entityComponentsDirty` to true.
   public: std::unordered_map<Entity,
-          std::unordered_map<ComponentTypeId, ComponentId>> entityComponents;
+          std::unordered_map<ComponentTypeId, ComponentKey>> entityComponents;
 
   /// \brief A vector of iterators to evenly distributed spots in the
   /// `entityComponents` map.  Threads in the `State` function use this
@@ -97,10 +113,10 @@ class ignition::gazebo::EntityComponentManagerPrivate
   /// is recalculated if `entityComponents` is changed (when
   /// `entityComponentsDirty` == true).
   public: std::vector<std::unordered_map<Entity,
-          std::unordered_map<ComponentTypeId, ComponentId>>::iterator>
+          std::unordered_map<ComponentTypeId, ComponentKey>>::iterator>
             entityComponentIterators;
 
-  /// \brief A mutex to protect newly created entityes.
+  /// \brief A mutex to protect newly created entities.
   public: std::mutex entityCreatedMutex;
 
   /// \brief A mutex to protect entity remove.
@@ -109,6 +125,9 @@ class ignition::gazebo::EntityComponentManagerPrivate
   /// \brief A mutex to protect from concurrent writes to views
   public: mutable std::mutex viewsMutex;
 
+  /// \brief A mutex to protect removed components
+  public: mutable std::mutex removedComponentsMutex;
+
   /// \brief The set of all views.
   public: mutable std::map<detail::ComponentTypeKey, detail::View> views;
 
@@ -120,6 +139,11 @@ class ignition::gazebo::EntityComponentManagerPrivate
 
   /// \brief Keep track of entities already used to ensure uniqueness.
   public: uint64_t entityCount{0};
+
+  /// \brief Unordered multimap of removed components. The key is the entity to
+  /// which belongs the component, and the value is the component being
+  /// removed.
+  std::unordered_multimap<Entity, ComponentKey> removedComponents;
 };
 
 //////////////////////////////////////////////////
@@ -182,6 +206,13 @@ void EntityComponentManager::ClearNewlyCreatedEntities()
   }
 }
 
+/////////////////////////////////////////////////
+void EntityComponentManager::ClearRemovedComponents()
+{
+  std::lock_guard<std::mutex> lock(this->dataPtr->removedComponentsMutex);
+  this->dataPtr->removedComponents.clear();
+}
+
 /////////////////////////////////////////////////
 void EntityComponentManagerPrivate::InsertEntityRecursive(Entity _entity,
     std::unordered_set<Entity> &_set)
@@ -274,7 +305,8 @@ void EntityComponentManager::ProcessRemoveEntityRequests()
       {
         for (const auto &key : entityIter->second)
         {
-          this->dataPtr->components.at(key.first)->Remove(key.second);
+          this->dataPtr->components.at(key.second.first)->Remove(
+              key.second.second);
         }
 
         // Remove the entry in the entityComponent map
@@ -321,6 +353,13 @@ bool EntityComponentManager::RemoveComponent(
   this->dataPtr->entityComponentsDirty = true;
 
   this->UpdateViews(_entity);
+
+  // Add component to map of removed components
+  {
+    std::lock_guard<std::mutex> lock(this->dataPtr->removedComponentsMutex);
+    this->dataPtr->removedComponents.insert(std::make_pair(_entity, _key));
+  }
+
   return true;
 }
 
@@ -385,14 +424,12 @@ ComponentState EntityComponentManager::ComponentState(const Entity _entity,
   if (typeKey == ecIter->second.end())
     return result;
 
-  ComponentKey key{_typeId, typeKey->second};
-
-  if (this->dataPtr->oneTimeChangedComponents.find(key) !=
+  if (this->dataPtr->oneTimeChangedComponents.find(typeKey->second) !=
       this->dataPtr->oneTimeChangedComponents.end())
   {
     result = ComponentState::OneTimeChange;
   }
-  else if (this->dataPtr->periodicChangedComponents.find(key) !=
+  else if (this->dataPtr->periodicChangedComponents.find(typeKey->second) !=
       this->dataPtr->periodicChangedComponents.end())
   {
     result = ComponentState::PeriodicChange;
@@ -480,15 +517,6 @@ ComponentKey EntityComponentManager::CreateComponentImplementation(
     const Entity _entity, const ComponentTypeId _componentTypeId,
     const components::BaseComponent *_data)
 {
-  // make sure the entity exists
-  if (!this->HasEntity(_entity))
-  {
-    ignerr << "Trying to create a component of type [" << _componentTypeId
-      << "] attached to entity [" << _entity << "], but this entity does not "
-      << "exist. This create component request will be ignored." << std::endl;
-    return ComponentKey();
-  }
-
   // If type hasn't been instantiated yet, create a storage for it
   if (!this->HasComponentType(_componentTypeId))
   {
@@ -508,7 +536,7 @@ ComponentKey EntityComponentManager::CreateComponentImplementation(
   ComponentKey componentKey{_componentTypeId, componentIdPair.first};
 
   this->dataPtr->entityComponents[_entity].insert(
-      {_componentTypeId, componentIdPair.first});
+      {_componentTypeId, componentKey});
   this->dataPtr->oneTimeChangedComponents.insert(componentKey);
   this->dataPtr->entityComponentsDirty = true;
 
@@ -553,7 +581,7 @@ ComponentId EntityComponentManager::EntityComponentIdFromType(
 
   auto typeIter = ecIter->second.find(_type);
   if (typeIter != ecIter->second.end())
-    return typeIter->second;
+    return typeIter->second.second;
 
   return -1;
 }
@@ -571,8 +599,8 @@ const components::BaseComponent
 
   auto typeIter = ecIter->second.find(_type);
   if (typeIter != ecIter->second.end())
-    return this->dataPtr->components.at(_type)->Component(
-        typeIter->second);
+    return this->dataPtr->components.at(typeIter->second.first)->Component(
+        typeIter->second.second);
 
   return nullptr;
 }
@@ -588,7 +616,8 @@ components::BaseComponent *EntityComponentManager::ComponentImplementation(
 
   auto typeIter = ecIter->second.find(_type);
   if (typeIter != ecIter->second.end())
-    return this->dataPtr->components.at(_type)->Component(typeIter->second);
+    return this->dataPtr->components.at(typeIter->second.first)->Component(
+        typeIter->second.second);
 
   return nullptr;
 }
@@ -749,6 +778,77 @@ void EntityComponentManager::RebuildViews()
   }
 }
 
+//////////////////////////////////////////////////
+void EntityComponentManagerPrivate::SetRemovedComponentsMsgs(Entity &_entity,
+    msgs::SerializedEntity *_entityMsg,
+    const std::unordered_set<ComponentTypeId> &_types)
+{
+  std::lock_guard<std::mutex> lock(this->removedComponentsMutex);
+  auto entRemovedComps = this->removedComponents.equal_range(_entity);
+  for (auto it = entRemovedComps.first; it != entRemovedComps.second; ++it)
+  {
+    auto removedComponent = it->second;
+
+    if (!_types.empty() && _types.find(removedComponent.first) == _types.end())
+    {
+      continue;
+    }
+
+    auto compMsg = _entityMsg->add_components();
+
+    // Empty data is needed for the component to be processed afterwards
+    compMsg->set_component(" ");
+    compMsg->set_type(removedComponent.first);
+    compMsg->set_remove(true);
+  }
+}
+
+//////////////////////////////////////////////////
+void EntityComponentManagerPrivate::SetRemovedComponentsMsgs(Entity &_entity,
+    msgs::SerializedStateMap &_msg,
+    const std::unordered_set<ComponentTypeId> &_types)
+{
+  std::lock_guard<std::mutex> lock(this->removedComponentsMutex);
+  uint64_t nEntityKeys = this->removedComponents.count(_entity);
+  if (nEntityKeys == 0)
+    return;
+
+  // The message need not necessarily contain the entity initially. For
+  // instance, when AddEntityToMessage() calls this function, the entity may
+  // have some removed components but none in entityComponents that changed,
+  // so the entity may not have been added to the message beforehand.
+  auto entIter = _msg.mutable_entities()->find(_entity);
+  if (entIter == _msg.mutable_entities()->end())
+  {
+    msgs::SerializedEntityMap ent;
+    ent.set_id(_entity);
+    entIter =
+      (_msg.mutable_entities())->insert({static_cast<uint64_t>(_entity), ent})
+      .first;
+  }
+
+  auto entRemovedComps = this->removedComponents.equal_range(_entity);
+  for (auto it = entRemovedComps.first; it != entRemovedComps.second; ++it)
+  {
+    auto removedComponent = it->second;
+
+    if (!_types.empty() && _types.find(removedComponent.first) == _types.end())
+    {
+      continue;
+    }
+
+    msgs::SerializedComponent compMsg;
+
+    // Empty data is needed for the component to be processed afterwards
+    compMsg.set_component(" ");
+    compMsg.set_type(removedComponent.first);
+    compMsg.set_remove(true);
+
+    (*(entIter->second.mutable_components()))[
+      static_cast<int64_t>(removedComponent.first)] = compMsg;
+  }
+}
+
 //////////////////////////////////////////////////
 void EntityComponentManager::AddEntityToMessage(msgs::SerializedState &_msg,
     Entity _entity, const std::unordered_set<ComponentTypeId> &_types) const
@@ -779,23 +879,27 @@ void EntityComponentManager::AddEntityToMessage(msgs::SerializedState &_msg,
   for (const ComponentTypeId type : types)
   {
     // If the entity does not have the component, continue
-    auto typeIter = iter->second.find(type);
+    std::unordered_map<ComponentTypeId, ComponentKey>::iterator typeIter =
+      iter->second.find(type);
     if (typeIter == iter->second.end())
     {
       continue;
     }
+    ComponentKey comp = (typeIter->second);
 
     auto compMsg = entityMsg->add_components();
-    auto compBase = this->ComponentImplementation(_entity, type);
+    auto compBase = this->ComponentImplementation(_entity, comp.first);
     compMsg->set_type(compBase->TypeId());
 
     std::ostringstream ostr;
     compBase->Serialize(ostr);
 
     compMsg->set_component(ostr.str());
-
-    // TODO(anyone) Set component being removed once we have a way to queue it
   }
+
+  // Add a component to the message and set it to be removed if the component
+  // exists in the removedComponents map.
+  this->dataPtr->SetRemovedComponentsMsgs(_entity, entityMsg, _types);
 }
 
 //////////////////////////////////////////////////
@@ -842,16 +946,16 @@ void EntityComponentManager::AddEntityToMessage(msgs::SerializedStateMap &_msg,
   // Empty means all types
   for (const ComponentTypeId type : types)
   {
-    auto typeIter = iter->second.find(type);
+    std::unordered_map<ComponentTypeId, ComponentKey>::iterator typeIter =
+      iter->second.find(type);
     if (typeIter == iter->second.end())
     {
       continue;
     }
 
+    ComponentKey comp = typeIter->second;
     const components::BaseComponent *compBase =
-      this->ComponentImplementation(_entity, type);
-
-    ComponentKey comp = {type, typeIter->second};
+      this->ComponentImplementation(_entity, comp.first);
 
     // If not sending full state, skip unchanged components
     if (!_full &&
@@ -893,15 +997,17 @@ void EntityComponentManager::AddEntityToMessage(msgs::SerializedStateMap &_msg,
     std::ostringstream ostr;
     compBase->Serialize(ostr);
     compIter->second.set_component(ostr.str());
-
-    // TODO(anyone) Set component being removed once we have a way to queue it
   }
+
+  // Add a component to the message and set it to be removed if the component
+  // exists in the removedComponents map.
+  this->dataPtr->SetRemovedComponentsMsgs(_entity, _msg, _types);
 }
 
 //////////////////////////////////////////////////
-msgs::SerializedState EntityComponentManager::ChangedState() const
+ignition::msgs::SerializedState EntityComponentManager::ChangedState() const
 {
-  msgs::SerializedState stateMsg;
+  ignition::msgs::SerializedState stateMsg;
 
   // New entities
   for (const auto &entity : this->dataPtr->newlyCreatedEntities)
@@ -922,7 +1028,7 @@ msgs::SerializedState EntityComponentManager::ChangedState() const
 
 //////////////////////////////////////////////////
 void EntityComponentManager::ChangedState(
-    msgs::SerializedStateMap &_state) const
+    ignition::msgs::SerializedStateMap &_state) const
 {
   // New entities
   for (const auto &entity : this->dataPtr->newlyCreatedEntities)
@@ -986,11 +1092,11 @@ void EntityComponentManagerPrivate::CalculateStateThreadLoad()
 }
 
 //////////////////////////////////////////////////
-msgs::SerializedState EntityComponentManager::State(
+ignition::msgs::SerializedState EntityComponentManager::State(
     const std::unordered_set<Entity> &_entities,
     const std::unordered_set<ComponentTypeId> &_types) const
 {
-  msgs::SerializedState stateMsg;
+  ignition::msgs::SerializedState stateMsg;
   for (const auto &it : this->dataPtr->entityComponents)
   {
     auto entity = it.first;
@@ -1056,7 +1162,7 @@ void EntityComponentManager::State(
 
 //////////////////////////////////////////////////
 void EntityComponentManager::SetState(
-    const msgs::SerializedState &_stateMsg)
+    const ignition::msgs::SerializedState &_stateMsg)
 {
   IGN_PROFILE("EntityComponentManager::SetState Non-map");
   // Create / remove / update entities
@@ -1108,51 +1214,49 @@ void EntityComponentManager::SetState(
         continue;
       }
 
+      // Create component
+      auto newComp = components::Factory::Instance()->New(compMsg.type());
+
+      if (nullptr == newComp)
+      {
+        ignerr << "Failed to deserialize component of type [" << compMsg.type()
+               << "]" << std::endl;
+        continue;
+      }
+
+      std::istringstream istr(compMsg.component());
+      newComp->Deserialize(istr);
+
+      // Get type id
+      auto typeId = newComp->TypeId();
+
+      // TODO(louise) Move into if, see TODO below
+      this->RemoveComponent(entity, typeId);
+
       // Remove component
       if (compMsg.remove())
       {
-        this->RemoveComponent(entity, type);
         continue;
       }
 
       // Get Component
-      auto comp = this->ComponentImplementation(entity, type);
+      auto comp = this->ComponentImplementation(entity, typeId);
 
       // Create if new
       if (nullptr == comp)
       {
-        auto newComp = components::Factory::Instance()->New(type);
-        if (nullptr == newComp)
-        {
-          ignerr << "Failed to create component type ["
-            << compMsg.type() << "]" << std::endl;
-          continue;
-        }
-        std::istringstream istr(compMsg.component());
-        newComp->Deserialize(istr);
-        this->CreateComponentImplementation(entity, type, newComp.get());
+        this->CreateComponentImplementation(entity, typeId, newComp.get());
       }
       // Update component value
       else
       {
-        std::istringstream istr(compMsg.component());
-        comp->Deserialize(istr);
-        // note on merging forward:
-        // `AddModifiedComponent` method is available/used in ign-gazebo4, so we
-        // don't need this header patch when merging forward
-        auto flag = ComponentState::PeriodicChange;
-        for (int i = 0; i < _stateMsg.header().data_size(); ++i)
-        {
-          if (_stateMsg.header().data(i).key() ==
-              "has_one_time_component_changes")
-          {
-            int v = stoi(_stateMsg.header().data(i).value(0));
-            if (v)
-              flag = ComponentState::OneTimeChange;
-            break;
-          }
-        }
-        this->SetChanged(entity, type, flag);
+        ignerr << "Internal error" << std::endl;
+        // TODO(louise) We're shortcutting above and always  removing the
+        // component so that we don't get here, gotta figure out why this
+        // doesn't update the component. The following line prints the correct
+        // values.
+        // igndbg << *comp << "  " << *newComp.get() << std::endl;
+        // *comp = *newComp.get();
       }
     }
   }
@@ -1160,7 +1264,7 @@ void EntityComponentManager::SetState(
 
 //////////////////////////////////////////////////
 void EntityComponentManager::SetState(
-    const msgs::SerializedStateMap &_stateMsg)
+    const ignition::msgs::SerializedStateMap &_stateMsg)
 {
   IGN_PROFILE("EntityComponentManager::SetState Map");
   // Create / remove / update entities
@@ -1247,22 +1351,10 @@ void EntityComponentManager::SetState(
       {
         std::istringstream istr(compMsg.component());
         comp->Deserialize(istr);
-        // Note on merging forward:
-        // `has_one_time_component_changes` field is available in Edifice so
-        // this workaround can be removed
-        auto flag = ComponentState::PeriodicChange;
-        for (int i = 0; i < _stateMsg.header().data_size(); ++i)
-        {
-          if (_stateMsg.header().data(i).key() ==
-              "has_one_time_component_changes")
-          {
-            int v = stoi(_stateMsg.header().data(i).value(0));
-            if (v)
-              flag = ComponentState::OneTimeChange;
-            break;
-          }
-        }
-        this->SetChanged(entity, compIter.first, flag);
+        this->SetChanged(entity, compIter.first,
+            _stateMsg.has_one_time_component_changes() ?
+            ComponentState::OneTimeChange :
+            ComponentState::PeriodicChange);
       }
     }
   }
@@ -1303,7 +1395,7 @@ void EntityComponentManager::SetAllComponentsUnchanged()
 /////////////////////////////////////////////////
 void EntityComponentManager::SetChanged(
     const Entity _entity, const ComponentTypeId _type,
-    gz::sim::ComponentState _c)
+    gazebo::ComponentState _c)
 {
   auto ecIter = this->dataPtr->entityComponents.find(_entity);
 
@@ -1314,22 +1406,20 @@ void EntityComponentManager::SetChanged(
   if (typeIter == ecIter->second.end())
     return;
 
-  ComponentKey key{_type, typeIter->second};
-
   if (_c == ComponentState::PeriodicChange)
   {
-    this->dataPtr->periodicChangedComponents.insert(key);
-    this->dataPtr->oneTimeChangedComponents.erase(key);
+    this->dataPtr->periodicChangedComponents.insert(typeIter->second);
+    this->dataPtr->oneTimeChangedComponents.erase(typeIter->second);
   }
   else if (_c == ComponentState::OneTimeChange)
   {
-    this->dataPtr->periodicChangedComponents.erase(key);
-    this->dataPtr->oneTimeChangedComponents.insert(key);
+    this->dataPtr->periodicChangedComponents.erase(typeIter->second);
+    this->dataPtr->oneTimeChangedComponents.insert(typeIter->second);
   }
   else
   {
-    this->dataPtr->periodicChangedComponents.erase(key);
-    this->dataPtr->oneTimeChangedComponents.erase(key);
+    this->dataPtr->periodicChangedComponents.erase(typeIter->second);
+    this->dataPtr->oneTimeChangedComponents.erase(typeIter->second);
   }
 }
 
