@@ -17,18 +17,17 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/math/Rand.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/math/Rand.hh>
 
-#include "gz/sim/components/Factory.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/config.hh"
-#include "../test/helpers/EnvTestFixture.hh"
+#include "ignition/gazebo/components/Factory.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/config.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace components;
 
 namespace ignition
@@ -38,31 +37,31 @@ namespace gazebo
 inline namespace IGNITION_GAZEBO_VERSION_NAMESPACE {
 namespace components
 {
-using IntComponent = Component<int, class IntComponentTag>;
+using IntComponent = components::Component<int, class IntComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.IntComponent",
     IntComponent)
 
-using UIntComponent = Component<int, class IntComponentTag>;
+using UIntComponent = components::Component<int, class IntComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.UIntComponent",
     UIntComponent)
 
-using DoubleComponent = Component<double, class DoubleComponentTag>;
+using DoubleComponent = components::Component<double, class DoubleComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.DoubleComponent",
     DoubleComponent)
 
 using StringComponent =
-    Component<std::string, class StringComponentTag>;
+    components::Component<std::string, class StringComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.StringComponent",
     StringComponent)
 
-using BoolComponent = Component<bool, class BoolComponentTag>;
+using BoolComponent = components::Component<bool, class BoolComponentTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.BoolComponent",
     BoolComponent)
 
-using Even = Component<NoData, class EvenTag>;
+using Even = components::Component<components::NoData, class EvenTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.Even", Even)
 
-using Odd = Component<NoData, class OddTag>;
+using Odd = components::Component<components::NoData, class OddTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.Odd", Odd)
 
 struct Custom
@@ -70,7 +69,7 @@ struct Custom
   int dummy{123};
 };
 
-using CustomComponent = Component<Custom, class CustomTag>;
+using CustomComponent = components::Component<Custom, class CustomTag>;
 IGN_GAZEBO_REGISTER_COMPONENT("ign_gazebo_components.CustomComponent",
     CustomComponent)
 }
@@ -92,18 +91,25 @@ class EntityCompMgrTest : public EntityComponentManager
   {
     this->SetAllComponentsUnchanged();
   }
+  public: void RunClearRemovedComponents()
+  {
+    this->ClearRemovedComponents();
+  }
 };
 
-class EntityComponentManagerFixture
-  : public InternalFixture<::testing::TestWithParam<int>>
+class EntityComponentManagerFixture : public ::testing::TestWithParam<int>
 {
+  public: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+  }
   public: EntityCompMgrTest manager;
 };
 
 /////////////////////////////////////////////////
 TEST_P(EntityComponentManagerFixture, AdjacentMemorySingleComponentType)
 {
-  std::vector<Pose> poses;
+  std::vector<components::Pose> poses;
   std::vector<ComponentKey> keys;
 
   int count = 10;
@@ -114,7 +120,7 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemorySingleComponentType)
   // Create the components.
   for (int i = 0; i < count; ++i)
   {
-    poses.push_back(Pose(math::Pose3d(
+    poses.push_back(components::Pose(math::Pose3d(
           math::Rand::IntNormal(10, 5),
           math::Rand::IntNormal(100, 50),
           math::Rand::IntNormal(-100, 30), 0, 0, 0)));
@@ -130,16 +136,16 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemorySingleComponentType)
   // Check the component values.
   for (int i = 0; i < count; ++i)
   {
-    EXPECT_EQ(poses[i], *(manager.Component<Pose>(keys[i])));
+    EXPECT_EQ(poses[i], *(manager.Component<components::Pose>(keys[i])));
   }
   {
-    uintptr_t poseSize = sizeof(Pose);
-    const Pose *pose = nullptr, *prevPose = nullptr;
+    uintptr_t poseSize = sizeof(components::Pose);
+    const components::Pose *pose = nullptr, *prevPose = nullptr;
 
     // Check that each component is adjacent in memory
     for (int i = 0; i < count; ++i)
     {
-      pose = manager.Component<Pose>(keys[i]);
+      pose = manager.Component<components::Pose>(keys[i]);
       if (prevPose != nullptr)
       {
         EXPECT_EQ(poseSize, reinterpret_cast<uintptr_t>(pose) -
@@ -153,9 +159,9 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemorySingleComponentType)
     const math::Pose3d *poseData = nullptr, *prevPoseData = nullptr;
     for (int i = 0; i < count; ++i)
     {
-      poseData = &(manager.Component<Pose>(keys[i])->Data());
+      poseData = &(manager.Component<components::Pose>(keys[i])->Data());
       uintptr_t poseDataSize = sizeof(math::Pose3d) +
-        sizeof(BaseComponent);
+        sizeof(components::BaseComponent);
       if (prevPoseData != nullptr)
       {
         EXPECT_EQ(poseDataSize, reinterpret_cast<uintptr_t>(poseData) -
@@ -169,7 +175,7 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemorySingleComponentType)
 /////////////////////////////////////////////////
 TEST_P(EntityComponentManagerFixture, AdjacentMemoryTwoComponentTypes)
 {
-  std::vector<Pose> poses;
+  std::vector<components::Pose> poses;
   std::vector<IntComponent> ints;
   std::vector<ComponentKey> poseKeys;
   std::vector<ComponentKey> intKeys;
@@ -182,7 +188,7 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemoryTwoComponentTypes)
   // Create the components.
   for (int i = 0; i < count; ++i)
   {
-    poses.push_back(Pose(math::Pose3d(1, 2, 3, 0, 0, 0)));
+    poses.push_back(components::Pose(math::Pose3d(1, 2, 3, 0, 0, 0)));
     ints.push_back(IntComponent(i));
 
     poseKeys.push_back(manager.CreateComponent(entity, poses.back()));
@@ -198,15 +204,15 @@ TEST_P(EntityComponentManagerFixture, AdjacentMemoryTwoComponentTypes)
   ASSERT_EQ(static_cast<size_t>(count), poseKeys.size());
   ASSERT_EQ(static_cast<size_t>(count), intKeys.size());
 
-  uintptr_t poseSize = sizeof(Pose);
+  uintptr_t poseSize = sizeof(components::Pose);
   uintptr_t intSize = sizeof(IntComponent);
-  const Pose *pose = nullptr, *prevPose = nullptr;
+  const components::Pose *pose = nullptr, *prevPose = nullptr;
   const IntComponent *it = nullptr, *prevIt = nullptr;
 
   // Check that each component is adjacent in memory
   for (int i = 0; i < count; ++i)
   {
-    pose = manager.Component<Pose>(poseKeys[i]);
+    pose = manager.Component<components::Pose>(poseKeys[i]);
     it = manager.Component<IntComponent>(intKeys[i]);
     if (prevPose != nullptr)
     {
@@ -307,7 +313,7 @@ TEST_P(EntityComponentManagerFixture, RemoveComponent)
 // adjacent to each other.
 TEST_P(EntityComponentManagerFixture, RemoveAdjacent)
 {
-  std::vector<Pose> poses;
+  std::vector<components::Pose> poses;
   std::vector<ComponentKey> keys;
 
   Entity entity = manager.CreateEntity();
@@ -317,19 +323,19 @@ TEST_P(EntityComponentManagerFixture, RemoveAdjacent)
   // Create the components.
   for (int i = 0; i < count; ++i)
   {
-    poses.push_back(Pose(math::Pose3d(1, 2, 3, 0, 0, 0)));
+    poses.push_back(components::Pose(math::Pose3d(1, 2, 3, 0, 0, 0)));
     keys.push_back(manager.CreateComponent(entity, poses.back()));
     EXPECT_EQ(keys.back().second, i);
   }
   ASSERT_EQ(poses.size(), keys.size());
 
-  uintptr_t poseSize = sizeof(Pose);
-  const Pose *pose = nullptr, *prevPose = nullptr;
+  uintptr_t poseSize = sizeof(components::Pose);
+  const components::Pose *pose = nullptr, *prevPose = nullptr;
 
   // Check that each component is adjacent in memory
   for (int i = 0; i < count; ++i)
   {
-    pose = manager.Component<Pose>(keys[i]);
+    pose = manager.Component<components::Pose>(keys[i]);
     if (prevPose != nullptr)
     {
       EXPECT_EQ(poseSize, reinterpret_cast<uintptr_t>(pose) -
@@ -347,10 +353,10 @@ TEST_P(EntityComponentManagerFixture, RemoveAdjacent)
   EXPECT_FALSE(manager.RemoveComponent(entity, keys[1]));
 
   // Check that the two remaining components are still adjacent in memory
-  const Pose *pose1 =
-    manager.Component<Pose>(keys[0]);
-  const Pose *pose3 =
-    manager.Component<Pose>(keys[2]);
+  const components::Pose *pose1 =
+    manager.Component<components::Pose>(keys[0]);
+  const components::Pose *pose3 =
+    manager.Component<components::Pose>(keys[2]);
   EXPECT_EQ(poseSize,
       reinterpret_cast<uintptr_t>(pose3) - reinterpret_cast<uintptr_t>(pose1));
 }
@@ -366,33 +372,33 @@ TEST_P(EntityComponentManagerFixture, RemoveAddAdjacent)
   std::vector<ComponentKey> keys;
 
   keys.push_back(manager.CreateComponent(entity,
-        Pose(math::Pose3d(1, 2, 3, 0, 0, 0))));
+        components::Pose(math::Pose3d(1, 2, 3, 0, 0, 0))));
   keys.push_back(manager.CreateComponent(entity,
-        Pose(math::Pose3d(3, 1, 2, 0, 0, 0))));
+        components::Pose(math::Pose3d(3, 1, 2, 0, 0, 0))));
   keys.push_back(manager.CreateComponent(entity,
-        Pose(math::Pose3d(0, 10, 20, 0, 0, 0))));
+        components::Pose(math::Pose3d(0, 10, 20, 0, 0, 0))));
 
-  uintptr_t poseSize = sizeof(Pose);
+  uintptr_t poseSize = sizeof(components::Pose);
 
   // Remove the middle component.
   EXPECT_TRUE(manager.RemoveComponent(entity, keys[1]));
 
   // Add two more new component
   keys.push_back(manager.CreateComponent(entity,
-        Pose(math::Pose3d(101, 51, 520, 0, 0, 0))));
+        components::Pose(math::Pose3d(101, 51, 520, 0, 0, 0))));
 
   keys.push_back(manager.CreateComponent(entity,
-        Pose(math::Pose3d(1010, 81, 821, 0, 0, 0))));
+        components::Pose(math::Pose3d(1010, 81, 821, 0, 0, 0))));
 
   // Check that the components are all adjacent in memory
-  const Pose *pose1 =
-    manager.Component<Pose>(keys[0]);
-  const Pose *pose2 =
-    manager.Component<Pose>(keys[2]);
-  const Pose *pose3 =
-    manager.Component<Pose>(keys[3]);
-  const Pose *pose4 =
-    manager.Component<Pose>(keys[4]);
+  const components::Pose *pose1 =
+    manager.Component<components::Pose>(keys[0]);
+  const components::Pose *pose2 =
+    manager.Component<components::Pose>(keys[2]);
+  const components::Pose *pose3 =
+    manager.Component<components::Pose>(keys[3]);
+  const components::Pose *pose4 =
+    manager.Component<components::Pose>(keys[4]);
 
   EXPECT_EQ(poseSize,
       reinterpret_cast<uintptr_t>(pose2) - reinterpret_cast<uintptr_t>(pose1));
@@ -404,10 +410,10 @@ TEST_P(EntityComponentManagerFixture, RemoveAddAdjacent)
       reinterpret_cast<uintptr_t>(pose4) - reinterpret_cast<uintptr_t>(pose3));
 
   // Check the values of the components.
-  EXPECT_EQ(Pose(math::Pose3d(1, 2, 3, 0, 0, 0)), *pose1);
-  EXPECT_EQ(Pose(math::Pose3d(0, 10, 20, 0, 0, 0)), *pose2);
-  EXPECT_EQ(Pose(math::Pose3d(101, 51, 520, 0, 0, 0)), *pose3);
-  EXPECT_EQ(Pose(math::Pose3d(1010, 81, 821, 0, 0, 0)), *pose4);
+  EXPECT_EQ(components::Pose(math::Pose3d(1, 2, 3, 0, 0, 0)), *pose1);
+  EXPECT_EQ(components::Pose(math::Pose3d(0, 10, 20, 0, 0, 0)), *pose2);
+  EXPECT_EQ(components::Pose(math::Pose3d(101, 51, 520, 0, 0, 0)), *pose3);
+  EXPECT_EQ(components::Pose(math::Pose3d(1010, 81, 821, 0, 0, 0)), *pose4);
 }
 
 /////////////////////////////////////////////////
@@ -431,16 +437,6 @@ TEST_P(EntityComponentManagerFixture, EntitiesAndComponents)
   EXPECT_FALSE(manager.EntityHasComponentType(entity, DoubleComponent::typeId));
   EXPECT_FALSE(manager.EntityHasComponentType(entity2, IntComponent::typeId));
 
-  // Try to add a component to an entity that does not exist
-  EXPECT_FALSE(manager.HasEntity(kNullEntity));
-  EXPECT_FALSE(manager.EntityHasComponentType(kNullEntity,
-        IntComponent::typeId));
-  EXPECT_EQ(ComponentKey(), manager.CreateComponent<IntComponent>(kNullEntity,
-        IntComponent(123)));
-  EXPECT_FALSE(manager.HasEntity(kNullEntity));
-  EXPECT_FALSE(manager.EntityHasComponentType(kNullEntity,
-        IntComponent::typeId));
-
   // Query non-existing component, the default value is default-constructed
   BoolComponent *boolComp = manager.ComponentDefault<BoolComponent>(entity);
   ASSERT_NE(nullptr, boolComp);
@@ -498,8 +494,8 @@ TEST_P(EntityComponentManagerFixture, ComponentValues)
   manager.CreateComponent<DoubleComponent>(eDouble, DoubleComponent(0.123));
   manager.CreateComponent<IntComponent>(eIntDouble, IntComponent(456));
   manager.CreateComponent<DoubleComponent>(eIntDouble, DoubleComponent(0.456));
-  manager.CreateComponent<Pose>(ePose,
-      Pose({1, 2, 3, 0, 0, 0}));
+  manager.CreateComponent<components::Pose>(ePose,
+      components::Pose({1, 2, 3, 0, 0, 0}));
   manager.CreateComponent<CustomComponent>(eCustom,
       CustomComponent(Custom()));
 
@@ -565,19 +561,19 @@ TEST_P(EntityComponentManagerFixture, ComponentValues)
   }
 
   {
-    const auto *value = manager.Component<Pose>(ePose);
+    const auto *value = manager.Component<components::Pose>(ePose);
     ASSERT_NE(nullptr, value);
     EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), value->Data());
 
-    auto data = manager.ComponentData<Pose>(ePose);
+    auto data = manager.ComponentData<components::Pose>(ePose);
     EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), data);
 
-    EXPECT_TRUE(manager.SetComponentData<Pose>(ePose,
+    EXPECT_TRUE(manager.SetComponentData<components::Pose>(ePose,
         {4, 5, 6, 0, 0, 0}));
-    data = manager.ComponentData<Pose>(ePose);
+    data = manager.ComponentData<components::Pose>(ePose);
     EXPECT_EQ(math::Pose3d(4, 5, 6, 0, 0, 0), data);
 
-    EXPECT_FALSE(manager.SetComponentData<Pose>(ePose,
+    EXPECT_FALSE(manager.SetComponentData<components::Pose>(ePose,
         {4, 5, 6, 0, 0, 0}));
   }
 
@@ -1515,11 +1511,11 @@ TEST_P(EntityComponentManagerFixture, EntityGraph)
   EXPECT_TRUE(manager.SetParentEntity(e6, e2));
   EXPECT_TRUE(manager.SetParentEntity(e7, e2));
 
-  EXPECT_FALSE(manager.SetParentEntity(e1, Entity(1000)));
-  EXPECT_FALSE(manager.SetParentEntity(Entity(1000), e1));
+  EXPECT_FALSE(manager.SetParentEntity(e1, gazebo::Entity(1000)));
+  EXPECT_FALSE(manager.SetParentEntity(gazebo::Entity(1000), e1));
 
   // Check their parents
-  EXPECT_EQ(kNullEntity, manager.ParentEntity(e1));
+  EXPECT_EQ(gazebo::kNullEntity, manager.ParentEntity(e1));
   EXPECT_EQ(e1, manager.ParentEntity(e2));
   EXPECT_EQ(e1, manager.ParentEntity(e3));
   EXPECT_EQ(e2, manager.ParentEntity(e4));
@@ -1528,8 +1524,8 @@ TEST_P(EntityComponentManagerFixture, EntityGraph)
   EXPECT_EQ(e2, manager.ParentEntity(e7));
 
   // Detach from graph
-  EXPECT_TRUE(manager.SetParentEntity(e7, kNullEntity));
-  EXPECT_EQ(kNullEntity, manager.ParentEntity(e7));
+  EXPECT_TRUE(manager.SetParentEntity(e7, gazebo::kNullEntity));
+  EXPECT_EQ(gazebo::kNullEntity, manager.ParentEntity(e7));
 
   // Reparent
   EXPECT_TRUE(manager.SetParentEntity(e5, e3));
@@ -2191,107 +2187,307 @@ TEST_P(EntityComponentManagerFixture, SetEntityCreateOffset)
   manager.SetEntityCreateOffset(1000);
   Entity entity2 = manager.CreateEntity();
   EXPECT_EQ(1001u, entity2);
-
-  // Apply a lower offset, prints warning but goes through.
-  manager.SetEntityCreateOffset(500);
-  Entity entity3 = manager.CreateEntity();
-  EXPECT_EQ(501u, entity3);
 }
 
 //////////////////////////////////////////////////
-/// \brief Test using msgs::SerializedStateMap and msgs::SerializedState
-/// to update existing component data between multiple ECMs
-TEST_P(EntityComponentManagerFixture, StateMsgUpdateComponent)
+TEST_P(EntityComponentManagerFixture, SerializedStateMapMsgAfterRemoveComponent)
 {
-  // create 2 ECMs: one will be modified directly, and the other should be
-  // updated to match the first via msgs::SerializedStateMap
-  EntityComponentManager originalECMStateMap;
-  EntityComponentManager otherECMStateMap;
+  // Create entity
+  Entity e1 = manager.CreateEntity();
+  auto e1c0 =
+    manager.CreateComponent<IntComponent>(e1, IntComponent(123));
+  auto e1c1 =
+    manager.CreateComponent<DoubleComponent>(e1, DoubleComponent(0.0));
+  auto e1c2 =
+    manager.CreateComponent<StringComponent>(e1, StringComponent("int"));
 
-  // create an entity and component
-  auto entity = originalECMStateMap.CreateEntity();
-  originalECMStateMap.CreateComponent(entity, IntComponent(1));
+  // We use this map because the order in which components are iterated
+  // through depends on the (undetermined) order of unordered multimaps
+  std::map<ComponentTypeId, bool> expectations;
+  expectations.insert(std::make_pair(e1c0.first, false));
+  expectations.insert(std::make_pair(e1c1.first, true));
+  expectations.insert(std::make_pair(e1c2.first, true));
 
-  int foundEntities = 0;
-  otherECMStateMap.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *)
-      {
-        foundEntities++;
-        return true;
-      });
-  EXPECT_EQ(0, foundEntities);
+  manager.RemoveComponent(e1, e1c1);
+  manager.RemoveComponent(e1, e1c2);
 
-  // update the other ECM to have the new entity and component
-  msgs::SerializedStateMap stateMapMsg;
-  originalECMStateMap.State(stateMapMsg);
-  otherECMStateMap.SetState(stateMapMsg);
-  foundEntities = 0;
-  otherECMStateMap.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *_intComp)
-      {
-        foundEntities++;
-        EXPECT_EQ(1, _intComp->Data());
-        return true;
-      });
-  EXPECT_EQ(1, foundEntities);
+  // Serialize into a message
+  msgs::SerializedStateMap stateMsg;
+  manager.State(stateMsg);
 
-  // modify a component and then share the update with the other ECM
-  stateMapMsg.Clear();
-  originalECMStateMap.SetComponentData<IntComponent>(entity, 2);
-  originalECMStateMap.State(stateMapMsg);
-  otherECMStateMap.SetState(stateMapMsg);
-  foundEntities = 0;
-  otherECMStateMap.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *_intComp)
-      {
-        foundEntities++;
-        EXPECT_EQ(2, _intComp->Data());
-        return true;
-      });
-  EXPECT_EQ(1, foundEntities);
+  // Check message
+  {
+    auto iter = stateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    auto compIter = e1Msg.components().begin();
 
-  // Run the same test as above, but this time, use a msgs::SerializedState
-  // instead of a msgs::SerializedStateMap
-  EntityComponentManager originalECMState;
-  EntityComponentManager otherECMState;
+    // First component
+    const auto &c0 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c0.remove(), expectations.find(c0.type())->second);
 
-  foundEntities = 0;
-  otherECMState.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *)
-      {
-        foundEntities++;
-        return true;
-      });
-  EXPECT_EQ(0, foundEntities);
+    // Second component
+    const auto &c1 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c1.remove(), expectations.find(c1.type())->second);
 
-  entity = originalECMState.CreateEntity();
-  originalECMState.CreateComponent(entity, IntComponent(1));
+    // Third component
+    const auto &c2 = compIter->second;
+    EXPECT_EQ(c2.remove(), expectations.find(c2.type())->second);
+  }
 
-  auto stateMsg = originalECMState.State();
-  otherECMState.SetState(stateMsg);
-  foundEntities = 0;
-  otherECMState.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *_intComp)
-      {
-        foundEntities++;
-        EXPECT_EQ(1, _intComp->Data());
-        return true;
-      });
-  EXPECT_EQ(1, foundEntities);
+  // Check that removed components don't exist anymore after clearing them
+  manager.RunClearRemovedComponents();
+  msgs::SerializedStateMap newStateMsg;
+  manager.State(newStateMsg);
 
-  stateMsg.Clear();
-  originalECMState.SetComponentData<IntComponent>(entity, 2);
-  stateMsg = originalECMState.State();
-  otherECMState.SetState(stateMsg);
-  foundEntities = 0;
-  otherECMState.Each<IntComponent>(
-      [&](const Entity &, const IntComponent *_intComp)
-      {
-        foundEntities++;
-        EXPECT_EQ(2, _intComp->Data());
-        return true;
-      });
-  EXPECT_EQ(1, foundEntities);
+  // Check message
+  {
+    auto iter = newStateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    EXPECT_EQ(1, e1Msg.components_size());
+    auto compIter = e1Msg.components().begin();
+
+    // First component
+    const auto &e1c0Msg = compIter->second;
+    EXPECT_FALSE(e1c0Msg.remove());
+  }
+}
+
+//////////////////////////////////////////////////
+TEST_P(EntityComponentManagerFixture, SerializedStateMsgAfterRemoveComponent)
+{
+  // Create entity
+  Entity e1 = manager.CreateEntity();
+  auto e1c0 =
+    manager.CreateComponent<IntComponent>(e1, IntComponent(123));
+  auto e1c1 =
+    manager.CreateComponent<DoubleComponent>(e1, DoubleComponent(0.0));
+  auto e1c2 =
+    manager.CreateComponent<StringComponent>(e1, StringComponent("int"));
+
+  // We use this map because the order in which components are iterated
+  // through depends on the (undetermined) order of unordered multimaps
+  std::map<ComponentTypeId, bool> expectations;
+  expectations.insert(std::make_pair(e1c0.first, false));
+  expectations.insert(std::make_pair(e1c1.first, true));
+  expectations.insert(std::make_pair(e1c2.first, true));
+
+  manager.RemoveComponent(e1, e1c1);
+  manager.RemoveComponent(e1, e1c2);
+
+  // Serialize into a message
+  msgs::SerializedState stateMsg;
+  stateMsg = manager.State();
+
+  // Check message
+  {
+    auto const &entityMsg = stateMsg.entities(0);
+
+    // First component
+    const auto &c0 = entityMsg.components(0);
+    EXPECT_EQ(c0.remove(), expectations.find(c0.type())->second);
+
+    // Second component
+    const auto &c1 = entityMsg.components(1);
+    EXPECT_EQ(c1.remove(), expectations.find(c1.type())->second);
+
+    // Third component
+    const auto &c2 = entityMsg.components(2);
+    EXPECT_EQ(c2.remove(), expectations.find(c2.type())->second);
+  }
+
+  // Check that removed components don't exist anymore after clearing them
+  manager.RunClearRemovedComponents();
+  msgs::SerializedState newStateMsg;
+  newStateMsg = manager.State();
+
+  // Check message
+  {
+    auto const &entityMsg = newStateMsg.entities(0);
+    EXPECT_EQ(1, entityMsg.components_size());
+
+    // First component
+    const auto &e1c0Msg = entityMsg.components(0);
+    EXPECT_FALSE(e1c0Msg.remove());
+  }
+}
+
+//////////////////////////////////////////////////
+// Verify SerializedStateMap message with no changed components,
+// but some removed components
+TEST_P(EntityComponentManagerFixture, SerializedStateMapMsgCompsRemovedOnly)
+{
+  // Create entity
+  Entity e1 = manager.CreateEntity();
+  auto e1c0 =
+    manager.CreateComponent<IntComponent>(e1, IntComponent(123));
+  manager.CreateComponent<DoubleComponent>(e1, DoubleComponent(0.0));
+  auto e1c2 =
+    manager.CreateComponent<StringComponent>(e1, StringComponent("int"));
+
+  manager.RunSetAllComponentsUnchanged();
+  manager.RemoveComponent(e1, e1c0);
+  manager.RemoveComponent(e1, e1c2);
+  // Serialize into a message
+  msgs::SerializedStateMap stateMsg;
+  manager.State(stateMsg);
+
+  // Check message
+  {
+    auto iter = stateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    auto compIter = e1Msg.components().begin();
+
+    // Check number of components
+    ASSERT_EQ(e1Msg.components().size(), 2u);
+
+    // First component
+    const auto &c0 = compIter->second;
+    compIter++;
+    ASSERT_EQ(c0.remove(), true);
+
+    // Second component
+    const auto &c2 = compIter->second;
+    ASSERT_EQ(c2.remove(), true);
+  }
+}
+
+//////////////////////////////////////////////////
+// Verify that removed components are correctly filtered when creating a
+// SerializedStateMap message
+TEST_P(EntityComponentManagerFixture, SetRemovedComponentsMsgTypesFilter)
+{
+  // Create entity
+  Entity e1 = manager.CreateEntity();
+  auto e1c0 =
+    manager.CreateComponent<IntComponent>(e1, IntComponent(123));
+  auto e1c1 =
+    manager.CreateComponent<DoubleComponent>(e1, DoubleComponent(0.0));
+  auto e1c2 =
+    manager.CreateComponent<StringComponent>(e1, StringComponent("foo"));
+
+  manager.RunSetAllComponentsUnchanged();
+  manager.RemoveComponent(e1, e1c0);
+  manager.RemoveComponent(e1, e1c2);
+
+  // Serialize into a message, providing a list of types to be included
+  msgs::SerializedStateMap stateMsg;
+  std::unordered_set<Entity> entitySet{e1};
+  std::unordered_set<ComponentTypeId> types{e1c0.first, e1c1.first};
+  manager.State(stateMsg, entitySet, types, false);
+
+  // Check message
+  {
+    auto iter = stateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    auto compIter = e1Msg.components().begin();
+
+    // Check number of components
+    ASSERT_EQ(e1Msg.components().size(), 1u);
+
+    // Only component in message should be e1c2
+    const auto &c0 = compIter->second;
+    EXPECT_EQ(c0.remove(), true);
+    EXPECT_EQ(c0.type(), e1c0.first);
+  }
+}
+
+//////////////////////////////////////////////////
+TEST_P(EntityComponentManagerFixture, RemovedComponentsSyncBetweenServerAndGUI)
+{
+  // Simulate the GUI's ECM
+  EntityCompMgrTest guiManager;
+
+  // Create entity
+  Entity e1 = manager.CreateEntity();
+  auto e1c0 =
+    manager.CreateComponent<IntComponent>(e1, IntComponent(123));
+  auto e1c1 =
+    manager.CreateComponent<DoubleComponent>(e1, DoubleComponent(0.0));
+  auto e1c2 =
+    manager.CreateComponent<StringComponent>(e1, StringComponent("int"));
+
+  // We use this map because the order in which components are iterated
+  // through depends on the (undetermined) order of unordered multimaps
+  std::map<ComponentTypeId, bool> expectationsBeforeRemoving;
+  expectationsBeforeRemoving.insert(std::make_pair(e1c0.first, false));
+  expectationsBeforeRemoving.insert(std::make_pair(e1c1.first, false));
+  expectationsBeforeRemoving.insert(std::make_pair(e1c2.first, false));
+
+  // Serialize server ECM into a message
+  msgs::SerializedStateMap stateMsg;
+  manager.State(stateMsg);
+
+  // Set GUI's ECM and serialize into a message
+  guiManager.SetState(stateMsg);
+  msgs::SerializedStateMap guiStateMsg;
+  guiManager.State(guiStateMsg);
+
+  // Check sync message
+  {
+    auto iter = guiStateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    auto compIter = e1Msg.components().begin();
+
+    // First component
+    const auto &c0 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c0.remove(), expectationsBeforeRemoving.find(c0.type())->second);
+
+    // Second component
+    const auto &c1 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c1.remove(), expectationsBeforeRemoving.find(c1.type())->second);
+
+    // Third component
+    const auto &c2 = compIter->second;
+    EXPECT_EQ(c2.remove(), expectationsBeforeRemoving.find(c2.type())->second);
+  }
+
+  std::map<ComponentTypeId, bool> expectationsAfterRemoving;
+  expectationsAfterRemoving.insert(std::make_pair(e1c0.first, false));
+  expectationsAfterRemoving.insert(std::make_pair(e1c1.first, true));
+  expectationsAfterRemoving.insert(std::make_pair(e1c2.first, true));
+
+  // Remove components and synchronize again
+  manager.RemoveComponent(e1, e1c1);
+  manager.RemoveComponent(e1, e1c2);
+
+  msgs::SerializedStateMap newStateMsg;
+  manager.State(newStateMsg);
+
+  EXPECT_TRUE(nullptr != guiManager.Component<IntComponent>(e1));
+  EXPECT_TRUE(nullptr != guiManager.Component<DoubleComponent>(e1));
+  EXPECT_TRUE(nullptr != guiManager.Component<StringComponent>(e1));
+  guiManager.SetState(newStateMsg);
+  EXPECT_TRUE(nullptr != guiManager.Component<IntComponent>(e1));
+  EXPECT_TRUE(nullptr == guiManager.Component<DoubleComponent>(e1));
+  EXPECT_TRUE(nullptr == guiManager.Component<StringComponent>(e1));
+
+  msgs::SerializedStateMap newGuiStateMsg;
+  guiManager.State(newGuiStateMsg);
+
+  // Check message
+  {
+    auto iter = newGuiStateMsg.entities().find(e1);
+    const auto &e1Msg = iter->second;
+    auto compIter = e1Msg.components().begin();
+
+    // First component
+    const auto &c0 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c0.remove(), expectationsAfterRemoving.find(c0.type())->second);
+
+    // Second component
+    const auto &c1 = compIter->second;
+    compIter++;
+    EXPECT_EQ(c1.remove(), expectationsAfterRemoving.find(c1.type())->second);
+
+    // Third component
+    const auto &c2 = compIter->second;
+    EXPECT_EQ(c2.remove(), expectationsAfterRemoving.find(c2.type())->second);
+  }
 }
 
 // Run multiple times. We want to make sure that static globals don't cause
