@@ -25,40 +25,40 @@
 #include <sdf/Model.hh>
 #include <sdf/World.hh>
 
-#include <gz/common/Profiler.hh>
+#include <ignition/common/Profiler.hh>
 
-#include "gz/sim/Events.hh"
-#include "gz/sim/EntityComponentManager.hh"
+#include "ignition/gazebo/Events.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
 
-#include "gz/sim/components/Actor.hh"
-#include "gz/sim/components/Atmosphere.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Level.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/LevelBuffer.hh"
-#include "gz/sim/components/LevelEntityNames.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/LinearVelocitySeed.hh"
-#include "gz/sim/components/MagneticField.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Performer.hh"
-#include "gz/sim/components/PerformerLevels.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/PhysicsEnginePlugin.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/RenderEngineGuiPlugin.hh"
-#include "gz/sim/components/RenderEngineServerPlugin.hh"
-#include "gz/sim/components/Scene.hh"
-#include "gz/sim/components/Wind.hh"
-#include "gz/sim/components/World.hh"
+#include "ignition/gazebo/components/Actor.hh"
+#include "ignition/gazebo/components/Atmosphere.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Level.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/LevelBuffer.hh"
+#include "ignition/gazebo/components/LevelEntityNames.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/LinearVelocitySeed.hh"
+#include "ignition/gazebo/components/MagneticField.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Performer.hh"
+#include "ignition/gazebo/components/PerformerLevels.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/PhysicsEnginePlugin.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/RenderEngineGuiPlugin.hh"
+#include "ignition/gazebo/components/RenderEngineServerPlugin.hh"
+#include "ignition/gazebo/components/Scene.hh"
+#include "ignition/gazebo/components/Wind.hh"
+#include "ignition/gazebo/components/World.hh"
 
 #include "SimulationRunner.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
 LevelManager::LevelManager(SimulationRunner *_runner, const bool _useLevels)
@@ -77,8 +77,14 @@ LevelManager::LevelManager(SimulationRunner *_runner, const bool _useLevels)
   this->ReadLevelPerformerInfo();
   this->CreatePerformers();
 
-  std::string service = "/world/";
-  service += this->runner->sdfWorld->Name() + "/level/set_performer";
+  std::string service = transport::TopicUtils::AsValidTopic("/world/" +
+      this->runner->sdfWorld->Name() + "/level/set_performer");
+  if (service.empty())
+  {
+    ignerr << "Failed to generate set_performer topic for world ["
+           << this->runner->sdfWorld->Name() << "]" << std::endl;
+    return;
+  }
   this->node.Advertise(service, &LevelManager::OnSetPerformer, this);
 }
 
@@ -151,11 +157,11 @@ void LevelManager::ReadLevelPerformerInfo()
 
   // TODO(anyone) This should probably go somewhere else as it is a global
   // constant.
-  const std::string kPluginName{"gz::sim"};
+  const std::string kPluginName{"ignition::gazebo"};
 
   sdf::ElementPtr pluginElem;
-  // Get the gz::sim plugin element
-  for (auto plugin = worldElem->FindElement("plugin"); plugin;
+  // Get the ignition::gazebo plugin element
+  for (auto plugin = worldElem->GetElement("plugin"); plugin;
        plugin = plugin->GetNextElement("plugin"))
   {
     if (plugin->Get<std::string>("name") == kPluginName)
