@@ -15,68 +15,63 @@
  *
 */
 
-#include <gz/common/Console.hh>
-#include <gz/common/Profiler.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Profiler.hh>
+#include <sdf/Types.hh>
 
-#include "gz/sim/Events.hh"
-#include "gz/sim/SdfEntityCreator.hh"
+#include "ignition/gazebo/Events.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
 
-#ifdef __APPLE__
-// Include all known components to ensure that they are registered by the core
-// library instead of a plugin to fix
-// https://github.com/gazebosim/gz-sim/issues/2204.
-//
-// NOTE(azeey): This should not be forward ported to ign-gazebo6.
-#include "gz/sim/components/components.hh"
-#endif
-#include "gz/sim/components/Actor.hh"
-#include "gz/sim/components/AirPressureSensor.hh"
-#include "gz/sim/components/Altimeter.hh"
-#include "gz/sim/components/AngularVelocity.hh"
-#include "gz/sim/components/Atmosphere.hh"
-#include "gz/sim/components/Camera.hh"
-#include "gz/sim/components/CanonicalLink.hh"
-#include "gz/sim/components/CastShadows.hh"
-#include "gz/sim/components/ChildLinkName.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/ContactSensor.hh"
-#include "gz/sim/components/DepthCamera.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/GpuLidar.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Imu.hh"
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointAxis.hh"
-#include "gz/sim/components/JointType.hh"
-#include "gz/sim/components/LaserRetro.hh"
-#include "gz/sim/components/Lidar.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/LinearAcceleration.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/LogicalCamera.hh"
-#include "gz/sim/components/MagneticField.hh"
-#include "gz/sim/components/Magnetometer.hh"
-#include "gz/sim/components/Material.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentLinkName.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/RgbdCamera.hh"
-#include "gz/sim/components/Scene.hh"
-#include "gz/sim/components/SelfCollide.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/SourceFilePath.hh"
-#include "gz/sim/components/Static.hh"
-#include "gz/sim/components/ThermalCamera.hh"
-#include "gz/sim/components/ThreadPitch.hh"
-#include "gz/sim/components/Transparency.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/WindMode.hh"
-#include "gz/sim/components/World.hh"
+#include "ignition/gazebo/components/Actor.hh"
+#include "ignition/gazebo/components/AirPressureSensor.hh"
+#include "ignition/gazebo/components/Altimeter.hh"
+#include "ignition/gazebo/components/AngularVelocity.hh"
+#include "ignition/gazebo/components/Atmosphere.hh"
+#include "ignition/gazebo/components/Camera.hh"
+#include "ignition/gazebo/components/CanonicalLink.hh"
+#include "ignition/gazebo/components/CastShadows.hh"
+#include "ignition/gazebo/components/ChildLinkName.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/ContactSensor.hh"
+#include "ignition/gazebo/components/DepthCamera.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/GpuLidar.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Imu.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointAxis.hh"
+#include "ignition/gazebo/components/JointType.hh"
+#include "ignition/gazebo/components/LaserRetro.hh"
+#include "ignition/gazebo/components/Lidar.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LightType.hh"
+#include "ignition/gazebo/components/LinearAcceleration.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/LogicalCamera.hh"
+#include "ignition/gazebo/components/MagneticField.hh"
+#include "ignition/gazebo/components/Magnetometer.hh"
+#include "ignition/gazebo/components/Material.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentLinkName.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/RgbdCamera.hh"
+#include "ignition/gazebo/components/Scene.hh"
+#include "ignition/gazebo/components/SelfCollide.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/SourceFilePath.hh"
+#include "ignition/gazebo/components/Static.hh"
+#include "ignition/gazebo/components/ThermalCamera.hh"
+#include "ignition/gazebo/components/ThreadPitch.hh"
+#include "ignition/gazebo/components/Transparency.hh"
+#include "ignition/gazebo/components/Visibility.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/WindMode.hh"
+#include "ignition/gazebo/components/World.hh"
 
 class ignition::gazebo::SdfEntityCreatorPrivate
 {
@@ -99,8 +94,8 @@ class ignition::gazebo::SdfEntityCreatorPrivate
   public: std::map<Entity, sdf::ElementPtr> newVisuals;
 };
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
 /// \brief Resolve the pose of an SDF DOM object with respect to its relative_to
@@ -117,6 +112,69 @@ static math::Pose3d ResolveSdfPose(const sdf::SemanticPose &_semPose)
   return pose;
 }
 
+/////////////////////////////////////////////////
+static std::optional<sdf::JointAxis> ResolveJointAxis(
+    const sdf::JointAxis &_unresolvedAxis)
+{
+  math::Vector3d axisXyz;
+  const sdf::Errors resolveAxisErrors = _unresolvedAxis.ResolveXyz(axisXyz);
+  if (!resolveAxisErrors.empty())
+  {
+    ignerr << "Failed to resolve axis" << std::endl;
+    return std::nullopt;
+  }
+
+  sdf::JointAxis resolvedAxis = _unresolvedAxis;
+
+  const sdf::Errors setXyzErrors = resolvedAxis.SetXyz(axisXyz);
+  if (!setXyzErrors.empty())
+  {
+    ignerr << "Failed to resolve axis" << std::endl;
+    return std::nullopt;
+  }
+
+  resolvedAxis.SetXyzExpressedIn("");
+  return resolvedAxis;
+}
+
+//////////////////////////////////////////////////
+/// \brief Find a descendent child link entity by name.
+/// \param[in] _name The relative name of the link with "::" as the scope
+/// delimiter
+/// \param[in] _model Model entity that defines the scope
+/// \param[in] _ecm Entity component manager
+/// \return The Entity of the descendent link or kNullEntity if link was not
+/// found
+static Entity FindDescendentLinkEntityByName(const std::string &_name,
+                                             const Entity &_model,
+                                             const EntityComponentManager &_ecm)
+{
+  auto ind = _name.find(sdf::kSdfScopeDelimiter);
+  std::vector<Entity> candidates;
+  if (ind != std::string::npos)
+  {
+    candidates = _ecm.ChildrenByComponents(
+        _model, components::Model(), components::Name(_name.substr(0, ind)));
+    if (candidates.size() != 1 || (ind + 2 >= _name.size()))
+    {
+      return kNullEntity;
+    }
+    return FindDescendentLinkEntityByName(_name.substr(ind + 2),
+                                          candidates.front(), _ecm);
+  }
+  else
+  {
+    candidates = _ecm.ChildrenByComponents(_model, components::Link(),
+                                           components::Name(_name));
+
+    if (candidates.size() != 1)
+    {
+      return kNullEntity;
+    }
+    return candidates.front();
+  }
+}
+
 //////////////////////////////////////////////////
 SdfEntityCreator::SdfEntityCreator(EntityComponentManager &_ecm,
           EventManager &_eventManager)
@@ -240,12 +298,7 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model)
 {
   IGN_PROFILE("SdfEntityCreator::CreateEntities(sdf::Model)");
 
-  // todo(anyone) Support multiple canonical links in nested models
-  // This version of CreateEntties keeps track whether or not to create a
-  // canonical link in a model tree using the second arg in this recursive
-  // function. We also override child nested models static property if parent
-  // model is static
-  auto ent = this->CreateEntities(_model, true, false);
+  auto ent = this->CreateEntities(_model, false);
 
   // Load all model plugins afterwards, so we get scoped name for nested models.
   for (const auto &[entity, element] : this->dataPtr->newModels)
@@ -273,7 +326,7 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model)
 
 //////////////////////////////////////////////////
 Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model,
-    bool _createCanonicalLink, bool _staticParent)
+                                        bool _staticParent)
 {
   // Entity
   Entity modelEntity = this->dataPtr->ecm->CreateEntity();
@@ -298,7 +351,8 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model,
   // the parent frame until we get frames working.
 
   // Links
-  bool canonicalLinkCreated = false;
+  const auto *canonicalLink = _model->CanonicalLink();
+
   for (uint64_t linkIndex = 0; linkIndex < _model->LinkCount();
       ++linkIndex)
   {
@@ -307,13 +361,10 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model,
 
     this->SetParent(linkEntity, modelEntity);
 
-    if (_createCanonicalLink &&
-        ((_model->CanonicalLinkName().empty() && linkIndex == 0) ||
-        (link == _model->CanonicalLink())))
+    if (canonicalLink == link)
     {
       this->dataPtr->ecm->CreateComponent(linkEntity,
           components::CanonicalLink());
-      canonicalLinkCreated = true;
     }
 
     // Set wind mode if the link didn't override it
@@ -339,17 +390,34 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Model *_model,
       ++modelIndex)
   {
     auto nestedModel = _model->ModelByIndex(modelIndex);
-
-    // Create nested model. Make sure to only create canonical link component
-    // in the nested model if a canonical link has not been created in this
-    // model yet. Also override static propery of the nested model if this model
-    //  is static
-    auto nestedModelEntity = this->CreateEntities(nestedModel,
-        (_createCanonicalLink && !canonicalLinkCreated), isStatic);
+    auto nestedModelEntity = this->CreateEntities(nestedModel, isStatic);
 
     this->SetParent(nestedModelEntity, modelEntity);
   }
 
+  // Find canonical link
+  const auto canonicalLinkPair = _model->CanonicalLinkAndRelativeName();
+  if (canonicalLinkPair.first)
+  {
+    Entity canonicalLinkEntity = FindDescendentLinkEntityByName(
+        canonicalLinkPair.second, modelEntity, *this->dataPtr->ecm);
+    if (kNullEntity != canonicalLinkEntity)
+    {
+      this->dataPtr->ecm->CreateComponent(
+          modelEntity, components::ModelCanonicalLink(canonicalLinkEntity));
+    }
+    else
+    {
+      ignerr << "Could not find the canonical link entity for "
+             << canonicalLinkPair.second << "\n";
+    }
+  }
+  else
+  {
+    ignerr << "Could not resolve the canonical link for " << _model->Name()
+           << "\n";
+  }
+
   // Store the model's SDF DOM to be used when saving the world to file
   this->dataPtr->ecm->CreateComponent(
       modelEntity, components::ModelSdf(*_model));
@@ -376,6 +444,10 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Actor *_actor)
   this->dataPtr->ecm->CreateComponent(actorEntity,
       components::Name(_actor->Name()));
 
+  // Actor plugins
+  this->dataPtr->eventManager->Emit<events::LoadPlugins>(actorEntity,
+      _actor->Element());
+
   return actorEntity;
 }
 
@@ -394,6 +466,9 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Light *_light)
   this->dataPtr->ecm->CreateComponent(lightEntity,
       components::Name(_light->Name()));
 
+  this->dataPtr->ecm->CreateComponent(lightEntity,
+    components::LightType(convert(_light->Type())));
+
   return lightEntity;
 }
 
@@ -480,14 +555,30 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Joint *_joint)
 
   if (_joint->Axis(0))
   {
+    auto resolvedAxis = ResolveJointAxis(*_joint->Axis(0));
+    if (!resolvedAxis)
+    {
+      ignerr << "Failed to resolve joint axis 0 for joint '" << _joint->Name()
+             << "'" << std::endl;
+      return kNullEntity;
+    }
+
     this->dataPtr->ecm->CreateComponent(jointEntity,
-        components::JointAxis(*_joint->Axis(0)));
+        components::JointAxis(std::move(*resolvedAxis)));
   }
 
   if (_joint->Axis(1))
   {
+    auto resolvedAxis = ResolveJointAxis(*_joint->Axis(1));
+    if (!resolvedAxis)
+    {
+      ignerr << "Failed to resolve joint axis 1 for joint '" << _joint->Name()
+             << "'" << std::endl;
+      return kNullEntity;
+    }
+
     this->dataPtr->ecm->CreateComponent(jointEntity,
-        components::JointAxis2(*_joint->Axis(1)));
+        components::JointAxis2(std::move(*resolvedAxis)));
   }
 
   this->dataPtr->ecm->CreateComponent(jointEntity,
@@ -496,10 +587,39 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Joint *_joint)
       components::Name(_joint->Name()));
   this->dataPtr->ecm->CreateComponent(jointEntity ,
       components::ThreadPitch(_joint->ThreadPitch()));
-  this->dataPtr->ecm->CreateComponent(jointEntity,
-      components::ParentLinkName(_joint->ParentLinkName()));
-  this->dataPtr->ecm->CreateComponent(jointEntity,
-      components::ChildLinkName(_joint->ChildLinkName()));
+
+  std::string resolvedParentLinkName;
+  const auto resolveParentErrors =
+    _joint->ResolveParentLink(resolvedParentLinkName);
+  if (!resolveParentErrors.empty())
+  {
+    ignerr << "Failed to resolve parent link for joint '" << _joint->Name()
+           << "' with parent name '" << _joint->ParentLinkName() << "'"
+           << std::endl;
+
+    return kNullEntity;
+  }
+  this->dataPtr->ecm->CreateComponent(
+      jointEntity, components::ParentLinkName(resolvedParentLinkName));
+
+  std::string resolvedChildLinkName;
+  const auto resolveChildErrors =
+    _joint->ResolveChildLink(resolvedChildLinkName);
+  if (!resolveChildErrors.empty())
+  {
+    ignerr << "Failed to resolve child link for joint '" << _joint->Name()
+           << "' with child name '" << _joint->ChildLinkName() << "'"
+           << std::endl;
+    for (const auto &error : resolveChildErrors)
+    {
+      ignerr << error << std::endl;
+    }
+
+    return kNullEntity;
+  }
+
+  this->dataPtr->ecm->CreateComponent(
+      jointEntity, components::ChildLinkName(resolvedChildLinkName));
 
   return jointEntity;
 }
@@ -522,6 +642,8 @@ Entity SdfEntityCreator::CreateEntities(const sdf::Visual *_visual)
       components::CastShadows(_visual->CastShadows()));
   this->dataPtr->ecm->CreateComponent(visualEntity,
       components::Transparency(_visual->Transparency()));
+  this->dataPtr->ecm->CreateComponent(visualEntity,
+      components::VisibilityFlags(_visual->VisibilityFlags()));
 
   if (_visual->HasLaserRetro())
   {
