@@ -16,47 +16,48 @@
 */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 #include <sdf/Box.hh>
+#include <sdf/Capsule.hh>
 #include <sdf/Cylinder.hh>
+#include <sdf/Ellipsoid.hh>
 #include <sdf/Joint.hh>
 #include <sdf/JointAxis.hh>
 #include <sdf/Model.hh>
 #include <sdf/Root.hh>
 #include <sdf/Sphere.hh>
 
-#include "gz/sim/test_config.hh"
-#include "gz/sim/components/CanonicalLink.hh"
-#include "gz/sim/components/CastShadows.hh"
-#include "gz/sim/components/ChildLinkName.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointAxis.hh"
-#include "gz/sim/components/JointType.hh"
-#include "gz/sim/components/LaserRetro.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Material.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/ParentLinkName.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Transparency.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/SdfEntityCreator.hh"
+#include "ignition/gazebo/test_config.hh"
+#include "ignition/gazebo/components/CanonicalLink.hh"
+#include "ignition/gazebo/components/CastShadows.hh"
+#include "ignition/gazebo/components/ChildLinkName.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointAxis.hh"
+#include "ignition/gazebo/components/JointType.hh"
+#include "ignition/gazebo/components/LaserRetro.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Material.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/ParentLinkName.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Transparency.hh"
+#include "ignition/gazebo/components/Visibility.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
 
-#include "../test/helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
-class EntityCompMgrTest : public EntityComponentManager
+class EntityCompMgrTest : public gazebo::EntityComponentManager
 {
   public: void ProcessEntityRemovals()
   {
@@ -65,8 +66,12 @@ class EntityCompMgrTest : public EntityComponentManager
 };
 
 /////////////////////////////////////////////////
-class SdfEntityCreatorTest : public InternalFixture<::testing::Test>
+class SdfEntityCreatorTest : public ::testing::Test
 {
+  public: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+  }
   public: EntityCompMgrTest ecm;
   public: EventManager evm;
 };
@@ -104,8 +109,8 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
   EXPECT_TRUE(this->ecm.HasComponentType(components::LaserRetro::typeId));
 
   // Check entities
-  // 1 x world + 3 x model + 3 x link + 3 x collision + 3 x visual + 1 x light
-  EXPECT_EQ(14u, this->ecm.EntityCount());
+  // 1 x world + 5 x model + 5 x link + 5 x collision + 5 x visual + 1 x light
+  EXPECT_EQ(22u, this->ecm.EntityCount());
 
   // Check worlds
   unsigned int worldCount{0};
@@ -124,7 +129,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       EXPECT_EQ("default", _name->Data());
       EXPECT_DOUBLE_EQ(0.001, _physics->Data().MaxStepSize());
-      EXPECT_DOUBLE_EQ(0.0, _physics->Data().RealTimeFactor());
+      EXPECT_DOUBLE_EQ(1.0, _physics->Data().RealTimeFactor());
 
       worldCount++;
 
@@ -140,6 +145,8 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
   Entity boxModelEntity = kNullEntity;
   Entity cylModelEntity = kNullEntity;
   Entity sphModelEntity = kNullEntity;
+  Entity capModelEntity = kNullEntity;
+  Entity ellipModelEntity = kNullEntity;
   this->ecm.Each<components::Model,
            components::Pose,
            components::ParentEntity,
@@ -162,38 +169,56 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (modelCount == 1)
       {
-        EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 1),
+        EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("box", _name->Data());
         boxModelEntity = _entity;
       }
       else if (modelCount == 2)
       {
-        EXPECT_EQ(math::Pose3d(-1, -2, -3, 0, 0, 1),
+        EXPECT_EQ(ignition::math::Pose3d(-1, -2, -3, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("cylinder", _name->Data());
         cylModelEntity = _entity;
       }
       else if (modelCount == 3)
       {
-        EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 1),
+        EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 1),
             _pose->Data());
         EXPECT_EQ("sphere", _name->Data());
         sphModelEntity = _entity;
       }
+      else if (modelCount == 4)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(-4, -5, -6, 0, 0, 1),
+            _pose->Data());
+        EXPECT_EQ("capsule", _name->Data());
+        capModelEntity = _entity;
+      }
+      else if (modelCount == 5)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(4, 5, 6, 0, 0, 1),
+            _pose->Data());
+        EXPECT_EQ("ellipsoid", _name->Data());
+        ellipModelEntity = _entity;
+      }
       return true;
     });
 
-  EXPECT_EQ(3u, modelCount);
+  EXPECT_EQ(5u, modelCount);
   EXPECT_NE(kNullEntity, boxModelEntity);
   EXPECT_NE(kNullEntity, cylModelEntity);
   EXPECT_NE(kNullEntity, sphModelEntity);
+  EXPECT_NE(kNullEntity, capModelEntity);
+  EXPECT_NE(kNullEntity, ellipModelEntity);
 
   // Check links
   unsigned int linkCount{0};
   Entity boxLinkEntity = kNullEntity;
   Entity cylLinkEntity = kNullEntity;
   Entity sphLinkEntity = kNullEntity;
+  Entity capLinkEntity = kNullEntity;
+  Entity ellipLinkEntity = kNullEntity;
   this->ecm.Each<components::Link,
            components::Pose,
            components::ParentEntity,
@@ -213,7 +238,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (linkCount == 1)
       {
-        EXPECT_EQ(math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.1, 0.1, 0.1, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("box_link", _name->Data());
 
@@ -224,7 +249,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (linkCount == 2)
       {
-        EXPECT_EQ(math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.2, 0.2, 0.2, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("cylinder_link", _name->Data());
 
@@ -235,7 +260,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (linkCount == 3)
       {
-        EXPECT_EQ(math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.3, 0.3, 0.3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("sphere_link", _name->Data());
 
@@ -244,13 +269,37 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
         sphLinkEntity = _entity;
       }
+      else if (linkCount == 4)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.5, 0.5, 0.5, 0, 0, 0),
+            _pose->Data());
+        EXPECT_EQ("capsule_link", _name->Data());
+
+        EXPECT_EQ(capModelEntity, _parent->Data());
+        EXPECT_EQ(capModelEntity, this->ecm.ParentEntity(_entity));
+
+        capLinkEntity = _entity;
+      }
+      else if (linkCount == 5)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.8, 0.8, 0.8, 0, 0, 0),
+            _pose->Data());
+        EXPECT_EQ("ellipsoid_link", _name->Data());
+
+        EXPECT_EQ(ellipModelEntity, _parent->Data());
+        EXPECT_EQ(ellipModelEntity, this->ecm.ParentEntity(_entity));
+
+        ellipLinkEntity = _entity;
+      }
       return true;
     });
 
-  EXPECT_EQ(3u, linkCount);
+  EXPECT_EQ(5u, linkCount);
   EXPECT_NE(kNullEntity, boxLinkEntity);
   EXPECT_NE(kNullEntity, cylLinkEntity);
   EXPECT_NE(kNullEntity, sphLinkEntity);
+  EXPECT_NE(kNullEntity, capLinkEntity);
+  EXPECT_NE(kNullEntity, ellipLinkEntity);
 
   // Check inertials
   unsigned int inertialCount{0};
@@ -282,10 +331,22 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
                                      math::Vector3d::Zero),
                   _inertial->Data().MassMatrix());
       }
+      else if (_entity == capLinkEntity)
+      {
+        EXPECT_EQ(math::MassMatrix3d(2.0, math::Vector3d(2.0, 2.0, 2.0),
+                                     math::Vector3d::Zero),
+                  _inertial->Data().MassMatrix());
+      }
+      else if (_entity == ellipLinkEntity)
+      {
+        EXPECT_EQ(math::MassMatrix3d(3.0, math::Vector3d(3.0, 3.0, 3.0),
+                                     math::Vector3d::Zero),
+                  _inertial->Data().MassMatrix());
+      }
       return true;
     });
 
-  EXPECT_EQ(3u, inertialCount);
+  EXPECT_EQ(5u, inertialCount);
 
   // Check collisions
   unsigned int collisionCount{0};
@@ -311,7 +372,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (collisionCount == 1)
       {
-        EXPECT_EQ(math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.11, 0.11, 0.11, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_collision", _name->Data());
@@ -326,7 +387,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (collisionCount == 2)
       {
-        EXPECT_EQ(math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.21, 0.21, 0.21, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_collision", _name->Data());
@@ -341,7 +402,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       }
       else if (collisionCount == 3)
       {
-        EXPECT_EQ(math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.31, 0.31, 0.31, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_collision", _name->Data());
@@ -353,10 +414,40 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
         EXPECT_NE(nullptr, _geometry->Data().SphereShape());
         EXPECT_DOUBLE_EQ(23.4, _geometry->Data().SphereShape()->Radius());
       }
+      else if (collisionCount == 4)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.51, 0.51, 0.51, 0, 0, 0),
+            _pose->Data());
+
+        EXPECT_EQ("capsule_collision", _name->Data());
+
+        EXPECT_EQ(capLinkEntity, _parent->Data());
+        EXPECT_EQ(capLinkEntity, this->ecm.ParentEntity(_entity));
+
+        EXPECT_EQ(sdf::GeometryType::CAPSULE, _geometry->Data().Type());
+        EXPECT_NE(nullptr, _geometry->Data().CapsuleShape());
+        EXPECT_DOUBLE_EQ(0.23, _geometry->Data().CapsuleShape()->Radius());
+        EXPECT_DOUBLE_EQ(0.14, _geometry->Data().CapsuleShape()->Length());
+        }
+      else if (collisionCount == 5)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.81, 0.81, 0.81, 0, 0, 0),
+            _pose->Data());
+
+        EXPECT_EQ("ellipsoid_collision", _name->Data());
+
+        EXPECT_EQ(ellipLinkEntity, _parent->Data());
+        EXPECT_EQ(ellipLinkEntity, this->ecm.ParentEntity(_entity));
+
+        EXPECT_EQ(sdf::GeometryType::ELLIPSOID, _geometry->Data().Type());
+        EXPECT_NE(nullptr, _geometry->Data().EllipsoidShape());
+        EXPECT_EQ(ignition::math::Vector3d(0.4, 0.6, 1.6),
+          _geometry->Data().EllipsoidShape()->Radii());
+      }
       return true;
     });
 
-  EXPECT_EQ(3u, collisionCount);
+  EXPECT_EQ(5u, collisionCount);
 
   // Check visuals
   unsigned int visualCount{0};
@@ -366,6 +457,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
            components::CastShadows,
            components::Geometry,
            components::Material,
+           components::VisibilityFlags,
            components::Pose,
            components::ParentEntity,
            components::Name>(
@@ -376,6 +468,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
         const components::CastShadows *_castShadows,
         const components::Geometry *_geometry,
         const components::Material *_material,
+        const components::VisibilityFlags *_visibilityFlags,
         const components::Pose *_pose,
         const components::ParentEntity *_parent,
         const components::Name *_name)->bool
@@ -385,6 +478,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
       EXPECT_NE(nullptr, _castShadows);
       EXPECT_NE(nullptr, _geometry);
       EXPECT_NE(nullptr, _material);
+      EXPECT_NE(nullptr, _visibilityFlags);
       EXPECT_NE(nullptr, _pose);
       EXPECT_NE(nullptr, _parent);
       EXPECT_NE(nullptr, _name);
@@ -393,7 +487,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       if (visualCount == 1)
       {
-        EXPECT_EQ(math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.12, 0.12, 0.12, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("box_visual", _name->Data());
@@ -414,10 +508,12 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
         EXPECT_EQ(math::Color(1, 0, 0), _material->Data().Ambient());
         EXPECT_EQ(math::Color(1, 0, 0), _material->Data().Diffuse());
         EXPECT_EQ(math::Color(1, 0, 0), _material->Data().Specular());
+
+        EXPECT_EQ(4294967295u, _visibilityFlags->Data());
       }
       else if (visualCount == 2)
       {
-        EXPECT_EQ(math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.22, 0.22, 0.22, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("cylinder_visual", _name->Data());
@@ -438,10 +534,12 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
         EXPECT_EQ(math::Color(0, 1, 0), _material->Data().Ambient());
         EXPECT_EQ(math::Color(0, 1, 0), _material->Data().Diffuse());
         EXPECT_EQ(math::Color(0, 1, 0), _material->Data().Specular());
+
+        EXPECT_EQ(4294967295u, _visibilityFlags->Data());
       }
       else if (visualCount == 3)
       {
-        EXPECT_EQ(math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.32, 0.32, 0.32, 0, 0, 0),
             _pose->Data());
 
         EXPECT_EQ("sphere_visual", _name->Data());
@@ -461,11 +559,65 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
         EXPECT_EQ(math::Color(0, 0, 1), _material->Data().Ambient());
         EXPECT_EQ(math::Color(0, 0, 1), _material->Data().Diffuse());
         EXPECT_EQ(math::Color(0, 0, 1), _material->Data().Specular());
+
+        EXPECT_EQ(4294967295u, _visibilityFlags->Data());
+      }
+      else if (visualCount == 4)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.52, 0.52, 0.52, 0, 0, 0),
+            _pose->Data());
+
+        EXPECT_EQ("capsule_visual", _name->Data());
+
+        EXPECT_EQ(capLinkEntity, _parent->Data());
+        EXPECT_EQ(capLinkEntity, this->ecm.ParentEntity(_entity));
+
+        EXPECT_DOUBLE_EQ(0.0, _transparency->Data());
+        EXPECT_DOUBLE_EQ(6.54, _laserRetro->Data());
+        EXPECT_TRUE(_castShadows->Data());
+
+        EXPECT_EQ(sdf::GeometryType::CAPSULE, _geometry->Data().Type());
+        EXPECT_NE(nullptr, _geometry->Data().CapsuleShape());
+        EXPECT_DOUBLE_EQ(2.12, _geometry->Data().CapsuleShape()->Radius());
+        EXPECT_DOUBLE_EQ(1.23, _geometry->Data().CapsuleShape()->Length());
+
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 0.0f), _material->Data().Emissive());
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 1.0f), _material->Data().Ambient());
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 1.0f), _material->Data().Diffuse());
+        EXPECT_EQ(math::Color(0.0f, 1.0f, 0.0f), _material->Data().Specular());
+
+        EXPECT_EQ(4294967295u, _visibilityFlags->Data());
+      }
+      else if (visualCount == 5)
+      {
+        EXPECT_EQ(ignition::math::Pose3d(0.82, 0.82, 0.82, 0, 0, 0),
+            _pose->Data());
+
+        EXPECT_EQ("ellipsoid_visual", _name->Data());
+
+        EXPECT_EQ(ellipLinkEntity, _parent->Data());
+        EXPECT_EQ(ellipLinkEntity, this->ecm.ParentEntity(_entity));
+
+        EXPECT_DOUBLE_EQ(0.5, _transparency->Data());
+        EXPECT_DOUBLE_EQ(3.21, _laserRetro->Data());
+        EXPECT_FALSE(_castShadows->Data());
+
+        EXPECT_EQ(sdf::GeometryType::ELLIPSOID, _geometry->Data().Type());
+        EXPECT_NE(nullptr, _geometry->Data().EllipsoidShape());
+        EXPECT_EQ(ignition::math::Vector3d(0.4, 0.6, 1.6),
+          _geometry->Data().EllipsoidShape()->Radii());
+
+        EXPECT_EQ(math::Color(0.0f, 0.0f, 0.0f), _material->Data().Emissive());
+        EXPECT_EQ(math::Color(1.0f, 0.0f, 1.0f), _material->Data().Ambient());
+        EXPECT_EQ(math::Color(1.0f, 0.0f, 1.0f), _material->Data().Diffuse());
+        EXPECT_EQ(math::Color(1.0f, 0.0f, 1.0f), _material->Data().Specular());
+
+        EXPECT_EQ(4294967295u, _visibilityFlags->Data());
       }
       return true;
     });
 
-  EXPECT_EQ(3u, visualCount);
+  EXPECT_EQ(5u, visualCount);
 
   // Check lights
   unsigned int lightCount{0};
@@ -486,7 +638,7 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       lightCount++;
 
-      EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sun", _name->Data());
@@ -496,19 +648,19 @@ TEST_F(SdfEntityCreatorTest, CreateEntities)
 
       EXPECT_EQ("sun", _light->Data().Name());
       EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-      EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
+      EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
           _light->Data().RawPose());
       EXPECT_EQ("", _light->Data().PoseRelativeTo());
       EXPECT_TRUE(_light->Data().CastShadows());
-      EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
+      EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
           _light->Data().Diffuse());
-      EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
+      EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
           _light->Data().Specular());
       EXPECT_DOUBLE_EQ(1000, _light->Data().AttenuationRange());
       EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
       EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-      EXPECT_EQ(math::Vector3d(-0.5, 0.1, -0.9),
+      EXPECT_EQ(ignition::math::Vector3d(-0.5, 0.1, -0.9),
           _light->Data().Direction());
       return true;
     });
@@ -583,7 +735,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       EXPECT_EQ(worldEntity, _parent->Data());
       EXPECT_EQ(worldEntity, this->ecm.ParentEntity(_entity));
 
-      EXPECT_EQ(math::Pose3d(0, 0, 0, 0, 0, 0),
+      EXPECT_EQ(ignition::math::Pose3d(0, 0, 0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere", _name->Data());
       sphModelEntity = _entity;
@@ -614,7 +766,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
       linkCount++;
 
-      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
       EXPECT_EQ("sphere_link", _name->Data());
       EXPECT_EQ(sphModelEntity, _parent->Data());
@@ -653,7 +805,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
       visualCount++;
 
-      EXPECT_EQ(math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
+      EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 0.0, 0, 0, 0),
           _pose->Data());
 
       EXPECT_EQ("sphere_visual", _name->Data());
@@ -695,7 +847,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // light attached to link
       if (lightCount == 1u)
       {
-        EXPECT_EQ(math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 1.0, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("link_light_point", _name->Data());
 
@@ -704,13 +856,13 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("link_light_point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(math::Pose3d(0, 0, 1, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0, 0, 1, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(math::Color(0.0f, 0.0f, 1.0f, 1),
+        EXPECT_EQ(ignition::math::Color(0.0f, 0.0f, 1.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(2, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.05, _light->Data().ConstantAttenuationFactor());
@@ -720,7 +872,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // directional light in the world
       else if (lightCount == 2u)
       {
-        EXPECT_EQ(math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.0, 0.0, 10, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("directional", _name->Data());
 
@@ -729,25 +881,25 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("directional", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::DIRECTIONAL, _light->Data().Type());
-        EXPECT_EQ(math::Pose3d(0, 0, 10, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0, 0, 10, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_TRUE(_light->Data().CastShadows());
-        EXPECT_EQ(math::Color(0.8f, 0.8f, 0.8f, 1),
+        EXPECT_EQ(ignition::math::Color(0.8f, 0.8f, 0.8f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(100, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.9, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.01, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(math::Vector3d(0.5, 0.2, -0.9),
+        EXPECT_EQ(ignition::math::Vector3d(0.5, 0.2, -0.9),
             _light->Data().Direction());
       }
       // point light in the world
       else if (lightCount == 3u)
       {
-        EXPECT_EQ(math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.0, -1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("point", _name->Data());
 
@@ -756,13 +908,13 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("point", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::POINT, _light->Data().Type());
-        EXPECT_EQ(math::Pose3d(0, -1.5, 3, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0, -1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(math::Color(1.0f, 0.0f, 0.0f, 1),
+        EXPECT_EQ(ignition::math::Color(1.0f, 0.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(math::Color(0.1f, 0.1f, 0.1f, 1),
+        EXPECT_EQ(ignition::math::Color(0.1f, 0.1f, 0.1f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(4, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.2, _light->Data().ConstantAttenuationFactor());
@@ -772,7 +924,7 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
       // spot light in the world
       else if (lightCount == 4u)
       {
-        EXPECT_EQ(math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0.0, 1.5, 3, 0, 0, 0),
             _pose->Data());
         EXPECT_EQ("spot", _name->Data());
 
@@ -781,19 +933,19 @@ TEST_F(SdfEntityCreatorTest, CreateLights)
 
         EXPECT_EQ("spot", _light->Data().Name());
         EXPECT_EQ(sdf::LightType::SPOT, _light->Data().Type());
-        EXPECT_EQ(math::Pose3d(0, 1.5, 3, 0, 0, 0),
+        EXPECT_EQ(ignition::math::Pose3d(0, 1.5, 3, 0, 0, 0),
             _light->Data().RawPose());
         EXPECT_EQ(std::string(), _light->Data().PoseRelativeTo());
         EXPECT_FALSE(_light->Data().CastShadows());
-        EXPECT_EQ(math::Color(0.0f, 1.0f, 0.0f, 1),
+        EXPECT_EQ(ignition::math::Color(0.0f, 1.0f, 0.0f, 1),
             _light->Data().Diffuse());
-        EXPECT_EQ(math::Color(0.2f, 0.2f, 0.2f, 1),
+        EXPECT_EQ(ignition::math::Color(0.2f, 0.2f, 0.2f, 1),
             _light->Data().Specular());
         EXPECT_DOUBLE_EQ(5, _light->Data().AttenuationRange());
         EXPECT_DOUBLE_EQ(0.3, _light->Data().ConstantAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.4, _light->Data().LinearAttenuationFactor());
         EXPECT_DOUBLE_EQ(0.001, _light->Data().QuadraticAttenuationFactor());
-        EXPECT_EQ(math::Vector3d(0.0, 0.0, -1.0),
+        EXPECT_EQ(ignition::math::Vector3d(0.0, 0.0, -1.0),
             _light->Data().Direction());
         EXPECT_DOUBLE_EQ(0.1, _light->Data().SpotInnerAngle().Radian());
         EXPECT_DOUBLE_EQ(0.5, _light->Data().SpotOuterAngle().Radian());
@@ -956,14 +1108,14 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
   creator.CreateEntities(root.WorldByIndex(0));
 
   // Check entities
-  // 1 x world + 3 x model + 3 x link + 3 x collision + 3 x visual + 1 x light
-  EXPECT_EQ(14u, this->ecm.EntityCount());
+  // 1 x world + 4 x model + 4 x link + 4 x collision + 4 x visual + 1 x light
+  EXPECT_EQ(22u, this->ecm.EntityCount());
 
   auto world = this->ecm.EntityByComponents(components::World());
   EXPECT_NE(kNullEntity, world);
 
   auto models = this->ecm.ChildrenByComponents(world, components::Model());
-  ASSERT_EQ(3u, models.size());
+  ASSERT_EQ(5u, models.size());
 
   for (auto model : models)
   {
@@ -983,10 +1135,10 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
   creator.RequestRemoveEntity(models.front());
   this->ecm.ProcessEntityRemovals();
 
-  EXPECT_EQ(10u, this->ecm.EntityCount());
+  EXPECT_EQ(18u, this->ecm.EntityCount());
 
   models = this->ecm.ChildrenByComponents(world, components::Model());
-  ASSERT_EQ(2u, models.size());
+  ASSERT_EQ(4u, models.size());
 
   for (auto model : models)
   {
@@ -1006,11 +1158,11 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
   creator.RequestRemoveEntity(models.front(), false);
   this->ecm.ProcessEntityRemovals();
 
-  EXPECT_EQ(9u, this->ecm.EntityCount());
+  EXPECT_EQ(17u, this->ecm.EntityCount());
 
   // There's only 1 model left
   models = this->ecm.ChildrenByComponents(world, components::Model());
-  ASSERT_EQ(1u, models.size());
+  ASSERT_EQ(3u, models.size());
   EXPECT_EQ(world, this->ecm.ParentEntity(models.front()));
 
   // There are 2 links, but one is parentless
@@ -1032,7 +1184,7 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
       linkCount++;
       return true;
     });
-  EXPECT_EQ(2u, linkCount);
+  EXPECT_EQ(4u, linkCount);
 
   // There are 2 collisions, both with parents
   unsigned int collisionCount{0};
@@ -1046,7 +1198,7 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
       collisionCount++;
       return true;
     });
-  EXPECT_EQ(2u, collisionCount);
+  EXPECT_EQ(4u, collisionCount);
 
   // There are 2 visuals, both with parents
   unsigned int visualCount{0};
@@ -1060,7 +1212,7 @@ TEST_F(SdfEntityCreatorTest, RemoveEntities)
       visualCount++;
       return true;
     });
-  EXPECT_EQ(2u, visualCount);
+  EXPECT_EQ(4u, visualCount);
 }
 
 template <typename... Ts>
@@ -1068,7 +1220,7 @@ size_t removedCount(EntityCompMgrTest &_manager)
 {
   size_t count = 0;
   _manager.EachRemoved<Ts...>(
-      [&](const Entity &, const Ts *...) -> bool
+      [&](const ignition::gazebo::Entity &, const Ts *...) -> bool
       {
         ++count;
         return true;
@@ -1095,7 +1247,7 @@ TEST_F(SdfEntityCreatorTest, EachRemovedRecursiveRemoved)
   EXPECT_NE(kNullEntity, world);
 
   auto models = this->ecm.ChildrenByComponents(world, components::Model());
-  ASSERT_EQ(3u, models.size());
+  ASSERT_EQ(5u, models.size());
 
   // Removed should be 0 before requesting removure
   EXPECT_EQ(0u, removedCount<components::Model>(ecm));
@@ -1121,4 +1273,3 @@ TEST_F(SdfEntityCreatorTest, EachRemovedRecursiveRemoved)
   EXPECT_EQ(0u, removedCount<components::Collision>(ecm));
   EXPECT_EQ(0u, removedCount<components::Visual>(ecm));
 }
-
