@@ -18,34 +18,33 @@
 #include <gtest/gtest.h>
 #include <tinyxml2.h>
 
-#include <gz/common/Console.hh>
-#include <gz/fuel_tools/ClientConfig.hh>
-#include <gz/fuel_tools/Interface.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/fuel_tools/ClientConfig.hh>
+#include <ignition/fuel_tools/Interface.hh>
 #include <sdf/Model.hh>
 #include <sdf/Root.hh>
 #include <sdf/sdf.hh>
 
-#include "gz/sim/EventManager.hh"
-#include "gz/sim/SdfEntityCreator.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/EventManager.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "helpers/UniqueTestDirectoryEnv.hh"
-#include "helpers/EnvTestFixture.hh"
 
 #include "SdfGenerator.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
 /// \breif Checks if elemA is a subset of elemB
@@ -148,11 +147,11 @@ TEST(CompareElements, CompareWithDuplicateElements)
 }
 
 /////////////////////////////////////////////////
-class ElementUpdateFixture : public InternalFixture<::testing::Test>
+class ElementUpdateFixture : public ::testing::Test
 {
   public: void SetUp() override
   {
-    InternalFixture::SetUp();
+    ignition::common::Console::SetVerbosity(4);
 
     fuel_tools::ClientConfig config;
     config.SetCacheLocation(test::UniqueTestDirectoryEnv::Path());
@@ -252,7 +251,9 @@ TEST_F(ModelElementFixture, ModelsInline)
 {
   this->LoadWorld("test/worlds/shapes.sdf");
   this->TestModel("box");
+  this->TestModel("capsule");
   this->TestModel("cylinder");
+  this->TestModel("ellipsoid");
   this->TestModel("sphere");
 }
 
@@ -544,17 +545,17 @@ TEST_F(ElementUpdateFixture, WorldWithModelsIncludedNotExpanded)
 TEST_F(ElementUpdateFixture, WorldWithModelsIncludedWithInvalidUris)
 {
   const std::string goodUri =
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack/3";
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/2/";
 
   // These are URIs that are potentially problematic.
   const std::vector<std::string> fuelUris = {
       // Thes following two URIs are valid, but have a trailing '/'
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack/",
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack/3/",
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/",
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/2/",
       // Thes following two URIs are invalid, and will not be saved
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack/"
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/"
       "notInt",
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack/"
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack/"
       "notInt/",
   };
 
@@ -609,7 +610,7 @@ TEST_F(ElementUpdateFixture, WorldWithModelsIncludedWithInvalidUris)
 TEST_F(ElementUpdateFixture, WorldWithModelsIncludedWithNonFuelUris)
 {
   const std::vector<std::string> includeUris = {
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/Backpack",
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/Backpack",
       std::string("file://") + PROJECT_SOURCE_PATH +
           "/test/worlds/models/sphere"};
 
