@@ -15,21 +15,23 @@
  *
 */
 
-#include <gz/common/SystemPaths.hh>
-#include <gz/fuel_tools/Interface.hh>
-#include <gz/fuel_tools/ClientConfig.hh>
+#include <numeric>
+
+#include <ignition/common/SystemPaths.hh>
+#include <ignition/fuel_tools/Interface.hh>
+#include <ignition/fuel_tools/ClientConfig.hh>
 #include <sdf/Root.hh>
 #include <sdf/Error.hh>
 
-#include "gz/sim/config.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/Util.hh"
 
 #include "ServerPrivate.hh"
 #include "SimulationRunner.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 //////////////////////////////////////////////////
 // Getting the first .sdf file in the path
@@ -182,14 +184,6 @@ Server::Server(const ServerConfig &_config)
     return;
   }
 
-  if (this->dataPtr->sdfRoot.WorldCount() == 0)
-  {
-    ignerr << "SDF file doesn't contain a world. " <<
-      "If you wish to spawn a model, use the ResourceSpawner GUI plugin " <<
-      "or the 'world/<world_name>/create' service.\n";
-    return;
-  }
-
   // Add record plugin
   if (_config.UseLogRecord())
   {
@@ -362,26 +356,6 @@ std::optional<bool> Server::AddSystem(const SystemPluginPtr &_system,
   return std::nullopt;
 }
 
-//////////////////////////////////////////////////
-std::optional<bool> Server::AddSystem(const std::shared_ptr<System> &_system,
-                                      const unsigned int _worldIndex)
-{
-  std::lock_guard<std::mutex> lock(this->dataPtr->runMutex);
-  if (this->dataPtr->running)
-  {
-    ignerr << "Cannot add system while the server is runnnng.\n";
-    return false;
-  }
-
-  if (_worldIndex < this->dataPtr->simRunners.size())
-  {
-    this->dataPtr->simRunners[_worldIndex]->AddSystem(_system);
-    return true;
-  }
-
-  return std::nullopt;
-}
-
 //////////////////////////////////////////////////
 bool Server::HasEntity(const std::string &_name,
                        const unsigned int _worldIndex) const
