@@ -14,21 +14,21 @@
  * limitations under the License.
  *
 */
-#include "gz/sim/ServerConfig.hh"
+#include "ignition/gazebo/ServerConfig.hh"
 
 #include <tinyxml2.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Util.hh>
-#include <gz/fuel_tools/FuelClient.hh>
-#include <gz/fuel_tools/Result.hh>
-#include <gz/math/Rand.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/fuel_tools/FuelClient.hh>
+#include <ignition/fuel_tools/Result.hh>
+#include <ignition/math/Rand.hh>
 
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/Util.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Private data for PluginInfoConfig.
 class ignition::gazebo::ServerConfig::PluginInfoPrivate
@@ -270,7 +270,7 @@ class ignition::gazebo::ServerConfigPrivate
   public: std::string logRecordCompressPath = "";
 
   /// \brief Path to where simulation resources, such as models downloaded
-  /// from fuel.gazebosim.org, should be stored.
+  /// from fuel.ignitionrobotics.org, should be stored.
   public: std::string resourceCache = "";
 
   /// \brief File containing physics engine plugin. If empty, DART will be used.
@@ -499,7 +499,7 @@ unsigned int ServerConfig::Seed() const
 void ServerConfig::SetSeed(unsigned int _seed)
 {
   this->dataPtr->seed = _seed;
-  math::Rand::Seed(_seed);
+  ignition::math::Rand::Seed(_seed);
 }
 
 /////////////////////////////////////////////////
@@ -562,7 +562,7 @@ ServerConfig::LogPlaybackPlugin() const
 {
   auto entityName = "*";
   auto entityType = "world";
-  auto pluginName = "gz::sim::systems::LogPlayback";
+  auto pluginName = "ignition::gazebo::systems::LogPlayback";
   auto pluginFilename = "ignition-gazebo-log-system";
 
   sdf::ElementPtr playbackElem;
@@ -572,9 +572,9 @@ ServerConfig::LogPlaybackPlugin() const
   if (!this->LogPlaybackPath().empty())
   {
     sdf::ElementPtr pathElem = std::make_shared<sdf::Element>();
-    pathElem->SetName("path");
+    pathElem->SetName("playback_path");
     playbackElem->AddElementDescription(pathElem);
-    pathElem = playbackElem->GetElement("path");
+    pathElem = playbackElem->GetElement("playback_path");
     pathElem->AddValue("string", "", false, "");
     pathElem->Set<std::string>(this->LogPlaybackPath());
   }
@@ -592,21 +592,22 @@ ServerConfig::LogRecordPlugin() const
 {
   auto entityName = "*";
   auto entityType = "world";
-  auto pluginName = "gz::sim::systems::LogRecord";
-  auto pluginFilename = std::string("ignition-gazebo") +
-    IGNITION_GAZEBO_MAJOR_VERSION_STR + "-log-system";
+  auto pluginName = "ignition::gazebo::systems::LogRecord";
+  auto pluginFilename = "ignition-gazebo-log-system";
 
   sdf::ElementPtr recordElem;
 
   recordElem = std::make_shared<sdf::Element>();
   recordElem->SetName("plugin");
 
+  igndbg << "Generating LogRecord SDF:" << std::endl;
+
   if (!this->LogRecordPath().empty())
   {
     sdf::ElementPtr pathElem = std::make_shared<sdf::Element>();
-    pathElem->SetName("path");
+    pathElem->SetName("record_path");
     recordElem->AddElementDescription(pathElem);
-    pathElem = recordElem->GetElement("path");
+    pathElem = recordElem->GetElement("record_path");
     pathElem->AddValue("string", "", false, "");
     pathElem->Set<std::string>(this->LogRecordPath());
   }
@@ -619,22 +620,24 @@ ServerConfig::LogRecordPlugin() const
   resourceElem->AddValue("bool", "false", false, "");
   resourceElem->Set<bool>(this->LogRecordResources() ? true : false);
 
-  // Set whether to compress
-  sdf::ElementPtr compressElem = std::make_shared<sdf::Element>();
-  compressElem->SetName("compress");
-  recordElem->AddElementDescription(compressElem);
-  compressElem = recordElem->GetElement("compress");
-  compressElem->AddValue("bool", "false", false, "");
-  compressElem->Set<bool>(this->LogRecordCompressPath().empty() ? false :
-    true);
+  if (!this->LogRecordCompressPath().empty())
+  {
+    // Set whether to compress
+    sdf::ElementPtr compressElem = std::make_shared<sdf::Element>();
+    compressElem->SetName("compress");
+    recordElem->AddElementDescription(compressElem);
+    compressElem = recordElem->GetElement("compress");
+    compressElem->AddValue("bool", "false", false, "");
+    compressElem->Set<bool>(true);
 
   // Set compress path
-  sdf::ElementPtr cPathElem = std::make_shared<sdf::Element>();
-  cPathElem->SetName("compress_path");
-  recordElem->AddElementDescription(cPathElem);
-  cPathElem = recordElem->GetElement("compress_path");
-  cPathElem->AddValue("string", "", false, "");
-  cPathElem->Set<std::string>(this->LogRecordCompressPath());
+    sdf::ElementPtr cPathElem = std::make_shared<sdf::Element>();
+    cPathElem->SetName("compress_path");
+    recordElem->AddElementDescription(cPathElem);
+    cPathElem = recordElem->GetElement("compress_path");
+    cPathElem->AddValue("string", "", false, "");
+    cPathElem->Set<std::string>(this->LogRecordCompressPath());
+  }
 
   // If record topics specified, add in SDF
   for (const std::string &topic : this->LogRecordTopics())
@@ -647,6 +650,8 @@ ServerConfig::LogRecordPlugin() const
     topicElem->Set<std::string>(topic);
   }
 
+  igndbg << recordElem->ToString("") << std::endl;
+
   return ServerConfig::PluginInfo(entityName,
       entityType,
       pluginFilename,
@@ -825,22 +830,21 @@ ignition::gazebo::loadPluginInfo(bool _isPlayback)
 
   // 1. Check contents of environment variable
   std::string envConfig;
-  bool configSet = common::env(kServerConfigPathEnv,
-                                         envConfig,
-                                         true);
+  bool configSet = ignition::common::env(gazebo::kServerConfigPathEnv,
+                                         envConfig);
 
   if (configSet)
   {
-    if (common::exists(envConfig))
+    if (ignition::common::exists(envConfig))
     {
       // Parse configuration stored in environment variable
-      ret = gz::sim::parsePluginsFromFile(envConfig);
+      ret = ignition::gazebo::parsePluginsFromFile(envConfig);
       if (ret.empty())
       {
         // This may be desired behavior, but warn just in case.
         // Some users may want to defer all loading until later
         // during runtime.
-        ignwarn << kServerConfigPathEnv
+        ignwarn << gazebo::kServerConfigPathEnv
                 << " set but no plugins found\n";
       }
       igndbg << "Loaded (" << ret.size() << ") plugins from file " <<
@@ -853,7 +857,7 @@ ignition::gazebo::loadPluginInfo(bool _isPlayback)
       // This may be desired behavior, but warn just in case.
       // Some users may want to defer all loading until late
       // during runtime.
-      ignwarn << kServerConfigPathEnv
+      ignwarn << gazebo::kServerConfigPathEnv
               << " set but no file found,"
               << " no plugins loaded\n";
       return ret;
@@ -870,28 +874,18 @@ ignition::gazebo::loadPluginInfo(bool _isPlayback)
     configFilename = "server.config";
   }
 
-  std::string defaultConfigDir;
-  common::env(IGN_HOMEDIR, defaultConfigDir);
-  defaultConfigDir = common::joinPaths(defaultConfigDir, ".ignition",
-    "gazebo");
+  std::string defaultConfig;
+  ignition::common::env(IGN_HOMEDIR, defaultConfig);
+  defaultConfig = ignition::common::joinPaths(defaultConfig, ".ignition",
+    "gazebo", configFilename);
 
-  auto defaultConfig = common::joinPaths(defaultConfigDir,
-      configFilename);
-
-  if (!common::exists(defaultConfig))
+  if (!ignition::common::exists(defaultConfig))
   {
-    auto installedConfig = common::joinPaths(
+    auto installedConfig = ignition::common::joinPaths(
         IGNITION_GAZEBO_SERVER_CONFIG_PATH,
         configFilename);
 
-    if (!common::createDirectories(defaultConfigDir))
-    {
-      ignerr << "Failed to create directory [" << defaultConfigDir
-             << "]." << std::endl;
-      return ret;
-    }
-
-    if (!common::exists(installedConfig))
+    if (!ignition::common::exists(installedConfig))
     {
       ignerr << "Failed to copy installed config [" << installedConfig
              << "] to default config [" << defaultConfig << "]."
@@ -899,7 +893,7 @@ ignition::gazebo::loadPluginInfo(bool _isPlayback)
              << std::endl;
       return ret;
     }
-    else if (!common::copyFile(installedConfig, defaultConfig))
+    else if (!ignition::common::copyFile(installedConfig, defaultConfig))
     {
       ignerr << "Failed to copy installed config [" << installedConfig
              << "] to default config [" << defaultConfig << "]."
@@ -914,7 +908,7 @@ ignition::gazebo::loadPluginInfo(bool _isPlayback)
     }
   }
 
-  ret = gz::sim::parsePluginsFromFile(defaultConfig);
+  ret = ignition::gazebo::parsePluginsFromFile(defaultConfig);
 
   if (ret.empty())
   {
