@@ -18,43 +18,36 @@
 #include <gtest/gtest.h>
 #include <csignal>
 #include <vector>
-#include <gz/common/Console.hh>
-#include <gz/common/StringUtils.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Rand.hh>
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/StringUtils.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Rand.hh>
+#include <ignition/transport/Node.hh>
 #include <sdf/Mesh.hh>
 
-#include "gz/sim/components/AxisAlignedBox.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/Entity.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/System.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/Types.hh"
-#include "gz/sim/Util.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/AxisAlignedBox.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/Entity.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/System.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/Types.hh"
+#include "ignition/gazebo/Util.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "plugins/MockSystem.hh"
 #include "../test/helpers/Relay.hh"
 #include "../test/helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace ignition::gazebo;
 using namespace std::chrono_literals;
 
-/////////////////////////////////////////////////
-class ServerFixture : public InternalFixture<::testing::TestWithParam<int>>
-{
-};
-
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, DefaultServerConfig)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
   EXPECT_TRUE(serverConfig.SdfFile().empty());
   EXPECT_TRUE(serverConfig.SdfString().empty());
   EXPECT_FALSE(serverConfig.UpdateRate());
@@ -64,7 +57,6 @@ TEST_P(ServerFixture, DefaultServerConfig)
   EXPECT_TRUE(serverConfig.NetworkRole().empty());
   EXPECT_FALSE(serverConfig.UseLogRecord());
   EXPECT_FALSE(serverConfig.LogRecordPath().empty());
-  EXPECT_FALSE(serverConfig.LogIgnoreSdfPath());
   EXPECT_TRUE(serverConfig.LogPlaybackPath().empty());
   EXPECT_FALSE(serverConfig.LogRecordResources());
   EXPECT_TRUE(serverConfig.LogRecordCompressPath().empty());
@@ -75,7 +67,7 @@ TEST_P(ServerFixture, DefaultServerConfig)
   EXPECT_TRUE(serverConfig.Plugins().empty());
   EXPECT_TRUE(serverConfig.LogRecordTopics().empty());
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_EQ(std::nullopt, server.Running(1));
@@ -91,7 +83,7 @@ TEST_P(ServerFixture, DefaultServerConfig)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, UpdateRate)
 {
-  gz::sim::ServerConfig serverConfig;
+  gazebo::ServerConfig serverConfig;
   serverConfig.SetUpdateRate(1000.0);
   EXPECT_DOUBLE_EQ(1000.0, *serverConfig.UpdateRate());
   serverConfig.SetUpdateRate(-1000.0);
@@ -111,7 +103,7 @@ TEST_P(ServerFixture, ServerConfigPluginInfo)
   pluginInfo.SetName("interface");
   pluginInfo.SetSdf(nullptr);
 
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
   serverConfig.AddPlugin(pluginInfo);
 
   const std::list<ServerConfig::PluginInfo> &plugins = serverConfig.Plugins();
@@ -172,7 +164,7 @@ TEST_P(ServerFixture, ServerConfigRealPlugin)
   sdf::ElementPtr sdf(new sdf::Element);
   sdf->SetName("plugin");
   sdf->AddAttribute("name", "string",
-      "gz::sim::TestModelSystem", true);
+      "ignition::gazebo::TestModelSystem", true);
   sdf->AddAttribute("filename", "string", "libTestModelSystem.so", true);
 
   sdf::ElementPtr child(new sdf::Element);
@@ -181,9 +173,9 @@ TEST_P(ServerFixture, ServerConfigRealPlugin)
   child->AddValue("string", "987", "1");
 
   serverConfig.AddPlugin({"box", "model",
-      "libTestModelSystem.so", "gz::sim::TestModelSystem", sdf});
+      "libTestModelSystem.so", "ignition::gazebo::TestModelSystem", sdf});
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   // The simulation runner should not be running.
   EXPECT_FALSE(*server.Running(0));
@@ -222,16 +214,16 @@ TEST_P(ServerFixture, ServerConfigSensorPlugin)
   sdf::ElementPtr sdf(new sdf::Element);
   sdf->SetName("plugin");
   sdf->AddAttribute("name", "string",
-      "gz::sim::TestSensorSystem", true);
+      "ignition::gazebo::TestSensorSystem", true);
   sdf->AddAttribute("filename", "string", "libTestSensorSystem.so", true);
 
   serverConfig.AddPlugin({
       "air_pressure_sensor::air_pressure_model::link::air_pressure_sensor",
-      "sensor", "libTestSensorSystem.so", "gz::sim::TestSensorSystem",
+      "sensor", "libTestSensorSystem.so", "ignition::gazebo::TestSensorSystem",
       sdf});
 
   igndbg << "Create server" << std::endl;
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   // The simulation runner should not be running.
   EXPECT_FALSE(*server.Running(0));
@@ -265,7 +257,7 @@ TEST_P(ServerFixture, ServerConfigSensorPlugin)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, SdfServerConfig)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
 
   serverConfig.SetSdfString(TestWorldSansPhysics::World());
   EXPECT_TRUE(serverConfig.SdfFile().empty());
@@ -277,18 +269,20 @@ TEST_P(ServerFixture, SdfServerConfig)
   EXPECT_FALSE(serverConfig.SdfFile().empty());
   EXPECT_TRUE(serverConfig.SdfString().empty());
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_TRUE(*server.Paused());
   EXPECT_EQ(0u, *server.IterationCount());
-  EXPECT_EQ(16u, *server.EntityCount());
+  EXPECT_EQ(24u, *server.EntityCount());
   EXPECT_EQ(3u, *server.SystemCount());
 
   EXPECT_TRUE(server.HasEntity("box"));
   EXPECT_FALSE(server.HasEntity("box", 1));
   EXPECT_TRUE(server.HasEntity("sphere"));
   EXPECT_TRUE(server.HasEntity("cylinder"));
+  EXPECT_TRUE(server.HasEntity("capsule"));
+  EXPECT_TRUE(server.HasEntity("ellipsoid"));
   EXPECT_FALSE(server.HasEntity("bad", 0));
   EXPECT_FALSE(server.HasEntity("bad", 1));
 }
@@ -309,11 +303,11 @@ TEST_P(ServerFixture, ServerConfigLogRecord)
   EXPECT_FALSE(common::exists(compressedFile));
 
   {
-    gz::sim::ServerConfig serverConfig;
+    gazebo::ServerConfig serverConfig;
     serverConfig.SetUseLogRecord(true);
     serverConfig.SetLogRecordPath(logPath);
 
-    gz::sim::Server server(serverConfig);
+    gazebo::Server server(serverConfig);
 
     EXPECT_EQ(0u, *server.IterationCount());
     EXPECT_EQ(3u, *server.EntityCount());
@@ -348,12 +342,12 @@ TEST_P(ServerFixture, ServerConfigLogRecordCompress)
   EXPECT_FALSE(common::exists(compressedFile));
 
   {
-    gz::sim::ServerConfig serverConfig;
+    gazebo::ServerConfig serverConfig;
     serverConfig.SetUseLogRecord(true);
     serverConfig.SetLogRecordPath(logPath);
     serverConfig.SetLogRecordCompressPath(compressedFile);
 
-    gz::sim::Server server(serverConfig);
+    gazebo::Server server(serverConfig);
     EXPECT_EQ(0u, *server.IterationCount());
     EXPECT_EQ(3u, *server.EntityCount());
     EXPECT_EQ(4u, *server.SystemCount());
@@ -366,7 +360,7 @@ TEST_P(ServerFixture, ServerConfigLogRecordCompress)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, SdfStringServerConfig)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
 
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
       "/test/worlds/shapes.sdf");
@@ -378,7 +372,7 @@ TEST_P(ServerFixture, SdfStringServerConfig)
   EXPECT_TRUE(serverConfig.SdfFile().empty());
   EXPECT_FALSE(serverConfig.SdfString().empty());
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_TRUE(*server.Paused());
@@ -390,7 +384,7 @@ TEST_P(ServerFixture, SdfStringServerConfig)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunBlocking)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_TRUE(*server.Paused());
@@ -416,7 +410,7 @@ TEST_P(ServerFixture, RunBlocking)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunNonBlockingPaused)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
 
   // The server should not be running.
   EXPECT_FALSE(server.Running());
@@ -466,7 +460,7 @@ TEST_P(ServerFixture, RunNonBlockingPaused)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunNonBlocking)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_EQ(0u, *server.IterationCount());
@@ -486,15 +480,15 @@ TEST_P(ServerFixture, RunNonBlocking)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunOnceUnpaused)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_EQ(0u, *server.IterationCount());
 
   // Load a system
-  gz::sim::SystemLoader systemLoader;
+  gazebo::SystemLoader systemLoader;
   auto mockSystemPlugin = systemLoader.LoadPlugin(
-      "libMockSystem.so", "gz::sim::MockSystem", nullptr);
+      "libMockSystem.so", "ignition::gazebo::MockSystem", nullptr);
   ASSERT_TRUE(mockSystemPlugin.has_value());
 
   // Check that it was loaded
@@ -503,9 +497,9 @@ TEST_P(ServerFixture, RunOnceUnpaused)
   EXPECT_EQ(systemCount + 1, *server.SystemCount());
 
   // Query the interface from the plugin
-  auto system = mockSystemPlugin.value()->QueryInterface<sim::System>();
+  auto system = mockSystemPlugin.value()->QueryInterface<gazebo::System>();
   EXPECT_NE(system, nullptr);
-  auto mockSystem = dynamic_cast<sim::MockSystem*>(system);
+  auto mockSystem = dynamic_cast<gazebo::MockSystem*>(system);
   EXPECT_NE(mockSystem, nullptr);
 
   // No steps should have been executed
@@ -533,15 +527,15 @@ TEST_P(ServerFixture, RunOnceUnpaused)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunOncePaused)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   EXPECT_EQ(0u, *server.IterationCount());
 
   // Load a system
-  gz::sim::SystemLoader systemLoader;
+  gazebo::SystemLoader systemLoader;
   auto mockSystemPlugin = systemLoader.LoadPlugin(
-      "libMockSystem.so", "gz::sim::MockSystem", nullptr);
+      "libMockSystem.so", "ignition::gazebo::MockSystem", nullptr);
   ASSERT_TRUE(mockSystemPlugin.has_value());
 
   // Check that it was loaded
@@ -550,9 +544,9 @@ TEST_P(ServerFixture, RunOncePaused)
   EXPECT_EQ(systemCount + 1, *server.SystemCount());
 
   // Query the interface from the plugin
-  auto system = mockSystemPlugin.value()->QueryInterface<sim::System>();
+  auto system = mockSystemPlugin.value()->QueryInterface<gazebo::System>();
   EXPECT_NE(system, nullptr);
-  auto mockSystem = dynamic_cast<sim::MockSystem*>(system);
+  auto mockSystem = dynamic_cast<gazebo::MockSystem*>(system);
   EXPECT_NE(mockSystem, nullptr);
 
   // No steps should have been executed
@@ -580,9 +574,9 @@ TEST_P(ServerFixture, RunOncePaused)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, RunNonBlockingMultiple)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
   serverConfig.SetSdfString(TestWorldSansPhysics::World());
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
@@ -602,7 +596,7 @@ TEST_P(ServerFixture, RunNonBlockingMultiple)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, SigInt)
 {
-  gz::sim::Server server;
+  gazebo::Server server;
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
 
@@ -620,148 +614,15 @@ TEST_P(ServerFixture, SigInt)
   EXPECT_FALSE(*server.Running(0));
 }
 
-/////////////////////////////////////////////////
-TEST_P(ServerFixture, ServerControlStop)
-{
-  // Test that the server correctly reacts to requests on /server_control
-  // service with `stop` set to either false or true.
-
-  gz::sim::Server server;
-  EXPECT_FALSE(server.Running());
-  EXPECT_FALSE(*server.Running(0));
-
-  // Run forever, non-blocking.
-  server.Run(false, 0, false);
-
-  IGN_SLEEP_MS(500);
-
-  EXPECT_TRUE(server.Running());
-  EXPECT_TRUE(*server.Running(0));
-
-  transport::Node node;
-  msgs::ServerControl req;
-  msgs::Boolean res;
-  bool result{false};
-  bool executed{false};
-  int sleep{0};
-  int maxSleep{30};
-
-  // first, call with stop = false; the server should keep running
-  while (!executed && sleep < maxSleep)
-  {
-    igndbg << "Requesting /server_control" << std::endl;
-    executed = node.Request("/server_control", req, 100, res, result);
-    sleep++;
-  }
-  EXPECT_TRUE(executed);
-  EXPECT_TRUE(result);
-  EXPECT_FALSE(res.data());
-
-  IGN_SLEEP_MS(500);
-
-  EXPECT_TRUE(server.Running());
-  EXPECT_TRUE(*server.Running(0));
-
-  // now call with stop = true; the server should stop
-  req.set_stop(true);
-
-  igndbg << "Requesting /server_control" << std::endl;
-  executed = node.Request("/server_control", req, 100, res, result);
-
-  EXPECT_TRUE(executed);
-  EXPECT_TRUE(result);
-  EXPECT_TRUE(res.data());
-
-  IGN_SLEEP_MS(500);
-
-  EXPECT_FALSE(server.Running());
-  EXPECT_FALSE(*server.Running(0));
-}
-
-/////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/1544
-TEST_P(ServerFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(TwoServersNonBlocking))
-{
-  ServerConfig serverConfig;
-  serverConfig.SetSdfString(TestWorldSansPhysics::World());
-
-  gz::sim::Server server1(serverConfig);
-  gz::sim::Server server2(serverConfig);
-  EXPECT_FALSE(server1.Running());
-  EXPECT_FALSE(*server1.Running(0));
-  EXPECT_FALSE(server2.Running());
-  EXPECT_FALSE(*server2.Running(0));
-  EXPECT_EQ(0u, *server1.IterationCount());
-  EXPECT_EQ(0u, *server2.IterationCount());
-
-  // Make the servers run fast.
-  server1.SetUpdatePeriod(1ns);
-  server2.SetUpdatePeriod(1ns);
-
-  // Start non-blocking
-  const size_t iters1 = 9999;
-  EXPECT_TRUE(server1.Run(false, iters1, false));
-
-  // Expect that we can't start another instance.
-  EXPECT_FALSE(server1.Run(true, 10, false));
-
-  // It's okay to start another server
-  EXPECT_TRUE(server2.Run(false, 500, false));
-
-  while (*server1.IterationCount() < iters1 || *server2.IterationCount() < 500)
-    IGN_SLEEP_MS(100);
-
-  EXPECT_EQ(iters1, *server1.IterationCount());
-  EXPECT_EQ(500u, *server2.IterationCount());
-  EXPECT_FALSE(server1.Running());
-  EXPECT_FALSE(*server1.Running(0));
-  EXPECT_FALSE(server2.Running());
-  EXPECT_FALSE(*server2.Running(0));
-}
-
-/////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/1544
-TEST_P(ServerFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(TwoServersMixedBlocking))
-{
-  ServerConfig serverConfig;
-  serverConfig.SetSdfString(TestWorldSansPhysics::World());
-
-  gz::sim::Server server1(serverConfig);
-  gz::sim::Server server2(serverConfig);
-  EXPECT_FALSE(server1.Running());
-  EXPECT_FALSE(*server1.Running(0));
-  EXPECT_FALSE(server2.Running());
-  EXPECT_FALSE(*server2.Running(0));
-  EXPECT_EQ(0u, *server1.IterationCount());
-  EXPECT_EQ(0u, *server2.IterationCount());
-
-  // Make the servers run fast.
-  server1.SetUpdatePeriod(1ns);
-  server2.SetUpdatePeriod(1ns);
-
-  server1.Run(false, 10, false);
-  server2.Run(true, 1000, false);
-
-  while (*server1.IterationCount() < 10)
-    IGN_SLEEP_MS(100);
-
-  EXPECT_EQ(10u, *server1.IterationCount());
-  EXPECT_EQ(1000u, *server2.IterationCount());
-  EXPECT_FALSE(server1.Running());
-  EXPECT_FALSE(*server1.Running(0));
-  EXPECT_FALSE(server2.Running());
-  EXPECT_FALSE(*server2.Running(0));
-}
-
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, AddSystemWhileRunning)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
 
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
       "/test/worlds/shapes.sdf");
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
   server.SetUpdatePeriod(1us);
@@ -776,10 +637,9 @@ TEST_P(ServerFixture, AddSystemWhileRunning)
 
   EXPECT_EQ(3u, *server.SystemCount());
 
-  // Add system from plugin
-  gz::sim::SystemLoader systemLoader;
+  gazebo::SystemLoader systemLoader;
   auto mockSystemPlugin = systemLoader.LoadPlugin("libMockSystem.so",
-      "gz::sim::MockSystem", nullptr);
+      "ignition::gazebo::MockSystem", nullptr);
   ASSERT_TRUE(mockSystemPlugin.has_value());
 
   auto result = server.AddSystem(mockSystemPlugin.value());
@@ -787,13 +647,6 @@ TEST_P(ServerFixture, AddSystemWhileRunning)
   EXPECT_FALSE(result.value());
   EXPECT_EQ(3u, *server.SystemCount());
 
-  // Add system pointer
-  auto mockSystem = std::make_shared<MockSystem>();
-  result = server.AddSystem(mockSystem);
-  ASSERT_TRUE(result.has_value());
-  EXPECT_FALSE(result.value());
-  EXPECT_EQ(3u, *server.SystemCount());
-
   // Stop the server
   std::raise(SIGTERM);
 
@@ -804,93 +657,66 @@ TEST_P(ServerFixture, AddSystemWhileRunning)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, AddSystemAfterLoad)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
 
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
       "/test/worlds/shapes.sdf");
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
 
-  // Add system from plugin
-  gz::sim::SystemLoader systemLoader;
+  gazebo::SystemLoader systemLoader;
   auto mockSystemPlugin = systemLoader.LoadPlugin("libMockSystem.so",
-      "gz::sim::MockSystem", nullptr);
+      "ignition::gazebo::MockSystem", nullptr);
   ASSERT_TRUE(mockSystemPlugin.has_value());
 
-  auto system = mockSystemPlugin.value()->QueryInterface<sim::System>();
-  EXPECT_NE(system, nullptr);
-  auto mockSystem = dynamic_cast<sim::MockSystem*>(system);
-  ASSERT_NE(mockSystem, nullptr);
-
   EXPECT_EQ(3u, *server.SystemCount());
-  EXPECT_EQ(0u, mockSystem->configureCallCount);
-
   EXPECT_TRUE(*server.AddSystem(mockSystemPlugin.value()));
-
   EXPECT_EQ(4u, *server.SystemCount());
-  EXPECT_EQ(1u, mockSystem->configureCallCount);
 
-  // Add system pointer
-  auto mockSystemLocal = std::make_shared<MockSystem>();
-  EXPECT_EQ(0u, mockSystemLocal->configureCallCount);
+  auto system = mockSystemPlugin.value()->QueryInterface<gazebo::System>();
+  EXPECT_NE(system, nullptr);
+  auto mockSystem = dynamic_cast<gazebo::MockSystem*>(system);
+  EXPECT_NE(mockSystem, nullptr);
 
-  EXPECT_TRUE(server.AddSystem(mockSystemLocal));
-  EXPECT_EQ(5u, *server.SystemCount());
-  EXPECT_EQ(1u, mockSystemLocal->configureCallCount);
-
-  // Check that update callbacks are called
   server.SetUpdatePeriod(1us);
   EXPECT_EQ(0u, mockSystem->preUpdateCallCount);
   EXPECT_EQ(0u, mockSystem->updateCallCount);
   EXPECT_EQ(0u, mockSystem->postUpdateCallCount);
-  EXPECT_EQ(0u, mockSystemLocal->preUpdateCallCount);
-  EXPECT_EQ(0u, mockSystemLocal->updateCallCount);
-  EXPECT_EQ(0u, mockSystemLocal->postUpdateCallCount);
   server.Run(true, 1, false);
   EXPECT_EQ(1u, mockSystem->preUpdateCallCount);
   EXPECT_EQ(1u, mockSystem->updateCallCount);
   EXPECT_EQ(1u, mockSystem->postUpdateCallCount);
-  EXPECT_EQ(1u, mockSystemLocal->preUpdateCallCount);
-  EXPECT_EQ(1u, mockSystemLocal->updateCallCount);
-  EXPECT_EQ(1u, mockSystemLocal->postUpdateCallCount);
-
-  // Add to inexistent world
-  auto result = server.AddSystem(mockSystemPlugin.value(), 100);
-  EXPECT_FALSE(result.has_value());
-
-  result = server.AddSystem(mockSystemLocal, 100);
-  EXPECT_FALSE(result.has_value());
 }
 
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, Seed)
 {
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
   EXPECT_EQ(0u, serverConfig.Seed());
   unsigned int mySeed = 12345u;
   serverConfig.SetSeed(mySeed);
   EXPECT_EQ(mySeed, serverConfig.Seed());
-  EXPECT_EQ(mySeed, math::Rand::Seed());
+  EXPECT_EQ(mySeed, ignition::math::Rand::Seed());
 }
 
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, ResourcePath)
 {
-  common::setenv("IGN_GAZEBO_RESOURCE_PATH",
+  ignition::common::setenv("IGN_GAZEBO_RESOURCE_PATH",
          (std::string(PROJECT_SOURCE_PATH) + "/test/worlds:" +
           std::string(PROJECT_SOURCE_PATH) + "/test/worlds/models").c_str());
 
   ServerConfig serverConfig;
   serverConfig.SetSdfFile("resource_paths.sdf");
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   test::Relay testSystem;
   unsigned int preUpdates{0};
   testSystem.OnPreUpdate(
-    [&preUpdates](const gz::sim::UpdateInfo &,
-    gz::sim::EntityComponentManager &_ecm)
+    [&preUpdates](const gazebo::UpdateInfo &,
+    gazebo::EntityComponentManager &_ecm)
     {
       // Create AABB so it is populated
       unsigned int eachCount{0};
@@ -908,8 +734,8 @@ TEST_P(ServerFixture, ResourcePath)
     });
 
   unsigned int postUpdates{0};
-  testSystem.OnPostUpdate([&postUpdates](const gz::sim::UpdateInfo &,
-    const gz::sim::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&postUpdates](const gazebo::UpdateInfo &,
+    const gazebo::EntityComponentManager &_ecm)
     {
       // Check geometry components
       unsigned int eachCount{0};
@@ -937,7 +763,7 @@ TEST_P(ServerFixture, ResourcePath)
       // Check physics system loaded meshes and got their BB correct
       eachCount = 0;
       _ecm.Each<components::AxisAlignedBox>(
-        [&](const Entity &,
+        [&](const ignition::gazebo::Entity &,
             const components::AxisAlignedBox *_box)->bool
         {
           auto box = _box->Data();
@@ -966,11 +792,11 @@ TEST_P(ServerFixture, ResourcePath)
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, GetResourcePaths)
 {
-  common::setenv("IGN_GAZEBO_RESOURCE_PATH",
+  ignition::common::setenv("IGN_GAZEBO_RESOURCE_PATH",
       "/tmp/some/path:/home/user/another_path");
 
   ServerConfig serverConfig;
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   EXPECT_FALSE(*server.Running(0));
 
@@ -993,42 +819,16 @@ TEST_P(ServerFixture, GetResourcePaths)
   EXPECT_EQ("/home/user/another_path", res.data(1));
 }
 
-/////////////////////////////////////////////////
-TEST_P(ServerFixture, CachedFuelWorld)
-{
-  auto cachedWorldPath =
-    common::joinPaths(std::string(PROJECT_SOURCE_PATH), "test", "worlds");
-  common::setenv("IGN_FUEL_CACHE_PATH", cachedWorldPath.c_str());
-
-  ServerConfig serverConfig;
-  auto fuelWorldURL =
-    "https://fuel.gazebosim.org/1.0/OpenRobotics/worlds/Test%20world";
-  EXPECT_TRUE(serverConfig.SetSdfFile(fuelWorldURL));
-
-  EXPECT_EQ(fuelWorldURL, serverConfig.SdfFile());
-  EXPECT_TRUE(serverConfig.SdfString().empty());
-
-  // Check that world was loaded
-  auto server = Server(serverConfig);
-  EXPECT_NE(std::nullopt, server.Running(0));
-  EXPECT_FALSE(*server.Running(0));
-
-  server.Run(true /*blocking*/, 1, false/*paused*/);
-
-  EXPECT_NE(std::nullopt, server.Running(0));
-  EXPECT_FALSE(*server.Running(0));
-}
-
 /////////////////////////////////////////////////
 TEST_P(ServerFixture, AddResourcePaths)
 {
-  common::setenv("IGN_GAZEBO_RESOURCE_PATH",
+  ignition::common::setenv("IGN_GAZEBO_RESOURCE_PATH",
       "/tmp/some/path:/home/user/another_path");
-  common::setenv("SDF_PATH", "");
-  common::setenv("IGN_FILE_PATH", "");
+  ignition::common::setenv("SDF_PATH", "");
+  ignition::common::setenv("IGN_FILE_PATH", "");
 
   ServerConfig serverConfig;
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   EXPECT_FALSE(*server.Running(0));
 
@@ -1088,45 +888,6 @@ TEST_P(ServerFixture, AddResourcePaths)
   }
 }
 
-/////////////////////////////////////////////////
-TEST_P(ServerFixture, SdfWithoutWorld)
-{
-  // Initialize logging
-  std::string logBasePath = common::joinPaths(PROJECT_BINARY_PATH, "tmp");
-  common::setenv(IGN_HOMEDIR, logBasePath);
-  std::string path = common::uuid();
-  ignLogInit(path, "test.log");
-
-  // Start server with model SDF file
-  ServerConfig serverConfig;
-  serverConfig.SetSdfFile(common::joinPaths(PROJECT_SOURCE_PATH,
-      "test", "worlds", "models", "sphere", "model.sdf"));
-
-  gz::sim::Server server(serverConfig);
-  EXPECT_FALSE(server.Running());
-  EXPECT_FALSE(*server.Running(0));
-
-  // Check error message in log file
-  std::string logFullPath = common::joinPaths(logBasePath, path, "test.log");
-  std::ifstream ifs(logFullPath.c_str(), std::ios::in);
-  bool errFound = false;
-  while ((!errFound) && (!ifs.eof()))
-  {
-    std::string line;
-    std::getline(ifs, line);
-    std::string errString = "SDF file doesn't contain a world. ";
-    errString += "If you wish to spawn a model, ";
-    errString += "use the ResourceSpawner GUI plugin ";
-    errString += "or the 'world/<world_name>/create' service.";
-    errFound = (line.find(errString) != std::string::npos);
-  }
-  EXPECT_TRUE(errFound);
-
-  // Stop logging
-  ignLogClose();
-  common::removeAll(logBasePath);
-}
-
 // Run multiple times. We want to make sure that static globals don't cause
 // problems.
 INSTANTIATE_TEST_SUITE_P(ServerRepeat, ServerFixture, ::testing::Range(1, 2));
