@@ -21,23 +21,23 @@
 
 #include <sdf/Root.hh>
 
-#include "gz/common/Profiler.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/PhysicsCmd.hh"
-#include "gz/sim/Events.hh"
-#include "gz/sim/SdfEntityCreator.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/common/Profiler.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/PhysicsCmd.hh"
+#include "ignition/gazebo/Events.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
+#include "ignition/gazebo/Util.hh"
 
 #include "network/NetworkManagerPrimary.hh"
 #include "SdfGenerator.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 using StringSet = std::unordered_set<std::string>;
 
@@ -103,15 +103,8 @@ SimulationRunner::SimulationRunner(const sdf::World *_world,
   // So to get a given RTF, our desired period is:
   //
   // period = step_size / RTF
-  if (this->desiredRtf < 1e-9)
-  {
-    this->updatePeriod = 0ms;
-  }
-  else
-  {
-    this->updatePeriod = std::chrono::nanoseconds(
-        static_cast<int>(this->stepSize.count() / this->desiredRtf));
-  }
+  this->updatePeriod = std::chrono::nanoseconds(
+      static_cast<int>(this->stepSize.count() / this->desiredRtf));
 
   this->pauseConn = this->eventMgr.Connect<events::Pause>(
       std::bind(&SimulationRunner::SetPaused, this, std::placeholders::_1));
@@ -175,7 +168,7 @@ SimulationRunner::SimulationRunner(const sdf::World *_world,
   {
     ignmsg << "No systems loaded from SDF, loading defaults" << std::endl;
     bool isPlayback = !this->serverConfig.LogPlaybackPath().empty();
-    auto plugins = gz::sim::loadPluginInfo(isPlayback);
+    auto plugins = ignition::gazebo::loadPluginInfo(isPlayback);
     this->LoadServerPlugins(plugins);
   }
 
@@ -183,15 +176,20 @@ SimulationRunner::SimulationRunner(const sdf::World *_world,
 
   // World control
   transport::NodeOptions opts;
+  std::string ns{"/world/" + this->worldName};
   if (this->networkMgr)
   {
-    opts.SetNameSpace(this->networkMgr->Namespace() +
-                      "/world/" + this->worldName);
+    ns = this->networkMgr->Namespace() + ns;
   }
-  else
+
+  auto validNs = transport::TopicUtils::AsValidTopic(ns);
+  if (validNs.empty())
   {
-    opts.SetNameSpace("/world/" + this->worldName);
+    ignerr << "Invalid namespace [" << ns
+           << "], not initializing runner transport." << std::endl;
+    return;
   }
+  opts.SetNameSpace(validNs);
 
   this->node = std::make_unique<transport::Node>(opts);
 
@@ -381,14 +379,14 @@ void SimulationRunner::PublishStats()
   IGN_PROFILE("SimulationRunner::PublishStats");
 
   // Create the world statistics message.
-  msgs::WorldStatistics msg;
+  ignition::msgs::WorldStatistics msg;
   msg.set_real_time_factor(this->realTimeFactor);
 
   auto realTimeSecNsec =
-    math::durationToSecNsec(this->currentInfo.realTime);
+    ignition::math::durationToSecNsec(this->currentInfo.realTime);
 
   auto simTimeSecNsec =
-    math::durationToSecNsec(this->currentInfo.simTime);
+    ignition::math::durationToSecNsec(this->currentInfo.simTime);
 
   msg.mutable_real_time()->set_sec(realTimeSecNsec.first);
   msg.mutable_real_time()->set_nsec(realTimeSecNsec.second);
@@ -408,7 +406,7 @@ void SimulationRunner::PublishStats()
 
   // Create and publish the clock message. The clock message is not
   // throttled.
-  msgs::Clock clockMsg;
+  ignition::msgs::Clock clockMsg;
   clockMsg.mutable_real()->set_sec(realTimeSecNsec.first);
   clockMsg.mutable_real()->set_nsec(realTimeSecNsec.second);
   clockMsg.mutable_sim()->set_sec(simTimeSecNsec.first);
@@ -423,61 +421,28 @@ void SimulationRunner::PublishStats()
     this->rootClockPub.Publish(clockMsg);
 }
 
-//////////////////////////////////////////////////
-void SimulationRunner::AddSystem(const SystemPluginPtr &_system,
-      std::optional<Entity> _entity,
-      std::optional<std::shared_ptr<const sdf::Element>> _sdf)
+/////////////////////////////////////////////////
+void SimulationRunner::AddSystem(const SystemPluginPtr &_system)
 {
-  this->AddSystemImpl(SystemInternal(_system), _entity, _sdf);
-}
-
-//////////////////////////////////////////////////
-void SimulationRunner::AddSystem(
-      const std::shared_ptr<System> &_system,
-      std::optional<Entity> _entity,
-      std::optional<std::shared_ptr<const sdf::Element>> _sdf)
-{
-  this->AddSystemImpl(SystemInternal(_system), _entity, _sdf);
-}
-
-//////////////////////////////////////////////////
-void SimulationRunner::AddSystemImpl(
-      SystemInternal _system,
-      std::optional<Entity> _entity,
-      std::optional<std::shared_ptr<const sdf::Element>> _sdf)
-{
-  // Call configure
-  if (_system.configure)
-  {
-    // Default to world entity and SDF
-    auto entity = _entity.has_value() ? _entity.value()
-        : worldEntity(this->entityCompMgr);
-    auto sdf = _sdf.has_value() ? _sdf.value() : this->sdfWorld->Element();
-
-    _system.configure->Configure(
-        entity, sdf,
-        this->entityCompMgr,
-        this->eventMgr);
-  }
-
-  // Update callbacks will be handled later, add to queue
   std::lock_guard<std::mutex> lock(this->pendingSystemsMutex);
   this->pendingSystems.push_back(_system);
 }
 
 /////////////////////////////////////////////////
-void SimulationRunner::AddSystemToRunner(SystemInternal _system)
+void SimulationRunner::AddSystemToRunner(const SystemPluginPtr &_system)
 {
-  this->systems.push_back(_system);
+  this->systems.push_back(SystemInternal(_system));
 
-  if (_system.preupdate)
-    this->systemsPreupdate.push_back(_system.preupdate);
+  const auto &system = this->systems.back();
 
-  if (_system.update)
-    this->systemsUpdate.push_back(_system.update);
+  if (system.preupdate)
+    this->systemsPreupdate.push_back(system.preupdate);
 
-  if (_system.postupdate)
-    this->systemsPostupdate.push_back(_system.postupdate);
+  if (system.update)
+    this->systemsUpdate.push_back(system.update);
+
+  if (system.postupdate)
+    this->systemsPostupdate.push_back(system.postupdate);
 }
 
 /////////////////////////////////////////////////
@@ -496,6 +461,7 @@ void SimulationRunner::ProcessSystemQueue()
   {
     this->AddSystemToRunner(system);
   }
+
   this->pendingSystems.clear();
 
   // If additional systems were added, recreate the worker threads.
@@ -505,9 +471,9 @@ void SimulationRunner::ProcessSystemQueue()
       << this->systemsPostupdate.size() + 1 << std::endl;
 
     this->postUpdateStartBarrier =
-      std::make_unique<Barrier>(this->systemsPostupdate.size() + 1u);
+      std::make_unique<Barrier>(this->systemsPostupdate.size() + 1);
     this->postUpdateStopBarrier =
-      std::make_unique<Barrier>(this->systemsPostupdate.size() + 1u);
+      std::make_unique<Barrier>(this->systemsPostupdate.size() + 1);
 
     this->postUpdateThreadsRunning = true;
     int id = 0;
@@ -543,7 +509,7 @@ void SimulationRunner::UpdateSystems()
 {
   IGN_PROFILE("SimulationRunner::UpdateSystems");
   // \todo(nkoenig)  Systems used to be updated in parallel using
-  // an common::WorkerPool. There is overhead associated with
+  // an ignition::common::WorkerPool. There is overhead associated with
   // this, most notably the creation and destruction of WorkOrders (see
   // WorkerPool.cc). We could turn on parallel updates in the future, and/or
   // turn it on if there are sufficient systems. More testing is required.
@@ -650,14 +616,14 @@ bool SimulationRunner::Run(const uint64_t _iterations)
   {
     transport::AdvertiseMessageOptions advertOpts;
     advertOpts.SetMsgsPerSec(5);
-    this->statsPub = this->node->Advertise<msgs::WorldStatistics>(
+    this->statsPub = this->node->Advertise<ignition::msgs::WorldStatistics>(
         "stats", advertOpts);
   }
 
   if (!this->rootStatsPub.Valid())
   {
     // Check for the existence of other publishers on `/stats`
-    std::vector<transport::MessagePublisher> publishers;
+    std::vector<ignition::transport::MessagePublisher> publishers;
     this->node->TopicInfo("/stats", publishers);
 
     if (!publishers.empty())
@@ -684,13 +650,13 @@ bool SimulationRunner::Run(const uint64_t _iterations)
 
   // Create the clock publisher.
   if (!this->clockPub.Valid())
-    this->clockPub = this->node->Advertise<msgs::Clock>("clock");
+    this->clockPub = this->node->Advertise<ignition::msgs::Clock>("clock");
 
   // Create the global clock publisher.
   if (!this->rootClockPub.Valid())
   {
     // Check for the existence of other publishers on `/clock`
-    std::vector<transport::MessagePublisher> publishers;
+    std::vector<ignition::transport::MessagePublisher> publishers;
     this->node->TopicInfo("/clock", publishers);
 
     if (!publishers.empty())
@@ -710,7 +676,7 @@ bool SimulationRunner::Run(const uint64_t _iterations)
     {
       ignmsg << "Found no publishers on /clock, adding root clock topic"
              << std::endl;
-      this->rootClockPub = this->node->Advertise<msgs::Clock>(
+      this->rootClockPub = this->node->Advertise<ignition::msgs::Clock>(
           "/clock");
     }
   }
@@ -808,6 +774,15 @@ void SimulationRunner::Step(const UpdateInfo &_info)
   // Update all the systems.
   this->UpdateSystems();
 
+  if (!this->Paused() &&
+       this->requestedRunToSimTime >
+       std::chrono::steady_clock::duration::zero() &&
+       this->currentInfo.simTime >= this->requestedRunToSimTime)
+  {
+    this->SetPaused(true);
+    this->requestedRunToSimTime = std::chrono::steady_clock::duration{-1};
+  }
+
   if (!this->Paused() && this->pendingSimIterations > 0)
   {
     // Decrement the pending sim iterations, if there are any.
@@ -829,6 +804,9 @@ void SimulationRunner::Step(const UpdateInfo &_info)
   // Process entity removals.
   this->entityCompMgr.ProcessRemoveEntityRequests();
 
+  // Process components removals
+  this->entityCompMgr.ClearRemovedComponents();
+
   // Each network manager takes care of marking its components as unchanged
   if (!this->networkMgr)
     this->entityCompMgr.SetAllComponentsUnchanged();
@@ -846,10 +824,18 @@ void SimulationRunner::LoadPlugin(const Entity _entity,
     system = this->systemLoader->LoadPlugin(_fname, _name, _sdf);
   }
 
-  // System correctly loaded from library
+  // System correctly loaded from library, try to configure
   if (system)
   {
-    this->AddSystem(system.value(), _entity, _sdf);
+    auto systemConfig = system.value()->QueryInterface<ISystemConfigure>();
+    if (systemConfig != nullptr)
+    {
+      systemConfig->Configure(_entity, _sdf,
+          this->entityCompMgr,
+          this->eventMgr);
+    }
+
+    this->AddSystem(system.value());
     igndbg << "Loaded system [" << _name
            << "] for entity [" << _entity << "]" << std::endl;
   }
@@ -966,7 +952,7 @@ void SimulationRunner::LoadLoggingPlugins(const ServerConfig &_config)
 void SimulationRunner::LoadPlugins(const Entity _entity,
     const sdf::ElementPtr &_sdf)
 {
-  sdf::ElementPtr pluginElem = _sdf->FindElement("plugin");
+  sdf::ElementPtr pluginElem = _sdf->GetElement("plugin");
   while (pluginElem)
   {
     auto filename = pluginElem->Get<std::string>("filename");
@@ -974,7 +960,8 @@ void SimulationRunner::LoadPlugins(const Entity _entity,
     // No error message for the 'else' case of the following 'if' statement
     // because SDF create a default <plugin> element even if it's not
     // specified. An error message would result in spamming
-    // the console.
+    // the console. \todo(nkoenig) Fix SDF should so that elements are not
+    // automatically added.
     if (filename != "__default__" && name != "__default__")
     {
       this->LoadPlugin(_entity, filename, name, pluginElem);
@@ -1054,6 +1041,21 @@ void SimulationRunner::SetPaused(const bool _paused)
   this->currentInfo.paused = _paused;
 }
 
+/////////////////////////////////////////////////
+void SimulationRunner::SetRunToSimTime(
+    const std::chrono::steady_clock::duration &_time)
+{
+  if (_time >= std::chrono::steady_clock::duration::zero() &&
+      _time > this->currentInfo.simTime)
+  {
+    this->requestedRunToSimTime = _time;
+  }
+  else
+  {
+    this->requestedRunToSimTime = std::chrono::seconds(-1);
+  }
+}
+
 /////////////////////////////////////////////////
 bool SimulationRunner::OnWorldControl(const msgs::WorldControl &_req,
     msgs::Boolean &_res)
@@ -1083,6 +1085,12 @@ bool SimulationRunner::OnWorldControl(const msgs::WorldControl &_req,
     ignwarn << "Changing seed is not supported." << std::endl;
   }
 
+  if (_req.has_run_to_sim_time())
+  {
+    control.runToSimTime = std::chrono::seconds(_req.run_to_sim_time().sec()) +
+                   std::chrono::nanoseconds(_req.run_to_sim_time().nsec());
+  }
+
   this->worldControls.push_back(control);
 
   _res.set_data(true);
@@ -1150,6 +1158,8 @@ void SimulationRunner::ProcessWorldControl()
     {
       this->requestedSeek = control.seek;
     }
+
+    this->SetRunToSimTime(control.runToSimTime);
   }
 
   this->worldControls.clear();
@@ -1187,13 +1197,13 @@ SimulationRunner::UpdatePeriod() const
 }
 
 /////////////////////////////////////////////////
-const math::clock::duration &SimulationRunner::StepSize() const
+const ignition::math::clock::duration &SimulationRunner::StepSize() const
 {
   return this->stepSize;
 }
 
 /////////////////////////////////////////////////
-void SimulationRunner::SetStepSize(const math::clock::duration &_step)
+void SimulationRunner::SetStepSize(const ignition::math::clock::duration &_step)
 {
   this->stepSize = _step;
 }
@@ -1269,7 +1279,7 @@ bool SimulationRunner::RequestRemoveEntity(const Entity _entity,
 }
 
 //////////////////////////////////////////////////
-bool SimulationRunner::GuiInfoService(msgs::GUI &_res)
+bool SimulationRunner::GuiInfoService(ignition::msgs::GUI &_res)
 {
   _res.Clear();
 
