@@ -15,9 +15,9 @@
  *
 */
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
-#include "gz/sim/gui/TmpIface.hh"
+#include "ignition/gazebo/gui/TmpIface.hh"
 
 using namespace ignition;
 using namespace gazebo;
@@ -25,23 +25,31 @@ using namespace gazebo;
 /////////////////////////////////////////////////
 TmpIface::TmpIface()
 {
+  // Server control
+  this->node.Advertise("/server_control",
+      &TmpIface::OnServerControl, this);
 }
 
-
 /////////////////////////////////////////////////
-bool TmpIface::OnServerControl(const msgs::ServerControl &/*_req*/,
-                                     msgs::Boolean &/*_res*/)
+bool TmpIface::OnServerControl(const msgs::ServerControl &_req,
+                                     msgs::Boolean &_res)
 {
-  ignerr << "Called wrong /server_control callback. Call the one in "
-         << "ServerPrivate instead." << std::endl;
-  return false;
+  igndbg << "OnServerControl: request" << std::endl;
+  igndbg << _req.DebugString() << std::endl;
+
+  _res.set_data(true);
+
+  igndbg << "OnServerControl: response" << std::endl;
+  igndbg << _res.DebugString() << std::endl;
+
+  return true;
 }
 
 /////////////////////////////////////////////////
 void TmpIface::OnNewWorld()
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &_res, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &_res, const bool _result)
   {
     igndbg << "NewWorld callback: result: " << _result << std::endl;
     igndbg << "NewWorld callback: response: " << _res.DebugString()
@@ -60,8 +68,8 @@ void TmpIface::OnLoadWorld(const QString &_path)
   if (localPath.isEmpty())
     localPath = _path;
 
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &_res, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &_res, const bool _result)
   {
     igndbg << "LoadWorld callback: result: " << _result << std::endl;
     igndbg << "LoadWorld callback: response: " << _res.DebugString()
@@ -80,8 +88,8 @@ void TmpIface::OnSaveWorldAs(const QString &_path)
   if (localPath.isEmpty())
     localPath = _path;
 
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &_res, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &_res, const bool _result)
   {
     igndbg << "SaveWorldAs callback: result: " << _result << std::endl;
     igndbg << "SaveWorldAs callback: response: " << _res.DebugString()
