@@ -15,8 +15,8 @@
  *
 */
 
-#include <gz/msgs/boolean.pb.h>
-#include <gz/msgs/pose.pb.h>
+#include <ignition/msgs/boolean.pb.h>
+#include <ignition/msgs/vector3d.pb.h>
 
 #include <algorithm>
 #include <iostream>
@@ -25,25 +25,25 @@
 #include <string>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/gui/Application.hh>
-#include <gz/gui/MainWindow.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/rendering/Geometry.hh>
-#include <gz/rendering/Material.hh>
-#include <gz/rendering/RenderEngine.hh>
-#include <gz/rendering/RenderTypes.hh>
-#include <gz/rendering/RenderingIface.hh>
-#include <gz/rendering/Scene.hh>
-#include <gz/rendering/Visual.hh>
-#include <gz/transport/Node.hh>
-
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/gui/GuiEvents.hh"
-#include "gz/sim/rendering/RenderUtil.hh"
+#include <ignition/gui/Application.hh>
+#include <ignition/gui/GuiEvents.hh>
+#include <ignition/gui/MainWindow.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/rendering/Visual.hh>
+#include <ignition/rendering/Geometry.hh>
+#include <ignition/rendering/Material.hh>
+#include <ignition/rendering/RenderTypes.hh>
+#include <ignition/rendering/RenderingIface.hh>
+#include <ignition/rendering/RenderEngine.hh>
+#include <ignition/rendering/Scene.hh>
+#include <ignition/rendering/WireBox.hh>
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/components/Name.hh"
 
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/gui/GuiEvents.hh"
 #include "AlignTool.hh"
 
 namespace ignition::gazebo
@@ -68,7 +68,12 @@ namespace ignition::gazebo
     /// \brief The current align state.
     public: AlignState currentState{AlignState::NONE};
 
-    /// \brief Flag to indicate if the entities should be aligned to the first
+    public: AlignConfig config{AlignConfig::ALIGN_MID};
+
+    /// \brief Flag to indicate if the align direction should be reversed.
+    public: bool reverse{false};
+
+    /// \brief Flag to indicate if the entities to should aligned to the first
     /// or last entity selected.
     public: bool first{true};
 
@@ -84,14 +89,11 @@ namespace ignition::gazebo
 
     /// \brief The map of the original transparency values for the nodes.
     public: std::map<std::string, double> originalTransparency;
-
-    /// \brief Pointer to the scene.
-    public: rendering::ScenePtr scene{nullptr};
   };
 }
 
 using namespace ignition;
-using namespace ignition::gazebo;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
 AlignTool::AlignTool()
@@ -99,8 +101,8 @@ AlignTool::AlignTool()
 {
   // Deselect all entities upon loading plugin
   gui::events::DeselectAllEntities deselectEvent(true);
-  gz::gui::App()->sendEvent(
-      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+  ignition::gui::App()->sendEvent(
+      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
       &deselectEvent);
 }
 
@@ -114,8 +116,8 @@ void AlignTool::LoadConfig(const tinyxml2::XMLElement *)
     this->title = "Align tool";
 
   // For align tool requests
-  gz::gui::App()->findChild
-      <gz::gui::MainWindow *>()->installEventFilter(this);
+  ignition::gui::App()->findChild
+      <ignition::gui::MainWindow *>()->installEventFilter(this);
 }
 
 /////////////////////////////////////////////////
@@ -137,6 +139,42 @@ void AlignTool::Update(const UpdateInfo &/* _info */,
   }
 }
 
+/////////////////////////////////////////////////
+void AlignTool::OnAlignConfig(const QString &_config)
+{
+  std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
+  std::string newConfig = _config.toStdString();
+  std::transform(newConfig.begin(), newConfig.end(),
+                 newConfig.begin(), ::tolower);
+
+  if (newConfig == "min")
+  {
+    this->dataPtr->config = AlignConfig::ALIGN_MIN;
+  }
+  else if (newConfig == "mid")
+  {
+    this->dataPtr->config = AlignConfig::ALIGN_MID;
+  }
+  else if (newConfig == "max")
+  {
+    this->dataPtr->config = AlignConfig::ALIGN_MAX;
+  }
+  else
+  {
+    ignwarn << "Invalid align axis config: " << newConfig << "\n";
+    ignwarn << "The valid options are:\n";
+    ignwarn << " - min\n";
+    ignwarn << " - mid\n";
+    ignwarn << " - max\n";
+  }
+}
+
+/////////////////////////////////////////////////
+void AlignTool::OnReverse(bool _reverse)
+{
+  this->dataPtr->reverse = _reverse;
+}
+
 /////////////////////////////////////////////////
 void AlignTool::OnAlignAxis(const QString &_axis)
 {
@@ -221,7 +259,8 @@ void AlignTool::AddState(const AlignState &_state)
 }
 
 ////////////////////////////////////////////////
-void AlignTool::MakeTransparent(const rendering::NodePtr &_node)
+void AlignTool::UpdateTransparency(const rendering::NodePtr &_node,
+    bool _makeTransparent)
 {
   if (!_node)
     return;
@@ -229,56 +268,7 @@ void AlignTool::MakeTransparent(const rendering::NodePtr &_node)
   for (auto n = 0u; n < _node->ChildCount(); ++n)
   {
     auto child = _node->ChildByIndex(n);
-    this->MakeTransparent(child);
-  }
-
-  auto vis = std::dynamic_pointer_cast<rendering::Visual>(_node);
-  if (nullptr == vis)
-    return;
-
-  // Visual material
-  auto visMat = vis->Material();
-  if (nullptr != visMat)
-  {
-    // If the entity isn't already transparent, make it transparent
-    if (this->dataPtr->originalTransparency.find(vis->Name()) ==
-        this->dataPtr->originalTransparency.end())
-    {
-      this->dataPtr->originalTransparency[vis->Name()] = visMat->Transparency();
-      visMat->SetTransparency(visMat->Transparency() + 0.5);
-    }
-  }
-
-  for (auto g = 0u; g < vis->GeometryCount(); ++g)
-  {
-    auto geom = vis->GeometryByIndex(g);
-
-    // Geometry material
-    auto geomMat = geom->Material();
-    if (nullptr == geomMat)
-      continue;
-
-    // If the entity isn't already transparent, make it transparent
-    if (this->dataPtr->originalTransparency.find(geom->Name()) ==
-        this->dataPtr->originalTransparency.end())
-    {
-      this->dataPtr->originalTransparency[geom->Name()] =
-          geomMat->Transparency();
-      geomMat->SetTransparency(geomMat->Transparency() + 0.5);
-    }
-  }
-}
-
-/////////////////////////////////////////////////
-void AlignTool::MakeSolid(const rendering::NodePtr &_node)
-{
-  if (!_node)
-    return;
-
-  for (auto n = 0u; n < _node->ChildCount(); ++n)
-  {
-    auto child = _node->ChildByIndex(n);
-    this->MakeSolid(child);
+    this->UpdateTransparency(child, _makeTransparent);
   }
 
   auto vis = std::dynamic_pointer_cast<rendering::Visual>(_node);
@@ -291,26 +281,57 @@ void AlignTool::MakeSolid(const rendering::NodePtr &_node)
   {
     auto visTransparency =
         this->dataPtr->originalTransparency.find(vis->Name());
-    if (visTransparency != this->dataPtr->originalTransparency.end())
+    if (_makeTransparent)
     {
-      visMat->SetTransparency(visTransparency->second);
+      // If the entity isn't already transparent, make it transparent
+      if (visTransparency == this->dataPtr->originalTransparency.end())
+      {
+        this->dataPtr->originalTransparency[vis->Name()] =
+          visMat->Transparency();
+        visMat->SetTransparency(1.0 - ((1.0 - visMat->Transparency()) * 0.5));
+      }
+    }
+    else
+    {
+      if (visTransparency != this->dataPtr->originalTransparency.end())
+      {
+        visMat->SetTransparency(visTransparency->second);
+      }
     }
   }
 
   for (auto g = 0u; g < vis->GeometryCount(); ++g)
   {
     auto geom = vis->GeometryByIndex(g);
+    auto wireBox = std::dynamic_pointer_cast<rendering::WireBox>(geom);
+
+    // Skip wirebox geometry
+    if (wireBox)
+      continue;
 
     // Geometry material
     auto geomMat = geom->Material();
     if (nullptr == geomMat)
       continue;
-
     auto geomTransparency =
         this->dataPtr->originalTransparency.find(geom->Name());
-    if (geomTransparency != this->dataPtr->originalTransparency.end())
+
+    if (_makeTransparent)
     {
-      geomMat->SetTransparency(geomTransparency->second);
+      // If the entity isn't already transparent, make it transparent
+      if (geomTransparency == this->dataPtr->originalTransparency.end())
+      {
+        this->dataPtr->originalTransparency[geom->Name()] =
+            geomMat->Transparency();
+        geomMat->SetTransparency(1.0 - ((1.0 - geomMat->Transparency()) * 0.5));
+      }
+    }
+    else
+    {
+      if (geomTransparency != this->dataPtr->originalTransparency.end())
+      {
+        geomMat->SetTransparency(geomTransparency->second);
+      }
     }
   }
 }
@@ -321,25 +342,73 @@ void AlignTool::Align()
   if (this->dataPtr->currentState == AlignState::NONE)
     return;
 
+  auto loadedEngNames = rendering::loadedEngines();
+  if (loadedEngNames.empty())
+  {
+    ignerr << "Internal error: engine should be loaded at this point."
+      << std::endl;
+    return;
+  }
+
+  // Assume there is only one engine loaded
+  auto engineName = loadedEngNames[0];
+  if (loadedEngNames.size() > 1)
+  {
+    ignwarn << "Found more than one loaded engine "
+      "- using " << engineName << "." << std::endl;
+  }
+  auto engine = rendering::engine(engineName);
+
+  if (!engine)
+  {
+    ignerr << "Internal error: failed to load engine [" << engineName
+      << "]. Align tool plugin won't work." << std::endl;
+    return;
+  }
+
+  if (engine->SceneCount() == 0)
+  {
+    ignerr<< "Internal error: no scenes are available with the loaded engine."
+      << std::endl;
+    return;
+  }
+  // assume there is only one scene
   // load scene
-  if (!this->dataPtr->scene)
-    this->dataPtr->scene = rendering::sceneFromFirstRenderEngine();
+  auto scene = engine->SceneByIndex(0);
+
+  if (!scene)
+  {
+    ignerr << "Internal error: scene is null." << std::endl;
+    return;
+  }
+
+  if (!scene->IsInitialized() || scene->VisualCount() == 0)
+  {
+    ignerr << "Internal error: scene is either not initialized "
+      "or there are no visuals within it." << std::endl;
+    return;
+  }
 
   // Get current list of selected entities
-  std::vector<rendering::VisualPtr> selectedList;
-  rendering::VisualPtr relativeVisual;
+  std::vector<ignition::rendering::VisualPtr> selectedList;
+  ignition::rendering::VisualPtr relativeVisual;
 
   for (const auto &entityId : this->dataPtr->selectedEntities)
   {
-    for (auto i = 0u; i < this->dataPtr->scene->VisualCount(); ++i)
+    for (auto i = 0u; i < scene->VisualCount(); ++i)
     {
-      rendering::VisualPtr vis =
-        this->dataPtr->scene->VisualByIndex(i);
+      ignition::rendering::VisualPtr vis = scene->VisualByIndex(i);
       if (!vis)
         continue;
+
       if (std::get<int>(vis->UserData("gazebo-entity")) ==
           static_cast<int>(entityId))
       {
+        // Check here to see if visual is top level or not, continue if not
+        rendering::VisualPtr topLevelVis = this->TopLevelVisual(scene, vis);
+        if (topLevelVis != vis)
+          continue;
+
         selectedList.push_back(vis);
       }
     }
@@ -356,8 +425,8 @@ void AlignTool::Align()
     (relativeVisual = selectedList.back());
 
   // Callback function for ignition node request
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &/* _rep*/, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &/* _rep*/, const bool _result)
   {
     if (!_result)
       ignerr << "Error setting pose" << std::endl;
@@ -371,31 +440,39 @@ void AlignTool::Align()
   }
 
   int axisIndex = static_cast<int>(this->dataPtr->axis);
-  msgs::Pose req;
+  ignition::msgs::Pose req;
+
+  ignition::math::AxisAlignedBox targetBox = relativeVisual->BoundingBox();
+  ignition::math::Vector3d targetMin = targetBox.Min();
+  ignition::math::Vector3d targetMax = targetBox.Max();
 
   // Index math to avoid iterating through the selected node
   for (unsigned int i = this->dataPtr->first;
        i < selectedList.size() + this->dataPtr->first - 1; i++)
   {
     rendering::VisualPtr vis = selectedList[i];
+    if (!vis)
+      continue;
+
+    ignition::math::AxisAlignedBox box = vis->BoundingBox();
+    ignition::math::Vector3d min = box.Min();
+    ignition::math::Vector3d max = box.Max();
 
     // Check here to see if visual is top level or not, continue if not
-    rendering::VisualPtr topLevelVis = this->TopLevelVisual(
-        this->dataPtr->scene, vis);
+    rendering::VisualPtr topLevelVis = this->TopLevelVisual(scene, vis);
     if (topLevelVis != vis)
       continue;
 
     math::Vector3d newPos = vis->WorldPosition();
 
-    // If a reset is occuring, the user has not clicked align,
-    // so pull all of the previous positions and set
+    // If a reset is occurring, pull all of the previous positions and set
     if (this->dataPtr->currentState == AlignState::RESET)
     {
       // Index offset given the relative node does not get added to the
       // prevPositions vector
       newPos = this->dataPtr->prevPositions[i-this->dataPtr->first];
 
-      this->MakeSolid(vis);
+      this->UpdateTransparency(vis, false /* opaque */);
       vis->SetWorldPosition(newPos);
       vis->SetUserData("pause-update", static_cast<int>(0));
     }
@@ -403,7 +480,7 @@ void AlignTool::Align()
     // make a request to the backend to send the node to the new position
     else if (this->dataPtr->currentState == AlignState::ALIGN)
     {
-      this->MakeSolid(vis);
+      this->UpdateTransparency(vis, false /* opaque */);
       req.set_name(vis->Name());
       msgs::Set(req.mutable_position(), newPos);
       msgs::Set(req.mutable_orientation(), vis->WorldRotation());
@@ -416,13 +493,39 @@ void AlignTool::Align()
     // and store the current position of the nodes
     else if (this->dataPtr->currentState == AlignState::HOVER)
     {
-      newPos[axisIndex] = relativeVisual->WorldPosition()[axisIndex];
+      double translation = 0.0;
+      if (this->dataPtr->config == AlignConfig::ALIGN_MID)
+      {
+        translation = (targetMin[axisIndex] + (targetMax[axisIndex]
+                                 - targetMin[axisIndex]) / 2) - (min[axisIndex]
+                                 + (max[axisIndex] - min[axisIndex]) / 2);
+      }
+      else
+      {
+        if (this->dataPtr->reverse)
+        {
+          if (this->dataPtr->config == AlignConfig::ALIGN_MIN)
+            translation = targetMin[axisIndex] - max[axisIndex];
+          else if (this->dataPtr->config == AlignConfig::ALIGN_MAX)
+            translation = targetMax[axisIndex] - min[axisIndex];
+        }
+        else
+        {
+          if (this->dataPtr->config == AlignConfig::ALIGN_MIN)
+            translation = targetMin[axisIndex] - min[axisIndex];
+          else if (this->dataPtr->config == AlignConfig::ALIGN_MAX)
+            translation = targetMax[axisIndex] - max[axisIndex];
+        }
+      }
+
+      // Add calculated translation to the chosen index
+      newPos[axisIndex] += translation;
 
       // Store the vis's world positions in a vector
       this->dataPtr->prevPositions.push_back(vis->WorldPosition());
 
       // Make the visual transparent and update to new position
-      this->MakeTransparent(vis);
+      this->UpdateTransparency(vis, true /* transparent */);
       vis->SetWorldPosition(newPos);
       vis->SetUserData("pause-update", static_cast<int>(1));
     }
@@ -483,7 +586,7 @@ rendering::NodePtr AlignTool::TopLevelNode(rendering::ScenePtr &_scene,
 /////////////////////////////////////////////////
 bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == gui::events::Render::kType)
+  if (_event->type() == ignition::gui::events::Render::kType)
   {
     // This event is called in Scene3d's RenderThread, so it's safe to make
     // rendering calls here
@@ -498,10 +601,11 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   else if (_event->type() ==
-           gui::events::EntitiesSelected::kType)
+           ignition::gazebo::gui::events::EntitiesSelected::kType)
   {
     auto selectedEvent =
-        reinterpret_cast<gui::events::EntitiesSelected *>(_event);
+        reinterpret_cast<ignition::gazebo::gui::events::EntitiesSelected *>(
+        _event);
 
     // Only update if a valid cast, the data isn't empty, and
     // the command is not from user (sent from backend)
@@ -509,8 +613,8 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
     {
       for (const auto &_entity : selectedEvent->Data())
       {
-        // If the element already exists in the selected entities vector,
-        // continue
+        // If the element already exists in the selected entity's
+        // vector, then continue
         if (std::find(this->dataPtr->selectedEntities.begin(),
               this->dataPtr->selectedEntities.end(),
               _entity) != this->dataPtr->selectedEntities.end())
@@ -520,7 +624,7 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   else if (_event->type() ==
-           gui::events::DeselectAllEntities::kType)
+           ignition::gazebo::gui::events::DeselectAllEntities::kType)
   {
     this->dataPtr->selectedEntities.clear();
   }
@@ -528,5 +632,5 @@ bool AlignTool::eventFilter(QObject *_obj, QEvent *_event)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(AlignTool,
-                    gz::gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gazebo::AlignTool,
+                    ignition::gui::Plugin)
