@@ -17,53 +17,51 @@
 
 #include <iostream>
 #include <regex>
-#include <gz/common/Console.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/gui/Application.hh>
-#include <gz/gui/MainWindow.hh>
-#include <gz/plugin/Register.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/gui/Application.hh>
+#include <ignition/gui/MainWindow.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/Actor.hh"
-#include "gz/sim/components/AngularAcceleration.hh"
-#include "gz/sim/components/AngularVelocity.hh"
-#include "gz/sim/components/BatterySoC.hh"
-#include "gz/sim/components/CastShadows.hh"
-#include "gz/sim/components/CenterOfVolume.hh"
-#include "gz/sim/components/ChildLinkName.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Factory.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/LaserRetro.hh"
-#include "gz/sim/components/Level.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/LinearAcceleration.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/LinearVelocitySeed.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/MagneticField.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/ParentLinkName.hh"
-#include "gz/sim/components/Performer.hh"
-#include "gz/sim/components/PerformerAffinity.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/SelfCollide.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/SourceFilePath.hh"
-#include "gz/sim/components/Static.hh"
-#include "gz/sim/components/ThreadPitch.hh"
-#include "gz/sim/components/Transparency.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/Volume.hh"
-#include "gz/sim/components/WindMode.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/gui/GuiEvents.hh"
+#include "ignition/gazebo/components/Actor.hh"
+#include "ignition/gazebo/components/AngularAcceleration.hh"
+#include "ignition/gazebo/components/AngularVelocity.hh"
+#include "ignition/gazebo/components/CastShadows.hh"
+#include "ignition/gazebo/components/ChildLinkName.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Factory.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/Level.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LightCmd.hh"
+#include "ignition/gazebo/components/LightType.hh"
+#include "ignition/gazebo/components/LinearAcceleration.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/LinearVelocitySeed.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/MagneticField.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/ParentLinkName.hh"
+#include "ignition/gazebo/components/Performer.hh"
+#include "ignition/gazebo/components/PerformerAffinity.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/PoseCmd.hh"
+#include "ignition/gazebo/components/SelfCollide.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/SourceFilePath.hh"
+#include "ignition/gazebo/components/Static.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/WindMode.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/gui/GuiEvents.hh"
 
 #include "ComponentInspector.hh"
-#include "Pose3d.hh"
 
 namespace ignition::gazebo
 {
@@ -81,6 +79,9 @@ namespace ignition::gazebo
     /// \brief Name of the world
     public: std::string worldName;
 
+    /// \brief Entity name
+    public: std::string entityName;
+
     /// \brief Entity type, such as 'world' or 'model'.
     public: QString type;
 
@@ -95,27 +96,78 @@ namespace ignition::gazebo
 
     /// \brief Transport node for making command requests
     public: transport::Node node;
-
-    /// \brief A map of component types to the function used to update it.
-    public: std::map<ComponentTypeId, inspector::UpdateViewCb>
-        updateViewCbs;
-
-    /// \brief Handles all components displayed as a 3D pose.
-    public: std::unique_ptr<inspector::Pose3d> pose3d;
   };
 }
 
 using namespace ignition;
-using namespace ignition::gazebo;
+using namespace gazebo;
+
+//////////////////////////////////////////////////
+template<>
+void ignition::gazebo::setData(QStandardItem *_item, const math::Pose3d &_data)
+{
+  _item->setData(QString("Pose3d"),
+      ComponentsModel::RoleNames().key("dataType"));
+  _item->setData(QList({
+    QVariant(_data.Pos().X()),
+    QVariant(_data.Pos().Y()),
+    QVariant(_data.Pos().Z()),
+    QVariant(_data.Rot().Roll()),
+    QVariant(_data.Rot().Pitch()),
+    QVariant(_data.Rot().Yaw())
+  }), ComponentsModel::RoleNames().key("data"));
+}
+
+//////////////////////////////////////////////////
+template<>
+void ignition::gazebo::setData(QStandardItem *_item, const msgs::Light &_data)
+{
+  int lightType = -1;
+  if (_data.type() == msgs::Light::POINT)
+  {
+    lightType = 0;
+  }
+  else if (_data.type() == msgs::Light::SPOT)
+  {
+    lightType = 1;
+  }
+  else if (_data.type() == msgs::Light::DIRECTIONAL)
+  {
+    lightType = 2;
+  }
+
+  _item->setData(QString("Light"),
+      ComponentsModel::RoleNames().key("dataType"));
+  _item->setData(QList({
+    QVariant(_data.specular().r()),
+    QVariant(_data.specular().g()),
+    QVariant(_data.specular().b()),
+    QVariant(_data.specular().a()),
+    QVariant(_data.diffuse().r()),
+    QVariant(_data.diffuse().g()),
+    QVariant(_data.diffuse().b()),
+    QVariant(_data.diffuse().a()),
+    QVariant(_data.range()),
+    QVariant(_data.attenuation_linear()),
+    QVariant(_data.attenuation_constant()),
+    QVariant(_data.attenuation_quadratic()),
+    QVariant(_data.cast_shadows()),
+    QVariant(_data.direction().x()),
+    QVariant(_data.direction().y()),
+    QVariant(_data.direction().z()),
+    QVariant(_data.spot_inner_angle()),
+    QVariant(_data.spot_outer_angle()),
+    QVariant(_data.spot_falloff()),
+    QVariant(_data.intensity()),
+    QVariant(lightType)
+  }), ComponentsModel::RoleNames().key("data"));
+}
 
 //////////////////////////////////////////////////
 template<>
 void ignition::gazebo::setData(QStandardItem *_item,
     const math::Vector3d &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Vector3d"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(QList({
@@ -129,9 +181,6 @@ void ignition::gazebo::setData(QStandardItem *_item,
 template<>
 void ignition::gazebo::setData(QStandardItem *_item, const std::string &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("String"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(QString::fromStdString(_data),
@@ -143,9 +192,6 @@ template<>
 void ignition::gazebo::setData(QStandardItem *_item,
     const std::ostringstream &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Raw"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(QString::fromStdString(_data.str()),
@@ -156,9 +202,6 @@ void ignition::gazebo::setData(QStandardItem *_item,
 template<>
 void ignition::gazebo::setData(QStandardItem *_item, const bool &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Boolean"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(_data, ComponentsModel::RoleNames().key("data"));
@@ -168,28 +211,15 @@ void ignition::gazebo::setData(QStandardItem *_item, const bool &_data)
 template<>
 void ignition::gazebo::setData(QStandardItem *_item, const int &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Integer"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(_data, ComponentsModel::RoleNames().key("data"));
 }
 
-//////////////////////////////////////////////////
-template<>
-void ignition::gazebo::setData(QStandardItem *_item, const Entity &_data)
-{
-  setData(_item, static_cast<int>(_data));
-}
-
 //////////////////////////////////////////////////
 template<>
 void ignition::gazebo::setData(QStandardItem *_item, const double &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Float"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(_data, ComponentsModel::RoleNames().key("data"));
@@ -199,9 +229,6 @@ void ignition::gazebo::setData(QStandardItem *_item, const double &_data)
 template<>
 void ignition::gazebo::setData(QStandardItem *_item, const sdf::Physics &_data)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString("Physics"),
       ComponentsModel::RoleNames().key("dataType"));
   _item->setData(QList({
@@ -213,9 +240,6 @@ void ignition::gazebo::setData(QStandardItem *_item, const sdf::Physics &_data)
 //////////////////////////////////////////////////
 void ignition::gazebo::setUnit(QStandardItem *_item, const std::string &_unit)
 {
-  if (nullptr == _item)
-    return;
-
   _item->setData(QString::fromStdString(_unit),
       ComponentsModel::RoleNames().key("unit"));
 }
@@ -240,7 +264,7 @@ ComponentsModel::ComponentsModel() : QStandardItemModel()
 
 /////////////////////////////////////////////////
 QStandardItem *ComponentsModel::AddComponentType(
-    ComponentTypeId _typeId)
+    ignition::gazebo::ComponentTypeId _typeId)
 {
   IGN_PROFILE_THREAD_NAME("Qt thread");
   IGN_PROFILE("ComponentsModel::AddComponentType");
@@ -271,7 +295,7 @@ QStandardItem *ComponentsModel::AddComponentType(
 
 /////////////////////////////////////////////////
 void ComponentsModel::RemoveComponentType(
-      ComponentTypeId _typeId)
+      ignition::gazebo::ComponentTypeId _typeId)
 {
   IGN_PROFILE_THREAD_NAME("Qt thread");
   IGN_PROFILE("ComponentsModel::RemoveComponentType");
@@ -300,15 +324,15 @@ QHash<int, QByteArray> ComponentsModel::RoleNames()
           std::pair(102, "shortName"),
           std::pair(103, "dataType"),
           std::pair(104, "unit"),
-          std::pair(105, "data")};
+          std::pair(105, "data"),
+          std::pair(106, "entity")};
 }
 
 /////////////////////////////////////////////////
 ComponentInspector::ComponentInspector()
   : GuiSystem(), dataPtr(std::make_unique<ComponentInspectorPrivate>())
 {
-  qRegisterMetaType<ComponentTypeId>();
-  qRegisterMetaType<Entity>("Entity");
+  qRegisterMetaType<ignition::gazebo::ComponentTypeId>();
 }
 
 /////////////////////////////////////////////////
@@ -320,15 +344,12 @@ void ComponentInspector::LoadConfig(const tinyxml2::XMLElement *)
   if (this->title.empty())
     this->title = "Component inspector";
 
-  gz::gui::App()->findChild<
-      gz::gui::MainWindow *>()->installEventFilter(this);
+  ignition::gui::App()->findChild<
+      ignition::gui::MainWindow *>()->installEventFilter(this);
 
   // Connect model
   this->Context()->setContextProperty(
       "ComponentsModel", &this->dataPtr->componentsModel);
-
-  // Type-specific handlers
-  this->dataPtr->pose3d = std::make_unique<inspector::Pose3d>(this);
 }
 
 //////////////////////////////////////////////////
@@ -412,12 +433,6 @@ void ComponentInspector::Update(const UpdateInfo &,
       continue;
     }
 
-    if (typeId == components::Light::typeId)
-    {
-      this->SetType("light");
-      continue;
-    }
-
     if (typeId == components::Actor::typeId)
     {
       this->SetType("actor");
@@ -434,9 +449,17 @@ void ComponentInspector::Update(const UpdateInfo &,
     // Add component to list
     else
     {
-      item = this->dataPtr->componentsModel.AddComponentType(typeId);
+      // TODO(louise) Blocking here is not the best idea
+      QMetaObject::invokeMethod(&this->dataPtr->componentsModel,
+          "AddComponentType",
+          Qt::BlockingQueuedConnection,
+          Q_RETURN_ARG(QStandardItem *, item),
+          Q_ARG(ignition::gazebo::ComponentTypeId, typeId));
     }
 
+    item->setData(QString::number(this->dataPtr->entity),
+                  ComponentsModel::RoleNames().key("entity"));
+
     if (nullptr == item)
     {
       ignerr << "Failed to get item for component type [" << typeId << "]"
@@ -465,9 +488,9 @@ void ComponentInspector::Update(const UpdateInfo &,
         setUnit(item, "rad/s");
       }
     }
-    else if (typeId == components::BatterySoC::typeId)
+    else if (typeId == components::AnimationName::typeId)
     {
-      auto comp = _ecm.Component<components::BatterySoC>(
+      auto comp = _ecm.Component<components::AnimationName>(
           this->dataPtr->entity);
       if (comp)
         setData(item, comp->Data());
@@ -479,16 +502,6 @@ void ComponentInspector::Update(const UpdateInfo &,
       if (comp)
         setData(item, comp->Data());
     }
-    else if (typeId == components::CenterOfVolume::typeId)
-    {
-      auto comp = _ecm.Component<components::CenterOfVolume>(
-          this->dataPtr->entity);
-      if (comp)
-      {
-        setData(item, comp->Data());
-        setUnit(item, "m");
-      }
-    }
     else if (typeId == components::ChildLinkName::typeId)
     {
       auto comp = _ecm.Component<components::ChildLinkName>(
@@ -505,12 +518,6 @@ void ComponentInspector::Update(const UpdateInfo &,
         setUnit(item, "m/s\u00B2");
       }
     }
-    else if (typeId == components::LaserRetro::typeId)
-    {
-      auto comp = _ecm.Component<components::LaserRetro>(this->dataPtr->entity);
-      if (comp)
-        setData(item, comp->Data());
-    }
     else if (typeId == components::LinearAcceleration::typeId)
     {
       auto comp = _ecm.Component<components::LinearAcceleration>(
@@ -549,6 +556,13 @@ void ComponentInspector::Update(const UpdateInfo &,
 
       if (this->dataPtr->entity == this->dataPtr->worldEntity)
         this->dataPtr->worldName = comp->Data();
+      this->dataPtr->entityName = comp->Data();
+    }
+    else if (typeId == components::LightType::typeId)
+    {
+      auto comp = _ecm.Component<components::LightType>(this->dataPtr->entity);
+      if (comp)
+        setData(item, comp->Data());
     }
     else if (typeId == components::ParentEntity::typeId)
     {
@@ -571,12 +585,28 @@ void ComponentInspector::Update(const UpdateInfo &,
       if (comp)
         setData(item, comp->Data());
     }
+    else if (typeId == components::Light::typeId)
+    {
+      this->SetType("light");
+      auto comp = _ecm.Component<components::Light>(this->dataPtr->entity);
+      if (comp)
+      {
+        msgs::Light lightMsgs = convert<msgs::Light>(comp->Data());
+        setData(item, lightMsgs);
+      }
+    }
     else if (typeId == components::Physics::typeId)
     {
       auto comp = _ecm.Component<components::Physics>(this->dataPtr->entity);
       if (comp)
         setData(item, comp->Data());
     }
+    else if (typeId == components::Pose::typeId)
+    {
+      auto comp = _ecm.Component<components::Pose>(this->dataPtr->entity);
+      if (comp)
+        setData(item, comp->Data());
+    }
     else if (typeId == components::Static::typeId)
     {
       auto comp = _ecm.Component<components::Static>(this->dataPtr->entity);
@@ -604,33 +634,6 @@ void ComponentInspector::Update(const UpdateInfo &,
       if (comp)
         setData(item, comp->Data());
     }
-    else if (typeId == components::ThreadPitch::typeId)
-    {
-      auto comp = _ecm.Component<components::ThreadPitch>(
-          this->dataPtr->entity);
-      if (comp)
-      {
-        setData(item, comp->Data());
-        setUnit(item, "m");
-      }
-    }
-    else if (typeId == components::Transparency::typeId)
-    {
-      auto comp = _ecm.Component<components::Transparency>(
-          this->dataPtr->entity);
-      if (comp)
-        setData(item, comp->Data());
-    }
-    else if (typeId == components::Volume::typeId)
-    {
-      auto comp = _ecm.Component<components::Volume>(
-          this->dataPtr->entity);
-      if (comp)
-      {
-        setData(item, comp->Data());
-        setUnit(item, "m\u00B3");
-      }
-    }
     else if (typeId == components::WindMode::typeId)
     {
       auto comp = _ecm.Component<components::WindMode>(this->dataPtr->entity);
@@ -647,16 +650,6 @@ void ComponentInspector::Update(const UpdateInfo &,
         setUnit(item, "rad/s\u00B2");
       }
     }
-    else if (typeId == components::WorldAngularVelocity::typeId)
-    {
-      auto comp = _ecm.Component<components::WorldAngularVelocity>(
-          this->dataPtr->entity);
-      if (comp)
-      {
-        setData(item, comp->Data());
-        setUnit(item, "rad/s");
-      }
-    }
     else if (typeId == components::WorldLinearVelocity::typeId)
     {
       auto comp = _ecm.Component<components::WorldLinearVelocity>(
@@ -677,10 +670,18 @@ void ComponentInspector::Update(const UpdateInfo &,
         setUnit(item, "m/s");
       }
     }
-    else if (this->dataPtr->updateViewCbs.find(typeId) !=
-          this->dataPtr->updateViewCbs.end())
+    else if (typeId == components::WorldPose::typeId)
     {
-      this->dataPtr->updateViewCbs[typeId](_ecm, item);
+      auto comp = _ecm.Component<components::WorldPose>(this->dataPtr->entity);
+      if (comp)
+        setData(item, comp->Data());
+    }
+    else if (typeId == components::WorldPoseCmd::typeId)
+    {
+      auto comp = _ecm.Component<components::WorldPoseCmd>(
+          this->dataPtr->entity);
+      if (comp)
+        setData(item, comp->Data());
     }
   }
 
@@ -698,19 +699,12 @@ void ComponentInspector::Update(const UpdateInfo &,
   }
 }
 
-/////////////////////////////////////////////////
-void ComponentInspector::AddUpdateViewCb(ComponentTypeId _id,
-    inspector::UpdateViewCb _cb)
-{
-  this->dataPtr->updateViewCbs[_id] = _cb;
-}
-
 /////////////////////////////////////////////////
 bool ComponentInspector::eventFilter(QObject *_obj, QEvent *_event)
 {
   if (!this->dataPtr->locked)
   {
-    if (_event->type() == gui::events::EntitiesSelected::kType)
+    if (_event->type() == gazebo::gui::events::EntitiesSelected::kType)
     {
       auto event = reinterpret_cast<gui::events::EntitiesSelected *>(_event);
       if (event && !event->Data().empty())
@@ -719,7 +713,7 @@ bool ComponentInspector::eventFilter(QObject *_obj, QEvent *_event)
       }
     }
 
-    if (_event->type() == gui::events::DeselectAllEntities::kType)
+    if (_event->type() == gazebo::gui::events::DeselectAllEntities::kType)
     {
       auto event = reinterpret_cast<gui::events::DeselectAllEntities *>(
           _event);
@@ -735,13 +729,13 @@ bool ComponentInspector::eventFilter(QObject *_obj, QEvent *_event)
 }
 
 /////////////////////////////////////////////////
-Entity ComponentInspector::GetEntity() const
+int ComponentInspector::Entity() const
 {
   return this->dataPtr->entity;
 }
 
 /////////////////////////////////////////////////
-void ComponentInspector::SetEntity(const Entity &_entity)
+void ComponentInspector::SetEntity(const int &_entity)
 {
   // If nothing is selected, display world properties
   if (_entity == kNullEntity)
@@ -794,17 +788,98 @@ void ComponentInspector::SetPaused(bool _paused)
   this->PausedChanged();
 }
 
+/////////////////////////////////////////////////
+void ComponentInspector::OnPose(double _x, double _y, double _z, double _roll,
+    double _pitch, double _yaw)
+{
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
+  {
+    if (!_result)
+        ignerr << "Error setting pose" << std::endl;
+  };
+
+  ignition::msgs::Pose req;
+  req.set_id(this->dataPtr->entity);
+  msgs::Set(req.mutable_position(), math::Vector3d(_x, _y, _z));
+  msgs::Set(req.mutable_orientation(), math::Quaterniond(_roll, _pitch, _yaw));
+  auto poseCmdService = "/world/" + this->dataPtr->worldName
+      + "/set_pose";
+  this->dataPtr->node.Request(poseCmdService, req, cb);
+}
+
+/////////////////////////////////////////////////
+void ComponentInspector::OnLight(
+  double _rSpecular, double _gSpecular, double _bSpecular, double _aSpecular,
+  double _rDiffuse, double _gDiffuse, double _bDiffuse, double _aDiffuse,
+  double _attRange, double _attLinear, double _attConstant,
+  double _attQuadratic, bool _castShadows, double _directionX,
+  double _directionY, double _directionZ, double _innerAngle,
+  double _outerAngle, double _falloff, double _intensity, int _type)
+{
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
+  {
+    if (!_result)
+      ignerr << "Error setting light configuration" << std::endl;
+  };
+
+  ignition::msgs::Light req;
+  req.set_name(this->dataPtr->entityName);
+  req.set_id(this->dataPtr->entity);
+  ignition::msgs::Set(req.mutable_diffuse(),
+    ignition::math::Color(_rDiffuse, _gDiffuse, _bDiffuse, _aDiffuse));
+  ignition::msgs::Set(req.mutable_specular(),
+    ignition::math::Color(_rSpecular, _gSpecular, _bSpecular, _aSpecular));
+  req.set_range(_attRange);
+  req.set_attenuation_linear(_attLinear);
+  req.set_attenuation_constant(_attConstant);
+  req.set_attenuation_quadratic(_attQuadratic);
+  req.set_cast_shadows(_castShadows);
+  req.set_intensity(_intensity);
+  if (_type == 0)
+    req.set_type(ignition::msgs::Light::POINT);
+  else if (_type == 1)
+    req.set_type(ignition::msgs::Light::SPOT);
+  else
+    req.set_type(ignition::msgs::Light::DIRECTIONAL);
+
+  if (_type == 1)  // sdf::LightType::SPOT
+  {
+    req.set_spot_inner_angle(_innerAngle);
+    req.set_spot_outer_angle(_outerAngle);
+    req.set_spot_falloff(_falloff);
+  }
+
+  // if sdf::LightType::SPOT || sdf::LightType::DIRECTIONAL
+  if (_type == 1 || _type == 2)
+  {
+    ignition::msgs::Set(req.mutable_direction(),
+      ignition::math::Vector3d(_directionX, _directionY, _directionZ));
+  }
+
+  auto lightConfigService = "/world/" + this->dataPtr->worldName +
+    "/light_config";
+  lightConfigService = transport::TopicUtils::AsValidTopic(lightConfigService);
+  if (lightConfigService.empty())
+  {
+    ignerr << "Invalid light command service topic provided" << std::endl;
+    return;
+  }
+  this->dataPtr->node.Request(lightConfigService, req, cb);
+}
+
 /////////////////////////////////////////////////
 void ComponentInspector::OnPhysics(double _stepSize, double _realTimeFactor)
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &/*_rep*/, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
   {
     if (!_result)
         ignerr << "Error setting physics parameters" << std::endl;
   };
 
-  msgs::Physics req;
+  ignition::msgs::Physics req;
   req.set_max_step_size(_stepSize);
   req.set_real_time_factor(_realTimeFactor);
   auto physicsCmdService = "/world/" + this->dataPtr->worldName
@@ -824,18 +899,6 @@ bool ComponentInspector::NestedModel() const
   return this->dataPtr->nestedModel;
 }
 
-/////////////////////////////////////////////////
-const std::string &ComponentInspector::WorldName() const
-{
-  return this->dataPtr->worldName;
-}
-
-/////////////////////////////////////////////////
-transport::Node &ComponentInspector::TransportNode()
-{
-  return this->dataPtr->node;
-}
-
 // Register this plugin
-IGNITION_ADD_PLUGIN(ComponentInspector,
-                    gz::gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gazebo::ComponentInspector,
+                    ignition::gui::Plugin)
