@@ -20,27 +20,27 @@
 #include <iostream>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/gui/Application.hh>
-#include <gz/gui/MainWindow.hh>
-#include <gz/plugin/Register.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/gui/Application.hh>
+#include <ignition/gui/MainWindow.hh>
+#include <ignition/plugin/Register.hh>
 
-#include "gz/sim/components/Actor.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/Level.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Performer.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/gui/GuiEvents.hh"
+#include "ignition/gazebo/components/Actor.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/Level.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Performer.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/gui/GuiEvents.hh"
 
 namespace ignition::gazebo
 {
@@ -58,7 +58,7 @@ namespace ignition::gazebo
 }
 
 using namespace ignition;
-using namespace ignition::gazebo;
+using namespace gazebo;
 
 //////////////////////////////////////////////////
 QString entityType(Entity _entity,
@@ -132,13 +132,6 @@ void TreeModel::AddEntity(unsigned int _entity, const QString &_entityName,
     return;
   }
 
-  if (this->entityItems.find(_entity) != this->entityItems.end())
-  {
-    ignwarn << "Internal error: Trying to create item for entity [" << _entity
-            << "], but entity already has an item." << std::endl;
-    return;
-  }
-
   // New entity item
   auto entityItem = new QStandardItem(_entityName);
   entityItem->setData(_entityName, this->roleNames().key("entityName"));
@@ -274,7 +267,7 @@ EntityTree::EntityTree()
   : GuiSystem(), dataPtr(std::make_unique<EntityTreePrivate>())
 {
   // Connect model
-  gz::gui::App()->Engine()->rootContext()->setContextProperty(
+  ignition::gui::App()->Engine()->rootContext()->setContextProperty(
      "EntityTreeModel", &this->dataPtr->treeModel);
 }
 
@@ -287,8 +280,8 @@ void EntityTree::LoadConfig(const tinyxml2::XMLElement *)
   if (this->title.empty())
     this->title = "Entity tree";
 
-  gz::gui::App()->findChild<
-      gz::gui::MainWindow *>()->installEventFilter(this);
+  ignition::gui::App()->findChild<
+      ignition::gui::MainWindow *>()->installEventFilter(this);
 }
 
 //////////////////////////////////////////////////
@@ -383,8 +376,8 @@ void EntityTree::OnEntitySelectedFromQml(unsigned int _entity)
 {
   std::vector<Entity> entitySet {_entity};
   gui::events::EntitiesSelected event(entitySet, true);
-  gz::gui::App()->sendEvent(
-      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+  ignition::gui::App()->sendEvent(
+      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
       &event);
 }
 
@@ -392,15 +385,15 @@ void EntityTree::OnEntitySelectedFromQml(unsigned int _entity)
 void EntityTree::DeselectAllEntities()
 {
   gui::events::DeselectAllEntities event(true);
-  gz::gui::App()->sendEvent(
-      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+  ignition::gui::App()->sendEvent(
+      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
       &event);
 }
 
 /////////////////////////////////////////////////
 bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == gui::events::EntitiesSelected::kType)
+  if (_event->type() == ignition::gazebo::gui::events::EntitiesSelected::kType)
   {
     auto selectedEvent =
         reinterpret_cast<gui::events::EntitiesSelected *>(_event);
@@ -418,7 +411,7 @@ bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   else if (_event->type() ==
-           gui::events::DeselectAllEntities::kType)
+           ignition::gazebo::gui::events::DeselectAllEntities::kType)
   {
     auto deselectAllEvent =
         reinterpret_cast<gui::events::DeselectAllEntities *>(_event);
@@ -434,5 +427,5 @@ bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(EntityTree,
-                    gz::gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gazebo::EntityTree,
+                    ignition::gui::Plugin)
