@@ -15,23 +15,23 @@
  *
 */
 
-#include <gz/msgs/marker.pb.h>
+#include <ignition/msgs/marker.pb.h>
 
 #include <iostream>
 #include <unordered_set>
 #include <string>
 #include <memory>
 
-#include <gz/common/Console.hh>
-#include <gz/gui/Application.hh>
-#include <gz/gui/GuiEvents.hh>
-#include <gz/gui/MainWindow.hh>
-#include <gz/msgs/Utility.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
-#include <gz/transport/Publisher.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/gui/Application.hh>
+#include <ignition/gui/GuiEvents.hh>
+#include <ignition/gui/MainWindow.hh>
+#include <ignition/msgs/Utility.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/transport/Publisher.hh>
 
-#include "gz/sim/gui/GuiEvents.hh"
+#include "ignition/gazebo/gui/GuiEvents.hh"
 #include "TapeMeasure.hh"
 
 namespace ignition::gazebo
@@ -60,22 +60,22 @@ namespace ignition::gazebo
 
     /// \brief The location of the placed starting point of the tape measure
     /// tool, only set when the user clicks to set the point.
-    public: gz::math::Vector3d startPoint =
-            gz::math::Vector3d::Zero;
+    public: ignition::math::Vector3d startPoint =
+            ignition::math::Vector3d::Zero;
 
     /// \brief The location of the placed ending point of the tape measure
     /// tool, only set when the user clicks to set the point.
-    public: gz::math::Vector3d endPoint = gz::math::Vector3d::Zero;
+    public: ignition::math::Vector3d endPoint = ignition::math::Vector3d::Zero;
 
     /// \brief The color to set the marker when hovering the mouse over the
     /// scene.
-    public: gz::math::Color
-            hoverColor{gz::math::Color(0.2, 0.2, 0.2, 0.5)};
+    public: ignition::math::Color
+            hoverColor{ignition::math::Color(0.2, 0.2, 0.2, 0.5)};
 
     /// \brief The color to draw the marker when the user clicks to confirm
     /// its location.
-    public: gz::math::Color
-            drawColor{gz::math::Color(0.2, 0.2, 0.2, 1.0)};
+    public: ignition::math::Color
+            drawColor{ignition::math::Color(0.2, 0.2, 0.2, 1.0)};
 
     /// \brief A set of the currently placed markers.  Used to make sure a
     /// non-existent marker is not deleted.
@@ -91,11 +91,11 @@ namespace ignition::gazebo
 }
 
 using namespace ignition;
-using namespace ignition::gazebo;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
 TapeMeasure::TapeMeasure()
-  : gz::gui::Plugin(),
+  : ignition::gui::Plugin(),
   dataPtr(std::make_unique<TapeMeasurePrivate>())
 {
 }
@@ -109,9 +109,9 @@ void TapeMeasure::LoadConfig(const tinyxml2::XMLElement *)
   if (this->title.empty())
     this->title = "Tape measure";
 
-  gz::gui::App()->findChild<gz::gui::MainWindow *>
+  ignition::gui::App()->findChild<ignition::gui::MainWindow *>
       ()->installEventFilter(this);
-  gz::gui::App()->findChild<gz::gui::MainWindow *>
+  ignition::gui::App()->findChild<ignition::gui::MainWindow *>
       ()->QuickWindow()->installEventFilter(this);
 }
 
@@ -130,9 +130,9 @@ void TapeMeasure::Measure()
 
   // Notify Scene3D to disable the right click menu while we use it to
   // cancel our current measuring action
-  gz::gui::events::DropdownMenuEnabled dropdownMenuEnabledEvent(false);
-  gz::gui::App()->sendEvent(
-      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+  ignition::gui::events::DropdownMenuEnabled dropdownMenuEnabledEvent(false);
+  ignition::gui::App()->sendEvent(
+      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
       &dropdownMenuEnabledEvent);
 }
 
@@ -150,8 +150,8 @@ void TapeMeasure::Reset()
   this->DeleteMarker(this->dataPtr->kLineId);
 
   this->dataPtr->currentId = this->dataPtr->kStartPointId;
-  this->dataPtr->startPoint = math::Vector3d::Zero;
-  this->dataPtr->endPoint = math::Vector3d::Zero;
+  this->dataPtr->startPoint = ignition::math::Vector3d::Zero;
+  this->dataPtr->endPoint = ignition::math::Vector3d::Zero;
   this->dataPtr->distance = 0.0;
   this->dataPtr->measure = false;
   this->newDistance();
@@ -159,9 +159,9 @@ void TapeMeasure::Reset()
 
   // Notify Scene3D that we are done using the right click, so it can
   // re-enable the settings menu
-  gz::gui::events::DropdownMenuEnabled dropdownMenuEnabledEvent(true);
-  gz::gui::App()->sendEvent(
-      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+  ignition::gui::events::DropdownMenuEnabled dropdownMenuEnabledEvent(true);
+  ignition::gui::App()->sendEvent(
+      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
       &dropdownMenuEnabledEvent);
 }
 
@@ -179,51 +179,51 @@ void TapeMeasure::DeleteMarker(int _id)
     return;
 
   // Delete the previously created marker
-  msgs::Marker markerMsg;
+  ignition::msgs::Marker markerMsg;
   markerMsg.set_ns(this->dataPtr->ns);
   markerMsg.set_id(_id);
-  markerMsg.set_action(msgs::Marker::DELETE_MARKER);
+  markerMsg.set_action(ignition::msgs::Marker::DELETE_MARKER);
   this->dataPtr->node.Request("/marker", markerMsg);
   this->dataPtr->placedMarkers.erase(_id);
 }
 
 /////////////////////////////////////////////////
 void TapeMeasure::DrawPoint(int _id,
-    math::Vector3d &_point, math::Color &_color)
+    ignition::math::Vector3d &_point, ignition::math::Color &_color)
 {
   this->DeleteMarker(_id);
 
-  msgs::Marker markerMsg;
+  ignition::msgs::Marker markerMsg;
   markerMsg.set_ns(this->dataPtr->ns);
   markerMsg.set_id(_id);
-  markerMsg.set_action(msgs::Marker::ADD_MODIFY);
-  markerMsg.set_type(msgs::Marker::SPHERE);
-  msgs::Set(markerMsg.mutable_material()->mutable_ambient(), _color);
-  msgs::Set(markerMsg.mutable_material()->mutable_diffuse(), _color);
-  msgs::Set(markerMsg.mutable_scale(),
-    math::Vector3d(0.1, 0.1, 0.1));
-  msgs::Set(markerMsg.mutable_pose(),
-    math::Pose3d(_point.X(), _point.Y(), _point.Z(), 0, 0, 0));
+  markerMsg.set_action(ignition::msgs::Marker::ADD_MODIFY);
+  markerMsg.set_type(ignition::msgs::Marker::SPHERE);
+  ignition::msgs::Set(markerMsg.mutable_material()->mutable_ambient(), _color);
+  ignition::msgs::Set(markerMsg.mutable_material()->mutable_diffuse(), _color);
+  ignition::msgs::Set(markerMsg.mutable_scale(),
+    ignition::math::Vector3d(0.1, 0.1, 0.1));
+  ignition::msgs::Set(markerMsg.mutable_pose(),
+    ignition::math::Pose3d(_point.X(), _point.Y(), _point.Z(), 0, 0, 0));
 
   this->dataPtr->node.Request("/marker", markerMsg);
   this->dataPtr->placedMarkers.insert(_id);
 }
 
 /////////////////////////////////////////////////
-void TapeMeasure::DrawLine(int _id, math::Vector3d &_startPoint,
-    math::Vector3d &_endPoint, math::Color &_color)
+void TapeMeasure::DrawLine(int _id, ignition::math::Vector3d &_startPoint,
+    ignition::math::Vector3d &_endPoint, ignition::math::Color &_color)
 {
   this->DeleteMarker(_id);
 
-  msgs::Marker markerMsg;
+  ignition::msgs::Marker markerMsg;
   markerMsg.set_ns(this->dataPtr->ns);
   markerMsg.set_id(_id);
-  markerMsg.set_action(msgs::Marker::ADD_MODIFY);
-  markerMsg.set_type(msgs::Marker::LINE_LIST);
-  msgs::Set(markerMsg.mutable_material()->mutable_ambient(), _color);
-  msgs::Set(markerMsg.mutable_material()->mutable_diffuse(), _color);
-  msgs::Set(markerMsg.add_point(), _startPoint);
-  msgs::Set(markerMsg.add_point(), _endPoint);
+  markerMsg.set_action(ignition::msgs::Marker::ADD_MODIFY);
+  markerMsg.set_type(ignition::msgs::Marker::LINE_LIST);
+  ignition::msgs::Set(markerMsg.mutable_material()->mutable_ambient(), _color);
+  ignition::msgs::Set(markerMsg.mutable_material()->mutable_diffuse(), _color);
+  ignition::msgs::Set(markerMsg.add_point(), _startPoint);
+  ignition::msgs::Set(markerMsg.add_point(), _endPoint);
 
   this->dataPtr->node.Request("/marker", markerMsg);
   this->dataPtr->placedMarkers.insert(_id);
@@ -232,16 +232,16 @@ void TapeMeasure::DrawLine(int _id, math::Vector3d &_startPoint,
 /////////////////////////////////////////////////
 bool TapeMeasure::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == gz::gui::events::HoverToScene::kType)
+  if (_event->type() == ignition::gui::events::HoverToScene::kType)
   {
     auto hoverToSceneEvent =
-        reinterpret_cast<gz::gui::events::HoverToScene *>(_event);
+        reinterpret_cast<ignition::gui::events::HoverToScene *>(_event);
 
     // This event is called in Scene3d's RenderThread, so it's safe to make
     // rendering calls here
     if (this->dataPtr->measure && hoverToSceneEvent)
     {
-      math::Vector3d point = hoverToSceneEvent->Point();
+      ignition::math::Vector3d point = hoverToSceneEvent->Point();
       this->DrawPoint(this->dataPtr->currentId, point,
         this->dataPtr->hoverColor);
 
@@ -256,16 +256,16 @@ bool TapeMeasure::eventFilter(QObject *_obj, QEvent *_event)
       }
     }
   }
-  else if (_event->type() == gz::gui::events::LeftClickToScene::kType)
+  else if (_event->type() == ignition::gui::events::LeftClickToScene::kType)
   {
     auto leftClickToSceneEvent =
-        reinterpret_cast<gz::gui::events::LeftClickToScene *>(_event);
+        reinterpret_cast<ignition::gui::events::LeftClickToScene *>(_event);
 
     // This event is called in Scene3d's RenderThread, so it's safe to make
     // rendering calls here
     if (this->dataPtr->measure && leftClickToSceneEvent)
     {
-      math::Vector3d point = leftClickToSceneEvent->Point();
+      ignition::math::Vector3d point = leftClickToSceneEvent->Point();
       this->DrawPoint(this->dataPtr->currentId, point,
         this->dataPtr->drawColor);
       // If the user is placing the start point, update its position
@@ -288,11 +288,11 @@ bool TapeMeasure::eventFilter(QObject *_obj, QEvent *_event)
 
         // Notify Scene3D that we are done using the right click, so it can
         // re-enable the settings menu
-        gz::gui::events::DropdownMenuEnabled
+        ignition::gui::events::DropdownMenuEnabled
           dropdownMenuEnabledEvent(true);
 
-        gz::gui::App()->sendEvent(
-            gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+        ignition::gui::App()->sendEvent(
+            ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
             &dropdownMenuEnabledEvent);
       }
       this->dataPtr->currentId = this->dataPtr->kEndPointId;
@@ -317,7 +317,7 @@ bool TapeMeasure::eventFilter(QObject *_obj, QEvent *_event)
     }
   }
   // Cancel the current action if a right click is detected
-  else if (_event->type() == gz::gui::events::RightClickToScene::kType)
+  else if (_event->type() == ignition::gui::events::RightClickToScene::kType)
   {
     if (this->dataPtr->measure)
     {
@@ -329,5 +329,5 @@ bool TapeMeasure::eventFilter(QObject *_obj, QEvent *_event)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(TapeMeasure,
-                    gz::gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gazebo::TapeMeasure,
+                    ignition::gui::Plugin)
