@@ -17,29 +17,31 @@
 
 #include "AckermannSteering.hh"
 
-#include <gz/msgs/odometry.pb.h>
+#include <ignition/msgs/odometry.pb.h>
 
+#include <limits>
 #include <mutex>
 #include <set>
 #include <string>
 #include <vector>
 
-#include <gz/common/Profiler.hh>
-#include <gz/math/Quaternion.hh>
-#include <gz/math/Angle.hh>
-#include <gz/math/SpeedLimiter.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/math/Quaternion.hh>
+#include <ignition/math/Angle.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/CanonicalLink.hh"
-#include "gz/sim/components/JointPosition.hh"
-#include "gz/sim/components/JointVelocityCmd.hh"
-#include "gz/sim/Link.hh"
-#include "gz/sim/Model.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/components/CanonicalLink.hh"
+#include "ignition/gazebo/components/JointPosition.hh"
+#include "ignition/gazebo/components/JointVelocityCmd.hh"
+#include "ignition/gazebo/Link.hh"
+#include "ignition/gazebo/Model.hh"
+#include "ignition/gazebo/Util.hh"
 
-using namespace gz;
-using namespace gz::sim;
+#include "SpeedLimiter.hh"
+
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 /// \brief Velocity command.
@@ -58,21 +60,21 @@ class ignition::gazebo::systems::AckermannSteeringPrivate
 {
   /// \brief Callback for velocity subscription
   /// \param[in] _msg Velocity message
-  public: void OnCmdVel(const msgs::Twist &_msg);
+  public: void OnCmdVel(const ignition::msgs::Twist &_msg);
 
   /// \brief Update odometry and publish an odometry message.
   /// \param[in] _info System update information.
   /// \param[in] _ecm The EntityComponentManager of the given simulation
   /// instance.
-  public: void UpdateOdometry(const UpdateInfo &_info,
-    const EntityComponentManager &_ecm);
+  public: void UpdateOdometry(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm);
 
   /// \brief Update the linear and angular velocities.
   /// \param[in] _info System update information.
   /// \param[in] _ecm The EntityComponentManager of the given simulation
   /// instance.
-  public: void UpdateVelocity(const UpdateInfo &_info,
-    const EntityComponentManager &_ecm);
+  public: void UpdateVelocity(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm);
 
   /// \brief Ignition communication node.
   public: transport::Node node;
@@ -143,9 +145,6 @@ class ignition::gazebo::systems::AckermannSteeringPrivate
   /// \brief Ackermann steering odometry message publisher.
   public: transport::Node::Publisher odomPub;
 
-  /// \brief Ackermann tf message publisher.
-  public: transport::Node::Publisher tfPub;
-
   /// \brief Odometry X value
   public: double odomX{0.0};
 
@@ -165,10 +164,10 @@ class ignition::gazebo::systems::AckermannSteeringPrivate
   public: std::chrono::steady_clock::duration lastOdomTime{0};
 
   /// \brief Linear velocity limiter.
-  public: std::unique_ptr<math::SpeedLimiter> limiterLin;
+  public: std::unique_ptr<SpeedLimiter> limiterLin;
 
   /// \brief Angular velocity limiter.
-  public: std::unique_ptr<math::SpeedLimiter> limiterAng;
+  public: std::unique_ptr<SpeedLimiter> limiterAng;
 
   /// \brief Previous control command.
   public: Commands last0Cmd;
@@ -259,48 +258,56 @@ void AckermannSteering::Configure(const Entity &_entity,
   this->dataPtr->wheelRadius = _sdf->Get<double>("wheel_radius",
       this->dataPtr->wheelRadius).first;
 
-  // Instantiate the speed limiters.
-  this->dataPtr->limiterLin = std::make_unique<math::SpeedLimiter>();
-  this->dataPtr->limiterAng = std::make_unique<math::SpeedLimiter>();
-
   // Parse speed limiter parameters.
+  bool hasVelocityLimits     = false;
+  bool hasAccelerationLimits = false;
+  bool hasJerkLimits         = false;
+  double minVel              = std::numeric_limits<double>::lowest();
+  double maxVel              = std::numeric_limits<double>::max();
+  double minAccel            = std::numeric_limits<double>::lowest();
+  double maxAccel            = std::numeric_limits<double>::max();
+  double minJerk             = std::numeric_limits<double>::lowest();
+  double maxJerk             = std::numeric_limits<double>::max();
+
   if (_sdf->HasElement("min_velocity"))
   {
-    const double minVel = _sdf->Get<double>("min_velocity");
-    this->dataPtr->limiterLin->SetMinVelocity(minVel);
-    this->dataPtr->limiterAng->SetMinVelocity(minVel);
+    minVel = _sdf->Get<double>("min_velocity");
+    hasVelocityLimits = true;
   }
   if (_sdf->HasElement("max_velocity"))
   {
-    const double maxVel = _sdf->Get<double>("max_velocity");
-    this->dataPtr->limiterLin->SetMaxVelocity(maxVel);
-    this->dataPtr->limiterAng->SetMaxVelocity(maxVel);
+    maxVel = _sdf->Get<double>("max_velocity");
+    hasVelocityLimits = true;
   }
   if (_sdf->HasElement("min_acceleration"))
   {
-    const double minAccel = _sdf->Get<double>("min_acceleration");
-    this->dataPtr->limiterLin->SetMinAcceleration(minAccel);
-    this->dataPtr->limiterAng->SetMinAcceleration(minAccel);
+    minAccel = _sdf->Get<double>("min_acceleration");
+    hasAccelerationLimits = true;
   }
   if (_sdf->HasElement("max_acceleration"))
   {
-    const double maxAccel = _sdf->Get<double>("max_acceleration");
-    this->dataPtr->limiterLin->SetMaxAcceleration(maxAccel);
-    this->dataPtr->limiterAng->SetMaxAcceleration(maxAccel);
+    maxAccel = _sdf->Get<double>("max_acceleration");
+    hasAccelerationLimits = true;
   }
   if (_sdf->HasElement("min_jerk"))
   {
-    const double minJerk = _sdf->Get<double>("min_jerk");
-    this->dataPtr->limiterLin->SetMinJerk(minJerk);
-    this->dataPtr->limiterAng->SetMinJerk(minJerk);
+    minJerk = _sdf->Get<double>("min_jerk");
+    hasJerkLimits = true;
   }
   if (_sdf->HasElement("max_jerk"))
   {
-    const double maxJerk = _sdf->Get<double>("max_jerk");
-    this->dataPtr->limiterLin->SetMaxJerk(maxJerk);
-    this->dataPtr->limiterAng->SetMaxJerk(maxJerk);
+    maxJerk = _sdf->Get<double>("max_jerk");
+    hasJerkLimits = true;
   }
 
+  // Instantiate the speed limiters.
+  this->dataPtr->limiterLin = std::make_unique<SpeedLimiter>(
+    hasVelocityLimits, hasAccelerationLimits, hasJerkLimits,
+    minVel, maxVel, minAccel, maxAccel, minJerk, maxJerk);
+
+  this->dataPtr->limiterAng = std::make_unique<SpeedLimiter>(
+    hasVelocityLimits, hasAccelerationLimits, hasJerkLimits,
+    minVel, maxVel, minAccel, maxAccel, minJerk, maxJerk);
 
   double odomFreq = _sdf->Get<double>("odom_publish_frequency", 50).first;
   if (odomFreq > 0)
@@ -346,24 +353,6 @@ void AckermannSteering::Configure(const Entity &_entity,
   this->dataPtr->odomPub = this->dataPtr->node.Advertise<msgs::Odometry>(
       odomTopic);
 
-  std::vector<std::string> tfTopics;
-  if (_sdf->HasElement("tf_topic"))
-  {
-    tfTopics.push_back(_sdf->Get<std::string>("tf_topic"));
-  }
-  tfTopics.push_back("/model/" + this->dataPtr->model.Name(_ecm) +
-    "/tf");
-  auto tfTopic = validTopic(tfTopics);
-  if (tfTopic.empty())
-  {
-    ignerr << "AckermannSteering plugin invalid tf topic name "
-           << "Failed to initialize." << std::endl;
-    return;
-  }
-
-  this->dataPtr->tfPub = this->dataPtr->node.Advertise<msgs::Pose_V>(
-      tfTopic);
-
   if (_sdf->HasElement("frame_id"))
     this->dataPtr->sdfFrameId = _sdf->Get<std::string>("frame_id");
 
@@ -375,8 +364,8 @@ void AckermannSteering::Configure(const Entity &_entity,
 }
 
 //////////////////////////////////////////////////
-void AckermannSteering::PreUpdate(const UpdateInfo &_info,
-    EntityComponentManager &_ecm)
+void AckermannSteering::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
+    ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("AckermannSteering::PreUpdate");
 
@@ -587,8 +576,8 @@ void AckermannSteering::PostUpdate(const UpdateInfo &_info,
 
 //////////////////////////////////////////////////
 void AckermannSteeringPrivate::UpdateOdometry(
-    const UpdateInfo &_info,
-    const EntityComponentManager &_ecm)
+    const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("AckermannSteering::UpdateOdometry");
   // Initialize, if not already initialized.
@@ -688,22 +677,14 @@ void AckermannSteeringPrivate::UpdateOdometry(
     childFrame->add_value(this->sdfChildFrameId);
   }
 
-  // Construct the Pose_V/tf message and publish it.
-  msgs::Pose_V tfMsg;
-  msgs::Pose *tfMsgPose = tfMsg.add_pose();
-  tfMsgPose->mutable_header()->CopyFrom(*msg.mutable_header());
-  tfMsgPose->mutable_position()->CopyFrom(msg.mutable_pose()->position());
-  tfMsgPose->mutable_orientation()->CopyFrom(msg.mutable_pose()->orientation());
-
   // Publish the message
   this->odomPub.Publish(msg);
-  this->tfPub.Publish(tfMsg);
 }
 
 //////////////////////////////////////////////////
 void AckermannSteeringPrivate::UpdateVelocity(
-    const UpdateInfo &_info,
-    const EntityComponentManager &_ecm)
+    const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("AckermannSteering::UpdateVelocity");
 
@@ -715,11 +696,11 @@ void AckermannSteeringPrivate::UpdateVelocity(
     angVel = this->targetVel.angular().z();
   }
 
+  const double dt = std::chrono::duration<double>(_info.dt).count();
+
   // Limit the target velocity if needed.
-  this->limiterLin->Limit(
-      linVel, this->last0Cmd.lin, this->last1Cmd.lin, _info.dt);
-  this->limiterAng->Limit(
-      angVel, this->last0Cmd.ang, this->last1Cmd.ang, _info.dt);
+  this->limiterLin->Limit(linVel, this->last0Cmd.lin, this->last1Cmd.lin, dt);
+  this->limiterAng->Limit(angVel, this->last0Cmd.ang, this->last1Cmd.ang, dt);
 
   // Update history of commands.
   this->last1Cmd = last0Cmd;
@@ -788,14 +769,10 @@ void AckermannSteeringPrivate::OnCmdVel(const msgs::Twist &_msg)
 }
 
 IGNITION_ADD_PLUGIN(AckermannSteering,
-                    System,
+                    ignition::gazebo::System,
                     AckermannSteering::ISystemConfigure,
                     AckermannSteering::ISystemPreUpdate,
                     AckermannSteering::ISystemPostUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(AckermannSteering,
-                          "gz::sim::systems::AckermannSteering")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(AckermannSteering,
                           "ignition::gazebo::systems::AckermannSteering")
