@@ -20,34 +20,32 @@
 #include <string>
 #include <unordered_map>
 
-#include <gz/common/Profiler.hh>
-#include <gz/common/VideoEncoder.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/VideoEncoder.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include <gz/rendering/Camera.hh>
-#include <gz/rendering/RenderEngine.hh>
-#include <gz/rendering/RenderingIface.hh>
-#include <gz/rendering/Scene.hh>
+#include <ignition/rendering/Camera.hh>
+#include <ignition/rendering/RenderEngine.hh>
+#include <ignition/rendering/RenderingIface.hh>
+#include <ignition/rendering/Scene.hh>
 
-#include "gz/sim/rendering/RenderUtil.hh"
-#include "gz/sim/rendering/Events.hh"
-#include "gz/sim/rendering/MarkerManager.hh"
+#include "ignition/gazebo/rendering/Events.hh"
 
-#include "gz/sim/components/Camera.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Conversions.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/Events.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/components/Camera.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Conversions.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/Events.hh"
+#include "ignition/gazebo/Util.hh"
 
 #include "CameraVideoRecorder.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 // Private data class.
@@ -70,7 +68,7 @@ class ignition::gazebo::systems::CameraVideoRecorderPrivate
   public: std::mutex updateMutex;
 
   /// \brief Connection to the post-render event.
-  public: common::ConnectionPtr postRenderConn;
+  public: ignition::common::ConnectionPtr postRenderConn;
 
   /// \brief Pointer to the event manager
   public: EventManager *eventMgr = nullptr;
@@ -110,33 +108,6 @@ class ignition::gazebo::systems::CameraVideoRecorderPrivate
 
   /// \brief Topic that the sensor publishes to
   public: std::string sensorTopic;
-
-  /// \brief Video recording statistics publisher
-  public: transport::Node::Publisher recorderStatsPub;
-
-  /// \brief Start time of video recording.
-  public: std::chrono::steady_clock::time_point recordStartTime;
-
-  /// \brief Current simulation time.
-  public: std::chrono::steady_clock::duration simTime{0};
-
-  /// \brief Use sim time as timestamp during video recording
-  /// By default (false), video encoding is done using real time.
-  public: bool recordVideoUseSimTime = false;
-
-  /// \brief Video recorder bitrate (bps). This is rougly 2Mbps which
-  /// produces decent video quality while not generating overly large
-  /// video files.
-  ///
-  /// Another point of reference is at:
-  /// https://support.google.com/youtube/answer/1722171?hl=en#zippy=%2Cbitrate
-  public: unsigned int recordVideoBitrate = 2070000;
-
-  /// \brief Recording frames per second.
-  public: unsigned int fps = 25;
-
-  /// \brief Marker manager
-  public: MarkerManager markerManager;
 };
 
 //////////////////////////////////////////////////
@@ -253,23 +224,6 @@ void CameraVideoRecorder::Configure(
     }
   }
   this->dataPtr->sensorTopic = topic;
-
-  // Get whether sim time should be used for recording.
-  this->dataPtr->recordVideoUseSimTime = _sdf->Get<bool>("use_sim_time",
-      this->dataPtr->recordVideoUseSimTime).first;
-
-  // Get video recoder bitrate param
-  this->dataPtr->recordVideoBitrate = _sdf->Get<unsigned int>("bitrate",
-      this->dataPtr->recordVideoBitrate).first;
-
-  this->dataPtr->fps = _sdf->Get<unsigned int>("fps", this->dataPtr->fps).first;
-
-  // recorder stats topic
-  std::string recorderStatsTopic = this->dataPtr->sensorTopic + "/stats";
-  this->dataPtr->recorderStatsPub =
-    this->dataPtr->node.Advertise<msgs::Time>(recorderStatsTopic);
-  ignmsg << "Camera Video recorder stats topic advertised on ["
-    << recorderStatsTopic << "]" << std::endl;
 }
 
 //////////////////////////////////////////////////
@@ -278,9 +232,38 @@ void CameraVideoRecorderPrivate::OnPostRender()
   // get scene
   if (!this->scene)
   {
-    this->scene = rendering::sceneFromFirstRenderEngine();
-    this->markerManager.SetTopic(this->sensorTopic + "/marker");
-    this->markerManager.Init(this->scene);
+    auto loadedEngNames = rendering::loadedEngines();
+    if (loadedEngNames.empty())
+      return;
+
+    // assume there is only one engine loaded
+    auto engineName = loadedEngNames[0];
+    if (loadedEngNames.size() > 1)
+    {
+      igndbg << "More than one engine is available. "
+        << "Camera video recorder system will use engine ["
+          << engineName << "]" << std::endl;
+    }
+    auto engine = rendering::engine(engineName);
+    if (!engine)
+    {
+      ignerr << "Internal error: failed to load engine [" << engineName
+        << "]. Camera video recorder system won't work." << std::endl;
+      return;
+    }
+
+    if (engine->SceneCount() == 0)
+      return;
+
+    // assume there is only one scene
+    // load scene
+    auto s = engine->SceneByIndex(0);
+    if (!s)
+    {
+      ignerr << "Internal error: scene is null." << std::endl;
+      return;
+    }
+    this->scene = s;
   }
 
   // return if scene not ready or no sensors available.
@@ -313,9 +296,6 @@ void CameraVideoRecorderPrivate::OnPostRender()
 
   std::lock_guard<std::mutex> lock(this->updateMutex);
 
-  this->markerManager.SetSimTime(this->simTime);
-  this->markerManager.Update();
-
   // record video
   if (this->recordVideo)
   {
@@ -332,36 +312,8 @@ void CameraVideoRecorderPrivate::OnPostRender()
     if (this->videoEncoder.IsEncoding())
     {
       this->camera->Copy(this->cameraImage);
-      std::chrono::steady_clock::time_point t;
-        std::chrono::steady_clock::now();
-      if (this->recordVideoUseSimTime)
-        t = std::chrono::steady_clock::time_point(this->simTime);
-      else
-        t = std::chrono::steady_clock::now();
-
-      bool frameAdded = this->videoEncoder.AddFrame(
-          this->cameraImage.Data<unsigned char>(), width, height, t);
-
-      if (frameAdded)
-      {
-        // publish recorder stats
-        if (this->recordStartTime ==
-            std::chrono::steady_clock::time_point(
-              std::chrono::duration(std::chrono::seconds(0))))
-        {
-          // start time, i.e. time when first frame is added
-          this->recordStartTime = t;
-        }
-
-        std::chrono::steady_clock::duration dt;
-        dt = t - this->recordStartTime;
-        int64_t sec, nsec;
-        std::tie(sec, nsec) = math::durationToSecNsec(dt);
-        msgs::Time msg;
-        msg.set_sec(sec);
-        msg.set_nsec(nsec);
-        this->recorderStatsPub.Publish(msg);
-      }
+      this->videoEncoder.AddFrame(
+          this->cameraImage.Data<unsigned char>(), width, height);
     }
     // Video recorder is idle. Start recording.
     else
@@ -375,11 +327,7 @@ void CameraVideoRecorderPrivate::OnPostRender()
           &CameraVideoRecorderPrivate::OnImage, this);
 
       this->videoEncoder.Start(this->recordVideoFormat,
-          this->tmpVideoFilename, width, height, this->fps,
-          this->recordVideoBitrate);
-
-      this->recordStartTime = std::chrono::steady_clock::time_point(
-            std::chrono::duration(std::chrono::seconds(0)));
+          this->tmpVideoFilename, width, height);
 
       ignmsg << "Start video recording on [" << this->service << "]. "
              << "Encoding to tmp file: ["
@@ -395,31 +343,18 @@ void CameraVideoRecorderPrivate::OnPostRender()
     // stop encoding
     this->videoEncoder.Stop();
 
-    ignmsg << "Stop video recording on [" << this->service << "]." << std::endl;
-
+    // move the tmp video file to user specified path
     if (common::exists(this->tmpVideoFilename))
     {
-      std::string parentPath = common::parentPath(this->recordVideoSavePath);
+      common::moveFile(this->tmpVideoFilename,
+          this->recordVideoSavePath);
 
-      // move the tmp video file to user specified path
-      if (parentPath != this->recordVideoSavePath &&
-          !common::exists(parentPath) && !common::createDirectory(parentPath))
-      {
-        ignerr << "Unable to create directory[" << parentPath
-          << "]. Video file[" << this->tmpVideoFilename
-          << "] will not be moved." << std::endl;
-      }
-      else
-      {
-        common::moveFile(this->tmpVideoFilename, this->recordVideoSavePath);
-
-        // Remove old temp file, if it exists.
-        std::remove(this->tmpVideoFilename.c_str());
-
-        ignmsg << "Saving tmp video[" << this->tmpVideoFilename << "] file to ["
-               << this->recordVideoSavePath << "]" << std::endl;
-      }
+      // Remove old temp file, if it exists.
+      std::remove(this->tmpVideoFilename.c_str());
     }
+    ignmsg << "Stop video recording on [" << this->service << "]. "
+           << "Saving file to: [" << this->recordVideoSavePath << "]"
+           << std::endl;
 
     // reset the event connection to prevent unnecessary render callbacks
     this->postRenderConn.reset();
@@ -427,10 +362,9 @@ void CameraVideoRecorderPrivate::OnPostRender()
 }
 
 //////////////////////////////////////////////////
-void CameraVideoRecorder::PostUpdate(const UpdateInfo &_info,
+void CameraVideoRecorder::PostUpdate(const UpdateInfo &,
     const EntityComponentManager &_ecm)
 {
-  this->dataPtr->simTime = _info.simTime;
   if (!this->dataPtr->cameraName.empty())
     return;
 
@@ -461,15 +395,11 @@ void CameraVideoRecorder::PostUpdate(const UpdateInfo &_info,
 }
 
 IGNITION_ADD_PLUGIN(CameraVideoRecorder,
-                    System,
+                    ignition::gazebo::System,
                     CameraVideoRecorder::ISystemConfigure,
                     CameraVideoRecorder::ISystemPostUpdate)
 
 // Add plugin alias so that we can refer to the plugin without the version
 // namespace
-IGNITION_ADD_PLUGIN_ALIAS(CameraVideoRecorder,
-                          "gz::sim::systems::CameraVideoRecorder")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(CameraVideoRecorder,
                           "ignition::gazebo::systems::CameraVideoRecorder")
