@@ -17,28 +17,31 @@
 
 #include "DiffDrive.hh"
 
-#include <gz/msgs/odometry.pb.h>
+#include <ignition/msgs/odometry.pb.h>
 
 #include <limits>
 #include <mutex>
+#include <set>
 #include <string>
 #include <vector>
 
-#include <gz/common/Profiler.hh>
-#include <gz/math/DiffDriveOdometry.hh>
-#include <gz/math/Quaternion.hh>
-#include <gz/math/SpeedLimiter.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/math/DiffDriveOdometry.hh>
+#include <ignition/math/Quaternion.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/CanonicalLink.hh"
-#include "gz/sim/components/JointPosition.hh"
-#include "gz/sim/components/JointVelocityCmd.hh"
-#include "gz/sim/Link.hh"
-#include "gz/sim/Model.hh"
+#include "ignition/gazebo/components/CanonicalLink.hh"
+#include "ignition/gazebo/components/JointPosition.hh"
+#include "ignition/gazebo/components/JointVelocityCmd.hh"
+#include "ignition/gazebo/Link.hh"
+#include "ignition/gazebo/Model.hh"
+#include "ignition/gazebo/Util.hh"
 
-using namespace gz;
-using namespace gz::sim;
+#include "SpeedLimiter.hh"
+
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 /// \brief Velocity command.
@@ -57,25 +60,21 @@ class ignition::gazebo::systems::DiffDrivePrivate
 {
   /// \brief Callback for velocity subscription
   /// \param[in] _msg Velocity message
-  public: void OnCmdVel(const msgs::Twist &_msg);
-
-  /// \brief Callback for enable/disable subscription
-  /// \param[in] _msg Boolean message
-  public: void OnEnable(const msgs::Boolean &_msg);
+  public: void OnCmdVel(const ignition::msgs::Twist &_msg);
 
   /// \brief Update odometry and publish an odometry message.
   /// \param[in] _info System update information.
   /// \param[in] _ecm The EntityComponentManager of the given simulation
   /// instance.
-  public: void UpdateOdometry(const UpdateInfo &_info,
-    const EntityComponentManager &_ecm);
+  public: void UpdateOdometry(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm);
 
   /// \brief Update the linear and angular velocities.
   /// \param[in] _info System update information.
   /// \param[in] _ecm The EntityComponentManager of the given simulation
   /// instance.
-  public: void UpdateVelocity(const UpdateInfo &_info,
-    const EntityComponentManager &_ecm);
+  public: void UpdateVelocity(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm);
 
   /// \brief Ignition communication node.
   public: transport::Node node;
@@ -126,10 +125,10 @@ class ignition::gazebo::systems::DiffDrivePrivate
   public: transport::Node::Publisher tfPub;
 
   /// \brief Linear velocity limiter.
-  public: std::unique_ptr<math::SpeedLimiter> limiterLin;
+  public: std::unique_ptr<SpeedLimiter> limiterLin;
 
   /// \brief Angular velocity limiter.
-  public: std::unique_ptr<math::SpeedLimiter> limiterAng;
+  public: std::unique_ptr<SpeedLimiter> limiterAng;
 
   /// \brief Previous control command.
   public: Commands last0Cmd;
@@ -140,9 +139,6 @@ class ignition::gazebo::systems::DiffDrivePrivate
   /// \brief Last target velocity requested.
   public: msgs::Twist targetVel;
 
-  /// \brief Enable/disable state of the controller.
-  public: bool enabled;
-
   /// \brief A mutex to protect the target velocity command.
   public: std::mutex mutex;
 
@@ -203,48 +199,57 @@ void DiffDrive::Configure(const Entity &_entity,
   this->dataPtr->wheelRadius = _sdf->Get<double>("wheel_radius",
       this->dataPtr->wheelRadius).first;
 
-  // Instantiate the speed limiters.
-  this->dataPtr->limiterLin = std::make_unique<math::SpeedLimiter>();
-  this->dataPtr->limiterAng = std::make_unique<math::SpeedLimiter>();
-
   // Parse speed limiter parameters.
+  bool hasVelocityLimits     = false;
+  bool hasAccelerationLimits = false;
+  bool hasJerkLimits         = false;
+  double minVel              = std::numeric_limits<double>::lowest();
+  double maxVel              = std::numeric_limits<double>::max();
+  double minAccel            = std::numeric_limits<double>::lowest();
+  double maxAccel            = std::numeric_limits<double>::max();
+  double minJerk             = std::numeric_limits<double>::lowest();
+  double maxJerk             = std::numeric_limits<double>::max();
+
   if (_sdf->HasElement("min_velocity"))
   {
-    const double minVel = _sdf->Get<double>("min_velocity");
-    this->dataPtr->limiterLin->SetMinVelocity(minVel);
-    this->dataPtr->limiterAng->SetMinVelocity(minVel);
+    minVel = _sdf->Get<double>("min_velocity");
+    hasVelocityLimits = true;
   }
   if (_sdf->HasElement("max_velocity"))
   {
-    const double maxVel = _sdf->Get<double>("max_velocity");
-    this->dataPtr->limiterLin->SetMaxVelocity(maxVel);
-    this->dataPtr->limiterAng->SetMaxVelocity(maxVel);
+    maxVel = _sdf->Get<double>("max_velocity");
+    hasVelocityLimits = true;
   }
   if (_sdf->HasElement("min_acceleration"))
   {
-    const double minAccel = _sdf->Get<double>("min_acceleration");
-    this->dataPtr->limiterLin->SetMinAcceleration(minAccel);
-    this->dataPtr->limiterAng->SetMinAcceleration(minAccel);
+    minAccel = _sdf->Get<double>("min_acceleration");
+    hasAccelerationLimits = true;
   }
   if (_sdf->HasElement("max_acceleration"))
   {
-    const double maxAccel = _sdf->Get<double>("max_acceleration");
-    this->dataPtr->limiterLin->SetMaxAcceleration(maxAccel);
-    this->dataPtr->limiterAng->SetMaxAcceleration(maxAccel);
+    maxAccel = _sdf->Get<double>("max_acceleration");
+    hasAccelerationLimits = true;
   }
   if (_sdf->HasElement("min_jerk"))
   {
-    const double minJerk = _sdf->Get<double>("min_jerk");
-    this->dataPtr->limiterLin->SetMinJerk(minJerk);
-    this->dataPtr->limiterAng->SetMinJerk(minJerk);
+    minJerk = _sdf->Get<double>("min_jerk");
+    hasJerkLimits = true;
   }
   if (_sdf->HasElement("max_jerk"))
   {
-    const double maxJerk = _sdf->Get<double>("max_jerk");
-    this->dataPtr->limiterLin->SetMaxJerk(maxJerk);
-    this->dataPtr->limiterAng->SetMaxJerk(maxJerk);
+    maxJerk = _sdf->Get<double>("max_jerk");
+    hasJerkLimits = true;
   }
 
+  // Instantiate the speed limiters.
+  this->dataPtr->limiterLin = std::make_unique<SpeedLimiter>(
+    hasVelocityLimits, hasAccelerationLimits, hasJerkLimits,
+    minVel, maxVel, minAccel, maxAccel, minJerk, maxJerk);
+
+  this->dataPtr->limiterAng = std::make_unique<SpeedLimiter>(
+    hasVelocityLimits, hasAccelerationLimits, hasJerkLimits,
+    minVel, maxVel, minAccel, maxAccel, minJerk, maxJerk);
+
   double odomFreq = _sdf->Get<double>("odom_publish_frequency", 50).first;
   if (odomFreq > 0)
   {
@@ -258,24 +263,26 @@ void DiffDrive::Configure(const Entity &_entity,
       this->dataPtr->wheelRadius, this->dataPtr->wheelRadius);
 
   // Subscribe to commands
-  std::string topic{"/model/" + this->dataPtr->model.Name(_ecm) + "/cmd_vel"};
+  std::vector<std::string> topics;
   if (_sdf->HasElement("topic"))
-    topic = _sdf->Get<std::string>("topic");
+  {
+    topics.push_back(_sdf->Get<std::string>("topic"));
+  }
+  topics.push_back("/model/" + this->dataPtr->model.Name(_ecm) + "/cmd_vel");
+  auto topic = validTopic(topics);
+
   this->dataPtr->node.Subscribe(topic, &DiffDrivePrivate::OnCmdVel,
       this->dataPtr.get());
 
-  // Subscribe to enable/disable
-  std::string enableTopic{"/model/" + this->dataPtr->model.Name(_ecm) +
-      "/enable"};
-
-  this->dataPtr->node.Subscribe(enableTopic, &DiffDrivePrivate::OnEnable,
-      this->dataPtr.get());
-  this->dataPtr->enabled = true;
-
-  std::string odomTopic{"/model/" + this->dataPtr->model.Name(_ecm) +
-    "/odometry"};
+  std::vector<std::string> odomTopics;
   if (_sdf->HasElement("odom_topic"))
-    odomTopic = _sdf->Get<std::string>("odom_topic");
+  {
+    odomTopics.push_back(_sdf->Get<std::string>("odom_topic"));
+  }
+  odomTopics.push_back("/model/" + this->dataPtr->model.Name(_ecm) +
+      "/odometry");
+  auto odomTopic = validTopic(odomTopics);
+
   this->dataPtr->odomPub = this->dataPtr->node.Advertise<msgs::Odometry>(
       odomTopic);
 
@@ -297,8 +304,8 @@ void DiffDrive::Configure(const Entity &_entity,
 }
 
 //////////////////////////////////////////////////
-void DiffDrive::PreUpdate(const UpdateInfo &_info,
-    EntityComponentManager &_ecm)
+void DiffDrive::PreUpdate(const ignition::gazebo::UpdateInfo &_info,
+    ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("DiffDrive::PreUpdate");
 
@@ -311,14 +318,23 @@ void DiffDrive::PreUpdate(const UpdateInfo &_info,
   }
 
   // If the joints haven't been identified yet, look for them
+  static std::set<std::string> warnedModels;
+  auto modelName = this->dataPtr->model.Name(_ecm);
   if (this->dataPtr->leftJoints.empty() ||
       this->dataPtr->rightJoints.empty())
   {
+    bool warned{false};
     for (const std::string &name : this->dataPtr->leftJointNames)
     {
       Entity joint = this->dataPtr->model.JointByName(_ecm, name);
       if (joint != kNullEntity)
         this->dataPtr->leftJoints.push_back(joint);
+      else if (warnedModels.find(modelName) == warnedModels.end())
+      {
+        ignwarn << "Failed to find left joint [" << name << "] for model ["
+                << modelName << "]" << std::endl;
+        warned = true;
+      }
     }
 
     for (const std::string &name : this->dataPtr->rightJointNames)
@@ -326,22 +342,35 @@ void DiffDrive::PreUpdate(const UpdateInfo &_info,
       Entity joint = this->dataPtr->model.JointByName(_ecm, name);
       if (joint != kNullEntity)
         this->dataPtr->rightJoints.push_back(joint);
+      else if (warnedModels.find(modelName) == warnedModels.end())
+      {
+        ignwarn << "Failed to find right joint [" << name << "] for model ["
+                << modelName << "]" << std::endl;
+        warned = true;
+      }
+    }
+    if (warned)
+    {
+      warnedModels.insert(modelName);
     }
   }
 
   if (this->dataPtr->leftJoints.empty() || this->dataPtr->rightJoints.empty())
     return;
 
+  if (warnedModels.find(modelName) != warnedModels.end())
+  {
+    ignmsg << "Found joints for model [" << modelName
+           << "], plugin will start working." << std::endl;
+    warnedModels.erase(modelName);
+  }
+
   // Nothing left to do if paused.
   if (_info.paused)
     return;
 
   for (Entity joint : this->dataPtr->leftJoints)
   {
-    // skip this entity if it has been removed
-    if (!_ecm.HasEntity(joint))
-      continue;
-
     // Update wheel velocity
     auto vel = _ecm.Component<components::JointVelocityCmd>(joint);
 
@@ -358,10 +387,6 @@ void DiffDrive::PreUpdate(const UpdateInfo &_info,
 
   for (Entity joint : this->dataPtr->rightJoints)
   {
-    // skip this entity if it has been removed
-    if (!_ecm.HasEntity(joint))
-      continue;
-
     // Update wheel velocity
     auto vel = _ecm.Component<components::JointVelocityCmd>(joint);
 
@@ -380,7 +405,7 @@ void DiffDrive::PreUpdate(const UpdateInfo &_info,
   // don't exist.
   auto leftPos = _ecm.Component<components::JointPosition>(
       this->dataPtr->leftJoints[0]);
-  if (!leftPos && _ecm.HasEntity(this->dataPtr->leftJoints[0]))
+  if (!leftPos)
   {
     _ecm.CreateComponent(this->dataPtr->leftJoints[0],
         components::JointPosition());
@@ -388,7 +413,7 @@ void DiffDrive::PreUpdate(const UpdateInfo &_info,
 
   auto rightPos = _ecm.Component<components::JointPosition>(
       this->dataPtr->rightJoints[0]);
-  if (!rightPos && _ecm.HasEntity(this->dataPtr->rightJoints[0]))
+  if (!rightPos)
   {
     _ecm.CreateComponent(this->dataPtr->rightJoints[0],
         components::JointPosition());
@@ -409,8 +434,8 @@ void DiffDrive::PostUpdate(const UpdateInfo &_info,
 }
 
 //////////////////////////////////////////////////
-void DiffDrivePrivate::UpdateOdometry(const UpdateInfo &_info,
-    const EntityComponentManager &_ecm)
+void DiffDrivePrivate::UpdateOdometry(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("DiffDrive::UpdateOdometry");
   // Initialize, if not already initialized.
@@ -420,6 +445,9 @@ void DiffDrivePrivate::UpdateOdometry(const UpdateInfo &_info,
     return;
   }
 
+  if (this->leftJoints.empty() || this->rightJoints.empty())
+    return;
+
   // Get the first joint positions for the left and right side.
   auto leftPos = _ecm.Component<components::JointPosition>(this->leftJoints[0]);
   auto rightPos = _ecm.Component<components::JointPosition>(
@@ -490,7 +518,8 @@ void DiffDrivePrivate::UpdateOdometry(const UpdateInfo &_info,
 
   // Construct the Pose_V/tf message and publish it.
   msgs::Pose_V tfMsg;
-  msgs::Pose *tfMsgPose = tfMsg.add_pose();
+  ignition::msgs::Pose *tfMsgPose = nullptr;
+  tfMsgPose = tfMsg.add_pose();
   tfMsgPose->mutable_header()->CopyFrom(*msg.mutable_header());
   tfMsgPose->mutable_position()->CopyFrom(msg.mutable_pose()->position());
   tfMsgPose->mutable_orientation()->CopyFrom(msg.mutable_pose()->orientation());
@@ -501,8 +530,8 @@ void DiffDrivePrivate::UpdateOdometry(const UpdateInfo &_info,
 }
 
 //////////////////////////////////////////////////
-void DiffDrivePrivate::UpdateVelocity(const UpdateInfo &_info,
-    const EntityComponentManager &/*_ecm*/)
+void DiffDrivePrivate::UpdateVelocity(const ignition::gazebo::UpdateInfo &_info,
+    const ignition::gazebo::EntityComponentManager &/*_ecm*/)
 {
   IGN_PROFILE("DiffDrive::UpdateVelocity");
 
@@ -514,11 +543,11 @@ void DiffDrivePrivate::UpdateVelocity(const UpdateInfo &_info,
     angVel = this->targetVel.angular().z();
   }
 
+  const double dt = std::chrono::duration<double>(_info.dt).count();
+
   // Limit the target velocity if needed.
-  this->limiterLin->Limit(
-      linVel, this->last0Cmd.lin, this->last1Cmd.lin, _info.dt);
-  this->limiterAng->Limit(
-      angVel, this->last0Cmd.ang, this->last1Cmd.ang, _info.dt);
+  this->limiterLin->Limit(linVel, this->last0Cmd.lin, this->last1Cmd.lin, dt);
+  this->limiterAng->Limit(angVel, this->last0Cmd.ang, this->last1Cmd.ang, dt);
 
   // Update history of commands.
   this->last1Cmd = last0Cmd;
@@ -536,32 +565,13 @@ void DiffDrivePrivate::UpdateVelocity(const UpdateInfo &_info,
 void DiffDrivePrivate::OnCmdVel(const msgs::Twist &_msg)
 {
   std::lock_guard<std::mutex> lock(this->mutex);
-  if (this->enabled)
-  {
-    this->targetVel = _msg;
-  }
-}
-
-//////////////////////////////////////////////////
-void DiffDrivePrivate::OnEnable(const msgs::Boolean &_msg)
-{
-  std::lock_guard<std::mutex> lock(this->mutex);
-  this->enabled = _msg.data();
-  if (!this->enabled)
-  {
-    math::Vector3d zeroVector{0, 0, 0};
-    msgs::Set(this->targetVel.mutable_linear(), zeroVector);
-    msgs::Set(this->targetVel.mutable_angular(), zeroVector);
-  }
+  this->targetVel = _msg;
 }
 
 IGNITION_ADD_PLUGIN(DiffDrive,
-                    System,
+                    ignition::gazebo::System,
                     DiffDrive::ISystemConfigure,
                     DiffDrive::ISystemPreUpdate,
                     DiffDrive::ISystemPostUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(DiffDrive, "gz::sim::systems::DiffDrive")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(DiffDrive, "ignition::gazebo::systems::DiffDrive")
