@@ -17,26 +17,23 @@
 
 #include "JointStatePublisher.hh"
 
-#include <gz/msgs/model.pb.h>
+#include <ignition/msgs/model.pb.h>
 
 #include <string>
 #include <vector>
 
-#include <gz/plugin/Register.hh>
+#include <ignition/plugin/Register.hh>
 
-#include "gz/sim/components/ChildLinkName.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointAxis.hh"
-#include "gz/sim/components/JointForce.hh"
-#include "gz/sim/components/JointPosition.hh"
-#include "gz/sim/components/JointVelocity.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/ParentLinkName.hh"
-#include "gz/sim/components/Pose.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointForce.hh"
+#include "ignition/gazebo/components/JointPosition.hh"
+#include "ignition/gazebo/components/JointVelocity.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 //////////////////////////////////////////////////
@@ -68,7 +65,7 @@ void JointStatePublisher::Configure(
     while (elem)
     {
       std::string jointName = elem->Get<std::string>();
-      Entity jointEntity = this->model.JointByName(_ecm, jointName);
+      gazebo::Entity jointEntity = this->model.JointByName(_ecm, jointName);
       if (jointEntity != kNullEntity)
       {
         this->CreateComponents(_ecm, jointEntity);
@@ -96,7 +93,7 @@ void JointStatePublisher::Configure(
 
 //////////////////////////////////////////////////
 void JointStatePublisher::CreateComponents(EntityComponentManager &_ecm,
-    Entity _joint)
+    gazebo::Entity _joint)
 {
   if (this->joints.find(_joint) != this->joints.end())
   {
@@ -172,8 +169,6 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
   if (pose)
     msgs::Set(msg.mutable_pose(), pose->Data());
 
-  static bool hasWarned {false};
-
   // Process each joint
   for (const Entity &joint : this->joints)
   {
@@ -187,18 +182,6 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
     if (pose)
       msgs::Set(jointMsg->mutable_pose(), pose->Data());
 
-    auto child = _ecm.Component<components::ChildLinkName>(joint);
-    if (child)
-    {
-      jointMsg->set_child(child->Data());
-    }
-
-    auto parent = _ecm.Component<components::ParentLinkName>(joint);
-    if (parent)
-    {
-      jointMsg->set_parent(parent->Data());
-    }
-
     // Set the joint position
     const auto *jointPositions  =
       _ecm.Component<components::JointPosition>(joint);
@@ -207,31 +190,11 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
       for (size_t i = 0; i < jointPositions->Data().size(); ++i)
       {
         if (i == 0)
-        {
           jointMsg->mutable_axis1()->set_position(jointPositions->Data()[i]);
-          auto jointAxis = _ecm.Component<components::JointAxis>(joint);
-          if (jointAxis)
-          {
-            msgs::Set(
-              jointMsg->mutable_axis1()->mutable_xyz(),
-              jointAxis->Data().Xyz());
-            jointMsg->mutable_axis1()->set_limit_upper(
-              jointAxis->Data().Upper());
-            jointMsg->mutable_axis1()->set_limit_lower(
-              jointAxis->Data().Lower());
-            jointMsg->mutable_axis1()->set_damping(
-              jointAxis->Data().Damping());
-          }
-        }
         else if (i == 1)
-        {
           jointMsg->mutable_axis2()->set_position(jointPositions->Data()[i]);
-        }
-        else if (!hasWarned)
-        {
+        else
           ignwarn << "Joint state publisher only supports two joint axis\n";
-          hasWarned = true;
-        }
       }
     }
 
@@ -243,18 +206,11 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
       for (size_t i = 0; i < jointVelocity->Data().size(); ++i)
       {
         if (i == 0)
-        {
           jointMsg->mutable_axis1()->set_velocity(jointVelocity->Data()[i]);
-        }
         else if (i == 1)
-        {
           jointMsg->mutable_axis2()->set_velocity(jointVelocity->Data()[i]);
-        }
-        else if (!hasWarned)
-        {
+        else
           ignwarn << "Joint state publisher only supports two joint axis\n";
-          hasWarned = true;
-        }
       }
     }
 
@@ -266,18 +222,11 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
       for (size_t i = 0; i < jointForce->Data().size(); ++i)
       {
         if (i == 0)
-        {
           jointMsg->mutable_axis1()->set_force(jointForce->Data()[i]);
-        }
         else if (i == 1)
-        {
           jointMsg->mutable_axis2()->set_force(jointForce->Data()[i]);
-        }
-        else if (!hasWarned)
-        {
+        else
           ignwarn << "Joint state publisher only supports two joint axis\n";
-          hasWarned = true;
-        }
       }
     }
   }
@@ -287,13 +236,9 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
 }
 
 IGNITION_ADD_PLUGIN(JointStatePublisher,
-                    System,
+                    ignition::gazebo::System,
                     JointStatePublisher::ISystemConfigure,
                     JointStatePublisher::ISystemPostUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(JointStatePublisher,
-    "gz::sim::systems::JointStatePublisher")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(JointStatePublisher,
     "ignition::gazebo::systems::JointStatePublisher")
