@@ -16,30 +16,30 @@
  */
 
 #include <google/protobuf/message.h>
-#include <gz/msgs/double.pb.h>
+#include <ignition/msgs/double.pb.h>
 
 #include <string>
 
-#include <gz/sim/components/AngularVelocity.hh>
-#include <gz/sim/components/Link.hh>
-#include <gz/sim/components/LinearVelocity.hh>
-#include <gz/sim/components/Name.hh>
-#include <gz/sim/components/Pose.hh>
-#include <gz/sim/components/World.hh>
-#include <gz/sim/components/Inertial.hh>
-#include <gz/sim/EntityComponentManager.hh>
-#include <gz/sim/Link.hh>
-#include <gz/sim/Model.hh>
-#include <gz/sim/Util.hh>
+#include <ignition/gazebo/components/AngularVelocity.hh>
+#include <ignition/gazebo/components/Link.hh>
+#include <ignition/gazebo/components/LinearVelocity.hh>
+#include <ignition/gazebo/components/Name.hh>
+#include <ignition/gazebo/components/Pose.hh>
+#include <ignition/gazebo/components/World.hh>
+#include <ignition/gazebo/components/Inertial.hh>
+#include <ignition/gazebo/EntityComponentManager.hh>
+#include <ignition/gazebo/Link.hh>
+#include <ignition/gazebo/Model.hh>
+#include <ignition/gazebo/Util.hh>
 
-#include <gz/plugin/Register.hh>
+#include <ignition/plugin/Register.hh>
 
-#include <gz/transport/Node.hh>
+#include <ignition/transport/Node.hh>
 
 #include "KineticEnergyMonitor.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 /// \brief Private data class
@@ -127,11 +127,40 @@ void KineticEnergyMonitor::Configure(const Entity &_entity,
   transport::Node node;
   this->dataPtr->pub = node.Advertise<msgs::Double>(topic);
 
-  Link link(this->dataPtr->linkEntity);
-  link.EnableVelocityChecks(_ecm, true);
+  if (!_ecm.Component<components::WorldPose>(this->dataPtr->linkEntity))
+  {
+    _ecm.CreateComponent(this->dataPtr->linkEntity,
+        components::WorldPose());
+  }
 
-  // Create a default inertia in case the link doesn't have it
-  enableComponent<components::Inertial>(_ecm, this->dataPtr->linkEntity, true);
+  if (!_ecm.Component<components::Inertial>(this->dataPtr->linkEntity))
+  {
+    _ecm.CreateComponent(this->dataPtr->linkEntity, components::Inertial());
+  }
+
+  // Create a world linear velocity component if one is not present.
+  if (!_ecm.Component<components::WorldLinearVelocity>(
+        this->dataPtr->linkEntity))
+  {
+    _ecm.CreateComponent(this->dataPtr->linkEntity,
+        components::WorldLinearVelocity());
+  }
+
+  // Create an angular velocity component if one is not present.
+  if (!_ecm.Component<components::AngularVelocity>(
+        this->dataPtr->linkEntity))
+  {
+    _ecm.CreateComponent(this->dataPtr->linkEntity,
+        components::AngularVelocity());
+  }
+
+  // Create an angular velocity component if one is not present.
+  if (!_ecm.Component<components::WorldAngularVelocity>(
+        this->dataPtr->linkEntity))
+  {
+    _ecm.CreateComponent(this->dataPtr->linkEntity,
+        components::WorldAngularVelocity());
+  }
 }
 
 //////////////////////////////////////////////////
@@ -167,9 +196,5 @@ IGNITION_ADD_PLUGIN(KineticEnergyMonitor, System,
   KineticEnergyMonitor::ISystemPostUpdate
 )
 
-IGNITION_ADD_PLUGIN_ALIAS(KineticEnergyMonitor,
-  "gz::sim::systems::KineticEnergyMonitor")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(KineticEnergyMonitor,
   "ignition::gazebo::systems::KineticEnergyMonitor")
