@@ -21,27 +21,27 @@
 #include <string>
 #include <vector>
 
-#include <gz/common/Profiler.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
 #include <sdf/Element.hh>
 
-#include "gz/sim/Link.hh"
-#include "gz/sim/Model.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/Link.hh"
+#include "ignition/gazebo/Model.hh"
+#include "ignition/gazebo/Util.hh"
 
-#include "gz/sim/components/AngularVelocity.hh"
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/JointPosition.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ExternalWorldWrenchCmd.hh"
-#include "gz/sim/components/Pose.hh"
+#include "ignition/gazebo/components/AngularVelocity.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/JointPosition.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ExternalWorldWrenchCmd.hh"
+#include "ignition/gazebo/components/Pose.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 class ignition::gazebo::systems::LiftDragPrivate
@@ -105,16 +105,16 @@ class ignition::gazebo::systems::LiftDragPrivate
 
   /// \brief center of pressure in link local coordinates with respect to the
   /// link's center of mass
-  public: math::Vector3d cp = math::Vector3d::Zero;
+  public: ignition::math::Vector3d cp = math::Vector3d::Zero;
 
   /// \brief Normally, this is taken as a direction parallel to the chord
   /// of the airfoil in zero angle of attack forward flight.
-  public: math::Vector3d forward = math::Vector3d::UnitX;
+  public: ignition::math::Vector3d forward = math::Vector3d::UnitX;
 
   /// \brief A vector in the lift/drag plane, perpendicular to the forward
   /// vector. Inflow velocity orthogonal to forward and upward vectors
   /// is considered flow in the wing sweep direction.
-  public: math::Vector3d upward = math::Vector3d::UnitZ;
+  public: ignition::math::Vector3d upward = math::Vector3d::UnitZ;
 
   /// \brief how much to change CL per radian of control surface joint
   /// value.
@@ -153,15 +153,15 @@ void LiftDragPrivate::Load(const EntityComponentManager &_ecm,
       this->radialSymmetry).first;
   this->area = _sdf->Get<double>("area", this->area).first;
   this->alpha0 = _sdf->Get<double>("a0", this->alpha0).first;
-  this->cp = _sdf->Get<math::Vector3d>("cp", this->cp).first;
+  this->cp = _sdf->Get<ignition::math::Vector3d>("cp", this->cp).first;
 
   // blade forward (-drag) direction in link frame
   this->forward =
-      _sdf->Get<math::Vector3d>("forward", this->forward).first;
+      _sdf->Get<ignition::math::Vector3d>("forward", this->forward).first;
   this->forward.Normalize();
 
   // blade upward (+lift) direction in link frame
-  this->upward = _sdf->Get<math::Vector3d>(
+  this->upward = _sdf->Get<ignition::math::Vector3d>(
       "upward", this->upward) .first;
   this->upward.Normalize();
 
@@ -246,12 +246,12 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   // rotate forward and upward vectors into world frame
   const auto forwardI = pose.Rot().RotateVector(this->forward);
 
-  math::Vector3d upwardI;
+  ignition::math::Vector3d upwardI;
   if (this->radialSymmetry)
   {
     // use inflow velocity to determine upward direction
     // which is the component of inflow perpendicular to forward direction.
-    math::Vector3d tmp = forwardI.Cross(velI);
+    ignition::math::Vector3d tmp = forwardI.Cross(velI);
     upwardI = forwardI.Cross(tmp).Normalize();
   }
   else
@@ -265,7 +265,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   const double minRatio = -1.0;
   const double maxRatio = 1.0;
   // check sweep (angle between velI and lift-drag-plane)
-  double sinSweepAngle = math::clamp(
+  double sinSweepAngle = ignition::math::clamp(
       spanwiseI.Dot(velI), minRatio, maxRatio);
 
   // get cos from trig identity
@@ -305,7 +305,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   // given upwardI and liftI are both unit vectors, we can drop the denominator
   //   cos(theta) = a.Dot(b)
   const double cosAlpha =
-      math::clamp(liftI.Dot(upwardI), minRatio, maxRatio);
+      ignition::math::clamp(liftI.Dot(upwardI), minRatio, maxRatio);
 
   // Is alpha positive or negative? Test:
   // forwardI points toward zero alpha
@@ -354,7 +354,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   }
 
   // compute lift force at cp
-  math::Vector3d lift = cl * q * this->area * liftI;
+  ignition::math::Vector3d lift = cl * q * this->area * liftI;
 
   // compute cd at cp, check for stall, correct for sweep
   double cd;
@@ -377,7 +377,7 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
   cd = std::fabs(cd);
 
   // drag at cp
-  math::Vector3d drag = cd * q * this->area * dragDirection;
+  ignition::math::Vector3d drag = cd * q * this->area * dragDirection;
 
   // compute cm at cp, check for stall, correct for sweep
   double cm;
@@ -406,12 +406,12 @@ void LiftDragPrivate::Update(EntityComponentManager &_ecm)
 
   // compute moment (torque) at cp
   // spanwiseI used to be momentDirection
-  math::Vector3d moment = cm * q * this->area * spanwiseI;
+  ignition::math::Vector3d moment = cm * q * this->area * spanwiseI;
 
 
   // force and torque about cg in world frame
-  math::Vector3d force = lift + drag;
-  math::Vector3d torque = moment;
+  ignition::math::Vector3d force = lift + drag;
+  ignition::math::Vector3d torque = moment;
   // Correct for nan or inf
   force.Correct();
   this->cp.Correct();
@@ -498,8 +498,24 @@ void LiftDrag::PreUpdate(const UpdateInfo &_info, EntityComponentManager &_ecm)
 
     if (this->dataPtr->validConfig)
     {
-      Link link(this->dataPtr->linkEntity);
-      link.EnableVelocityChecks(_ecm, true);
+      if (!_ecm.Component<components::WorldPose>(this->dataPtr->linkEntity))
+      {
+        _ecm.CreateComponent(this->dataPtr->linkEntity,
+                             components::WorldPose());
+      }
+
+      if (!_ecm.Component<components::WorldLinearVelocity>(
+              this->dataPtr->linkEntity))
+      {
+        _ecm.CreateComponent(this->dataPtr->linkEntity,
+                             components::WorldLinearVelocity());
+      }
+      if (!_ecm.Component<components::WorldAngularVelocity>(
+              this->dataPtr->linkEntity))
+      {
+        _ecm.CreateComponent(this->dataPtr->linkEntity,
+                             components::WorldAngularVelocity());
+      }
 
       if ((this->dataPtr->controlJointEntity != kNullEntity) &&
           !_ecm.Component<components::JointPosition>(
@@ -523,11 +539,8 @@ void LiftDrag::PreUpdate(const UpdateInfo &_info, EntityComponentManager &_ecm)
 }
 
 IGNITION_ADD_PLUGIN(LiftDrag,
-                    System,
+                    ignition::gazebo::System,
                     LiftDrag::ISystemConfigure,
                     LiftDrag::ISystemPreUpdate)
 
-IGNITION_ADD_PLUGIN_ALIAS(LiftDrag, "gz::sim::systems::LiftDrag")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(LiftDrag, "ignition::gazebo::systems::LiftDrag")
