@@ -17,56 +17,37 @@
 
 #include "SceneBroadcaster.hh"
 
-#include <gz/msgs/scene.pb.h>
+#include <ignition/msgs/scene.pb.h>
 
 #include <chrono>
 #include <condition_variable>
 #include <string>
 #include <unordered_set>
 
-#include <gz/common/Profiler.hh>
-#include <gz/math/graph/Graph.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/math/graph/Graph.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/AirPressureSensor.hh"
-#include "gz/sim/components/Altimeter.hh"
-#include "gz/sim/components/Camera.hh"
-#include "gz/sim/components/CastShadows.hh"
-#include "gz/sim/components/ContactSensor.hh"
-#include "gz/sim/components/DepthCamera.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/GpuLidar.hh"
-#include "gz/sim/components/Imu.hh"
-#include "gz/sim/components/LaserRetro.hh"
-#include "gz/sim/components/Lidar.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/LogicalCamera.hh"
-#include "gz/sim/components/Material.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/RgbdCamera.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/Static.hh"
-#include "gz/sim/components/ThermalCamera.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Conversions.hh"
-#include "gz/sim/EntityComponentManager.hh"
-
-#include <sdf/Camera.hh>
-#include <sdf/Imu.hh>
-#include <sdf/Lidar.hh>
-#include <sdf/Noise.hh>
-#include <sdf/Sensor.hh>
+#include "ignition/gazebo/components/CastShadows.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Material.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Static.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Conversions.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
 
 using namespace std::chrono_literals;
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 // Private data class.
@@ -83,21 +64,21 @@ class ignition::gazebo::systems::SceneBroadcasterPrivate
   /// \brief Callback for scene info service.
   /// \param[out] _res Response containing the latest scene message.
   /// \return True if successful.
-  public: bool SceneInfoService(msgs::Scene &_res);
+  public: bool SceneInfoService(ignition::msgs::Scene &_res);
 
   /// \brief Callback for scene graph service.
   /// \param[out] _res Response containing the the scene graph in DOT format.
   /// \return True if successful.
-  public: bool SceneGraphService(msgs::StringMsg &_res);
+  public: bool SceneGraphService(ignition::msgs::StringMsg &_res);
 
   /// \brief Callback for state service.
   /// \param[out] _res Response containing the latest full state.
   /// \return True if successful.
-  public: bool StateService(msgs::SerializedStepMap &_res);
+  public: bool StateService(ignition::msgs::SerializedStepMap &_res);
 
   /// \brief Callback for state service - non blocking.
   /// \param[out] _res Response containing the last available full state.
-  public: void StateAsyncService(const msgs::StringMsg &_req);
+  public: void StateAsyncService(const ignition::msgs::StringMsg &_req);
 
   /// \brief Updates the scene graph when entities are added
   /// \param[in] _manager The entity component manager
@@ -143,15 +124,6 @@ class ignition::gazebo::systems::SceneBroadcasterPrivate
   public: static void AddVisuals(msgs::Link *_msg, const Entity _entity,
                                  const SceneGraphType &_graph);
 
-  /// \brief Adds sensors to a msgs::Link object based on the contents of
-  /// the scene graph
-  /// \param[inout] _msg Pointer to msg object to which the sensors will be
-  /// added.
-  /// \param[in] _entity Parent entity in the graph
-  /// \param[in] _graph Scene graph
-  public: static void AddSensors(msgs::Link *_msg, const Entity _entity,
-                                 const SceneGraphType &_graph);
-
   /// \brief Recursively remove entities from the graph
   /// \param[in] _entity Entity
   /// \param[in/out] _graph Scene graph
@@ -478,8 +450,16 @@ void SceneBroadcasterPrivate::PoseUpdate(const UpdateInfo &_info,
 //////////////////////////////////////////////////
 void SceneBroadcasterPrivate::SetupTransport(const std::string &_worldName)
 {
+  auto ns = transport::TopicUtils::AsValidTopic("/world/" + _worldName);
+  if (ns.empty())
+  {
+    ignerr << "Failed to create valid namespace for world [" << _worldName
+           << "]" << std::endl;
+    return;
+  }
+
   transport::NodeOptions opts;
-  opts.SetNameSpace("/world/" + _worldName);
+  opts.SetNameSpace(ns);
   this->node = std::make_unique<transport::Node>(opts);
 
   // Scene info service
@@ -521,27 +501,27 @@ void SceneBroadcasterPrivate::SetupTransport(const std::string &_worldName)
          << stateAsyncService << "]" << std::endl;
 
   // Scene info topic
-  std::string sceneTopic{"/world/" + _worldName + "/scene/info"};
+  std::string sceneTopic{ns + "/scene/info"};
 
-  this->scenePub = this->node->Advertise<msgs::Scene>(sceneTopic);
+  this->scenePub = this->node->Advertise<ignition::msgs::Scene>(sceneTopic);
 
   ignmsg << "Publishing scene information on [" << sceneTopic
          << "]" << std::endl;
 
   // Entity deletion publisher
-  std::string deletionTopic{"/world/" + _worldName + "/scene/deletion"};
+  std::string deletionTopic{ns + "/scene/deletion"};
 
   this->deletionPub =
-      this->node->Advertise<msgs::UInt32_V>(deletionTopic);
+      this->node->Advertise<ignition::msgs::UInt32_V>(deletionTopic);
 
   ignmsg << "Publishing entity deletions on [" << deletionTopic << "]"
          << std::endl;
 
   // State topic
-  std::string stateTopic{"/world/" + _worldName + "/state"};
+  std::string stateTopic{ns + "/state"};
 
   this->statePub =
-      this->node->Advertise<msgs::SerializedStepMap>(stateTopic);
+      this->node->Advertise<ignition::msgs::SerializedStepMap>(stateTopic);
 
   ignmsg << "Publishing state changes on [" << stateTopic << "]"
       << std::endl;
@@ -570,7 +550,7 @@ void SceneBroadcasterPrivate::SetupTransport(const std::string &_worldName)
 }
 
 //////////////////////////////////////////////////
-bool SceneBroadcasterPrivate::SceneInfoService(msgs::Scene &_res)
+bool SceneBroadcasterPrivate::SceneInfoService(ignition::msgs::Scene &_res)
 {
   std::lock_guard<std::mutex> lock(this->graphMutex);
 
@@ -589,7 +569,7 @@ bool SceneBroadcasterPrivate::SceneInfoService(msgs::Scene &_res)
 
 //////////////////////////////////////////////////
 void SceneBroadcasterPrivate::StateAsyncService(
-    const msgs::StringMsg &_req)
+    const ignition::msgs::StringMsg &_req)
 {
   std::unique_lock<std::mutex> lock(this->stateMutex);
   this->stateServiceRequest = true;
@@ -598,7 +578,7 @@ void SceneBroadcasterPrivate::StateAsyncService(
 
 //////////////////////////////////////////////////
 bool SceneBroadcasterPrivate::StateService(
-    msgs::SerializedStepMap &_res)
+    ignition::msgs::SerializedStepMap &_res)
 {
   _res.Clear();
 
@@ -620,7 +600,7 @@ bool SceneBroadcasterPrivate::StateService(
 }
 
 //////////////////////////////////////////////////
-bool SceneBroadcasterPrivate::SceneGraphService(msgs::StringMsg &_res)
+bool SceneBroadcasterPrivate::SceneGraphService(ignition::msgs::StringMsg &_res)
 {
   std::lock_guard<std::mutex> lock(this->graphMutex);
 
@@ -762,189 +742,6 @@ void SceneBroadcasterPrivate::SceneGraphAddEntities(
         return true;
       });
 
-  // Sensors
-  _manager.EachNew<components::Sensor, components::Name,
-                   components::ParentEntity, components::Pose>(
-      [&](const Entity &_entity, const components::Sensor *,
-          const components::Name *_nameComp,
-          const components::ParentEntity *_parentComp,
-          const components::Pose *_poseComp) -> bool
-      {
-        auto sensorMsg = std::make_shared<msgs::Sensor>();
-        sensorMsg->set_id(_entity);
-        sensorMsg->set_parent_id(_parentComp->Data());
-        sensorMsg->set_name(_nameComp->Data());
-        sensorMsg->mutable_pose()->CopyFrom(msgs::Convert(_poseComp->Data()));
-
-        auto altimeterComp = _manager.Component<components::Altimeter>(_entity);
-        if (altimeterComp)
-        {
-          sensorMsg->set_type("altimeter");
-        }
-        auto airPressureComp = _manager.Component<
-          components::AirPressureSensor>(_entity);
-        if (airPressureComp)
-        {
-          sensorMsg->set_type("air_pressure");
-        }
-        auto cameraComp = _manager.Component<components::Camera>(_entity);
-        if (cameraComp)
-        {
-          sensorMsg->set_type("camera");
-          msgs::CameraSensor * cameraSensorMsg = sensorMsg->mutable_camera();
-          const auto * camera = cameraComp->Data().CameraSensor();
-          if (camera)
-          {
-            cameraSensorMsg->set_horizontal_fov(
-              camera->HorizontalFov().Radian());
-            cameraSensorMsg->mutable_image_size()->set_x(camera->ImageWidth());
-            cameraSensorMsg->mutable_image_size()->set_y(camera->ImageHeight());
-            cameraSensorMsg->set_image_format(camera->PixelFormatStr());
-            cameraSensorMsg->set_near_clip(camera->NearClip());
-            cameraSensorMsg->set_far_clip(camera->FarClip());
-            msgs::Distortion *distortionMsg =
-              cameraSensorMsg->mutable_distortion();
-            if (distortionMsg)
-            {
-              distortionMsg->mutable_center()->set_x(
-                camera->DistortionCenter().X());
-              distortionMsg->mutable_center()->set_y(
-                camera->DistortionCenter().Y());
-              distortionMsg->set_k1(camera->DistortionK1());
-              distortionMsg->set_k2(camera->DistortionK2());
-              distortionMsg->set_k3(camera->DistortionK3());
-              distortionMsg->set_p1(camera->DistortionP1());
-              distortionMsg->set_p2(camera->DistortionP2());
-            }
-          }
-        }
-        auto contactSensorComp = _manager.Component<
-          components::ContactSensor>(_entity);
-        if (contactSensorComp)
-        {
-          sensorMsg->set_type("contact_sensor");
-        }
-        auto depthCameraSensorComp = _manager.Component<
-          components::DepthCamera>(_entity);
-        if (depthCameraSensorComp)
-        {
-          sensorMsg->set_type("depth_camera");
-        }
-        auto gpuLidarComp = _manager.Component<components::GpuLidar>(_entity);
-        if (gpuLidarComp)
-        {
-          sensorMsg->set_type("gpu_lidar");
-          msgs::LidarSensor * lidarSensorMsg = sensorMsg->mutable_lidar();
-          const auto * lidar = gpuLidarComp->Data().LidarSensor();
-
-          if (lidar && lidarSensorMsg)
-          {
-            lidarSensorMsg->set_horizontal_samples(
-              lidar->HorizontalScanSamples());
-            lidarSensorMsg->set_horizontal_resolution(
-              lidar->HorizontalScanResolution());
-            lidarSensorMsg->set_horizontal_min_angle(
-              lidar->HorizontalScanMinAngle().Radian());
-            lidarSensorMsg->set_horizontal_max_angle(
-              lidar->HorizontalScanMaxAngle().Radian());
-            lidarSensorMsg->set_vertical_samples(lidar->VerticalScanSamples());
-            lidarSensorMsg->set_vertical_resolution(
-              lidar->VerticalScanResolution());
-            lidarSensorMsg->set_vertical_min_angle(
-              lidar->VerticalScanMinAngle().Radian());
-            lidarSensorMsg->set_vertical_max_angle(
-              lidar->VerticalScanMaxAngle().Radian());
-            lidarSensorMsg->set_range_min(lidar->RangeMin());
-            lidarSensorMsg->set_range_max(lidar->RangeMax());
-            lidarSensorMsg->set_range_resolution(lidar->RangeResolution());
-            msgs::SensorNoise *sensorNoise = lidarSensorMsg->mutable_noise();
-            if (sensorNoise)
-            {
-              const auto noise = lidar->LidarNoise();
-              switch(noise.Type())
-              {
-                case sdf::NoiseType::GAUSSIAN:
-                  sensorNoise->set_type(msgs::SensorNoise::GAUSSIAN);
-                  break;
-                case sdf::NoiseType::GAUSSIAN_QUANTIZED:
-                  sensorNoise->set_type(msgs::SensorNoise::GAUSSIAN_QUANTIZED);
-                  break;
-                default:
-                  sensorNoise->set_type(msgs::SensorNoise::NONE);
-              }
-              sensorNoise->set_mean(noise.Mean());
-              sensorNoise->set_stddev(noise.StdDev());
-              sensorNoise->set_bias_mean(noise.BiasMean());
-              sensorNoise->set_bias_stddev(noise.BiasStdDev());
-              sensorNoise->set_precision(noise.Precision());
-              sensorNoise->set_dynamic_bias_stddev(noise.DynamicBiasStdDev());
-              sensorNoise->set_dynamic_bias_correlation_time(
-                noise.DynamicBiasCorrelationTime());
-            }
-          }
-        }
-        auto imuComp = _manager.Component<components::Imu>(_entity);
-        if (imuComp)
-        {
-          sensorMsg->set_type("imu");
-          msgs::IMUSensor * imuMsg = sensorMsg->mutable_imu();
-          const auto * imu = imuComp->Data().ImuSensor();
-
-          set(
-              imuMsg->mutable_linear_acceleration()->mutable_x_noise(),
-              imu->LinearAccelerationXNoise());
-          set(
-              imuMsg->mutable_linear_acceleration()->mutable_y_noise(),
-              imu->LinearAccelerationYNoise());
-          set(
-              imuMsg->mutable_linear_acceleration()->mutable_z_noise(),
-              imu->LinearAccelerationZNoise());
-          set(
-              imuMsg->mutable_angular_velocity()->mutable_x_noise(),
-              imu->AngularVelocityXNoise());
-          set(
-              imuMsg->mutable_angular_velocity()->mutable_y_noise(),
-              imu->AngularVelocityYNoise());
-          set(
-              imuMsg->mutable_angular_velocity()->mutable_z_noise(),
-              imu->AngularVelocityZNoise());
-        }
-        auto laserRetroComp = _manager.Component<
-          components::LaserRetro>(_entity);
-        if (laserRetroComp)
-        {
-          sensorMsg->set_type("laser_retro");
-        }
-        auto lidarComp = _manager.Component<components::Lidar>(_entity);
-        if (lidarComp)
-        {
-          sensorMsg->set_type("lidar");
-        }
-        auto logicalCamera = _manager.Component<
-          components::LogicalCamera>(_entity);
-        if (logicalCamera)
-        {
-          sensorMsg->set_type("logical_camera");
-        }
-        auto rgbdCameraComp = _manager.Component<
-          components::RgbdCamera>(_entity);
-        if (rgbdCameraComp)
-        {
-          sensorMsg->set_type("rgbd_camera");
-        }
-        auto thermalCameraComp = _manager.Component<
-          components::ThermalCamera>(_entity);
-        if (thermalCameraComp)
-        {
-          sensorMsg->set_type("thermal_camera");
-        }
-
-        // Add to graph
-        newGraph.AddVertex(_nameComp->Data(), sensorMsg, _entity);
-        newGraph.AddEdge({_parentComp->Data(), _entity}, true);
-        newEntity = true;
-        return true;
-      });
 
   // Update the whole scene graph from the new graph
   {
@@ -1089,24 +886,6 @@ void SceneBroadcasterPrivate::AddVisuals(msgs::Link *_msg, const Entity _entity,
   }
 }
 
-//////////////////////////////////////////////////
-void SceneBroadcasterPrivate::AddSensors(msgs::Link *_msg, const Entity _entity,
-    const SceneGraphType &_graph)
-{
-  if (!_msg)
-    return;
-
-  for (const auto &vertex : _graph.AdjacentsFrom(_entity))
-  {
-    auto sensorMsg = std::dynamic_pointer_cast<msgs::Sensor>(
-        vertex.second.get().Data());
-    if (!sensorMsg)
-      continue;
-
-    _msg->add_sensor()->CopyFrom(*sensorMsg);
-  }
-}
-
 //////////////////////////////////////////////////
 void SceneBroadcasterPrivate::AddLinks(msgs::Model *_msg, const Entity _entity,
                                        const SceneGraphType &_graph)
@@ -1129,9 +908,6 @@ void SceneBroadcasterPrivate::AddLinks(msgs::Model *_msg, const Entity _entity,
 
     // Lights
     AddLights(msgOut, vertex.second.get().Id(), _graph);
-
-    // Sensors
-    AddSensors(msgOut, vertex.second.get().Id(), _graph);
   }
 }
 
@@ -1148,15 +924,11 @@ void SceneBroadcasterPrivate::RemoveFromGraph(const Entity _entity,
 
 
 IGNITION_ADD_PLUGIN(SceneBroadcaster,
-                    System,
+                    ignition::gazebo::System,
                     SceneBroadcaster::ISystemConfigure,
                     SceneBroadcaster::ISystemPostUpdate)
 
 // Add plugin alias so that we can refer to the plugin without the version
 // namespace
-IGNITION_ADD_PLUGIN_ALIAS(SceneBroadcaster,
-                          "gz::sim::systems::SceneBroadcaster")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(SceneBroadcaster,
                           "ignition::gazebo::systems::SceneBroadcaster")
