@@ -19,39 +19,39 @@
 
 #include <map>
 #include <set>
+#include <unordered_map>
 #include <utility>
 #include <vector>
 
-#include <gz/common/Profiler.hh>
-#include <gz/plugin/Register.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/plugin/Register.hh>
 
 #include <sdf/Sensor.hh>
 
-#include <gz/common/Time.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/math/Helpers.hh>
 
-#include <gz/rendering/Scene.hh>
-#include <gz/sensors/CameraSensor.hh>
-#include <gz/sensors/RenderingSensor.hh>
-#include <gz/sensors/ThermalCameraSensor.hh>
-#include <gz/sensors/Manager.hh>
+#include <ignition/rendering/Scene.hh>
+#include <ignition/sensors/CameraSensor.hh>
+#include <ignition/sensors/RenderingSensor.hh>
+#include <ignition/sensors/ThermalCameraSensor.hh>
+#include <ignition/sensors/Manager.hh>
 
-#include "gz/sim/components/Atmosphere.hh"
-#include "gz/sim/components/Camera.hh"
-#include "gz/sim/components/DepthCamera.hh"
-#include "gz/sim/components/GpuLidar.hh"
-#include "gz/sim/components/RenderEngineServerPlugin.hh"
-#include "gz/sim/components/RgbdCamera.hh"
-#include "gz/sim/components/ThermalCamera.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Events.hh"
-#include "gz/sim/EntityComponentManager.hh"
+#include "ignition/gazebo/components/Atmosphere.hh"
+#include "ignition/gazebo/components/Camera.hh"
+#include "ignition/gazebo/components/DepthCamera.hh"
+#include "ignition/gazebo/components/GpuLidar.hh"
+#include "ignition/gazebo/components/RenderEngineServerPlugin.hh"
+#include "ignition/gazebo/components/RgbdCamera.hh"
+#include "ignition/gazebo/components/ThermalCamera.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Events.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
 
-#include "gz/sim/rendering/Events.hh"
-#include "gz/sim/rendering/RenderUtil.hh"
+#include "ignition/gazebo/rendering/Events.hh"
+#include "ignition/gazebo/rendering/RenderUtil.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 // Private data class.
@@ -68,7 +68,6 @@ class ignition::gazebo::systems::SensorsPrivate
   public: RenderUtil renderUtil;
 
   /// \brief Unique set of sensor ids
-  // TODO(anyone) Remove element when sensor is deleted
   public: std::set<sensors::SensorId> sensorIds;
 
   /// \brief rendering scene to be managed by the scene manager and used to
@@ -79,12 +78,22 @@ class ignition::gazebo::systems::SensorsPrivate
   /// sea level
   public: double ambientTemperature = 288.15;
 
+  /// \brief Temperature gradient with respect to increasing altitude at sea
+  /// level in units of K/m.
+  public: double ambientTemperatureGradient = -0.0065;
+
   /// \brief Keep track of cameras, in case we need to handle stereo cameras.
   /// Key: Camera's parent scoped name
   /// Value: Pointer to camera
   // TODO(anyone) Remove element when sensor is deleted
   public: std::map<std::string, sensors::CameraSensor *> cameras;
 
+  /// \brief Maps gazebo entity to its matching sensor ID
+  ///
+  /// Useful for detecting when a sensor Entity has been deleted and trigger
+  /// the destruction of the corresponding ignition::sensors Sensor object
+  public: std::unordered_map<Entity, sensors::SensorId> entityToIdMap;
+
   /// \brief Flag to indicate if worker threads are running
   public: std::atomic<bool> running { false };
 
@@ -108,10 +117,10 @@ class ignition::gazebo::systems::SensorsPrivate
   public: std::condition_variable renderCv;
 
   /// \brief Connection to events::Stop event, used to stop thread
-  public: common::ConnectionPtr stopConn;
+  public: ignition::common::ConnectionPtr stopConn;
 
   /// \brief Update time for the next rendering iteration
-  public: common::Time updateTime;
+  public: std::chrono::steady_clock::duration updateTime;
 
   /// \brief Sensors to include in the next rendering iteration
   public: std::vector<sensors::RenderingSensor *> activeSensors;
@@ -120,7 +129,8 @@ class ignition::gazebo::systems::SensorsPrivate
   public: std::mutex sensorMaskMutex;
 
   /// \brief Mask sensor updates for sensors currently being rendered
-  public: std::map<sensors::SensorId, common::Time> sensorMask;
+  public: std::map<sensors::SensorId,
+    std::chrono::steady_clock::duration> sensorMask;
 
   /// \brief Pointer to the event manager
   public: EventManager *eventManager{nullptr};
@@ -164,12 +174,6 @@ class ignition::gazebo::systems::SensorsPrivate
 
   /// \brief Stop the rendering thread
   public: void Stop();
-
-  /// \brief Use to optionally set the background color.
-  public: std::optional<math::Color> backgroundColor;
-
-  /// \brief Use to optionally set the ambient light.
-  public: std::optional<math::Color> ambientLight;
 };
 
 //////////////////////////////////////////////////
@@ -190,10 +194,6 @@ void SensorsPrivate::WaitForInit()
     {
       // Only initialize if there are rendering sensors
       igndbg << "Initializing render context" << std::endl;
-      if (this->backgroundColor)
-        this->renderUtil.SetBackgroundColor(*this->backgroundColor);
-      if (this->ambientLight)
-        this->renderUtil.SetAmbientLight(*this->ambientLight);
       this->renderUtil.Init();
       this->scene = this->renderUtil.Scene();
       this->initialized = true;
@@ -242,7 +242,8 @@ void SensorsPrivate::RunOnce()
     for (const auto & sensor : this->activeSensors)
     {
       // 90% of update delta (1/UpdateRate());
-      common::Time delta(0.9 / sensor->UpdateRate());
+      auto delta = std::chrono::duration_cast< std::chrono::milliseconds>(
+        std::chrono::duration< double >(0.9 / sensor->UpdateRate()));
       this->sensorMask[sensor->Id()] = this->updateTime + delta;
     }
     this->sensorMaskMutex.unlock();
@@ -287,7 +288,8 @@ void SensorsPrivate::RenderThread()
     this->RunOnce();
   }
 
-  for (auto id : this->sensorIds)
+  // clean up before exiting
+  for (const auto id : this->sensorIds)
     this->sensorManager.Remove(id);
 
   igndbg << "SensorsPrivate::RenderThread stopped" << std::endl;
@@ -323,6 +325,32 @@ void SensorsPrivate::Stop()
   }
 }
 
+//////////////////////////////////////////////////
+void Sensors::RemoveSensor(const Entity &_entity)
+{
+  auto idIter = this->dataPtr->entityToIdMap.find(_entity);
+  if (idIter != this->dataPtr->entityToIdMap.end())
+  {
+    // Remove from active sensors as well
+    // Locking mutex to make sure the vector is not being changed while
+    // the rendering thread is iterating over it
+    {
+      std::unique_lock<std::mutex> lock(this->dataPtr->sensorMaskMutex);
+      sensors::Sensor *s = this->dataPtr->sensorManager.Sensor(idIter->second);
+      auto rs = dynamic_cast<sensors::RenderingSensor *>(s);
+      auto activeSensorIt = std::find(this->dataPtr->activeSensors.begin(),
+          this->dataPtr->activeSensors.end(), rs);
+      if (activeSensorIt != this->dataPtr->activeSensors.end())
+      {
+        this->dataPtr->activeSensors.erase(activeSensorIt);
+      }
+    }
+    this->dataPtr->sensorIds.erase(idIter->second);
+    this->dataPtr->sensorManager.Remove(idIter->second);
+    this->dataPtr->entityToIdMap.erase(idIter);
+  }
+}
+
 //////////////////////////////////////////////////
 Sensors::Sensors() : System(), dataPtr(std::make_unique<SensorsPrivate>())
 {
@@ -341,23 +369,16 @@ void Sensors::Configure(const Entity &/*_id*/,
     EventManager &_eventMgr)
 {
   igndbg << "Configuring Sensors system" << std::endl;
-
   // Setup rendering
   std::string engineName =
       _sdf->Get<std::string>("render_engine", "ogre2").first;
 
-  // Get the background color, if specified.
-  if (_sdf->HasElement("background_color"))
-    this->dataPtr->backgroundColor = _sdf->Get<math::Color>("background_color");
-
-  // Get the ambient light, if specified.
-  if (_sdf->HasElement("ambient_light"))
-    this->dataPtr->ambientLight = _sdf->Get<math::Color>("ambient_light");
-
   this->dataPtr->renderUtil.SetEngineName(engineName);
   this->dataPtr->renderUtil.SetEnableSensors(true,
       std::bind(&Sensors::CreateSensor, this,
-      std::placeholders::_1, std::placeholders::_2));
+      std::placeholders::_1, std::placeholders::_2, std::placeholders::_3));
+    this->dataPtr->renderUtil.SetRemoveSensorCb(
+      std::bind(&Sensors::RemoveSensor, this, std::placeholders::_1));
 
   // parse sensor-specific data
   auto worldEntity = _ecm.EntityByComponents(components::World());
@@ -369,6 +390,8 @@ void Sensors::Configure(const Entity &/*_id*/,
     {
       auto atmosphereSdf = atmosphere->Data();
       this->dataPtr->ambientTemperature = atmosphereSdf.Temperature().Kelvin();
+      this->dataPtr->ambientTemperatureGradient =
+          atmosphereSdf.TemperatureGradient();
     }
 
     // Set render engine if specified from command line
@@ -389,6 +412,17 @@ void Sensors::Configure(const Entity &/*_id*/,
   this->dataPtr->Run();
 }
 
+//////////////////////////////////////////////////
+void Sensors::Update(const UpdateInfo &_info,
+                     EntityComponentManager &_ecm)
+{
+  IGN_PROFILE("Sensors::Update");
+  if (this->dataPtr->running && this->dataPtr->initialized)
+  {
+    this->dataPtr->renderUtil.UpdateECM(_info, _ecm);
+  }
+}
+
 //////////////////////////////////////////////////
 void Sensors::PostUpdate(const UpdateInfo &_info,
                          const EntityComponentManager &_ecm)
@@ -421,7 +455,7 @@ void Sensors::PostUpdate(const UpdateInfo &_info,
     this->dataPtr->renderUtil.UpdateFromECM(_info, _ecm);
 
     auto time = math::durationToSecNsec(_info.simTime);
-    auto t = common::Time(time.first, time.second);
+    auto t = math::secNsecToDuration(time.first, time.second);
 
     std::vector<sensors::RenderingSensor *> activeSensors;
 
@@ -444,7 +478,7 @@ void Sensors::PostUpdate(const UpdateInfo &_info,
         }
       }
 
-      if (rs && rs->NextUpdateTime() <= t)
+      if (rs && rs->NextDataUpdateTime() <= t)
       {
         activeSensors.push_back(rs);
       }
@@ -472,8 +506,8 @@ void Sensors::PostUpdate(const UpdateInfo &_info,
 }
 
 //////////////////////////////////////////////////
-std::string Sensors::CreateSensor(const sdf::Sensor &_sdf,
-    const std::string &_parentName)
+std::string Sensors::CreateSensor(const Entity &_entity,
+    const sdf::Sensor &_sdf, const std::string &_parentName)
 {
   if (_sdf.Type() == sdf::SensorType::NONE)
   {
@@ -485,6 +519,9 @@ std::string Sensors::CreateSensor(const sdf::Sensor &_sdf,
   auto sensorId = this->dataPtr->sensorManager.CreateSensor(_sdf);
   auto sensor = this->dataPtr->sensorManager.Sensor(sensorId);
 
+  // Add to sensorID -> entity map
+  this->dataPtr->entityToIdMap.insert({_entity, sensorId});
+
   if (nullptr == sensor || sensors::NO_SENSOR == sensor->Id())
   {
     ignerr << "Failed to create sensor [" << _sdf.Name()
@@ -544,6 +581,27 @@ std::string Sensors::CreateSensor(const sdf::Sensor &_sdf,
   if (nullptr != thermalSensor)
   {
     thermalSensor->SetAmbientTemperature(this->dataPtr->ambientTemperature);
+
+    // temperature gradient is in kelvin per meter - typically change in
+    // temperature over change in altitude. However the implementation of
+    // thermal sensor in ign-sensors varies temperature for all objects in its
+    // view. So we will do an approximation based on camera view's vertical
+    // distance.
+    auto camSdf = _sdf.CameraSensor();
+    double farClip = camSdf->FarClip();
+    double angle = camSdf->HorizontalFov().Radian();
+    double aspect = camSdf->ImageWidth() / camSdf->ImageHeight();
+    double vfov = 2.0 * atan(tan(angle / 2.0) / aspect);
+    double height = tan(vfov / 2.0) * farClip * 2.0;
+    double tempRange =
+        std::fabs(this->dataPtr->ambientTemperatureGradient * height);
+    thermalSensor->SetAmbientTemperatureRange(tempRange);
+
+    ignmsg << "Setting ambient temperature to "
+           << this->dataPtr->ambientTemperature << " Kelvin and gradient to "
+           << this->dataPtr->ambientTemperatureGradient << " K/m. "
+           << "The resulting temperature range is: " << tempRange
+           << " Kelvin." << std::endl;
   }
 
   return sensor->Name();
@@ -551,10 +609,8 @@ std::string Sensors::CreateSensor(const sdf::Sensor &_sdf,
 
 IGNITION_ADD_PLUGIN(Sensors, System,
   Sensors::ISystemConfigure,
+  Sensors::ISystemUpdate,
   Sensors::ISystemPostUpdate
 )
 
-IGNITION_ADD_PLUGIN_ALIAS(Sensors, "gz::sim::systems::Sensors")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(Sensors, "ignition::gazebo::systems::Sensors")
