@@ -24,17 +24,17 @@
 #include <limits>
 #include <utility>
 
-#include <gz/common/Profiler.hh>
-#include <gz/common/Util.hh>
-#include <gz/plugin/Register.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/plugin/Register.hh>
 
 // bug https://github.com/protocolbuffers/protobuf/issues/5051
 #ifdef _WIN32
 #undef GetMessage
 #endif
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 /// \brief Base class for input matchers.
@@ -492,10 +492,11 @@ void TriggeredPublisher::Configure(const Entity &,
       return;
     }
 
-    this->inputTopic = inputElem->Get<std::string>("topic");
+    auto inTopic = inputElem->Get<std::string>("topic");
+    this->inputTopic = transport::TopicUtils::AsValidTopic(inTopic);
     if (this->inputTopic.empty())
     {
-      ignerr << "Input topic cannot be empty\n";
+      ignerr << "Invalid input topic [" << inTopic << "]" << std::endl;
       return;
     }
 
@@ -544,10 +545,11 @@ void TriggeredPublisher::Configure(const Entity &,
         ignerr << "Output message type cannot be empty\n";
         continue;
       }
-      info.topic = outputElem->Get<std::string>("topic");
+      auto topic = outputElem->Get<std::string>("topic");
+      info.topic = transport::TopicUtils::AsValidTopic(topic);
       if (info.topic.empty())
       {
-        ignerr << "Output topic cannot be empty\n";
+        ignerr << "Invalid topic [" << topic << "]" << std::endl;
         continue;
       }
       const std::string msgStr = outputElem->Get<std::string>();
@@ -652,17 +654,20 @@ bool TriggeredPublisher::MatchInput(const transport::ProtoMsg &_inputMsg)
   return std::all_of(this->matchers.begin(), this->matchers.end(),
                      [&](const auto &_matcher)
                      {
-                       return _matcher->Match(_inputMsg);
+                       try
+                       {
+                         return _matcher->Match(_inputMsg);
+                       } catch (const google::protobuf::FatalException &err)
+                       {
+                          ignerr << err.what() << std::endl;
+                          return false;
+                       }
                      });
 }
 
 IGNITION_ADD_PLUGIN(TriggeredPublisher,
-                    System,
+                    ignition::gazebo::System,
                     TriggeredPublisher::ISystemConfigure)
 
-IGNITION_ADD_PLUGIN_ALIAS(TriggeredPublisher,
-                          "gz::sim::systems::TriggeredPublisher")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(TriggeredPublisher,
                           "ignition::gazebo::systems::TriggeredPublisher")
