@@ -18,42 +18,44 @@
 #include "UserCommands.hh"
 
 #include <google/protobuf/message.h>
-#include <gz/msgs/boolean.pb.h>
-#include <gz/msgs/entity_factory.pb.h>
-#include <gz/msgs/pose.pb.h>
-#include <gz/msgs/pose_v.pb.h>
-#include <gz/msgs/physics.pb.h>
+#include <ignition/msgs/boolean.pb.h>
+#include <ignition/msgs/entity_factory.pb.h>
+#include <ignition/msgs/light.pb.h>
+#include <ignition/msgs/pose.pb.h>
+#include <ignition/msgs/physics.pb.h>
 
 #include <string>
 #include <utility>
 #include <vector>
 
-#include <gz/msgs/Utility.hh>
+#include <ignition/msgs/Utility.hh>
 
 #include <sdf/Physics.hh>
 #include <sdf/Root.hh>
 #include <sdf/Error.hh>
+#include <sdf/Light.hh>
 
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/common/Profiler.hh"
+#include "ignition/common/Profiler.hh"
 
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/PoseCmd.hh"
-#include "gz/sim/components/PhysicsCmd.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Conversions.hh"
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/SdfEntityCreator.hh"
-#include "gz/sim/Util.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LightCmd.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/PoseCmd.hh"
+#include "ignition/gazebo/components/PhysicsCmd.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Conversions.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 namespace ignition
@@ -129,6 +131,74 @@ class RemoveCommand : public UserCommandBase
   public: bool Execute() final;
 };
 
+/// \brief Command to modify a light entity from simulation.
+class LightCommand : public UserCommandBase
+{
+  /// \brief Constructor
+  /// \param[in] _msg Message identifying the entity to be edited.
+  /// \param[in] _iface Pointer to user commands interface.
+  public: LightCommand(msgs::Light *_msg,
+      std::shared_ptr<UserCommandsInterface> &_iface);
+
+  // Documentation inherited
+  public: bool Execute() final;
+
+  /// \brief Light equality comparison function.
+  public: std::function<bool(const msgs::Light &, const msgs::Light &)>
+          lightEql { [](const msgs::Light &_a, const msgs::Light &_b)
+            {
+             return
+                _a.type() == _b.type() &&
+                _a.name() == _b.name() &&
+                math::equal(
+                   _a.diffuse().a(), _b.diffuse().a(), 1e-6f) &&
+                math::equal(
+                  _a.diffuse().r(), _b.diffuse().r(), 1e-6f) &&
+                math::equal(
+                  _a.diffuse().g(), _b.diffuse().g(), 1e-6f) &&
+                math::equal(
+                  _a.diffuse().b(), _b.diffuse().b(), 1e-6f) &&
+                math::equal(
+                  _a.specular().a(), _b.specular().a(), 1e-6f) &&
+                math::equal(
+                  _a.specular().r(), _b.specular().r(), 1e-6f) &&
+                math::equal(
+                  _a.specular().g(), _b.specular().g(), 1e-6f) &&
+                math::equal(
+                  _a.specular().b(), _b.specular().b(), 1e-6f) &&
+                math::equal(
+                  _a.range(), _b.range(), 1e-6f) &&
+               math::equal(
+                 _a.attenuation_linear(),
+                 _b.attenuation_linear(),
+                 1e-6f) &&
+               math::equal(
+                 _a.attenuation_constant(),
+                 _b.attenuation_constant(),
+                 1e-6f) &&
+               math::equal(
+                 _a.attenuation_quadratic(),
+                 _b.attenuation_quadratic(),
+                 1e-6f) &&
+               _a.cast_shadows() == _b.cast_shadows() &&
+               math::equal(
+                 _a.intensity(),
+                 _b.intensity(),
+                 1e-6f) &&
+               math::equal(
+                 _a.direction().x(), _b.direction().x(), 1e-6) &&
+               math::equal(
+                 _a.direction().y(), _b.direction().y(), 1e-6) &&
+               math::equal(
+                 _a.direction().z(), _b.direction().z(), 1e-6) &&
+               math::equal(
+                 _a.spot_inner_angle(), _b.spot_inner_angle(), 1e-6f) &&
+               math::equal(
+                 _a.spot_outer_angle(), _b.spot_outer_angle(), 1e-6f) &&
+               math::equal(_a.spot_falloff(), _b.spot_falloff(), 1e-6f);
+            }};
+};
+
 /// \brief Command to update an entity's pose transform.
 class PoseCommand : public UserCommandBase
 {
@@ -140,19 +210,17 @@ class PoseCommand : public UserCommandBase
 
   // Documentation inherited
   public: bool Execute() final;
-};
 
-/// \brief Command to update an entity's pose transform.
-class PoseVectorCommand : public UserCommandBase
-{
-  /// \brief Constructor
-  /// \param[in] _msg pose_v message.
-  /// \param[in] _iface Pointer to user commands interface.
-  public: PoseVectorCommand(msgs::Pose_V *_msg,
-      std::shared_ptr<UserCommandsInterface> &_iface);
-
-  // Documentation inherited
-  public: bool Execute() final;
+  /// \brief Pose3d equality comparison function.
+  public: std::function<bool(const math::Pose3d &, const math::Pose3d &)>
+          pose3Eql { [](const math::Pose3d &_a, const math::Pose3d &_b)
+                     {
+                       return _a.Pos().Equal(_b.Pos(), 1e-6) &&
+                         math::equal(_a.Rot().X(), _b.Rot().X(), 1e-6) &&
+                         math::equal(_a.Rot().Y(), _b.Rot().Y(), 1e-6) &&
+                         math::equal(_a.Rot().Z(), _b.Rot().Z(), 1e-6) &&
+                         math::equal(_a.Rot().W(), _b.Rot().W(), 1e-6);
+                     }};
 };
 
 /// \brief Command to modify the physics parameters of a simulation.
@@ -199,6 +267,13 @@ class ignition::gazebo::systems::UserCommandsPrivate
   public: bool RemoveService(const msgs::Entity &_req,
       msgs::Boolean &_res);
 
+  /// \brief Callback for light service
+  /// \param[in] _req Request containing light update of an entity.
+  /// \param[in] _res True if message successfully received and queued.
+  /// It does not mean that the light will be successfully updated.
+  /// \return True if successful.
+  public: bool LightService(const msgs::Light &_req, msgs::Boolean &_res);
+
   /// \brief Callback for pose service
   /// \param[in] _req Request containing pose update of an entity.
   /// \param[in] _res True if message successfully received and queued.
@@ -206,13 +281,6 @@ class ignition::gazebo::systems::UserCommandsPrivate
   /// \return True if successful.
   public: bool PoseService(const msgs::Pose &_req, msgs::Boolean &_res);
 
-  /// \brief Callback for pose_v service
-  /// \param[in] _req Request containing pose update of several entities.
-  /// \param[out] _res True if message successfully received and queued.
-  /// It does not mean that the entity will be successfully moved.
-  /// \return True if successful.
-  public: bool PoseVectorService(const msgs::Pose_V &_req, msgs::Boolean &_res);
-
   /// \brief Callback for physics service
   /// \param[in] _req Request containing updates to the physics parameters.
   /// \param[in] _res True if message successfully received and queued.
@@ -233,26 +301,6 @@ class ignition::gazebo::systems::UserCommandsPrivate
   public: std::mutex pendingMutex;
 };
 
-/// \brief Pose3d equality comparison function.
-/// \param[in] _a A pose to compare
-/// \param[in] _b Another pose to compare
-bool pose3Eql(const math::Pose3d &_a, const math::Pose3d &_b)
-{
-  return _a.Pos().Equal(_b.Pos(), 1e-6) &&
-    math::equal(_a.Rot().X(), _b.Rot().X(), 1e-6) &&
-    math::equal(_a.Rot().Y(), _b.Rot().Y(), 1e-6) &&
-    math::equal(_a.Rot().Z(), _b.Rot().Z(), 1e-6) &&
-    math::equal(_a.Rot().W(), _b.Rot().W(), 1e-6);
-}
-
-/// \brief Update pose for a specific pose message
-/// \param[in] _req Message containing new pose
-/// \param[in] _iface Pointer to user commands interface.
-/// \return True if successful.
-bool updatePose(
-  const msgs::Pose &_req,
-  std::shared_ptr<UserCommandsInterface> _iface);
-
 //////////////////////////////////////////////////
 UserCommands::UserCommands() : System(),
     dataPtr(std::make_unique<UserCommandsPrivate>())
@@ -278,42 +326,52 @@ void UserCommands::Configure(const Entity &_entity,
   const components::Name *constCmp = _ecm.Component<components::Name>(_entity);
   const std::string &worldName = constCmp->Data();
 
+  auto validWorldName = transport::TopicUtils::AsValidTopic(worldName);
+  if (validWorldName.empty())
+  {
+    ignerr << "World name [" << worldName
+           << "] doesn't work well with transport, services not advertised."
+           << std::endl;
+    return;
+  }
+
   // Create service
-  std::string createService{"/world/" + worldName + "/create"};
+  std::string createService{"/world/" + validWorldName + "/create"};
   this->dataPtr->node.Advertise(createService,
       &UserCommandsPrivate::CreateService, this->dataPtr.get());
 
   // Create service for EntityFactory_V
-  std::string createServiceMultiple{"/world/" + worldName + "/create_multiple"};
+  std::string createServiceMultiple{"/world/" + validWorldName +
+      "/create_multiple"};
   this->dataPtr->node.Advertise(createServiceMultiple,
       &UserCommandsPrivate::CreateServiceMultiple, this->dataPtr.get());
 
   ignmsg << "Create service on [" << createService << "]" << std::endl;
 
   // Remove service
-  std::string removeService{"/world/" + worldName + "/remove"};
+  std::string removeService{"/world/" + validWorldName + "/remove"};
   this->dataPtr->node.Advertise(removeService,
       &UserCommandsPrivate::RemoveService, this->dataPtr.get());
 
   ignmsg << "Remove service on [" << removeService << "]" << std::endl;
 
   // Pose service
-  std::string poseService{"/world/" + worldName + "/set_pose"};
+  std::string poseService{"/world/" + validWorldName + "/set_pose"};
   this->dataPtr->node.Advertise(poseService,
       &UserCommandsPrivate::PoseService, this->dataPtr.get());
 
   ignmsg << "Pose service on [" << poseService << "]" << std::endl;
 
-  // Pose vector service
-  std::string poseVectorService{
-    "/world/" + worldName + "/set_pose_vector"};
-  this->dataPtr->node.Advertise(poseVectorService,
-      &UserCommandsPrivate::PoseVectorService, this->dataPtr.get());
+  // Light service
+  std::string lightService{"/world/" + validWorldName + "/light_config"};
+  this->dataPtr->node.Advertise(lightService,
+      &UserCommandsPrivate::LightService, this->dataPtr.get());
 
-  ignmsg << "Pose service on [" << poseVectorService << "]" << std::endl;
+  ignmsg << "Light configuration service on [" << lightService << "]"
+    << std::endl;
 
   // Physics service
-  std::string physicsService{"/world/" + worldName + "/set_physics"};
+  std::string physicsService{"/world/" + validWorldName + "/set_physics"};
   this->dataPtr->node.Advertise(physicsService,
       &UserCommandsPrivate::PhysicsService, this->dataPtr.get());
 
@@ -411,13 +469,13 @@ bool UserCommandsPrivate::RemoveService(const msgs::Entity &_req,
 }
 
 //////////////////////////////////////////////////
-bool UserCommandsPrivate::PoseService(const msgs::Pose &_req,
+bool UserCommandsPrivate::LightService(const msgs::Light &_req,
     msgs::Boolean &_res)
 {
   // Create command and push it to queue
   auto msg = _req.New();
   msg->CopyFrom(_req);
-  auto cmd = std::make_unique<PoseCommand>(msg, this->iface);
+  auto cmd = std::make_unique<LightCommand>(msg, this->iface);
 
   // Push to pending
   {
@@ -430,13 +488,13 @@ bool UserCommandsPrivate::PoseService(const msgs::Pose &_req,
 }
 
 //////////////////////////////////////////////////
-bool UserCommandsPrivate::PoseVectorService(const msgs::Pose_V &_req,
+bool UserCommandsPrivate::PoseService(const msgs::Pose &_req,
     msgs::Boolean &_res)
 {
   // Create command and push it to queue
   auto msg = _req.New();
   msg->CopyFrom(_req);
-  auto cmd = std::make_unique<PoseVectorCommand>(msg, this->iface);
+  auto cmd = std::make_unique<PoseCommand>(msg, this->iface);
 
   // Push to pending
   {
@@ -500,6 +558,7 @@ bool CreateCommand::Execute()
 
   // Load SDF
   sdf::Root root;
+  sdf::Light lightSdf;
   sdf::Errors errors;
   switch (createMsg->from_case())
   {
@@ -521,9 +580,8 @@ bool CreateCommand::Execute()
     }
     case msgs::EntityFactory::kLight:
     {
-      // TODO(louise) Support light msg
-      ignerr << "light field not yet supported." << std::endl;
-      return false;
+      lightSdf = convert<sdf::Light>(createMsg->light());
+      break;
     }
     case msgs::EntityFactory::kCloneName:
     {
@@ -548,18 +606,26 @@ bool CreateCommand::Execute()
   bool isModel{false};
   bool isLight{false};
   bool isActor{false};
-  if (root.ModelCount() > 0)
+  bool isRoot{false};
+  if (nullptr != root.Model())
   {
+    isRoot = true;
     isModel = true;
   }
-  else if (root.LightCount() > 0)
+  else if (nullptr != root.Light())
   {
+    isRoot = true;
     isLight = true;
   }
-  else if (root.ActorCount() > 0)
+  else if (nullptr != root.Actor())
   {
+    isRoot = true;
     isActor = true;
   }
+  else if (!lightSdf.Name().empty())
+  {
+    isLight = true;
+  }
   else
   {
     ignerr << "Expected exactly one top-level <model>, <light> or <actor> on"
@@ -567,7 +633,7 @@ bool CreateCommand::Execute()
     return false;
   }
 
-  if ((root.ModelCount() + root.LightCount() + root.ActorCount()) > 1)
+  if ((isModel && isLight) || (isModel && isActor) || (isLight && isActor))
   {
     ignwarn << "Expected exactly one top-level <model>, <light> or <actor>, "
             << "but found more. Only the 1st will be spawned." << std::endl;
@@ -581,15 +647,19 @@ bool CreateCommand::Execute()
   }
   else if (isModel)
   {
-    desiredName = root.ModelByIndex(0)->Name();
+    desiredName = root.Model()->Name();
+  }
+  else if (isLight && isRoot)
+  {
+    desiredName = root.Light()->Name();
   }
   else if (isLight)
   {
-    desiredName = root.LightByIndex(0)->Name();
+    desiredName = lightSdf.Name();
   }
   else if (isActor)
   {
-    desiredName = root.ActorByIndex(0)->Name();
+    desiredName = root.Actor()->Name();
   }
 
   // Check if there's already a top-level entity with the given name
@@ -621,19 +691,24 @@ bool CreateCommand::Execute()
   Entity entity{kNullEntity};
   if (isModel)
   {
-    auto model = *root.ModelByIndex(0);
+    auto model = *root.Model();
     model.SetName(desiredName);
     entity = this->iface->creator->CreateEntities(&model);
   }
+  else if (isLight && isRoot)
+  {
+    auto light = *root.Light();
+    light.SetName(desiredName);
+    entity = this->iface->creator->CreateEntities(&light);
+  }
   else if (isLight)
   {
-    auto light = root.LightByIndex(0);
-    light->SetName(desiredName);
-    entity = this->iface->creator->CreateEntities(light);
+    lightSdf.SetName(desiredName);
+    entity = this->iface->creator->CreateEntities(&lightSdf);
   }
   else if (isActor)
   {
-    auto actor = *root.ActorByIndex(0);
+    auto actor = *root.Actor();
     actor.SetName(desiredName);
     entity = this->iface->creator->CreateEntities(&actor);
   }
@@ -670,7 +745,42 @@ bool RemoveCommand::Execute()
     return false;
   }
 
-  auto entity = entityFromMsg(*this->iface->ecm, *removeMsg);
+  Entity entity{kNullEntity};
+  if (removeMsg->id() != kNullEntity)
+  {
+    entity = removeMsg->id();
+  }
+  else if (!removeMsg->name().empty() &&
+      removeMsg->type() != msgs::Entity::NONE)
+  {
+    if (removeMsg->type() == msgs::Entity::MODEL)
+    {
+      entity = this->iface->ecm->EntityByComponents(components::Model(),
+        components::Name(removeMsg->name()));
+    }
+    else if (removeMsg->type() == msgs::Entity::LIGHT)
+    {
+      entity = this->iface->ecm->EntityByComponents(
+        components::Name(removeMsg->name()));
+
+      auto lightComp = this->iface->ecm->Component<components::Light>(entity);
+      if (nullptr == lightComp)
+        entity = kNullEntity;
+    }
+    else
+    {
+      ignerr << "Deleting entities of type [" << removeMsg->type()
+             << "] is not supported." << std::endl;
+      return false;
+    }
+  }
+  else
+  {
+    ignerr << "Remove command missing either entity's ID or name + type"
+           << std::endl;
+    return false;
+  }
+
   if (entity == kNullEntity)
   {
     ignerr << "Entity named [" << removeMsg->name() << "] of type ["
@@ -704,47 +814,88 @@ bool RemoveCommand::Execute()
 
 
 //////////////////////////////////////////////////
-bool updatePose(
-  const msgs::Pose &_poseMsg,
-  std::shared_ptr<UserCommandsInterface> _iface)
+LightCommand::LightCommand(msgs::Light *_msg,
+    std::shared_ptr<UserCommandsInterface> &_iface)
+    : UserCommandBase(_msg, _iface)
 {
-  // Check the name of the entity being spawned
-  std::string entityName = _poseMsg.name();
-  Entity entity = kNullEntity;
-  // TODO(anyone) Update pose message to use Entity, with default ID null
-  if (_poseMsg.id() != kNullEntity && _poseMsg.id() != 0)
-  {
-    entity = _poseMsg.id();
-  }
-  else if (!entityName.empty())
-  {
-    entity = _iface->ecm->EntityByComponents(components::Name(entityName),
-      components::ParentEntity(_iface->worldEntity));
-  }
+}
 
-  if (!_iface->ecm->HasEntity(entity))
+//////////////////////////////////////////////////
+bool LightCommand::Execute()
+{
+  auto lightMsg = dynamic_cast<const msgs::Light *>(this->msg);
+  if (nullptr == lightMsg)
   {
-    ignerr << "Unable to update the pose for entity id:[" << _poseMsg.id()
-           << "], name[" << entityName << "]" << std::endl;
+    ignerr << "Internal error, null light message" << std::endl;
     return false;
   }
 
-  auto poseCmdComp =
-    _iface->ecm->Component<components::WorldPoseCmd>(entity);
-  if (!poseCmdComp)
+  Entity lightEntity{kNullEntity};
+
+  if (lightMsg->id() != kNullEntity)
   {
-    _iface->ecm->CreateComponent(
-        entity, components::WorldPoseCmd(msgs::Convert(_poseMsg)));
+    lightEntity = lightMsg->id();
+  }
+  else if (!lightMsg->name().empty())
+  {
+    if (lightMsg->parent_id() != kNullEntity)
+    {
+      lightEntity = this->iface->ecm->EntityByComponents(
+        components::Name(lightMsg->name()),
+        components::ParentEntity(lightMsg->parent_id()));
+    }
+    else
+    {
+      lightEntity = this->iface->ecm->EntityByComponents(
+        components::Name(lightMsg->name()));
+    }
+  }
+  if (kNullEntity == lightEntity)
+  {
+    ignerr << "Failed to find light with name [" << lightMsg->name()
+           << "], ID [" << lightMsg->id() << "] and parent ID ["
+           << lightMsg->parent_id() << "]." << std::endl;
+    return false;
+  }
+
+  if (!lightEntity)
+  {
+    ignmsg << "Failed to find light entity named [" << lightMsg->name()
+      << "]." << std::endl;
+    return false;
+  }
+
+  auto lightPose = this->iface->ecm->Component<components::Pose>(lightEntity);
+  if (nullptr == lightPose)
+    lightEntity = kNullEntity;
+
+  if (!lightEntity)
+  {
+    ignmsg << "Pose component not available" << std::endl;
+    return false;
+  }
+
+  if (lightMsg->has_pose())
+  {
+    lightPose->Data().Pos() = msgs::Convert(lightMsg->pose()).Pos();
+  }
+
+  auto lightCmdComp =
+    this->iface->ecm->Component<components::LightCmd>(lightEntity);
+  if (!lightCmdComp)
+  {
+    this->iface->ecm->CreateComponent(
+        lightEntity, components::LightCmd(*lightMsg));
   }
   else
   {
-    /// \todo(anyone) Moving an object is not captured in a log file.
-    auto state = poseCmdComp->SetData(msgs::Convert(_poseMsg), pose3Eql) ?
+    auto state = lightCmdComp->SetData(*lightMsg, this->lightEql) ?
         ComponentState::OneTimeChange :
         ComponentState::NoChange;
-    _iface->ecm->SetChanged(entity, components::WorldPoseCmd::typeId,
-        state);
+    this->iface->ecm->SetChanged(lightEntity, components::LightCmd::typeId,
+      state);
   }
+
   return true;
 }
 
@@ -765,32 +916,42 @@ bool PoseCommand::Execute()
     return false;
   }
 
-  return updatePose(*poseMsg, this->iface);
-}
-
-//////////////////////////////////////////////////
-PoseVectorCommand::PoseVectorCommand(msgs::Pose_V *_msg,
-    std::shared_ptr<UserCommandsInterface> &_iface)
-    : UserCommandBase(_msg, _iface)
-{
-}
-
-//////////////////////////////////////////////////
-bool PoseVectorCommand::Execute()
-{
-  auto poseVectorMsg = dynamic_cast<const msgs::Pose_V *>(this->msg);
-  if (nullptr == poseVectorMsg)
+  // Check the name of the entity being spawned
+  std::string entityName = poseMsg->name();
+  Entity entity = kNullEntity;
+  // TODO(anyone) Update pose message to use Entity, with default ID null
+  if (poseMsg->id() != kNullEntity && poseMsg->id() != 0)
   {
-    ignerr << "Internal error, null create message" << std::endl;
+    entity = poseMsg->id();
+  }
+  else if (!entityName.empty())
+  {
+    entity = this->iface->ecm->EntityByComponents(components::Name(entityName),
+      components::ParentEntity(this->iface->worldEntity));
+  }
+
+  if (!this->iface->ecm->HasEntity(entity))
+  {
+    ignerr << "Unable to update the pose for entity id:[" << poseMsg->id()
+           << "], name[" << entityName << "]" << std::endl;
     return false;
   }
 
-  for (int i = 0; i < poseVectorMsg->pose_size(); i++)
+  auto poseCmdComp =
+    this->iface->ecm->Component<components::WorldPoseCmd>(entity);
+  if (!poseCmdComp)
   {
-    if (!updatePose(poseVectorMsg->pose(i), this->iface))
-    {
-      return false;
-    }
+    this->iface->ecm->CreateComponent(
+        entity, components::WorldPoseCmd(msgs::Convert(*poseMsg)));
+  }
+  else
+  {
+    /// \todo(anyone) Moving an object is not captured in a log file.
+    auto state = poseCmdComp->SetData(msgs::Convert(*poseMsg), this->pose3Eql) ?
+        ComponentState::OneTimeChange :
+        ComponentState::NoChange;
+    this->iface->ecm->SetChanged(entity, components::WorldPoseCmd::typeId,
+        state);
   }
 
   return true;
@@ -835,9 +996,5 @@ IGNITION_ADD_PLUGIN(UserCommands, System,
   UserCommands::ISystemPreUpdate
 )
 
-IGNITION_ADD_PLUGIN_ALIAS(UserCommands,
-                          "gz::sim::systems::UserCommands")
-
-// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(UserCommands,
                           "ignition::gazebo::systems::UserCommands")
