@@ -18,8 +18,8 @@
 #include "WindEffects.hh"
 
 #include <google/protobuf/message.h>
-#include <gz/msgs/boolean.pb.h>
-#include <gz/msgs/entity_factory.pb.h>
+#include <ignition/msgs/boolean.pb.h>
+#include <ignition/msgs/entity_factory.pb.h>
 
 #include <string>
 #include <vector>
@@ -27,30 +27,30 @@
 #include <sdf/Root.hh>
 #include <sdf/Error.hh>
 
-#include <gz/common/Profiler.hh>
-#include <gz/msgs/Utility.hh>
-#include <gz/plugin/Register.hh>
-#include <gz/transport/Node.hh>
-#include <gz/sensors/Noise.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/msgs/Utility.hh>
+#include <ignition/plugin/Register.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/sensors/Noise.hh>
 
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/SdfEntityCreator.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
 
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/LinearVelocitySeed.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Wind.hh"
-#include "gz/sim/components/WindMode.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/LinearVelocitySeed.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Wind.hh"
+#include "ignition/gazebo/components/WindMode.hh"
 
-#include "gz/sim/Link.hh"
+#include "ignition/gazebo/Link.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace systems;
 
 /// \brief Private WindEffects data class.
@@ -152,6 +152,10 @@ class ignition::gazebo::systems::WindEffectsPrivate
   /// valid.
   public: bool validConfig{false};
 
+  /// \brief Whether links have been initialized. Initialization involves
+  /// creating components this system needs on links that are affected by wind.
+  public: bool linksInitialized{false};
+
   /// \brief Mutex to protect currWindVelSeed and windEnabled
   public: std::mutex windInfoMutex;
 
@@ -301,12 +305,20 @@ void WindEffectsPrivate::Load(EntityComponentManager &_ecm,
 //////////////////////////////////////////////////
 void WindEffectsPrivate::SetupTransport(const std::string &_worldName)
 {
+  auto validWorldName = transport::TopicUtils::AsValidTopic(_worldName);
+  if (validWorldName.empty())
+  {
+    ignerr << "Failed to setup transport, invalid world name [" << _worldName
+           << "]" << std::endl;
+    return;
+  }
+
   // Wind seed velocity topic
-  this->node.Subscribe("/world/" + _worldName + "/wind",
+  this->node.Subscribe("/world/" + validWorldName + "/wind",
                        &WindEffectsPrivate::OnWindMsg, this);
 
   // Wind info service
-  this->node.Advertise("/world/" + _worldName + "/wind_info",
+  this->node.Advertise("/world/" + validWorldName + "/wind_info",
                        &WindEffectsPrivate::WindInfoService, this);
 }
 
@@ -374,7 +386,7 @@ void WindEffectsPrivate::UpdateWindVelocity(const UpdateInfo &_info,
     direction = this->noiseDirection->Apply(direction);
 
   // Apply wind velocity
-  math::Vector3d windVel;
+  ignition::math::Vector3d windVel;
   windVel.X(magnitude * std::cos(IGN_DTOR(direction)));
   windVel.Y(magnitude * std::sin(IGN_DTOR(direction)));
 
@@ -538,30 +550,45 @@ void WindEffects::PreUpdate(const UpdateInfo &_info,
   // Process commands
   this->dataPtr->ProcessCommandQueue(_ecm);
 
-  if (!this->dataPtr->validConfig)
-    return;
-
-  _ecm.EachNew<components::Link, components::WindMode>(
-      [&](const Entity &_entity, components::Link *,
-          components::WindMode *_windMode) -> bool
+  if (this->dataPtr->validConfig)
   {
-    if (_windMode->Data())
+    if (!this->dataPtr->linksInitialized)
     {
-      Link link(_entity);
-      link.EnableVelocityChecks(_ecm, true);
+      _ecm.Each<components::Link, components::WindMode>(
+          [&](const Entity &_entity, components::Link *,
+              components::WindMode *_windMode) -> bool
+          {
+            if (_windMode->Data())
+            {
+              // Create a WorldLinearVelocity component on the link so that
+              // physics can populate it
+              if (!_ecm.Component<components::WorldLinearVelocity>(_entity))
+              {
+                _ecm.CreateComponent(_entity,
+                                     components::WorldLinearVelocity());
+              }
+              if (!_ecm.Component<components::WorldPose>(_entity))
+              {
+                _ecm.CreateComponent(_entity, components::WorldPose());
+              }
+            }
+            return true;
+          });
+
+      this->dataPtr->linksInitialized = true;
     }
-    return true;
-  });
+    else
+    {
+      if (_info.paused)
+        return;
 
-  if (_info.paused)
-    return;
-
-  if (!this->dataPtr->currentWindInfo.enable_wind())
-    return;
-
-  this->dataPtr->UpdateWindVelocity(_info, _ecm);
-  this->dataPtr->ApplyWindForce(_info, _ecm);
+      if (!this->dataPtr->currentWindInfo.enable_wind())
+        return;
 
+      this->dataPtr->UpdateWindVelocity(_info, _ecm);
+      this->dataPtr->ApplyWindForce(_info, _ecm);
+    }
+  }
 }
 
 IGNITION_ADD_PLUGIN(WindEffects, System,
@@ -569,9 +596,4 @@ IGNITION_ADD_PLUGIN(WindEffects, System,
   WindEffects::ISystemPreUpdate
 )
 
-IGNITION_ADD_PLUGIN_ALIAS(WindEffects,
-                          "gz::sim::systems::WindEffects")
-
-// TODO(CH3): Deprecated, remove on version 8
-IGNITION_ADD_PLUGIN_ALIAS(WindEffects,
-                          "ignition::gazebo::systems::WindEffects")
+IGNITION_ADD_PLUGIN_ALIAS(WindEffects, "ignition::gazebo::systems::WindEffects")
