@@ -17,27 +17,33 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/fluid_pressure.pb.h>
+#include <ignition/msgs/fluid_pressure.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/AirPressureSensor.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/AirPressureSensor.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test AirPressureTest system
-class AirPressureTest : public InternalFixture<::testing::Test>
+class AirPressureTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
@@ -62,11 +68,11 @@ TEST_F(AirPressureTest, AirPressure)
 
   // Create a system that checks sensor topic
   test::Relay testSystem;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                              const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &,
+                              const gazebo::EntityComponentManager &_ecm)
       {
         _ecm.Each<components::AirPressureSensor, components::Name>(
-            [&](const Entity &_entity,
+            [&](const ignition::gazebo::Entity &_entity,
                 const components::AirPressureSensor *,
                 const components::Name *_name) -> bool
             {
@@ -75,10 +81,6 @@ TEST_F(AirPressureTest, AirPressure)
               auto sensorComp = _ecm.Component<components::Sensor>(_entity);
               EXPECT_NE(nullptr, sensorComp);
 
-              if (_info.iterations == 1)
-                return true;
-
-              // This component is created on the 2nd PreUpdate
               auto topicComp = _ecm.Component<components::SensorTopic>(_entity);
               EXPECT_NE(nullptr, topicComp);
               if (topicComp)
