@@ -17,31 +17,37 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/double.pb.h>
+#include <ignition/msgs/double.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/JointForceCmd.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/JointForceCmd.hh"
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
 #define TOL 1e-4
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test fixture for ApplyJointForce system
-class ApplyJointForceTestFixture : public InternalFixture<::testing::Test>
+class ApplyJointForceTestFixture : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
@@ -69,7 +75,7 @@ TEST_F(ApplyJointForceTestFixture, JointVelocityCommand)
   test::Relay testSystem;
   std::vector<double> jointForceCmd;
   testSystem.OnPreUpdate(
-      [&](const UpdateInfo &, EntityComponentManager &_ecm)
+      [&](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
       {
         auto joint = _ecm.EntityByComponents(components::Joint(),
                                              components::Name(jointName));
