@@ -17,8 +17,8 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/empty.pb.h>
-#include <gz/msgs/twist.pb.h>
+#include <ignition/msgs/empty.pb.h>
+#include <ignition/msgs/twist.pb.h>
 
 #include <optional>
 #include <regex>
@@ -26,27 +26,33 @@
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Entity.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Entity.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "helpers/Relay.hh"
 #include "helpers/UniqueTestDirectoryEnv.hh"
-#include "helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
-class BreadcrumbsTest : public InternalFixture<::testing::Test>
+class BreadcrumbsTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
   public: void LoadWorld(const std::string &_path, bool _useLevels = false)
   {
     this->serverConfig.SetResourceCache(test::UniqueTestDirectoryEnv::Path());
@@ -145,8 +151,8 @@ TEST_F(BreadcrumbsTest, DeployAtOffset)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B1/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // After 1000 iterations, stop the vehicle, spawn a breadcrumb
@@ -210,8 +216,8 @@ TEST_F(BreadcrumbsTest, MaxDeployments)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B1/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // Every 1000 iterations, deploy
@@ -268,8 +274,8 @@ TEST_F(BreadcrumbsTest, FuelDeploy)
   const std::size_t nIters = iterTestStart + 2500;
   const std::size_t maxDeployments = 5;
   std::size_t deployCount = 0;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // Every 500 iterations, deploy
@@ -322,8 +328,8 @@ TEST_F(BreadcrumbsTest, Performer)
   const std::size_t nIters = iterTestStart + 10000;
 
   std::optional<math::Pose3d> initialPose;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Deploy a performer breadcrumb on a tile that's on a level, and ensure
     // that it keeps the tile from being unloaded.
@@ -395,8 +401,8 @@ TEST_F(BreadcrumbsTest, PerformerSetVolume)
   const std::size_t nIters = iterTestStart + 2000;
 
   std::optional<math::Pose3d> initialPose;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Deploy a performer breadcrumb on a tile that's on the default a level,
     // and check that it causes tile_1 to be loaded since the performer's volume
@@ -448,8 +454,8 @@ TEST_F(BreadcrumbsTest, DeployDisablePhysics)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B2/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                              const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                              const gazebo::EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // After 1000 iterations, stop the vehicle, spawn a breadcrumb
@@ -549,7 +555,7 @@ TEST_F(BreadcrumbsTest, AllowRenaming)
 /////////////////////////////////////////////////
 /// Return a list of model entities whose names match the given regex
 std::vector<Entity> ModelsByNameRegex(
-    const EntityComponentManager &_ecm, const std::regex &_re)
+    const gazebo::EntityComponentManager &_ecm, const std::regex &_re)
 {
   std::vector<Entity> entities;
   _ecm.Each<components::Model, components::Name>(
@@ -584,8 +590,8 @@ TEST_F(BreadcrumbsTest, LevelLoadUnload)
   std::regex reTile1{"tile_1"};
   std::regex reBreadcrumb{"B1_.*"};
   testSystem.OnPostUpdate(
-      [&](const UpdateInfo &_info,
-          const EntityComponentManager &_ecm)
+      [&](const gazebo::UpdateInfo &_info,
+          const gazebo::EntityComponentManager &_ecm)
       {
         // Ensure that tile_1 is loaded at the start, deploy a breadcrumb
         if (_info.iterations == iterTestStart)
