@@ -17,30 +17,34 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
 
-#include "gz/sim/Util.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/TestFixture.hh"
-#include "gz/sim/components/CenterOfVolume.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Volume.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/components/CenterOfVolume.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Volume.hh"
 
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/test_config.hh"
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
-class BuoyancyTest : public InternalFixture<::testing::Test>
+class BuoyancyTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
@@ -63,8 +67,8 @@ TEST_F(BuoyancyTest, Movement)
 
   bool finished = false;
   test::Relay testSystem;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                             const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
+                             const gazebo::EntityComponentManager &_ecm)
   {
     // Check pose
     Entity submarine = _ecm.EntityByComponents(
@@ -99,7 +103,7 @@ TEST_F(BuoyancyTest, Movement)
     auto submarineCenterOfVolume =
       _ecm.Component<components::CenterOfVolume>(submarineLink);
     ASSERT_NE(submarineCenterOfVolume, nullptr);
-    EXPECT_EQ(math::Vector3d(0, 0, 0),
+    EXPECT_EQ(ignition::math::Vector3d(0, 0, 0),
         submarineCenterOfVolume->Data());
 
     // Get the submarine buoyant link
@@ -117,7 +121,7 @@ TEST_F(BuoyancyTest, Movement)
     auto submarineBuoyantCenterOfVolume =
       _ecm.Component<components::CenterOfVolume>(submarineBuoyantLink);
     ASSERT_NE(submarineBuoyantCenterOfVolume, nullptr);
-    EXPECT_EQ(math::Vector3d(0, 0, 0),
+    EXPECT_EQ(ignition::math::Vector3d(0, 0, 0),
         submarineBuoyantCenterOfVolume->Data());
 
     // Get the submarine sinking link
@@ -135,7 +139,7 @@ TEST_F(BuoyancyTest, Movement)
     auto submarineSinkingCenterOfVolume =
       _ecm.Component<components::CenterOfVolume>(submarineSinkingLink);
     ASSERT_NE(submarineSinkingCenterOfVolume, nullptr);
-    EXPECT_EQ(math::Vector3d(0, 0, 0),
+    EXPECT_EQ(ignition::math::Vector3d(0, 0, 0),
         submarineSinkingCenterOfVolume->Data());
 
     // Get the duck link
@@ -151,7 +155,7 @@ TEST_F(BuoyancyTest, Movement)
     auto duckCenterOfVolume =
       _ecm.Component<components::CenterOfVolume>(duckLink);
     ASSERT_NE(duckCenterOfVolume, nullptr);
-    EXPECT_EQ(math::Vector3d(0, 0, -0.4),
+    EXPECT_EQ(ignition::math::Vector3d(0, 0, -0.4),
         duckCenterOfVolume->Data());
 
     auto submarinePose = _ecm.Component<components::Pose>(submarine);
@@ -196,77 +200,3 @@ TEST_F(BuoyancyTest, Movement)
   server.Run(true, iterations, false);
   EXPECT_TRUE(finished);
 }
-
-/////////////////////////////////////////////////
-TEST_F(BuoyancyTest, OffsetAndRotation)
-{
-  TestFixture fixture(common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-    "test", "worlds", "center_of_volume.sdf"));
-
-  std::size_t iterations{0};
-  fixture.OnPostUpdate([&](
-      const UpdateInfo &,
-      const EntityComponentManager &_ecm)
-  {
-    // Get links
-    auto noOffsets = entitiesFromScopedName("no_offset::link", _ecm);
-    ASSERT_EQ(1u, noOffsets.size());
-    auto noOffset = *noOffsets.begin();
-    EXPECT_NE(kNullEntity, noOffset);
-
-    auto noOffsetRotateds = entitiesFromScopedName("no_offset_rotated::link",
-        _ecm);
-    ASSERT_EQ(1u, noOffsetRotateds.size());
-    auto noOffsetRotated = *noOffsetRotateds.begin();
-    EXPECT_NE(kNullEntity, noOffsetRotated);
-
-    auto withOffsets = entitiesFromScopedName("com_cov_offset::link", _ecm);
-    ASSERT_EQ(1u, withOffsets.size());
-    auto withOffset = *withOffsets.begin();
-    EXPECT_NE(kNullEntity, withOffset);
-
-    auto withOffsetRotateds = entitiesFromScopedName(
-        "com_cov_offset_rotated::link", _ecm);
-    ASSERT_EQ(1u, withOffsetRotateds.size());
-    auto withOffsetRotated = *withOffsetRotateds.begin();
-    EXPECT_NE(kNullEntity, withOffsetRotated);
-
-    // Check CoVs have correct offsets
-    auto noOffsetCoV = _ecm.Component<components::CenterOfVolume>(noOffset);
-    ASSERT_NE(noOffsetCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::Zero, noOffsetCoV->Data());
-
-    auto noOffsetRotatedCoV = _ecm.Component<components::CenterOfVolume>(
-        noOffsetRotated);
-    ASSERT_NE(noOffsetRotatedCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::Zero, noOffsetRotatedCoV->Data());
-
-    auto withOffsetCoV = _ecm.Component<components::CenterOfVolume>(withOffset);
-    ASSERT_NE(withOffsetCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::One, withOffsetCoV->Data());
-
-    auto withOffsetRotatedCoV = _ecm.Component<components::CenterOfVolume>(
-        withOffsetRotated);
-    ASSERT_NE(withOffsetRotatedCoV, nullptr);
-    EXPECT_EQ(math::Vector3d::One, withOffsetRotatedCoV->Data());
-
-    // Check that all objects are neutrally buoyant and stay still
-    auto noOffsetPose = worldPose(noOffset, _ecm);
-    EXPECT_EQ(math::Pose3d(), noOffsetPose);
-
-    auto noOffsetRotatedPose = worldPose(noOffsetRotated, _ecm);
-    EXPECT_EQ(math::Pose3d(-3, 0, 0, 0.1, 0.2, 0.3), noOffsetRotatedPose);
-
-    auto withOffsetPose = worldPose(withOffset, _ecm);
-    EXPECT_EQ(math::Pose3d(0, 3, 0, 0, 0, 0), withOffsetPose);
-
-    auto withOffsetRotatedPose = worldPose(withOffsetRotated, _ecm);
-    EXPECT_EQ(math::Pose3d(-3, 3, 0, 0.1, 0.2, 0.3), withOffsetRotatedPose);
-
-    iterations++;
-  }).Finalize();
-
-  std::size_t targetIterations{1000};
-  fixture.Server()->Run(true, targetIterations, false);
-  EXPECT_EQ(targetIterations, iterations);
-}
