@@ -16,24 +16,30 @@
 */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test CameraVideoRecorder system
-class CameraVideoRecorderTest : public InternalFixture<::testing::Test>
+class CameraVideoRecorderTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
@@ -51,7 +57,7 @@ TEST_F(CameraVideoRecorderTest, IGN_UTILS_TEST_DISABLED_ON_MAC(RecordVideo))
   // Run server
   server.Run(true, 1, false);
 
-  transport::Node node;
+  ignition::transport::Node node;
   std::vector<std::string> services;
   bool hasService = false;
 
@@ -75,8 +81,8 @@ TEST_F(CameraVideoRecorderTest, IGN_UTILS_TEST_DISABLED_ON_MAC(RecordVideo))
   }
   EXPECT_TRUE(hasService);
 
-  msgs::VideoRecord videoRecordMsg;
-  msgs::Boolean res;
+  ignition::msgs::VideoRecord videoRecordMsg;
+  ignition::msgs::Boolean res;
   bool result = false;
   unsigned int timeout = 5000;
 
