@@ -17,6 +17,8 @@
 
 #include <gtest/gtest.h>
 
+#include <ignition/msgs/particle_emitter.pb.h>
+
 #include <chrono>
 
 #include <sdf/Cylinder.hh>
@@ -30,58 +32,64 @@
 #include <sdf/Pbr.hh>
 #include <sdf/Sensor.hh>
 
-#include "gz/sim/components/Actor.hh"
-#include "gz/sim/components/AirPressureSensor.hh"
-#include "gz/sim/components/Altimeter.hh"
-#include "gz/sim/components/AngularVelocity.hh"
-#include "gz/sim/components/Camera.hh"
-#include "gz/sim/components/CanonicalLink.hh"
-#include "gz/sim/components/ChildLinkName.hh"
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/DetachableJoint.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Imu.hh"
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointAxis.hh"
-#include "gz/sim/components/JointEffortLimitsCmd.hh"
-#include "gz/sim/components/JointPositionLimitsCmd.hh"
-#include "gz/sim/components/JointVelocityLimitsCmd.hh"
-#include "gz/sim/components/JointType.hh"
-#include "gz/sim/components/JointVelocity.hh"
-#include "gz/sim/components/JointVelocityCmd.hh"
-#include "gz/sim/components/Level.hh"
-#include "gz/sim/components/LevelBuffer.hh"
-#include "gz/sim/components/LevelEntityNames.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/LinearAcceleration.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/LogicalAudio.hh"
-#include "gz/sim/components/Magnetometer.hh"
-#include "gz/sim/components/Material.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/ParentLinkName.hh"
-#include "gz/sim/components/Performer.hh"
-#include "gz/sim/components/PerformerLevels.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Scene.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/components/Static.hh"
-#include "gz/sim/components/ThreadPitch.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
-#include "../helpers/EnvTestFixture.hh"
+#include "ignition/gazebo/components/Actor.hh"
+#include "ignition/gazebo/components/AirPressureSensor.hh"
+#include "ignition/gazebo/components/Altimeter.hh"
+#include "ignition/gazebo/components/AngularVelocity.hh"
+#include "ignition/gazebo/components/Camera.hh"
+#include "ignition/gazebo/components/CanonicalLink.hh"
+#include "ignition/gazebo/components/ChildLinkName.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/DetachableJoint.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Imu.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointAxis.hh"
+#include "ignition/gazebo/components/JointType.hh"
+#include "ignition/gazebo/components/JointVelocity.hh"
+#include "ignition/gazebo/components/JointVelocityCmd.hh"
+#include "ignition/gazebo/components/Level.hh"
+#include "ignition/gazebo/components/LevelBuffer.hh"
+#include "ignition/gazebo/components/LevelEntityNames.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LinearAcceleration.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/LogicalAudio.hh"
+#include "ignition/gazebo/components/Magnetometer.hh"
+#include "ignition/gazebo/components/Material.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/ParentLinkName.hh"
+#include "ignition/gazebo/components/ParticleEmitter.hh"
+#include "ignition/gazebo/components/Performer.hh"
+#include "ignition/gazebo/components/PerformerAffinity.hh"
+#include "ignition/gazebo/components/PerformerLevels.hh"
+#include "ignition/gazebo/components/PhysicsEnginePlugin.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Scene.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/components/SourceFilePath.hh"
+#include "ignition/gazebo/components/Static.hh"
+#include "ignition/gazebo/components/TemperatureRange.hh"
+#include "ignition/gazebo/components/ThreadPitch.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-using namespace gz;
-using namespace gz::sim;
 
-class ComponentsTest : public InternalFixture<::testing::Test>
+using namespace ignition;
+using namespace gazebo;
+
+class ComponentsTest : public ::testing::Test
 {
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+  }
 };
 
 /////////////////////////////////////////////////
@@ -109,7 +117,61 @@ TEST_F(ComponentsTest, Actor)
   comp3.Deserialize(istr);
   EXPECT_EQ("abc", comp3.Data().Name());
   EXPECT_EQ("def", comp3.Data().SkinFilename());
-  EXPECT_EQ(math::Pose3d(3, 2, 1, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(ignition::math::Pose3d(3, 2, 1, 0, 0, 0), comp3.Data().RawPose());
+}
+
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, AnimationName)
+{
+  // Create components
+  auto comp11 = components::AnimationName("comp1");
+  auto comp12 = components::AnimationName("comp1");
+  auto comp2 = components::AnimationName("comp2");
+
+  // Equality operators
+  EXPECT_EQ(comp11, comp12);
+  EXPECT_NE(comp11, comp2);
+  EXPECT_TRUE(comp11 == comp12);
+  EXPECT_TRUE(comp11 != comp2);
+  EXPECT_FALSE(comp11 == comp2);
+  EXPECT_FALSE(comp11 != comp12);
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp11.Serialize(ostr);
+  EXPECT_EQ("comp1", ostr.str());
+
+  std::istringstream istr("comp3");
+  components::AnimationName comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ("comp3", comp3.Data());
+}
+
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, AnimationTime)
+{
+  auto start = std::chrono::steady_clock::now();
+  auto end1 = start + std::chrono::seconds(5);
+  auto end2 = start + std::chrono::seconds(10);
+
+  // Create components
+  auto comp1 = components::AnimationTime(end1 - start);
+  auto comp2 = components::AnimationTime(end2 - start);
+
+  // Equality operators
+  EXPECT_NE(comp1, comp2);
+  EXPECT_FALSE(comp1 == comp2);
+  EXPECT_TRUE(comp1 != comp2);
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp1.Serialize(ostr);
+  EXPECT_EQ("5000000000", ostr.str());
+
+  std::istringstream istr(ostr.str());
+  components::AnimationTime comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ(comp1, comp3);
 }
 
 /////////////////////////////////////////////////
@@ -118,7 +180,7 @@ TEST_F(ComponentsTest, AirPressureSensor)
   sdf::Sensor data1;
   data1.SetName("abc");
   data1.SetType(sdf::SensorType::AIR_PRESSURE);
-  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::AirPressure airPressure1;
   data1.SetAirPressureSensor(airPressure1);
@@ -146,7 +208,7 @@ TEST_F(ComponentsTest, AirPressureSensor)
   comp3.Deserialize(istr);
   EXPECT_EQ("abc", comp3.Data().Name());
   EXPECT_EQ(sdf::SensorType::AIR_PRESSURE, comp3.Data().Type());
-  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -409,7 +471,7 @@ TEST_F(ComponentsTest, Imu)
   data1.SetType(sdf::SensorType::IMU);
   data1.SetUpdateRate(100);
   data1.SetTopic("imu_data");
-  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Imu imu1;
   data1.SetImuSensor(imu1);
@@ -440,7 +502,7 @@ TEST_F(ComponentsTest, Imu)
   EXPECT_EQ(sdf::SensorType::IMU, comp3.Data().Type());
   EXPECT_EQ("imu_data", comp3.Data().Topic());
   EXPECT_DOUBLE_EQ(100, comp3.Data().UpdateRate());
-  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -497,7 +559,7 @@ TEST_F(ComponentsTest, Joint)
 TEST_F(ComponentsTest, JointAxis)
 {
   auto data1 = sdf::JointAxis();
-  data1.SetXyz(math::Vector3d(1, 2, 3));
+  EXPECT_TRUE(data1.SetXyz(math::Vector3d(1, 2, 3)).empty());
   data1.SetXyzExpressedIn("__model__");
   data1.SetDamping(0.1);
   data1.SetFriction(0.2);
@@ -523,7 +585,7 @@ TEST_F(ComponentsTest, JointAxis)
   components::JointAxis comp3;
   comp3.Deserialize(istr);
 
-  EXPECT_EQ(math::Vector3d(1, 2, 3), comp3.Data().Xyz());
+  EXPECT_EQ(math::Vector3d(1, 2, 3).Normalized(), comp3.Data().Xyz());
   EXPECT_DOUBLE_EQ(0.1, comp3.Data().Damping());
   EXPECT_DOUBLE_EQ(0.2, comp3.Data().Friction());
   EXPECT_DOUBLE_EQ(0.3, comp3.Data().Lower());
@@ -533,121 +595,6 @@ TEST_F(ComponentsTest, JointAxis)
   EXPECT_EQ(comp3.Data().XyzExpressedIn(), "__model__");
 }
 
-/////////////////////////////////////////////////
-TEST_F(ComponentsTest, JointEffortLimitsCmd)
-{
-  // Create components
-  auto comp1 = components::JointEffortLimitsCmd();
-  auto comp2 = components::JointEffortLimitsCmd();
-
-  // Equality operators
-  EXPECT_EQ(comp1, comp2);
-  EXPECT_TRUE(comp1 == comp2);
-  EXPECT_FALSE(comp1 != comp2);
-
-  // Stream operators
-  std::ostringstream ostr;
-  comp1.Serialize(ostr);
-  EXPECT_EQ("0", ostr.str());
-
-  comp2.Data().push_back(math::Vector2d(-1.0, 1.0));
-
-  std::ostringstream ostr2;
-  comp2.Serialize(ostr2);
-  EXPECT_EQ("1 -1 1", ostr2.str());
-
-  comp2.Data().push_back(math::Vector2d(-2.5, 2.5));
-
-  std::ostringstream ostr3;
-  comp2.Serialize(ostr3);
-  EXPECT_EQ("2 -1 1 -2.5 2.5", ostr3.str());
-
-  std::istringstream istr("ignored");
-  components::JointEffortLimitsCmd comp3;
-  comp3.Deserialize(istr);
-}
-
-/////////////////////////////////////////////////
-TEST_F(ComponentsTest, JointPositionLimitsCmd)
-{
-  // Create components
-  auto comp1 = components::JointPositionLimitsCmd();
-  auto comp2 = components::JointPositionLimitsCmd();
-  components::JointPositionLimitsCmd comp3;
-
-  // Equality operators
-  EXPECT_EQ(comp1, comp2);
-  EXPECT_TRUE(comp1 == comp2);
-  EXPECT_FALSE(comp1 != comp2);
-
-  // Stream operators
-  std::ostringstream ostr;
-  comp1.Serialize(ostr);
-  EXPECT_EQ("0", ostr.str());
-
-  auto istr = std::istringstream(ostr.str());
-  comp3.Deserialize(istr);
-  EXPECT_EQ(comp1, comp3);
-
-  comp2.Data().push_back(math::Vector2d(-1.0, 1.0));
-
-  std::ostringstream ostr2;
-  comp2.Serialize(ostr2);
-  EXPECT_EQ("1 -1 1", ostr2.str());
-
-  istr = std::istringstream(ostr2.str());
-  comp3.Deserialize(istr);
-  EXPECT_EQ(comp2, comp3);
-
-  comp2.Data().push_back(math::Vector2d(-2.5, 2.5));
-
-  std::ostringstream ostr3;
-  comp2.Serialize(ostr3);
-  EXPECT_EQ("2 -1 1 -2.5 2.5", ostr3.str());
-
-  istr = std::istringstream(ostr3.str());
-  comp3.Deserialize(istr);
-  EXPECT_EQ(comp2, comp3);
-
-  istr = std::istringstream("ignored");
-  comp3.Deserialize(istr);
-  EXPECT_EQ(comp1, comp3);
-}
-
-/////////////////////////////////////////////////
-TEST_F(ComponentsTest, JointVelocityLimitsCmd)
-{
-  // Create components
-  auto comp1 = components::JointVelocityLimitsCmd();
-  auto comp2 = components::JointVelocityLimitsCmd();
-
-  // Equality operators
-  EXPECT_EQ(comp1, comp2);
-  EXPECT_TRUE(comp1 == comp2);
-  EXPECT_FALSE(comp1 != comp2);
-
-  // Stream operators
-  std::ostringstream ostr;
-  comp1.Serialize(ostr);
-  EXPECT_EQ("0", ostr.str());
-
-  comp2.Data().push_back(math::Vector2d(-1.0, 1.0));
-
-  std::ostringstream ostr2;
-  comp2.Serialize(ostr2);
-  EXPECT_EQ("1 -1 1", ostr2.str());
-
-  comp2.Data().push_back(math::Vector2d(-2.5, 2.5));
-
-  std::ostringstream ostr3;
-  comp2.Serialize(ostr3);
-  EXPECT_EQ("2 -1 1 -2.5 2.5", ostr3.str());
-
-  std::istringstream istr("ignored");
-  components::JointVelocityLimitsCmd comp3;
-  comp3.Deserialize(istr);
-}
-
 /////////////////////////////////////////////////
 TEST_F(ComponentsTest, JointType)
 {
@@ -781,9 +728,9 @@ TEST_F(ComponentsTest, LevelEntityNames)
   // Stream operators
   std::ostringstream ostr;
   comp11.Serialize(ostr);
-  EXPECT_EQ("level1 level2 ", ostr.str());
+  EXPECT_EQ("level1\x1Flevel2\x1F", ostr.str());
 
-  std::istringstream istr("level3 level4");
+  std::istringstream istr("level3\x1Flevel4");
   components::LevelEntityNames comp3;
   comp3.Deserialize(istr);
 
@@ -809,6 +756,7 @@ TEST_F(ComponentsTest, Light)
   data1.SetSpotInnerAngle(math::Angle(0.3));
   data1.SetSpotOuterAngle(math::Angle(2.3));
   data1.SetSpotFalloff(5.15);
+  data1.SetIntensity(1.55);
 
   auto data2 = sdf::Light();
 
@@ -839,6 +787,7 @@ TEST_F(ComponentsTest, Light)
   EXPECT_EQ(math::Angle(2.3), comp3.Data().SpotOuterAngle());
   EXPECT_FLOAT_EQ(5.15, comp3.Data().SpotFalloff());
   EXPECT_EQ(math::Vector3d(2, 3, 4), comp3.Data().Direction());
+  EXPECT_FLOAT_EQ(1.55, comp3.Data().Intensity());
 }
 
 /////////////////////////////////////////////////
@@ -996,33 +945,31 @@ TEST_F(ComponentsTest, LogicalAudioSourcePlayInfo)
 TEST_F(ComponentsTest, LogicalMicrophone)
 {
   logical_audio::Microphone mic1;
-  mic1.id = 4;
+  mic1.id = 0;
   mic1.volumeDetectionThreshold = 0.5;
 
   logical_audio::Microphone mic2;
-  mic2.id = 8;
-  mic2.volumeDetectionThreshold = 0.8;
+  mic2.id = 1;
+  mic2.volumeDetectionThreshold = mic1.volumeDetectionThreshold;
 
   // create components
   auto comp1 = components::LogicalMicrophone(mic1);
   auto comp2 = components::LogicalMicrophone(mic2);
 
   // equality operators
-  EXPECT_NE(comp1, comp2);
-  EXPECT_FALSE(comp1 == comp2);
-  EXPECT_TRUE(comp1 != comp2);
+  EXPECT_NE(mic1, mic2);
+  EXPECT_FALSE(mic1 == mic2);
+  EXPECT_TRUE(mic1 != mic2);
 
   // stream operators
   std::ostringstream ostr;
   comp1.Serialize(ostr);
-  EXPECT_EQ("4 0.5", ostr.str());
+  EXPECT_EQ("0 0.5", ostr.str());
 
-  std::istringstream istr(ostr.str());
+  std::istringstream istr;
   components::LogicalMicrophone comp3;
   comp3.Deserialize(istr);
   EXPECT_EQ(comp1, comp3);
-  EXPECT_DOUBLE_EQ(comp1.Data().volumeDetectionThreshold,
-      comp3.Data().volumeDetectionThreshold);
 }
 
 /////////////////////////////////////////////////
@@ -1033,7 +980,7 @@ TEST_F(ComponentsTest, Magnetometer)
   data1.SetType(sdf::SensorType::MAGNETOMETER);
   data1.SetUpdateRate(12.4);
   data1.SetTopic("grape");
-  data1.SetRawPose(math::Pose3d(1, 2, 3, 0, 0, 0));
+  data1.SetRawPose(ignition::math::Pose3d(1, 2, 3, 0, 0, 0));
 
   sdf::Magnetometer mag1;
   data1.SetMagnetometerSensor(mag1);
@@ -1063,7 +1010,7 @@ TEST_F(ComponentsTest, Magnetometer)
   EXPECT_EQ(sdf::SensorType::MAGNETOMETER, comp3.Data().Type());
   EXPECT_EQ("grape", comp3.Data().Topic());
   EXPECT_DOUBLE_EQ(12.4, comp3.Data().UpdateRate());
-  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
+  EXPECT_EQ(ignition::math::Pose3d(1, 2, 3, 0, 0, 0), comp3.Data().RawPose());
 }
 
 /////////////////////////////////////////////////
@@ -1113,10 +1060,9 @@ TEST_F(ComponentsTest, Material)
   EXPECT_EQ(math::Color(1, 1, 1, 1), comp3.Data().Emissive());
   EXPECT_FALSE(comp3.Data().Lighting());
 
-  sdf::Pbr *newPbrMaterial = comp3.Data().PbrMaterial();
+  auto newPbrMaterial = comp3.Data().PbrMaterial();
   ASSERT_NE(nullptr, newPbrMaterial);
-  sdf::PbrWorkflow *newWorkflow =
-      newPbrMaterial->Workflow(sdf::PbrWorkflowType::METAL);
+  auto newWorkflow = newPbrMaterial->Workflow(sdf::PbrWorkflowType::METAL);
   ASSERT_NE(nullptr, newWorkflow);
   EXPECT_EQ("albedo_map.png", newWorkflow->AlbedoMap());
   EXPECT_EQ("normal_map.png", newWorkflow->NormalMap());
@@ -1170,14 +1116,26 @@ TEST_F(ComponentsTest, Name)
   EXPECT_FALSE(comp11 != comp12);
 
   // Stream operators
-  std::ostringstream ostr;
-  comp11.Serialize(ostr);
-  EXPECT_EQ("comp1", ostr.str());
+  for (auto str : {
+      "boring",
+      "snake_case",
+      "camelCase",
+      "with s p a c e s 123",
+      "with/slash",
+      "tópico",
+      "トピック"
+    })
+  {
+    auto compA = components::Name(str);
+    std::ostringstream ostr;
+    compA.Serialize(ostr);
+    EXPECT_EQ(str, ostr.str());
 
-  std::istringstream istr("comp3");
-  components::Name comp3;
-  comp3.Deserialize(istr);
-  EXPECT_EQ("comp3", comp3.Data());
+    std::istringstream istr(str);
+    components::Name compB;
+    compB.Deserialize(istr);
+    EXPECT_EQ(str, compB.Data());
+  }
 }
 
 /////////////////////////////////////////////////
@@ -1256,6 +1214,33 @@ TEST_F(ComponentsTest, Performer)
   comp3.Deserialize(istr);
 }
 
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, PerformerAffinity)
+{
+  // Create components
+  auto comp11 = components::PerformerAffinity("comp1");
+  auto comp12 = components::PerformerAffinity("comp1");
+  auto comp2 = components::PerformerAffinity("comp2");
+
+  // Equality operators
+  EXPECT_EQ(comp11, comp12);
+  EXPECT_NE(comp11, comp2);
+  EXPECT_TRUE(comp11 == comp12);
+  EXPECT_TRUE(comp11 != comp2);
+  EXPECT_FALSE(comp11 == comp2);
+  EXPECT_FALSE(comp11 != comp12);
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp11.Serialize(ostr);
+  EXPECT_EQ("comp1", ostr.str());
+
+  std::istringstream istr("comp3");
+  components::PerformerAffinity comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ("comp3", comp3.Data());
+}
+
 /////////////////////////////////////////////////
 TEST_F(ComponentsTest, PerformerLevels)
 {
@@ -1282,6 +1267,27 @@ TEST_F(ComponentsTest, PerformerLevels)
   EXPECT_EQ(0u, comp3.Data().count(1));
 }
 
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, PhysicsEnginePlugin)
+{
+  // Create components
+  auto comp11 = components::PhysicsEnginePlugin("engine-plugin");
+  auto comp12 = components::PhysicsEnginePlugin("engine-plugin");
+  auto comp2 = components::PhysicsEnginePlugin("another-engine-plugin");
+
+  // TODO(anyone) Equality operators
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp11.Serialize(ostr);
+  EXPECT_EQ("engine-plugin", ostr.str());
+
+  std::istringstream istr("libengine-plugin.so");
+  components::PhysicsEnginePlugin comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ("libengine-plugin.so", comp3.Data());
+}
+
 /////////////////////////////////////////////////
 TEST_F(ComponentsTest, Pose)
 {
@@ -1331,6 +1337,33 @@ TEST_F(ComponentsTest, Sensor)
   comp3.Deserialize(istr);
 }
 
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, SourceFilePath)
+{
+  // Create components
+  auto comp11 = components::SourceFilePath("comp1");
+  auto comp12 = components::SourceFilePath("comp1");
+  auto comp2 = components::SourceFilePath("comp2");
+
+  // Equality operators
+  EXPECT_EQ(comp11, comp12);
+  EXPECT_NE(comp11, comp2);
+  EXPECT_TRUE(comp11 == comp12);
+  EXPECT_TRUE(comp11 != comp2);
+  EXPECT_FALSE(comp11 == comp2);
+  EXPECT_FALSE(comp11 != comp12);
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp11.Serialize(ostr);
+  EXPECT_EQ("comp1", ostr.str());
+
+  std::istringstream istr("comp3");
+  components::SourceFilePath comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ("comp3", comp3.Data());
+}
+
 /////////////////////////////////////////////////
 TEST_F(ComponentsTest, Static)
 {
@@ -1348,6 +1381,45 @@ TEST_F(ComponentsTest, Static)
   EXPECT_FALSE(comp11 != comp12);
 }
 
+/////////////////////////////////////////////////
+TEST_F(ComponentsTest, TemperatureRange)
+{
+  // TODO(adlarkin) make sure min can't be >= max?
+  components::TemperatureRangeInfo range1;
+  range1.min = math::Temperature(125.0);
+  range1.max = math::Temperature(300.0);
+
+  components::TemperatureRangeInfo range2;
+  range2.min = math::Temperature(140.0);
+  range2.max = math::Temperature(200.0);
+
+  components::TemperatureRangeInfo range3;
+  range3.min = math::Temperature(125.0);
+  range3.max = math::Temperature(300.0);
+
+  // Create components
+  auto comp1 = components::TemperatureRange(range1);
+  auto comp2 = components::TemperatureRange(range2);
+  auto comp3 = components::TemperatureRange(range3);
+
+  // Equality operators
+  EXPECT_EQ(comp1, comp3);
+  EXPECT_NE(comp1, comp2);
+  EXPECT_NE(comp2, comp3);
+  EXPECT_FALSE(comp1 == comp2);
+  EXPECT_TRUE(comp1 != comp2);
+
+  // Stream operators
+  std::ostringstream ostr;
+  comp1.Serialize(ostr);
+  EXPECT_EQ("125 300", ostr.str());
+
+  std::istringstream istr(ostr.str());
+  components::TemperatureRange comp4;
+  comp4.Deserialize(istr);
+  EXPECT_EQ(comp1, comp4);
+}
+
 /////////////////////////////////////////////////
 TEST_F(ComponentsTest, ThreadPitch)
 {
@@ -1438,3 +1510,95 @@ TEST_F(ComponentsTest, Scene)
   EXPECT_FALSE(comp3.Data().Grid());
   EXPECT_TRUE(comp3.Data().OriginVisual());
 }
+
+//////////////////////////////////////////////////
+TEST_F(ComponentsTest, ParticleEmitter)
+{
+  msgs::ParticleEmitter emitter1;
+  emitter1.set_name("emitter1");
+  emitter1.set_id(0);
+  emitter1.set_type(ignition::msgs::ParticleEmitter_EmitterType_BOX);
+  emitter1.mutable_size()->set_x(1);
+  emitter1.mutable_size()->set_y(2);
+  emitter1.mutable_size()->set_z(3);
+  emitter1.mutable_rate()->set_data(4.0);
+  emitter1.mutable_duration()->set_data(5.0);
+  emitter1.mutable_emitting()->set_data(false);
+  emitter1.mutable_particle_size()->set_x(0.1);
+  emitter1.mutable_particle_size()->set_y(0.2);
+  emitter1.mutable_particle_size()->set_z(0.3);
+  emitter1.mutable_lifetime()->set_data(6.0);
+  emitter1.mutable_min_velocity()->set_data(7.0);
+  emitter1.mutable_max_velocity()->set_data(8.0);
+  emitter1.mutable_color_start()->set_r(1.0);
+  emitter1.mutable_color_start()->set_g(0);
+  emitter1.mutable_color_start()->set_b(0);
+  emitter1.mutable_color_start()->set_a(0);
+  emitter1.mutable_color_end()->set_r(1.0);
+  emitter1.mutable_color_end()->set_g(1.0);
+  emitter1.mutable_color_end()->set_b(1.0);
+  emitter1.mutable_color_end()->set_a(0);
+  emitter1.mutable_scale_rate()->set_data(9.0);
+  emitter1.mutable_color_range_image()->set_data("path_to_texture");
+
+  msgs::ParticleEmitter emitter2;
+  emitter2.set_name("emitter2");
+  emitter2.set_id(1);
+  emitter2.set_type(ignition::msgs::ParticleEmitter_EmitterType_BOX);
+  emitter2.mutable_size()->set_x(1);
+  emitter2.mutable_size()->set_y(2);
+  emitter2.mutable_size()->set_z(3);
+  emitter2.mutable_rate()->set_data(4.0);
+  emitter2.mutable_duration()->set_data(5.0);
+  emitter2.mutable_emitting()->set_data(false);
+  emitter2.mutable_particle_size()->set_x(0.1);
+  emitter2.mutable_particle_size()->set_y(0.2);
+  emitter2.mutable_particle_size()->set_z(0.3);
+  emitter2.mutable_lifetime()->set_data(6.0);
+  emitter2.mutable_min_velocity()->set_data(7.0);
+  emitter2.mutable_max_velocity()->set_data(8.0);
+  emitter2.mutable_color_start()->set_r(1.0);
+  emitter2.mutable_color_start()->set_g(0);
+  emitter2.mutable_color_start()->set_b(0);
+  emitter2.mutable_color_start()->set_a(0);
+  emitter2.mutable_color_end()->set_r(1.0);
+  emitter2.mutable_color_end()->set_g(1.0);
+  emitter2.mutable_color_end()->set_b(1.0);
+  emitter2.mutable_color_end()->set_a(0);
+  emitter2.mutable_scale_rate()->set_data(9.0);
+  emitter2.mutable_color_range_image()->set_data("path_to_texture");
+
+  // Create components.
+  auto comp1 = components::ParticleEmitter(emitter1);
+  auto comp2 = components::ParticleEmitter(emitter2);
+
+  // Stream operators.
+  std::ostringstream ostr;
+  comp1.Serialize(ostr);
+
+  std::istringstream istr(ostr.str());
+  components::ParticleEmitter comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ(comp1.Data().id(), comp3.Data().id());
+}
+
+//////////////////////////////////////////////////
+TEST_F(ComponentsTest, ParticleEmitterCmd)
+{
+  msgs::ParticleEmitter emitter1;
+  emitter1.set_name("emitter1");
+  emitter1.mutable_emitting()->set_data(true);
+
+  // Create components.
+  auto comp1 = components::ParticleEmitterCmd(emitter1);
+
+  // Stream operators.
+  std::ostringstream ostr;
+  comp1.Serialize(ostr);
+
+  std::istringstream istr(ostr.str());
+  components::ParticleEmitter comp3;
+  comp3.Deserialize(istr);
+  EXPECT_EQ(comp1.Data().emitting().data(), comp3.Data().emitting().data());
+  EXPECT_EQ(comp1.Data().name(), comp3.Data().name());
+}
