@@ -17,26 +17,32 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/contacts.pb.h>
+#include <ignition/msgs/contacts.pb.h>
 
 #include <thread>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "plugins/MockSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
-class ContactSystemTest : public InternalFixture<::testing::Test>
+class ContactSystemTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
