@@ -29,17 +29,22 @@
 #include "ignition/gazebo/test_config.hh"
 
 #include "plugins/MockSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
 #define DEPTH_TOL 1e-4
 
 using namespace ignition;
 using namespace gazebo;
-using namespace std::chrono_literals;
 
 /// \brief Test DepthCameraTest system
-class DepthCameraTest : public InternalFixture<::testing::Test>
+class DepthCameraTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 std::mutex mutex;
@@ -82,15 +87,15 @@ TEST_F(DepthCameraTest, IGN_UTILS_TEST_DISABLED_ON_MAC(DepthCameraBox))
   size_t iters100 = 100u;
   server.Run(true, iters100, false);
 
-  int sleep{0};
-  int maxSleep{30};
-  while (depthBuffer == nullptr && sleep < maxSleep)
+  auto waitTime = std::chrono::duration_cast< std::chrono::milliseconds>(
+      std::chrono::duration<double>(0.001));
+  int i = 0;
+  while (i < 300)
   {
-    std::this_thread::sleep_for(100ms);
-    sleep++;
+    std::this_thread::sleep_for(waitTime);
+    i++;
   }
-  EXPECT_LT(sleep, maxSleep);
-  ASSERT_NE(depthBuffer, nullptr);
+  EXPECT_NE(depthBuffer, nullptr);
 
   // Take into account box of 1 m on each side and 0.05 cm sensor offset
   double expectedRangeAtMidPointBox1 = 2.45;
@@ -104,9 +109,9 @@ TEST_F(DepthCameraTest, IGN_UTILS_TEST_DISABLED_ON_MAC(DepthCameraBox))
 
   // Lock access to buffer and don't release it
   mutex.lock();
-  EXPECT_DOUBLE_EQ(depthBuffer[left], math::INF_D);
+  EXPECT_DOUBLE_EQ(depthBuffer[left], ignition::math::INF_D);
   EXPECT_NEAR(depthBuffer[mid], expectedRangeAtMidPointBox1, DEPTH_TOL);
-  EXPECT_DOUBLE_EQ(depthBuffer[right], math::INF_D);
+  EXPECT_DOUBLE_EQ(depthBuffer[right], ignition::math::INF_D);
 
   delete[] depthBuffer;
 }
