@@ -16,26 +16,26 @@
 */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
 #include "plugins/EventTriggerSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
-
-class EventTrigger : public InternalFixture<::testing::Test>
-{
-};
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
-TEST_F(EventTrigger, TriggerPause)
+TEST(EventTrigger, TriggerPause)
 {
+  common::Console::SetVerbosity(4);
+
+  ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+    (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+
   // Create server
   ServerConfig config;
   const auto sdfFile = std::string(PROJECT_SOURCE_PATH) +
