@@ -18,18 +18,16 @@
 #include <gtest/gtest.h>
 #include <string>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/math/SemanticVersion.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/common/Filesystem.hh>
 
-#include "gz/sim/test_config.hh"
-#include "../helpers/EnvTestFixture.hh"
+#include "ignition/gazebo/test_config.hh"
 
 // File copied from
-// https://github.com/gazebosim/gz-gui/raw/ign-gui3/test/integration/ExamplesBuild_TEST.cc
+// https://github.com/ignitionrobotics/ign-gui/raw/ign-gui3/test/integration/ExamplesBuild_TEST.cc
 
-using namespace gz;
+using namespace ignition;
 
 #ifndef _WIN32
 #include <climits>  // NOLINT(build/include_order)
@@ -80,7 +78,6 @@ bool createAndSwitchToTempDir(std::string &_newTempPath)
 #include <windows.h>  // NOLINT(build/include_order)
 #include <winnt.h>  // NOLINT(build/include_order)
 #include <cstdint>
-#include <gz/common/PrintWindowsSystemWarning.hh>
 
 /////////////////////////////////////////////////
 bool createAndSwitchToTempDir(std::string &_newTempPath)
@@ -123,8 +120,7 @@ bool createAndSwitchToTempDir(std::string &_newTempPath)
 #endif
 
 //////////////////////////////////////////////////
-class ExamplesBuild
-  : public InternalFixture<::testing::TestWithParam<const char*>>
+class ExamplesBuild : public ::testing::TestWithParam<const char*>
 {
   /// \brief Build code in a temporary build folder.
   /// \param[in] _type Type of example to build (plugins, standalone).
@@ -138,33 +134,25 @@ void ExamplesBuild::Build(const std::string &_type)
 
   // Path to examples of the given type
   auto examplesDir = std::string(PROJECT_SOURCE_PATH) + "/examples/" + _type;
-  ASSERT_TRUE(common::exists(examplesDir));
+  ASSERT_TRUE(ignition::common::exists(examplesDir));
 
   // Iterate over directory
-  common::DirIter endIter;
-  for (common::DirIter dirIter(examplesDir);
+  ignition::common::DirIter endIter;
+  for (ignition::common::DirIter dirIter(examplesDir);
       dirIter != endIter; ++dirIter)
   {
-    auto base = common::basename(*dirIter);
-
-    math::SemanticVersion cmakeVersion{std::string(CMAKE_VERSION)};
-    if (base == "gtest_setup" && cmakeVersion < math::SemanticVersion(3, 11, 0))
-    {
-      igndbg << "Skipping [gtest_setup] test, which requires CMake version >= "
-             << "3.11.0. Currently using CMake " << cmakeVersion << std::endl;
-      continue;
-    }
+    auto base = ignition::common::basename(*dirIter);
 
     // Source directory for this example
     auto sourceDir = examplesDir;
     sourceDir += "/" + base;
-    ASSERT_TRUE(common::exists(sourceDir));
+    ASSERT_TRUE(ignition::common::exists(sourceDir));
     igndbg << "Source: " << sourceDir << std::endl;
 
     // Create a temp build directory
     std::string tmpBuildDir;
     ASSERT_TRUE(createAndSwitchToTempDir(tmpBuildDir));
-    EXPECT_TRUE(common::exists(tmpBuildDir));
+    EXPECT_TRUE(ignition::common::exists(tmpBuildDir));
     igndbg << "Build directory: " << tmpBuildDir<< std::endl;
 
     char cmd[1024];
