@@ -17,36 +17,42 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/imu.pb.h>
+#include <ignition/msgs/imu.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/AngularVelocity.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Imu.hh"
-#include "gz/sim/components/LinearAcceleration.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Sensor.hh"
+#include "ignition/gazebo/components/AngularVelocity.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Imu.hh"
+#include "ignition/gazebo/components/LinearAcceleration.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Sensor.hh"
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
 #define TOL 1e-4
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test ImuTest system
-class ImuTest : public InternalFixture<::testing::Test>
+class ImuTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 std::mutex mutex;
@@ -89,15 +95,15 @@ TEST_F(ImuTest, ModelFalling)
   std::vector<math::Pose3d> poses;
   std::vector<math::Vector3d> accelerations;
   std::vector<math::Vector3d> angularVelocities;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                              const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &,
+                              const gazebo::EntityComponentManager &_ecm)
       {
         _ecm.Each<components::Imu,
                   components::Name,
                   components::WorldPose,
                   components::AngularVelocity,
                   components::LinearAcceleration>(
-            [&](const Entity &_entity,
+            [&](const ignition::gazebo::Entity &_entity,
                 const components::Imu *,
                 const components::Name *_name,
                 const components::WorldPose *_worldPose,
@@ -113,10 +119,6 @@ TEST_F(ImuTest, ModelFalling)
               auto sensorComp = _ecm.Component<components::Sensor>(_entity);
               EXPECT_NE(nullptr, sensorComp);
 
-              if (_info.iterations == 1)
-                return true;
-
-              // This component is created on the 2nd PreUpdate
               auto topicComp = _ecm.Component<components::SensorTopic>(_entity);
               EXPECT_NE(nullptr, topicComp);
               if (topicComp)
@@ -128,7 +130,7 @@ TEST_F(ImuTest, ModelFalling)
             });
 
         _ecm.Each<components::Gravity>(
-            [&](const Entity &,
+            [&](const ignition::gazebo::Entity &,
                 const components::Gravity *_gravity) -> bool
             {
               // gtest is having a hard time with ASSERTs inside nested lambdas
