@@ -16,22 +16,27 @@
 */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"
-#include "../helpers/EnvTestFixture.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace std::chrono_literals;
 
 /// \brief Test JointStatePublisher system
-class JointStatePublisherTest
-  : public InternalFixture<::testing::TestWithParam<int>>
+class JointStatePublisherTest : public ::testing::TestWithParam<int>
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
