@@ -17,24 +17,31 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/double.pb.h>
+#include <ignition/msgs/double.pb.h>
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
-#include "../helpers/EnvTestFixture.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test Kinetic Energy Monitor system
-class KineticEnergyMonitorTest : public InternalFixture<::testing::Test>
+class KineticEnergyMonitorTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+      (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 std::mutex mutex;
