@@ -17,37 +17,36 @@
 
 
 #include <gtest/gtest.h>
-#include <gz/msgs/boolean.pb.h>
-#include <gz/msgs/stringmsg.pb.h>
+#include <ignition/msgs/boolean.pb.h>
+#include <ignition/msgs/stringmsg.pb.h>
 
 #include <optional>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-#include "gz/sim/components/Level.hh"
-#include "gz/sim/components/LevelBuffer.hh"
-#include "gz/sim/components/LevelEntityNames.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Performer.hh"
-#include "gz/sim/components/PerformerLevels.hh"
-#include "gz/sim/components/Pose.hh"
+#include "ignition/gazebo/components/Level.hh"
+#include "ignition/gazebo/components/LevelBuffer.hh"
+#include "ignition/gazebo/components/LevelEntityNames.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Performer.hh"
+#include "ignition/gazebo/components/PerformerLevels.hh"
+#include "ignition/gazebo/components/Pose.hh"
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace std::chrono_literals;
 
 //////////////////////////////////////////////////
@@ -58,7 +57,7 @@ class ModelMover: public test::Relay
   public: explicit ModelMover(Entity _entity): test::Relay(), entity(_entity)
   {
     using namespace std::placeholders;
-    this->systemPtr->preUpdateCallback =
+    this->mockSystem->preUpdateCallback =
         std::bind(&ModelMover::MoveModel, this, _1, _2);
   }
 
@@ -69,15 +68,15 @@ class ModelMover: public test::Relay
     poseCmd = std::move(_pose);
   }
 
-  public: Entity Id() const
+  public: gazebo::Entity Id() const
   {
     return entity;
   }
 
   /// \brief Sets the pose component of the entity to the commanded pose. This
   /// function meant to be called in the preupdate phase
-  private: void MoveModel(const UpdateInfo &,
-                          EntityComponentManager &_ecm)
+  private: void MoveModel(const gazebo::UpdateInfo &,
+                          gazebo::EntityComponentManager &_ecm)
   {
     if (this->poseCmd)
     {
@@ -89,20 +88,23 @@ class ModelMover: public test::Relay
 
 
   /// \brief Entity to move
-  private: Entity entity;
+  private: gazebo::Entity entity;
   /// \brief Pose command
   private: std::optional<math::Pose3d> poseCmd;
 };
 
 //////////////////////////////////////////////////
-class LevelManagerFixture : public InternalFixture<::testing::Test>
+class LevelManagerFixture : public ::testing::Test
 {
   // Documentation inherited
   protected: void SetUp() override
   {
-    InternalFixture::SetUp();
+    common::Console::SetVerbosity(4);
 
-    ServerConfig serverConfig;
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+      (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+
+    ignition::gazebo::ServerConfig serverConfig;
 
     // Except tile_0, which is on the default level, every tile belongs to a
     // level. The name of the level corresponds to the tile in its suffix, i.e.,
@@ -111,7 +113,7 @@ class LevelManagerFixture : public InternalFixture<::testing::Test>
                             "/test/worlds/levels_no_performers.sdf");
     serverConfig.SetUseLevels(true);
 
-    server = std::make_unique<Server>(serverConfig);
+    server = std::make_unique<gazebo::Server>(serverConfig);
 
     // Add in the "box" performer using a service call
     transport::Node node;
@@ -144,8 +146,8 @@ class LevelManagerFixture : public InternalFixture<::testing::Test>
 
     test::Relay testSystem;
     // Check entities loaded on the default level
-    testSystem.OnPostUpdate([&](const UpdateInfo &,
-                            const EntityComponentManager &_ecm)
+    testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &,
+                            const gazebo::EntityComponentManager &_ecm)
     {
       Entity sphere = _ecm.EntityByComponents(components::Name("sphere"));
       EXPECT_EQ(1u,
@@ -197,7 +199,7 @@ class LevelManagerFixture : public InternalFixture<::testing::Test>
     this->server->Run(true, 1, false);
   }
 
-  public: std::unique_ptr<Server> server;
+  public: std::unique_ptr<gazebo::Server> server;
   public: std::vector<std::string> loadedModels;
   public: std::vector<std::string> unloadedModels;
   public: std::vector<std::string> loadedLights;
@@ -212,8 +214,8 @@ TEST_F(LevelManagerFixture, DefaultLevel)
 
   test::Relay recorder;
   // Check entities loaded on the default level
-  recorder.OnPostUpdate([&](const UpdateInfo &,
-                            const EntityComponentManager &_ecm)
+  recorder.OnPostUpdate([&](const gazebo::UpdateInfo &,
+                            const gazebo::EntityComponentManager &_ecm)
   {
     _ecm.Each<components::DefaultLevel, components::LevelEntityNames>(
         [&](const Entity &, const components::DefaultLevel *,
