@@ -16,7 +16,7 @@
 */
 
 #include <gtest/gtest.h>
-#include <gz/msgs/pose_v.pb.h>
+#include <ignition/msgs/pose_v.pb.h>
 
 #include <algorithm>
 #include <climits>
@@ -26,43 +26,39 @@
 #include <numeric>
 #include <string>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/fuel_tools/Zip.hh>
-#include <gz/transport/Node.hh>
-#include <gz/transport/log/Batch.hh>
-#include <gz/transport/log/Log.hh>
-#include <gz/transport/log/MsgIter.hh>
-#include <gz/transport/log/Playback.hh>
-#include <gz/transport/log/QualifiedTime.hh>
-#include <gz/math/Pose3.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/fuel_tools/Zip.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/transport/log/Batch.hh>
+#include <ignition/transport/log/Log.hh>
+#include <ignition/transport/log/MsgIter.hh>
+#include <ignition/transport/log/Playback.hh>
+#include <ignition/transport/log/QualifiedTime.hh>
+#include <ignition/math/Pose3.hh>
 
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 #include <sdf/Element.hh>
 
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/LogPlaybackStatistics.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/ServerConfig.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/LogPlaybackStatistics.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/ServerConfig.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 static const std::string kBinPath(PROJECT_BINARY_PATH);
 
-// TODO(anyone) Support command line options for OSX, see
-// https://github.com/gazebosim/gz-sim/issues/25
+// \todo(anyone) Enable tests for OSX once command line works there
 #ifndef __APPLE__
-static const std::string kSdfFileOpt =  // NOLINT(runtime/string)
-" ";
 static const std::string kIgnCommand(
   "IGN_GAZEBO_SYSTEM_PLUGIN_PATH=" + kBinPath + "/lib LD_LIBRARY_PATH=" +
   kBinPath + "/lib:/usr/local/lib:${LD_LIBRARY_PATH} ign gazebo -s ");
@@ -151,8 +147,16 @@ void entryDiff(std::vector<std::string> &_paths1,
 #endif
 
 //////////////////////////////////////////////////
-class LogSystemTest : public InternalFixture<::testing::Test>
+class LogSystemTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
+
   // Create a temporary directory in build path for recorded data
   public: void CreateLogsDir()
   {
@@ -162,7 +166,6 @@ class LogSystemTest : public InternalFixture<::testing::Test>
       common::removeAll(this->logsDir);
     }
     common::createDirectories(this->logsDir);
-    common::createDirectories(this->logPlaybackDir);
   }
 
   // Append extension to the end of a path, removing the separator at
@@ -232,13 +235,17 @@ class LogSystemTest : public InternalFixture<::testing::Test>
 
   // Run the server to record, passing in compress flag.
   // \param[in] _recordSdfRoot SDF Root element of the world to load
+  // \param[in] _recordPath Path for SDF state file
   // \param[in] _cmpPath Path for compressed file
-  public: void RunCompress(sdf::Root &_recordSdfRoot,
-    const std::string &_cmpPath)
+  public: void RunCompress(const std::string &_recordSdfPath,
+    const std::string &_recordPath, const std::string &_cmpPath)
   {
     // Pass changed SDF to server
     ServerConfig recordServerConfig;
-    recordServerConfig.SetSdfString(_recordSdfRoot.Element()->ToString(""));
+    recordServerConfig.SetSdfFile(_recordSdfPath);
+
+    // Set record path
+    recordServerConfig.SetLogRecordPath(_recordPath);
 
     // Set compress path
     recordServerConfig.SetLogRecordCompressPath(_cmpPath);
@@ -259,10 +266,6 @@ class LogSystemTest : public InternalFixture<::testing::Test>
   /// \brief Path to recorded log file
   public: std::string logDir = common::joinPaths(logsDir,
       "test_logs_record");
-
-  /// \brief Path to log file for playback
-  public: std::string logPlaybackDir =
-      common::joinPaths(this->logsDir, "test_logs_playback");
 };
 
 /////////////////////////////////////////////////
@@ -331,18 +334,19 @@ TEST_F(LogSystemTest, LogDefaults)
   std::string homeOrig;
   common::env(IGN_HOMEDIR, homeOrig);
   std::string homeFake = common::joinPaths(this->logsDir, "default");
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeFake.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeFake.c_str()));
 
   // Test case 1:
   // No path specified on command line. This does not go through
-  // gz.cc, recording should take place in the `.ignition` directory
+  // ign.cc, so ignLogDirectory() is not initialized (empty string). Recording
+  // should not take place.
   {
-    // Change log path in SDF to empty
+    // Load SDF
     sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        " ");
+    EXPECT_EQ(recordSdfRoot.Load(recordSdfPath).size(), 0lu);
+    EXPECT_GT(recordSdfRoot.WorldCount(), 0lu);
 
-    // Pass changed SDF to server
+    // Pass SDF to server
     ServerConfig recordServerConfig;
     recordServerConfig.SetSdfString(recordSdfRoot.Element()->ToString(""));
 
@@ -355,12 +359,8 @@ TEST_F(LogSystemTest, LogDefaults)
     recordServer.Run(true, 200, false);
   }
 
-  // We should expect to see "auto_default.log"  and "state.tlog"
-  EXPECT_FALSE(ignLogDirectory().empty());
-  EXPECT_TRUE(common::exists(
-        common::joinPaths(ignLogDirectory(), "auto_default.log")));
-  EXPECT_TRUE(common::exists(
-        common::joinPaths(ignLogDirectory(), "state.tlog")));
+  // Check ignLogDirectory is empty
+  EXPECT_TRUE(ignLogDirectory().empty());
 
   // Remove artifacts. Recreate new directory
   this->RemoveLogsDir();
@@ -371,7 +371,7 @@ TEST_F(LogSystemTest, LogDefaults)
   // Test case 2:
   // No path specified on command line (only --record, no --record-path).
   // No path specified in SDF.
-  // Run from command line, which should trigger gz.cc, which should initialize
+  // Run from command line, which should trigger ign.cc, which should initialize
   // ignLogDirectory() to default timestamp path. Both console and state logs
   // should be recorded here.
 
@@ -383,9 +383,9 @@ TEST_F(LogSystemTest, LogDefaults)
   entryList(logPath, entriesBefore);
 
   {
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + "--record " + kSdfFileOpt + recordSdfPath;
+      + "--record " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -412,10 +412,13 @@ TEST_F(LogSystemTest, LogDefaults)
   EXPECT_TRUE(common::exists(common::joinPaths(timestampPath,
       "state.tlog")));
   EXPECT_EQ(2, entryCount(timestampPath));
+
+  // Remove artifacts. Recreate new directory
+  this->RemoveLogsDir();
 #endif
 
   // Revert environment variable after test is done
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
 }
 
 /////////////////////////////////////////////////
@@ -432,11 +435,10 @@ TEST_F(LogSystemTest, LogPaths)
     "log_record_dbl_pendulum.sdf");
 
   // Test case 1:
-  // A path is specified in SDF.
+  // A path is specified in SDF - a feature removed in Ignition Dome.
   // No path specified in C++ API.
-  // LogIgnoreSdfPath is not set.
-  // Should take SDF path. State log should be stored here. Console log is not
-  // initialized because gz.cc is not triggered.
+  // Should ignore SDF path. No default logging directory is initialized for
+  // state and console logs because ign.cc is not triggered.
   {
     // Change log path in SDF to build directory
     sdf::Root recordSdfRoot;
@@ -457,10 +459,11 @@ TEST_F(LogSystemTest, LogPaths)
     recordServer.Run(true, 200, false);
   }
 
-  EXPECT_TRUE(common::exists(common::joinPaths(this->logDir,
-      "state.tlog")));
+  // Check state.tlog is no longer stored to path specified in SDF
+  auto stateFile = common::joinPaths(this->logDir, "state.tlog");
+  EXPECT_FALSE(common::exists(stateFile)) << stateFile;
 #ifndef __APPLE__
-  EXPECT_EQ(1, entryCount(this->logDir));
+  EXPECT_EQ(0, entryCount(this->logDir));
 #endif
 
   // Remove artifacts. Recreate new directory
@@ -471,7 +474,7 @@ TEST_F(LogSystemTest, LogPaths)
   std::string homeOrig;
   common::env(IGN_HOMEDIR, homeOrig);
   std::string homeFake = common::joinPaths(this->logsDir, "default");
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeFake.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeFake.c_str()));
 
   // Store number of files before running
   auto logPath = common::joinPaths(homeFake.c_str(), ".ignition", "gazebo",
@@ -482,11 +485,10 @@ TEST_F(LogSystemTest, LogPaths)
   entryList(logPath, entriesBefore);
 
   // Test case 2:
-  // A path is specified in SDF.
-  // No path specified on command line (therefore LogIgnoreSdfPath is not set).
-  // State log should be stored in SDF path.
-  // Console log should be stored to default timestamp path ignLogDirectory
-  // because gz.cc is triggered by command line.
+  // A path is specified in SDF - a feature removed in Ignition Dome.
+  // SDF path should be ignored.
+  // State log and console log should be stored to default timestamp path
+  // ignLogDirectory because ign.cc is triggered by command line.
   {
     // Change log path in SDF to build directory
     sdf::Root recordSdfRoot;
@@ -501,9 +503,9 @@ TEST_F(LogSystemTest, LogPaths)
     ofs << recordSdfRoot.Element()->ToString("").c_str();
     ofs.close();
 
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + "--record " + kSdfFileOpt + tmpRecordSdfPath;
+      + "--record " + tmpRecordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -511,10 +513,10 @@ TEST_F(LogSystemTest, LogPaths)
     std::cout << output << std::endl;
   }
 
-  // Check state.tlog is stored to path specified in SDF
-  EXPECT_TRUE(common::exists(common::joinPaths(this->logDir,
+  // Check state.tlog is no longer stored to path specified in SDF
+  EXPECT_FALSE(common::exists(common::joinPaths(this->logDir,
       "state.tlog")));
-  EXPECT_EQ(1, entryCount(this->logDir));
+  EXPECT_EQ(0, entryCount(this->logDir));
 
   // Check the diff of list of files in directory, and assume there is
   // a single diff, it being the newly created log directory from the run above.
@@ -532,7 +534,9 @@ TEST_F(LogSystemTest, LogPaths)
   EXPECT_TRUE(common::exists(timestampPath));
   EXPECT_TRUE(common::exists(common::joinPaths(timestampPath,
       "server_console.log")));
-  EXPECT_EQ(1, entryCount(timestampPath));
+  EXPECT_TRUE(common::exists(common::joinPaths(timestampPath,
+      "state.tlog")));
+  EXPECT_EQ(2, entryCount(timestampPath));
 #endif
 
   // Remove artifacts. Recreate new directory
@@ -540,16 +544,12 @@ TEST_F(LogSystemTest, LogPaths)
   this->CreateLogsDir();
 
   // Test case 3:
-  // A path is specified in SDF.
-  // A different path is specified via C++ API.
-  // LogIgnoreSdfPath is not set (pure C++ API usage).
-  // Should store state.tlog to SDF path. Console log is not initialized
-  // because gz.cc is not triggered.
+  // A path is specified in SDF - a feature removed in Ignition Dome.
+  // Empty path is specified via C++ API.
+  // Should ignore SDF path. No default logging directory is initialized for
+  // state and console logs because ign.cc is not triggered.
   std::string stateLogPath = this->logDir;
 
-  std::string consoleLogPath = common::joinPaths(this->logsDir, "console");
-  common::createDirectories(consoleLogPath);
-
   {
     // Change log path in SDF to build directory
     sdf::Root recordSdfRoot;
@@ -573,24 +573,20 @@ TEST_F(LogSystemTest, LogPaths)
     // tlog-journal file
   }
 
-  auto stateLogFilePath = common::joinPaths(stateLogPath, "state.tlog");
-  EXPECT_TRUE(common::exists(stateLogFilePath)) << stateLogFilePath;
+  EXPECT_FALSE(common::exists(common::joinPaths(stateLogPath, "state.tlog")));
 #ifndef __APPLE__
-  EXPECT_EQ(1, entryCount(stateLogPath));
-  EXPECT_EQ(0, entryCount(consoleLogPath));
+  EXPECT_EQ(0, entryCount(stateLogPath));
 #endif
-  common::removeAll(consoleLogPath);
 
   // Remove artifacts. Recreate new directory
   this->RemoveLogsDir();
   this->CreateLogsDir();
 
   // Test case 4:
-  // A path is specified in SDF.
+  // A path is specified in SDF - a feature removed in Ignition Dome.
   // A different path is specified via C++ API.
-  // LogIgnoreSdfPath is set (similar to specifying a path on command line).
   // Should take C++ API path. State log should be stored here. Console log is
-  // not initialized because gz.cc is not triggered.
+  // not initialized because ign.cc is not triggered.
   const std::string sdfPath = common::joinPaths(this->logsDir, "sdfPath");
   const std::string cppPath = common::joinPaths(this->logsDir, "cppPath");
   {
@@ -608,8 +604,6 @@ TEST_F(LogSystemTest, LogPaths)
 
     // Mock command line arg. Set record path to something different from in SDF
     recordServerConfig.SetLogRecordPath(cppPath);
-    // Set this flag to simulate path being passed in from command line
-    recordServerConfig.SetLogIgnoreSdfPath(true);
 
     // Run for a few seconds to record different poses
     Server recordServer(recordServerConfig);
@@ -632,9 +626,9 @@ TEST_F(LogSystemTest, LogPaths)
   // A path is specified by --record-path on command line.
   // Both state and console logs should be stored here.
   {
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
+      + "--record-path " + this->logDir + " " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -654,7 +648,7 @@ TEST_F(LogSystemTest, LogPaths)
   this->CreateLogsDir();
 
   // Test case 6:
-  // A path is specified in SDF.
+  // A path is specified in SDF - a feature removed in Ignition Dome.
   // A path is specified by --record-path on command line.
   // Path in SDF should be ignored. Both state and console logs should be
   // stored to --record-path path.
@@ -674,9 +668,9 @@ TEST_F(LogSystemTest, LogPaths)
     ofs << recordSdfRoot.Element()->ToString("").c_str();
     ofs.close();
 
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + "--record-path " + cliPath + " " + kSdfFileOpt + tmpRecordSdfPath;
+      + "--record-path " + cliPath + " " + tmpRecordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -693,7 +687,7 @@ TEST_F(LogSystemTest, LogPaths)
 #endif
 
   // Revert environment variable after test is done
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
 
   this->RemoveLogsDir();
 }
@@ -714,16 +708,10 @@ TEST_F(LogSystemTest, RecordAndPlayback)
       std::string(PROJECT_SOURCE_PATH), "test", "worlds",
       "log_record_dbl_pendulum.sdf");
 
-    // Change log path in SDF to build directory
-    sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        this->logDir);
-    EXPECT_EQ(1u, recordSdfRoot.WorldCount());
-
-    // Pass changed SDF to server
     ServerConfig recordServerConfig;
-    recordServerConfig.SetSdfString(recordSdfRoot.Element()->ToString(""));
-    Server recordServer(recordServerConfig);
+    recordServerConfig.SetSdfFile(recordSdfPath);
+    recordServerConfig.SetUseLogRecord(true);
+    recordServerConfig.SetLogRecordPath(this->logDir);
 
     std::chrono::steady_clock::time_point lastPoseTime;
     const int poseHz = 60;
@@ -741,8 +729,9 @@ TEST_F(LogSystemTest, RecordAndPlayback)
             ++expectedPoseCount;
           }
         });
-    recordServer.AddSystem(recordedPoseCounter.systemPtr);
     // Run for a few seconds to record different poses
+    Server recordServer(recordServerConfig);
+    recordServer.AddSystem(recordedPoseCounter.systemPtr);
     recordServer.Run(true, 1000, false);
   }
 
@@ -750,25 +739,17 @@ TEST_F(LogSystemTest, RecordAndPlayback)
   auto logFile = common::joinPaths(this->logDir, "state.tlog");
   EXPECT_TRUE(common::exists(logFile));
 
-  // move the log file to the playback directory
-  auto logPlaybackFile = common::joinPaths(this->logPlaybackDir, "state.tlog");
+  // Path to log file for playback
+  std::string logPlaybackDir =
+      common::joinPaths(this->logsDir, "test_logs_playback");
+  common::createDirectories(logPlaybackDir);
+
+  // Move the log file to the playback directory
+  auto logPlaybackFile = common::joinPaths(logPlaybackDir, "state.tlog");
   common::moveFile(logFile, logPlaybackFile);
   EXPECT_TRUE(common::exists(logPlaybackFile));
 
-  // World file to load
-  const auto playSdfPath = common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-    "test", "worlds", "log_playback.sdf");
-
-  // Change log path in world SDF to build directory
-  sdf::Root playSdfRoot;
-  this->ChangeLogPath(playSdfRoot, playSdfPath, "LogPlayback",
-      this->logPlaybackDir);
-  ASSERT_EQ(1u, playSdfRoot.WorldCount());
-
-  const auto sdfWorld = playSdfRoot.WorldByIndex(0);
-  EXPECT_EQ("default", sdfWorld->Name());
-
-  // Load log file recorded above
+  // Load log file recorded above for validation
   transport::log::Log log;
   log.Open(logPlaybackFile);
 
@@ -801,10 +782,6 @@ TEST_F(LogSystemTest, RecordAndPlayback)
   EXPECT_EQ(32, stateMsg.entities_size());
   EXPECT_EQ(batch.end(), ++recordedIter);
 
-  // Pass changed SDF to server
-  ServerConfig playServerConfig;
-  playServerConfig.SetSdfString(playSdfRoot.Element()->ToString(""));
-
   // Keep track of total number of pose comparisons
   int nTotal{0};
 
@@ -825,6 +802,10 @@ TEST_F(LogSystemTest, RecordAndPlayback)
   EXPECT_EQ(0, recordedMsg.header().stamp().sec());
   EXPECT_EQ(1000000, recordedMsg.header().stamp().nsec());
 
+  // Playback config
+  ServerConfig playServerConfig;
+  playServerConfig.SetLogPlaybackPath(logPlaybackDir);
+
   // Start server
   Server playServer(playServerConfig);
 
@@ -1033,7 +1014,7 @@ TEST_F(LogSystemTest, LogOverwrite)
   // Create temp directory to store log
   this->CreateLogsDir();
 #ifndef __APPLE__
-  EXPECT_EQ(1, entryCount(this->logsDir));
+  EXPECT_EQ(0, entryCount(this->logsDir));
   EXPECT_EQ(0, entryCount(this->logDir));
 #endif
 
@@ -1047,14 +1028,10 @@ TEST_F(LogSystemTest, LogOverwrite)
 
   // Record something to create some files
   {
-    // Change log path in SDF to build directory
-    sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        this->logDir);
-
-    // Pass changed SDF to server
     ServerConfig recordServerConfig;
-    recordServerConfig.SetSdfString(recordSdfRoot.Element()->ToString(""));
+    recordServerConfig.SetSdfFile(recordSdfPath);
+    recordServerConfig.SetUseLogRecord(true);
+    recordServerConfig.SetLogRecordPath(this->logDir);
 
     // Run for a few seconds to record different poses
     Server recordServer(recordServerConfig);
@@ -1073,7 +1050,7 @@ TEST_F(LogSystemTest, LogOverwrite)
 
 #ifndef __APPLE__
   // Log files were created
-  EXPECT_EQ(2, entryCount(this->logsDir));
+  EXPECT_EQ(1, entryCount(this->logsDir));
   EXPECT_EQ(2, entryCount(this->logDir));
   std::filesystem::path tlogStdPath = tlogPath;
   auto tlogPrevTime = std::filesystem::last_write_time(tlogStdPath);
@@ -1082,50 +1059,11 @@ TEST_F(LogSystemTest, LogOverwrite)
   // Test case 1:
   // Path exists, no overwrite flag. LogRecord.cc should still overwrite by
   // default behavior whenever the specified path already exists.
-  // Path is set by SDF.
   {
-    EXPECT_TRUE(common::exists(this->logDir));
-
-    // Change log path in SDF to build directory
-    sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        this->logDir);
-
-    // Pass changed SDF to server
-    ServerConfig recordServerConfig;
-    recordServerConfig.SetSdfString(recordSdfRoot.Element()->ToString(""));
-
-    // Run for a few seconds to record different poses
-    Server recordServer(recordServerConfig);
-    recordServer.Run(true, 100, false);
-  }
-
-  // Log files still exist
-  EXPECT_TRUE(common::exists(tlogPath));
-  EXPECT_TRUE(common::exists(clogPath));
-
-#ifndef __APPLE__
-  // No new files were created
-  EXPECT_EQ(2, entryCount(this->logsDir));
-  EXPECT_EQ(2, entryCount(this->logDir));
-
-  // Test timestamp is newer
-  EXPECT_GT(std::filesystem::last_write_time(tlogStdPath), tlogPrevTime);
-  // Update timestamp for next test
-  tlogPrevTime = std::filesystem::last_write_time(tlogStdPath);
-#endif
-
-  // Test case 2:
-  // Path exists, no overwrite flag. LogRecord.cc should still overwrite by
-  // default behavior whenever the specified path already exists.
-  // Path is set by C++ API.
-  {
-    // Pass SDF file to server
     ServerConfig recordServerConfig;
     recordServerConfig.SetSdfFile(recordSdfPath);
     recordServerConfig.SetUseLogRecord(true);
     recordServerConfig.SetLogRecordPath(this->logDir);
-    recordServerConfig.SetLogIgnoreSdfPath(true);
 
     // Run for a few seconds to record different poses
     Server recordServer(recordServerConfig);
@@ -1138,100 +1076,22 @@ TEST_F(LogSystemTest, LogOverwrite)
 
 #ifndef __APPLE__
   // No new files were created
-  EXPECT_EQ(2, entryCount(this->logsDir));
+  EXPECT_EQ(1, entryCount(this->logsDir));
   EXPECT_EQ(2, entryCount(this->logDir));
 
   // Test timestamp is newer
   EXPECT_GT(std::filesystem::last_write_time(tlogStdPath), tlogPrevTime);
   // Update timestamp for next test
   tlogPrevTime = std::filesystem::last_write_time(tlogStdPath);
-#endif
 
-  // Test case 3:
-  // Path exists, no overwrite flag. LogRecord.cc should still overwrite by
-  // default behavior whenever the specified path already exists.
-  // Path is set by SDF.
-  // Server is run from command line, gz.cc should initialize new default
-  // timestamp directory, where console log should be recorded. State log should
-  // be recorded to the path in SDF.
-
-  // Change environment variable so that test files aren't written to $HOME
-  std::string homeOrig;
-  common::env(IGN_HOMEDIR, homeOrig);
-  std::string homeFake = common::joinPaths(this->logsDir, "default");
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeFake.c_str()));
-
-  // Store number of files before running
-  auto logPath = common::joinPaths(homeFake.c_str(), ".ignition", "gazebo",
-      "log");
-#ifndef __APPLE__
-  int nEntries = entryCount(logPath);
-  std::vector<std::string> entriesBefore;
-  entryList(logPath, entriesBefore);
-
-  std::string tmpRecordSdfPath = common::joinPaths(this->logsDir,
-    "with_record_path.sdf");
-
-  {
-    // Change log path in SDF to build directory
-    sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        this->logDir);
-    EXPECT_EQ(1u, recordSdfRoot.WorldCount());
-
-    // Save changed SDF to temporary file
-    // TODO(anyone): Does this work on Apple?
-    std::ofstream ofs(tmpRecordSdfPath);
-    ofs << recordSdfRoot.Element()->ToString("").c_str();
-    ofs.close();
-
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
-    std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + kSdfFileOpt + tmpRecordSdfPath;
-    std::cout << "Running command [" << cmd << "]" << std::endl;
-
-    // Run
-    std::string output = customExecStr(cmd);
-    std::cout << output << std::endl;
-  }
-
-  // State log file still exists
-  EXPECT_TRUE(common::exists(tlogPath));
-
-  // Check the diff of list of files and assume there is a single diff, it
-  // being the newly created log directory from the run above.
-  EXPECT_EQ(nEntries + 1, entryCount(logPath));
-  std::vector<std::string> entriesAfter;
-  entryList(logPath, entriesAfter);
-  std::vector<std::string> entriesDiff;
-  entryDiff(entriesBefore, entriesAfter, entriesDiff);
-  EXPECT_EQ(1ul, entriesDiff.size());
-  // This should be $HOME/.ignition/..., default path
-  std::string timestampPath = entriesDiff[0];
-
-  EXPECT_FALSE(timestampPath.empty());
-  EXPECT_EQ(0, timestampPath.compare(0, logPath.length(), logPath));
-  EXPECT_TRUE(common::exists(timestampPath));
-  EXPECT_TRUE(common::exists(common::joinPaths(timestampPath,
-      "server_console.log")));
-  EXPECT_EQ(1, entryCount(timestampPath));
-
-  // Cleanup
-  common::removeFile(tmpRecordSdfPath);
-  common::removeAll(homeFake);
-  common::removeAll(timestampPath);
-
-  // Revert environment variable after test is done
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
-
-  // Test case 4:
+  // Test case 2:
   // Path exists, command line --log-overwrite, should overwrite by
-  // command-line logic in gz.cc
+  // command-line logic in ign.cc
   {
-    // Command line triggers gz.cc, which handles creating a unique path if
+    // Command line triggers ign.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-overwrite "
-      + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
+      + "--record-path " + this->logDir + " " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -1244,7 +1104,7 @@ TEST_F(LogSystemTest, LogOverwrite)
   EXPECT_TRUE(common::exists(clogPath));
 
   // No new files were created
-  EXPECT_EQ(2, entryCount(this->logsDir));
+  EXPECT_EQ(1, entryCount(this->logsDir));
   EXPECT_EQ(2, entryCount(this->logDir));
 
   // Test timestamp is newer
@@ -1252,14 +1112,14 @@ TEST_F(LogSystemTest, LogOverwrite)
   // Update timestamp for next test
   tlogPrevTime = std::filesystem::last_write_time(tlogStdPath);
 
-  // Test case 5:
+  // Test case 3:
   // Path exists, no --log-overwrite, should create new files by command-line
-  // logic in gz.cc
+  // logic in ign.cc
   {
-    // Command line triggers gz.cc, which handles creating a unique path if
+    // Command line triggers ign.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
-      + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
+      + "--record-path " + this->logDir + " " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -1276,7 +1136,7 @@ TEST_F(LogSystemTest, LogOverwrite)
   // ign gazebo. server_main.cc is deprecated and does not have overwrite
   // renaming implemented. So will always overwrite. Will not test (#) type of
   // renaming on OS X until ign gazebo is fixed:
-  // https://github.com/gazebosim/gz-sim/issues/25
+  // https://github.com/ignitionrobotics/ign-gazebo/issues/25
 
   // New log files were created
   EXPECT_TRUE(common::exists(this->logDir + "(1)"));
@@ -1286,7 +1146,7 @@ TEST_F(LogSystemTest, LogOverwrite)
       "server_console.log")));
 
   // New files were created
-  EXPECT_EQ(3, entryCount(this->logsDir));
+  EXPECT_EQ(2, entryCount(this->logsDir));
   EXPECT_EQ(2, entryCount(this->logDir));
   EXPECT_EQ(2, entryCount(this->logDir + "(1)"));
 
@@ -1303,16 +1163,8 @@ TEST_F(LogSystemTest, LogControlLevels)
   auto logPath = common::joinPaths(PROJECT_SOURCE_PATH, "test", "media",
       "levels_log");
 
-  const auto playSdfPath = common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-    "test", "worlds", "log_playback.sdf");
-
-  // Change log path in world SDF to build directory
-  sdf::Root playSdfRoot;
-  this->ChangeLogPath(playSdfRoot, playSdfPath, "LogPlayback",
-      logPath);
-
   ServerConfig config;
-  config.SetSdfString(playSdfRoot.Element()->ToString(""));
+  config.SetLogPlaybackPath(logPath);
 
   Server server(config);
 
@@ -1462,14 +1314,10 @@ TEST_F(LogSystemTest, LogCompress)
         std::string(PROJECT_SOURCE_PATH), "test", "worlds",
         "log_record_dbl_pendulum.sdf");
 
-    // Change log path in SDF to build directory
-    sdf::Root recordSdfRoot;
-    this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-        recordPath);
-
-    // Pass changed SDF to server
     ServerConfig recordServerConfig;
-    recordServerConfig.SetSdfString(recordSdfRoot.Element()->ToString(""));
+    recordServerConfig.SetSdfFile(recordSdfPath);
+    recordServerConfig.SetUseLogRecord(true);
+    recordServerConfig.SetLogRecordPath(recordPath);
 
     // Set compress flag
     recordServerConfig.SetLogRecordCompressPath(defaultCmpPath);
@@ -1509,7 +1357,6 @@ TEST_F(LogSystemTest, LogCompress)
 
     // Set record path
     recordServerConfig.SetLogRecordPath(this->logDir);
-    recordServerConfig.SetLogIgnoreSdfPath(true);
 
     // This tells server to call AddRecordPlugin() where flags are passed to
     //   recorder.
@@ -1523,29 +1370,25 @@ TEST_F(LogSystemTest, LogCompress)
   // Test compressed file exists
   EXPECT_TRUE(common::exists(customCmpPath));
 
+  // Path to log file for playback
+  std::string logPlaybackDir =
+      common::joinPaths(this->logsDir, "test_logs_playback");
+  common::createDirectories(logPlaybackDir);
+
   // Move recorded file to playback directory
   // Prefix the zip by the name of the original recorded folder. Playback will
   // extract and assume subdirectory to take on the name of the zip file
   // without extension.
-  auto newCmpPath = common::joinPaths(this->logPlaybackDir,
+  auto newCmpPath = common::joinPaths(logPlaybackDir,
     common::basename(defaultCmpPath));
   common::moveFile(customCmpPath, newCmpPath);
   EXPECT_TRUE(common::exists(newCmpPath));
 
   // Play back compressed file
   {
-    // World with playback plugin
-    const auto playSdfPath = common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-        "test", "worlds", "log_playback.sdf");
-
-    // Change log path in world SDF to build directory
-    sdf::Root playSdfRoot;
-    this->ChangeLogPath(playSdfRoot, playSdfPath, "LogPlayback",
-        newCmpPath);
-
     // Pass changed SDF to server
     ServerConfig playServerConfig;
-    playServerConfig.SetSdfString(playSdfRoot.Element()->ToString(""));
+    playServerConfig.SetLogPlaybackPath(newCmpPath);
 
     // Run server
     Server playServer(playServerConfig);
@@ -1575,11 +1418,6 @@ TEST_F(LogSystemTest, LogCompressOverwrite)
       std::string(PROJECT_SOURCE_PATH), "test", "worlds",
       "log_record_dbl_pendulum.sdf");
 
-  // Change log path in SDF to build directory
-  sdf::Root recordSdfRoot;
-  this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-      recordPath);
-
   // Compress + overwrite, recorded directory exists, compressed file does not
   {
     // Create recording directory so that it exists
@@ -1589,7 +1427,7 @@ TEST_F(LogSystemTest, LogCompressOverwrite)
     EXPECT_TRUE(common::exists(recordPath));
     EXPECT_FALSE(common::exists(defaultCmpPath));
 
-    this->RunCompress(recordSdfRoot, defaultCmpPath);
+    this->RunCompress(recordSdfPath, recordPath, defaultCmpPath);
   }
 
   EXPECT_TRUE(common::exists(defaultCmpPath));
@@ -1601,11 +1439,11 @@ TEST_F(LogSystemTest, LogCompressOverwrite)
     EXPECT_FALSE(common::exists(recordPath));
     EXPECT_TRUE(common::exists(defaultCmpPath));
 
-    this->RunCompress(recordSdfRoot, defaultCmpPath);
+    this->RunCompress(recordSdfPath, recordPath, defaultCmpPath);
   }
 
   EXPECT_TRUE(common::exists(defaultCmpPath));
-  EXPECT_FALSE(common::exists(recordPath));
+  EXPECT_FALSE(common::exists(recordPath)) << recordPath;
 
   this->RemoveLogsDir();
 }
@@ -1627,15 +1465,10 @@ TEST_F(LogSystemTest, LogCompressCmdLine)
       std::string(PROJECT_SOURCE_PATH), "test", "worlds",
       "log_record_dbl_pendulum.sdf");
 
-  // Change log path in SDF to build directory
-  sdf::Root recordSdfRoot;
-  this->ChangeLogPath(recordSdfRoot, recordSdfPath, "LogRecord",
-      recordPath);
-
   // Compress only, both recorded directory and compressed file exist
   {
     // Create compressed file
-    this->RunCompress(recordSdfRoot, defaultCmpPath);
+    this->RunCompress(recordSdfPath, recordPath, defaultCmpPath);
 
     // Recreate recording directory so that it exists
     common::createDirectories(recordPath);
@@ -1644,11 +1477,10 @@ TEST_F(LogSystemTest, LogCompressCmdLine)
     EXPECT_TRUE(common::exists(recordPath));
     EXPECT_TRUE(common::exists(defaultCmpPath));
 
-    // Command line triggers gz.cc, which handles creating a unique path if
+    // Command line triggers ign.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-compress "
-      + "--record-path " + recordPath + " "
-      + kSdfFileOpt + recordSdfPath;
+      + "--record-path " + recordPath + " " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     std::string output = customExecStr(cmd);
@@ -1675,11 +1507,10 @@ TEST_F(LogSystemTest, LogCompressCmdLine)
     EXPECT_FALSE(common::exists(recordPath));
     EXPECT_TRUE(common::exists(this->AppendExtension(recordPath, "(1).zip")));
 
-    // Command line triggers gz.cc, which handles creating a unique path if
+    // Command line triggers ign.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-compress "
-      + "--record-path " + recordPath + " "
-      + kSdfFileOpt + recordSdfPath;
+      + "--record-path " + recordPath + " " + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     std::string output = customExecStr(cmd);
@@ -1713,7 +1544,7 @@ TEST_F(LogSystemTest, LogResources)
   std::string homeOrig;
   common::env(IGN_HOMEDIR, homeOrig);
   std::string homeFake = common::joinPaths(this->logsDir, "default");
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeFake.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeFake.c_str()));
 
   const std::string recordPath = this->logDir;
   std::string statePath = common::joinPaths(recordPath, "state.tlog");
@@ -1721,10 +1552,10 @@ TEST_F(LogSystemTest, LogResources)
 #ifndef __APPLE__
   // Log resources from command line
   {
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record --record-resources --record-path " + recordPath + " "
-      + kSdfFileOpt + recordSdfPath;
+      + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
@@ -1739,7 +1570,7 @@ TEST_F(LogSystemTest, LogResources)
   // Recorded models should exist
   EXPECT_GT(entryCount(recordPath), 2);
   EXPECT_TRUE(common::exists(common::joinPaths(recordPath, homeFake,
-      ".ignition", "fuel", "fuel.gazebosim.org", "openrobotics",
+      ".ignition", "fuel", "fuel.ignitionrobotics.org", "openrobotics",
       "models", "x2 config 1")));
 
   // Remove artifacts. Recreate new directory
@@ -1766,7 +1597,7 @@ TEST_F(LogSystemTest, LogResources)
   }
 
   // Console log is not created because ignLogDirectory() is not initialized,
-  // as gz.cc is not executed by command line.
+  // as ign.cc is not executed by command line.
   EXPECT_TRUE(common::exists(statePath));
 
   // Recorded models should exist
@@ -1774,11 +1605,11 @@ TEST_F(LogSystemTest, LogResources)
   EXPECT_GT(entryCount(recordPath), 1);
 #endif
   EXPECT_TRUE(common::exists(common::joinPaths(recordPath, homeFake,
-      ".ignition", "fuel", "fuel.gazebosim.org", "openrobotics",
+      ".ignition", "fuel", "fuel.ignitionrobotics.org", "openrobotics",
       "models", "x2 config 1")));
 
   // Revert environment variable after test is done
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeOrig.c_str()));
 
   // Remove artifacts
   this->RemoveLogsDir();
@@ -1800,7 +1631,7 @@ TEST_F(LogSystemTest, LogTopics)
   std::string homeOrig;
   common::env(IGN_HOMEDIR, homeOrig);
   std::string homeFake = common::joinPaths(this->logsDir, "default");
-  EXPECT_TRUE(common::setenv(IGN_HOMEDIR, homeFake.c_str()));
+  EXPECT_TRUE(ignition::common::setenv(IGN_HOMEDIR, homeFake.c_str()));
 
   const std::string recordPath = this->logDir;
   std::string statePath = common::joinPaths(recordPath, "state.tlog");
@@ -1808,11 +1639,11 @@ TEST_F(LogSystemTest, LogTopics)
 #ifndef __APPLE__
   // Log only the /clock topic from command line
   {
-    // Command line triggers gz.cc, which handles initializing ignLogDirectory
+    // Command line triggers ign.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record-topic /clock "
       + "--record-path " + recordPath + " "
-      + kSdfFileOpt + recordSdfPath;
+      + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
 
     // Run
