@@ -17,34 +17,40 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/magnetometer.pb.h>
+#include <ignition/msgs/magnetometer.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/MagneticField.hh"
-#include "gz/sim/components/Magnetometer.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Sensor.hh"
+#include "ignition/gazebo/components/MagneticField.hh"
+#include "ignition/gazebo/components/Magnetometer.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Sensor.hh"
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
 #define TOL 1e-4
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test MagnetometerTest system
-class MagnetometerTest : public InternalFixture<::testing::Test>
+class MagnetometerTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 std::mutex mutex;
@@ -81,13 +87,13 @@ TEST_F(MagnetometerTest, RotatedMagnetometer)
   test::Relay testSystem;
 
   std::vector<math::Pose3d> poses;
-  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
-                              const EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &,
+                              const gazebo::EntityComponentManager &_ecm)
       {
         _ecm.Each<components::Magnetometer,
                   components::Name,
                   components::WorldPose>(
-            [&](const Entity &_entity,
+            [&](const ignition::gazebo::Entity &_entity,
                 const components::Magnetometer *,
                 const components::Name *_name,
                 const components::WorldPose *_worldPose) -> bool
@@ -98,10 +104,6 @@ TEST_F(MagnetometerTest, RotatedMagnetometer)
               auto sensorComp = _ecm.Component<components::Sensor>(_entity);
               EXPECT_NE(nullptr, sensorComp);
 
-              if (_info.iterations == 1)
-                return true;
-
-              // This component is created on the 2nd PreUpdate
               auto topicComp = _ecm.Component<components::SensorTopic>(_entity);
               EXPECT_NE(nullptr, topicComp);
               if (topicComp)
@@ -128,7 +130,7 @@ TEST_F(MagnetometerTest, RotatedMagnetometer)
   // Hardcoded SDF values
   math::Vector3d worldMagneticField(0.94, 0.76, -0.12);
 
-  math::Vector3d field = poses.back().Rot().Inverse().RotateVector(
+  ignition::math::Vector3d field = poses.back().Rot().Inverse().RotateVector(
         worldMagneticField);
   mutex.lock();
   EXPECT_NEAR(magnetometerMsgs.back().mutable_field_tesla()->x(),
