@@ -18,18 +18,15 @@
 #include <gtest/gtest.h>
 #include <chrono>
 #include <condition_variable>
-#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "gz/msgs/world_control.pb.h"
-#include "gz/msgs/world_stats.pb.h"
-#include "gz/transport/Node.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include "ignition/msgs/world_control.pb.h"
+#include "ignition/msgs/world_stats.pb.h"
+#include "ignition/transport/Node.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-#include "../helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace std::chrono_literals;
 
 uint64_t kIterations;
@@ -44,8 +41,8 @@ uint64_t testPaused(bool _paused)
   bool paused = !_paused;
   uint64_t iterations = 0;
 
-  std::function<void(const msgs::WorldStatistics &)> cb =
-      [&](const msgs::WorldStatistics &_msg)
+  std::function<void(const ignition::msgs::WorldStatistics &)> cb =
+      [&](const ignition::msgs::WorldStatistics &_msg)
   {
     std::unique_lock<std::mutex> lock(mutex);
     paused = _msg.paused();
@@ -62,8 +59,13 @@ uint64_t testPaused(bool _paused)
 }
 
 /////////////////////////////////////////////////
-class NetworkHandshake : public InternalFixture<::testing::Test>
+class NetworkHandshake : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+  }
 };
 
 /////////////////////////////////////////////////
@@ -123,8 +125,7 @@ TEST_F(NetworkHandshake, Handshake)
 }
 
 /////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/630
-TEST_F(NetworkHandshake, IGN_UTILS_TEST_DISABLED_ON_MAC(Updates))
+TEST_F(NetworkHandshake, Updates)
 {
   auto pluginElem = std::make_shared<sdf::Element>();
   pluginElem->SetName("plugin");
@@ -137,7 +138,7 @@ TEST_F(NetworkHandshake, IGN_UTILS_TEST_DISABLED_ON_MAC(Updates))
   primaryPluginInfo.SetEntityType("world");
   primaryPluginInfo.SetFilename(
       "libignition-gazebo-scene-broadcaster-system.so");
-  primaryPluginInfo.SetName("sim::systems::SceneBroadcaster");
+  primaryPluginInfo.SetName("ignition::gazebo::systems::SceneBroadcaster");
   primaryPluginInfo.SetSdf(pluginElem);
 
   ServerConfig configPrimary;
@@ -145,7 +146,7 @@ TEST_F(NetworkHandshake, IGN_UTILS_TEST_DISABLED_ON_MAC(Updates))
   configPrimary.SetUseLevels(true);
   // Can only test one secondary running physics, because running 2 physics in
   // the same process causes a segfault, see
-  // https://github.com/gazebosim/gz-sim/issues/18
+  // https://github.com/ignitionrobotics/ign-gazebo/issues/18
   configPrimary.SetNetworkSecondaries(1);
   configPrimary.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
       "/test/worlds/performers.sdf");
@@ -158,7 +159,7 @@ TEST_F(NetworkHandshake, IGN_UTILS_TEST_DISABLED_ON_MAC(Updates))
   secondaryPluginInfo.SetEntityName("default");
   secondaryPluginInfo.SetEntityType("world");
   secondaryPluginInfo.SetFilename("libignition-gazebo-physics-system.so");
-  secondaryPluginInfo.SetName("sim::systems::Physics");
+  secondaryPluginInfo.SetName("ignition::gazebo::systems::Physics");
   secondaryPluginInfo.SetSdf(pluginElem);
 
   ServerConfig configSecondary;
@@ -173,8 +174,8 @@ TEST_F(NetworkHandshake, IGN_UTILS_TEST_DISABLED_ON_MAC(Updates))
   // Subscribe to pose updates, which should come from the primary
   transport::Node node;
   std::vector<double> zPos;
-  std::function<void(const msgs::Pose_V &)> cb =
-      [&](const msgs::Pose_V &_msg)
+  std::function<void(const ignition::msgs::Pose_V &)> cb =
+      [&](const ignition::msgs::Pose_V &_msg)
   {
     for (int i = 0; i < _msg.pose().size(); ++i)
     {
