@@ -20,14 +20,12 @@
 #include <condition_variable>
 
 #include "ignition/msgs.hh"
-#include "gz/transport.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include "ignition/transport.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-#include "../helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 using namespace std::chrono_literals;
 
 uint64_t kIterations;
@@ -36,13 +34,13 @@ uint64_t kIterations;
 // Send a world control message.
 void worldControl(bool _paused, uint64_t _steps)
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [&](const msgs::Boolean &/*_rep*/, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [&](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
   {
     EXPECT_TRUE(_result);
   };
 
-  msgs::WorldControl req;
+  ignition::msgs::WorldControl req;
   req.set_pause(_paused);
   req.set_multi_step(_steps);
   transport::Node node;
@@ -58,8 +56,8 @@ void testPaused(bool _paused)
   transport::Node node;
   bool paused = !_paused;
 
-  std::function<void(const msgs::WorldStatistics &)> cb =
-      [&](const msgs::WorldStatistics &_msg)
+  std::function<void(const ignition::msgs::WorldStatistics &)> cb =
+      [&](const ignition::msgs::WorldStatistics &_msg)
   {
     std::unique_lock<std::mutex> lock(mutex);
     paused = _msg.paused();
@@ -81,8 +79,8 @@ uint64_t iterations()
   transport::Node node;
   uint64_t iterations = 0;
 
-  std::function<void(const msgs::WorldStatistics &)> cb =
-      [&](const msgs::WorldStatistics &_msg)
+  std::function<void(const ignition::msgs::WorldStatistics &)> cb =
+      [&](const ignition::msgs::WorldStatistics &_msg)
   {
     std::unique_lock<std::mutex> lock(mutex);
     iterations = _msg.iterations();
@@ -95,12 +93,8 @@ uint64_t iterations()
   return iterations;
 }
 
-class PlayPause : public InternalFixture<::testing::Test>
-{
-};
-
 /////////////////////////////////////////////////
-TEST_F(PlayPause, PlayPause)
+TEST(PlayPause, PlayPause)
 {
   common::Console::SetVerbosity(4);
 
