@@ -18,32 +18,37 @@
 #include <gtest/gtest.h>
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/Sensor.hh"
-#include "gz/sim/Model.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/Sensor.hh"
+#include "ignition/gazebo/Model.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
 #define tol 10e-4
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test PosePublisher system
-class PosePublisherTest : public InternalFixture<::testing::TestWithParam<int>>
+class PosePublisherTest : public ::testing::TestWithParam<int>
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 std::mutex mutex;
@@ -137,13 +142,13 @@ TEST_F(PosePublisherTest, PublishCmd)
   std::list<math::Pose3d> lowerLinkPoses;
   std::list<math::Pose3d> upperLinkPoses;
   std::list<math::Pose3d> sensorPoses;
-  std::list<common::Time> timestamps;
+  std::list<std::chrono::steady_clock::time_point> timestamps;
   testSystem.OnPostUpdate(
       [&modelName, &baseName, &lowerLinkName, &upperLinkName, &sensorName,
       &poses, &basePoses, &lowerLinkPoses, &upperLinkPoses, &sensorPoses,
       &timestamps](
-      const UpdateInfo &_info,
-      const EntityComponentManager &_ecm)
+      const gazebo::UpdateInfo &_info,
+      const gazebo::EntityComponentManager &_ecm)
     {
       // get our double pendulum model
       auto id = _ecm.EntityByComponents(
@@ -190,9 +195,11 @@ TEST_F(PosePublisherTest, PublishCmd)
 
       // timestamps
       auto simTimeSecNsec =
-          math::durationToSecNsec(_info.simTime);
+          ignition::math::durationToSecNsec(_info.simTime);
        timestamps.push_back(
-           common::Time(simTimeSecNsec.first, simTimeSecNsec.second));
+           math::secNsecToTimePoint(
+             simTimeSecNsec.first,
+             simTimeSecNsec.second));
     });
   server.AddSystem(testSystem.systemPtr);
 
@@ -237,10 +244,16 @@ TEST_F(PosePublisherTest, PublishCmd)
 
   // sort the pose msgs according to timestamp
   std::sort(poseMsgs.begin(), poseMsgs.end(), [](
-      const msgs::Pose &_l, const msgs::Pose &_r)
+      const ignition::msgs::Pose &_l, const ignition::msgs::Pose &_r)
   {
-    common::Time lt(_l.header().stamp().sec(), _l.header().stamp().nsec());
-    common::Time rt(_r.header().stamp().sec(), _r.header().stamp().nsec());
+    std::chrono::steady_clock::time_point lt =
+      math::secNsecToTimePoint(
+        _l.header().stamp().sec(),
+        _l.header().stamp().nsec());
+    std::chrono::steady_clock::time_point rt =
+      math::secNsecToTimePoint(
+        _r.header().stamp().sec(),
+        _r.header().stamp().nsec());
     return lt < rt;
   });
 
@@ -269,7 +282,10 @@ TEST_F(PosePublisherTest, PublishCmd)
     EXPECT_EQ(childFrame, msg.name());
 
     // verify timestamp
-    common::Time time(msg.header().stamp().sec(), msg.header().stamp().nsec());
+    std::chrono::steady_clock::time_point time =
+      math::secNsecToTimePoint(
+        msg.header().stamp().sec(),
+        msg.header().stamp().nsec());
     EXPECT_EQ(timestamps.front(), time);
     // assume msgs arrive in order and there is a pose msg for every link
     // so we only remove a timestamp from list after checking against all links
@@ -310,8 +326,7 @@ TEST_F(PosePublisherTest, PublishCmd)
 }
 
 /////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/630
-TEST_F(PosePublisherTest, IGN_UTILS_TEST_DISABLED_ON_MAC(UpdateFrequency))
+TEST_F(PosePublisherTest, UpdateFrequency)
 {
   // Start server
   ServerConfig serverConfig;
@@ -341,9 +356,9 @@ TEST_F(PosePublisherTest, IGN_UTILS_TEST_DISABLED_ON_MAC(UpdateFrequency))
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 30; ++sleep)
+  for (int sleep = 0; sleep < 300; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(100));
+    std::this_thread::sleep_for(std::chrono::milliseconds(10));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -420,15 +435,15 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
   std::list<math::Pose3d> lowerLinkPoses;
   std::list<math::Pose3d> upperLinkPoses;
   std::list<math::Pose3d> sensorPoses;
-  std::list<common::Time> timestamps;
-  std::list<common::Time> staticPoseTimestamps;
+  std::list<std::chrono::steady_clock::time_point> timestamps;
+  std::list<std::chrono::steady_clock::time_point> staticPoseTimestamps;
 
   testSystem.OnPostUpdate(
       [&modelName, &baseName, &lowerLinkName, &upperLinkName, &sensorName,
       &poses, &basePoses, &lowerLinkPoses, &upperLinkPoses, &sensorPoses,
       &timestamps, &staticPoseTimestamps](
-      const UpdateInfo &_info,
-      const EntityComponentManager &_ecm)
+      const gazebo::UpdateInfo &_info,
+      const gazebo::EntityComponentManager &_ecm)
     {
       // get our double pendulum model
       auto id = _ecm.EntityByComponents(
@@ -475,11 +490,13 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
 
       // timestamps
       auto simTimeSecNsec =
-          math::durationToSecNsec(_info.simTime);
+          ignition::math::durationToSecNsec(_info.simTime);
       timestamps.push_back(
-          common::Time(simTimeSecNsec.first, simTimeSecNsec.second));
+          math::secNsecToTimePoint(
+            simTimeSecNsec.first, simTimeSecNsec.second));
       staticPoseTimestamps.push_back(
-          common::Time(simTimeSecNsec.first, simTimeSecNsec.second));
+          math::secNsecToTimePoint(
+            simTimeSecNsec.first, simTimeSecNsec.second));
     });
   server.AddSystem(testSystem.systemPtr);
 
@@ -545,8 +562,9 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
       EXPECT_EQ(childFrame, msg.name());
 
       // verify timestamp
-      common::Time time(msg.header().stamp().sec(),
-          msg.header().stamp().nsec());
+      std::chrono::steady_clock::time_point time =
+        math::secNsecToTimePoint(msg.header().stamp().sec(),
+        msg.header().stamp().nsec());
       EXPECT_EQ(timestamps.front(), time);
 
       // verify pose
@@ -599,7 +617,8 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
       EXPECT_EQ(childFrame, msg.name());
 
       // verify timestamp
-      common::Time time(msg.header().stamp().sec(),
+      std::chrono::steady_clock::time_point time =
+        math::secNsecToTimePoint(msg.header().stamp().sec(),
           msg.header().stamp().nsec());
       EXPECT_EQ(staticPoseTimestamps.front(), time);
 
@@ -628,9 +647,7 @@ TEST_F(PosePublisherTest, StaticPosePublisher)
 }
 
 /////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/630
-TEST_F(PosePublisherTest,
-       IGN_UTILS_TEST_DISABLED_ON_MAC(StaticPoseUpdateFrequency))
+TEST_F(PosePublisherTest, StaticPoseUpdateFrequency)
 {
   // Start server
   ServerConfig serverConfig;
@@ -661,9 +678,9 @@ TEST_F(PosePublisherTest,
   std::size_t nExpMessages = 100;
   // Wait for 100 messages to be received
   bool received = false;
-  for (int sleep = 0; sleep < 30; ++sleep)
+  for (int sleep = 0; sleep < 300; ++sleep)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(100));
+    std::this_thread::sleep_for(std::chrono::milliseconds(10));
 
     {
       std::lock_guard<std::mutex> lock(mutex);
@@ -721,9 +738,9 @@ TEST_F(PosePublisherTest, NestedModelLoadPlugin)
 
   // Wait for messages to be received
   int sleep = 0;
-  while (poseMsgs.empty() && sleep++ < 30)
+  while (poseMsgs.empty() && sleep++ < 300)
   {
-    std::this_thread::sleep_for(std::chrono::milliseconds(100));
+    std::this_thread::sleep_for(std::chrono::milliseconds(10));
   }
 
   EXPECT_TRUE(!poseMsgs.empty());
