@@ -16,7 +16,7 @@
  */
 
 #include <gtest/gtest.h>
-#include <gz/msgs/sdf_generator_config.pb.h>
+#include <ignition/msgs/sdf_generator_config.pb.h>
 #include <tinyxml2.h>
 
 #include <sdf/Collision.hh>
@@ -26,26 +26,30 @@
 #include <sdf/Visual.hh>
 #include <sdf/World.hh>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "helpers/UniqueTestDirectoryEnv.hh"
 #include "plugins/MockSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
-class SdfGeneratorFixture : public InternalFixture<::testing::Test>
+class SdfGeneratorFixture : public ::testing::Test
 {
+  public: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+  }
+
   public: void LoadWorld(const std::string &_path)
   {
     ServerConfig serverConfig;
@@ -100,7 +104,7 @@ TEST_F(SdfGeneratorFixture, WorldWithModelsSpawnedAfterLoad)
   // This has to be different from the backpack in order to test SDFormat
   // generation for a Fuel URI that was not known when simulation started.
   const std::string groundPlaneUri =
-      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/ground plane";
+      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/ground plane";
 
   transport::Node node;
   {
