@@ -22,37 +22,45 @@
 #include <sdf/Root.hh>
 #include <sdf/Model.hh>
 
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/EventManager.hh"
-#include "gz/sim/Link.hh"
-#include "gz/sim/Model.hh"
-#include "gz/sim/SdfEntityCreator.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/Types.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/EventManager.hh"
+#include "ignition/gazebo/Link.hh"
+#include "ignition/gazebo/Model.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/Types.hh"
+#include "ignition/gazebo/test_config.hh"
 
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Visual.hh"
-#include "gz/sim/components/World.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Visual.hh"
+#include "ignition/gazebo/components/World.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
-class SdfFrameSemanticsTest : public InternalFixture<::testing::Test>
+class SdfFrameSemanticsTest : public ::testing::Test
 {
-  public: void StartServer()
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
+
+  public: ::testing::AssertionResult StartServer(
+    const ignition::gazebo::ServerConfig &_serverConfig =
+      ignition::gazebo::ServerConfig())
   {
     this->relay = std::make_unique<test::Relay>();
-    this->server = std::make_unique<Server>();
+    this->server = std::make_unique<Server>(_serverConfig);
     using namespace std::chrono_literals;
     this->server->SetUpdatePeriod(0ns);
 
@@ -60,17 +68,22 @@ class SdfFrameSemanticsTest : public InternalFixture<::testing::Test>
     EXPECT_FALSE(*this->server->Running(0));
     // A pointer to the ecm. This will be valid once we run the mock system
     relay->OnPreUpdate(
-        [this](const UpdateInfo &, EntityComponentManager &_ecm)
+        [this](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
         {
           this->ecm = &_ecm;
         });
 
     this->server->AddSystem(this->relay->systemPtr);
     this->server->Run(true, 1, false);
-    ASSERT_NE(nullptr, ecm);
+    if (nullptr == this->ecm)
+    {
+      return ::testing::AssertionFailure()
+        << "Failed to create EntityComponentManager";
+    }
 
     this->creator =
         std::make_unique<SdfEntityCreator>(*this->ecm, this->dummyEventMgr);
+    return ::testing::AssertionSuccess();
   }
 
   public: void SpawnModelSDF(const std::string &_sdfString)
@@ -81,19 +94,28 @@ class SdfFrameSemanticsTest : public InternalFixture<::testing::Test>
     sdf::Root root;
     sdf::Errors errors = root.LoadSdfString(_sdfString);
     EXPECT_TRUE(errors.empty());
-    ASSERT_EQ(root.ModelCount(), 1u);
+    ASSERT_NE(nullptr, root.Model());
 
-    Entity modelEntity = this->creator->CreateEntities(root.ModelByIndex(0));
+    Entity modelEntity = this->creator->CreateEntities(root.Model());
     Entity worldEntity = this->ecm->EntityByComponents(components::World());
     this->creator->SetParent(modelEntity, worldEntity);
   }
 
-  public: Model GetModel(const std::string &_name)
+  public: gazebo::Model GetModel(const std::string &_name)
   {
-    return Model(this->ecm->EntityByComponents(
+    return gazebo::Model(this->ecm->EntityByComponents(
         components::Model(), components::Name(_name)));
   }
 
+  public: gazebo::Model GetChildModel(Entity _parent, const std::string &_name)
+  {
+    return gazebo::Model(
+      this->ecm->EntityByComponents(
+        components::Model(),
+        components::ParentEntity(_parent),
+        components::Name(_name)));
+  }
+
   public: math::Pose3d GetPose(Entity _entity)
   {
     auto poseComp = this->ecm->Component<components::Pose>(_entity);
@@ -135,7 +157,7 @@ TEST_F(SdfFrameSemanticsTest, LinkRelativeTo)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -145,8 +167,8 @@ TEST_F(SdfFrameSemanticsTest, LinkRelativeTo)
   EXPECT_NE(link2, kNullEntity);
 
   // Expect the pose of L2 relative to model to be 0 0 1 0 0 pi
-  math::Pose3d expRelPose(0, 0, 1, 0, 0, IGN_PI);
-  math::Pose3d expWorldPose(0, 0, 3, 0, 0, IGN_PI);
+  ignition::math::Pose3d expRelPose(0, 0, 1, 0, 0, IGN_PI);
+  ignition::math::Pose3d expWorldPose(0, 0, 3, 0, 0, IGN_PI);
 
   EXPECT_EQ(expRelPose, this->GetPose(link2));
 
@@ -188,7 +210,7 @@ TEST_F(SdfFrameSemanticsTest, JointRelativeTo)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -212,7 +234,7 @@ TEST_F(SdfFrameSemanticsTest, JointRelativeTo)
 
   // Expect the pose of J1 relative to model to be the same as L2 (default
   // behavior)
-  math::Pose3d expWorldPose(1, 0, 2, 0, 0, 0);
+  ignition::math::Pose3d expWorldPose(1, 0, 2, 0, 0, 0);
 
   // Expect the pose of J2 relative to model to be the same as L2 (non default
   // behavior due to "relative_to='L2'")
@@ -246,7 +268,7 @@ TEST_F(SdfFrameSemanticsTest, VisualCollisionRelativeTo)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -267,7 +289,7 @@ TEST_F(SdfFrameSemanticsTest, VisualCollisionRelativeTo)
 
   // Expect the pose of v1 and relative to L2 (their parent link) to be the same
   // as the pose of L1 relative to L2
-  math::Pose3d expPose(0, 0, -1, 0, 0, 0);
+  ignition::math::Pose3d expPose(0, 0, -1, 0, 0, 0);
   EXPECT_EQ(expPose, this->GetPose(visual));
   EXPECT_EQ(expPose, this->GetPose(collision));
 
@@ -301,7 +323,7 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithLinks)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -315,13 +337,13 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithLinks)
 
   // Expect the pose of L1 and relative to M to be the same
   // as the pose of F1 relative to M
-  math::Pose3d link1ExpRelativePose(0, 0, 1, 0, 0, 0);
+  ignition::math::Pose3d link1ExpRelativePose(0, 0, 1, 0, 0, 0);
 
   EXPECT_EQ(link1ExpRelativePose, this->GetPose(link1));
 
   // Expect the pose of L2 and relative to M to be the same
   // as the pose of F2, which is at the origin of M
-  math::Pose3d link2ExpRelativePose = math::Pose3d::Zero;
+  ignition::math::Pose3d link2ExpRelativePose = ignition::math::Pose3d::Zero;
 
   EXPECT_EQ(link2ExpRelativePose, this->GetPose(link2));
 
@@ -356,7 +378,7 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithJoints)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -370,7 +392,7 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithJoints)
   this->server->Run(true, 1, false);
 
   // Expect the pose of J1 relative to model to be the same as F1 in world
-  math::Pose3d expWorldPose(1, 0, 2, 0, 0, 0);
+  ignition::math::Pose3d expWorldPose(1, 0, 2, 0, 0, 0);
   // TODO(anyone) Enable the following expectation when a joint's WorldPose
   // can be computed by ign-physics.
   // EXPECT_EQ(expWorldPose, this->GetWorldPose(joint1));
@@ -400,7 +422,7 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithVisualAndCollision)
   </sdf>
   )sdf";
 
-  this->StartServer();
+  ASSERT_TRUE(this->StartServer());
   this->SpawnModelSDF(modelSdf);
 
   auto model = this->GetModel("M");
@@ -421,7 +443,7 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithVisualAndCollision)
 
   // Expect the pose of v1 and relative to L1 (their parent link) to be the same
   // as the pose of F1 relative to L1
-  math::Pose3d expPose(0, 0, 1, 0, 0, 0);
+  ignition::math::Pose3d expPose(0, 0, 1, 0, 0, 0);
   EXPECT_EQ(expPose, this->GetPose(visual));
   EXPECT_EQ(expPose, this->GetPose(collision));
 
@@ -431,3 +453,175 @@ TEST_F(SdfFrameSemanticsTest, ExplicitFramesWithVisualAndCollision)
   EXPECT_EQ(expPose, this->GetPose(visual));
   EXPECT_EQ(expPose, this->GetPose(collision));
 }
+
+TEST_F(SdfFrameSemanticsTest, NestedModelsRelativeTo)
+{
+  const std::string modelSdf = R"sdf(
+  <sdf version="1.8">
+    <model name="M1">
+      <link name="L1">
+        <pose relative_to="M2::L2">1 0 0 0 0 0</pose>
+      </link>
+      <model name="M2">
+        <frame name="F1">
+          <pose>0 0 1 0 0 0</pose>
+        </frame>
+        <link name="L2">
+          <pose relative_to="F1">0 1 0 0 0 0</pose>
+        </link>
+      </model>
+    </model>
+  </sdf>
+  )sdf";
+
+  ASSERT_TRUE(this->StartServer());
+  this->SpawnModelSDF(modelSdf);
+
+  auto model1 = this->GetModel("M1");
+  ASSERT_TRUE(model1.Valid(*this->ecm));
+
+  auto model2 = this->GetModel("M2");
+  ASSERT_TRUE(model2.Valid(*this->ecm));
+
+  Entity link1 = model1.LinkByName(*this->ecm, "L1");
+  ASSERT_NE(link1, kNullEntity);
+
+  Entity link2 = model2.LinkByName(*this->ecm, "L2");
+  ASSERT_NE(link2, kNullEntity);
+
+  const ignition::math::Pose3d link1ExpectedPose(1, 1, 1, 0, 0, 0);
+  const ignition::math::Pose3d link2ExpectedPose(0, 1, 1, 0, 0, 0);
+
+  EXPECT_EQ(link1ExpectedPose, this->GetPose(link1));
+  EXPECT_EQ(link2ExpectedPose, this->GetPose(link2));
+
+  // Step once and check, the pose should still be close to its initial pose
+  this->server->Run(true, 1, false);
+
+  EXPECT_EQ(link1ExpectedPose, this->GetPose(link1));
+  EXPECT_EQ(link2ExpectedPose, this->GetPose(link2));
+}
+
+TEST_F(SdfFrameSemanticsTest, IncludeNestedModelsRelativeToTPE)
+{
+  std::string path = std::string(PROJECT_SOURCE_PATH) + "/test/worlds/models";
+  ignition::common::setenv("IGN_GAZEBO_RESOURCE_PATH", path.c_str());
+  ignition::gazebo::ServerConfig serverConfig;
+  serverConfig.SetResourceCache(path);
+  serverConfig.SetPhysicsEngine("libignition-physics-tpe-plugin.so");
+
+  const std::string sdfFile = std::string(PROJECT_SOURCE_PATH) +
+    "/test/worlds/include_nested_models.sdf";
+  serverConfig.SetSdfFile(sdfFile);
+
+  ASSERT_TRUE(this->StartServer(serverConfig));
+
+  auto includeNestedModel = this->GetModel("include_nested_new_name");
+  ASSERT_TRUE(includeNestedModel.Valid(*this->ecm));
+
+  auto model00 = this->GetModel("model_00");
+  ASSERT_TRUE(model00.Valid(*this->ecm));
+
+  auto nestedModel =
+    this->GetChildModel(includeNestedModel.Entity(), "nested_models_new_name");
+  ASSERT_TRUE(nestedModel.Valid(*this->ecm));
+
+  auto nestedModel00 = this->GetChildModel(nestedModel.Entity(), "model_00");
+  ASSERT_TRUE(nestedModel00.Valid(*this->ecm));
+
+  auto nestedModel01 = this->GetChildModel(nestedModel00.Entity(), "model_01");
+  ASSERT_TRUE(nestedModel01.Valid(*this->ecm));
+
+  Entity link00 = includeNestedModel.LinkByName(*this->ecm, "link_00");
+  ASSERT_NE(link00, kNullEntity);
+
+  ignition::math::Pose3d link00ExpectedPose(30, 32, 34, 0, 0, 0);
+  EXPECT_EQ(link00ExpectedPose, this->GetPose(link00));
+
+  auto link01 = includeNestedModel.LinkByName(*this->ecm, "link_01");
+  ASSERT_NE(link01, kNullEntity);
+
+  ignition::math::Pose3d link01ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(link01ExpectedPose, this->GetPose(link01));
+
+  Entity nestedModelsLink00 = nestedModel00.LinkByName(*this->ecm, "link_00");
+  ASSERT_NE(nestedModelsLink00, kNullEntity);
+
+  ignition::math::Pose3d nestedModelsLink00ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(nestedModelsLink00ExpectedPose, this->GetPose(nestedModelsLink00));
+
+  auto nestedModelsLink01 = nestedModel01.LinkByName(*this->ecm, "link_01");
+  ASSERT_NE(nestedModelsLink01, kNullEntity);
+
+  ignition::math::Pose3d nestedModelsLink01ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(nestedModelsLink01ExpectedPose, this->GetPose(nestedModelsLink01));
+
+  this->server->Run(true, 1, false);
+
+  EXPECT_EQ(link01ExpectedPose, this->GetPose(link01));
+  EXPECT_EQ(link00ExpectedPose, this->GetPose(link00));
+  EXPECT_EQ(nestedModelsLink00ExpectedPose, this->GetPose(nestedModelsLink00));
+  EXPECT_EQ(nestedModelsLink01ExpectedPose, this->GetPose(nestedModelsLink01));
+}
+
+TEST_F(SdfFrameSemanticsTest, IncludeNestedModelsRelativeToDartsim)
+{
+  std::string path = std::string(PROJECT_SOURCE_PATH) + "/test/worlds/models";
+  ignition::common::setenv("IGN_GAZEBO_RESOURCE_PATH", path.c_str());
+  ignition::gazebo::ServerConfig serverConfig;
+  serverConfig.SetResourceCache(path);
+  serverConfig.SetPhysicsEngine("libignition-physics-dartsim-plugin.so");
+
+  const std::string sdfFile = std::string(PROJECT_SOURCE_PATH) +
+    "/test/worlds/include_nested_models.sdf";
+  serverConfig.SetSdfFile(sdfFile);
+
+  ASSERT_TRUE(this->StartServer(serverConfig));
+
+  auto includeNestedModel = this->GetModel("include_nested_new_name");
+  ASSERT_TRUE(includeNestedModel.Valid(*this->ecm));
+
+  auto model00 = this->GetModel("model_00");
+  ASSERT_TRUE(model00.Valid(*this->ecm));
+
+  auto nestedModel =
+    this->GetChildModel(includeNestedModel.Entity(), "nested_models_new_name");
+  ASSERT_TRUE(nestedModel.Valid(*this->ecm));
+
+  auto nestedModel00 = this->GetChildModel(nestedModel.Entity(), "model_00");
+  ASSERT_TRUE(nestedModel00.Valid(*this->ecm));
+
+  auto nestedModel01 = this->GetChildModel(nestedModel00.Entity(), "model_01");
+  ASSERT_TRUE(nestedModel01.Valid(*this->ecm));
+
+  Entity link00 = includeNestedModel.LinkByName(*this->ecm, "link_00");
+  ASSERT_NE(link00, kNullEntity);
+
+  ignition::math::Pose3d link00ExpectedPose(30, 32, 34, 0, 0, 0);
+  EXPECT_EQ(link00ExpectedPose, this->GetPose(link00));
+
+  auto link01 = includeNestedModel.LinkByName(*this->ecm, "link_01");
+  ASSERT_NE(link01, kNullEntity);
+
+  ignition::math::Pose3d link01ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(link01ExpectedPose, this->GetPose(link01));
+
+  Entity nestedModelsLink00 = nestedModel00.LinkByName(*this->ecm, "link_00");
+  ASSERT_NE(nestedModelsLink00, kNullEntity);
+
+  ignition::math::Pose3d nestedModelsLink00ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(nestedModelsLink00ExpectedPose, this->GetPose(nestedModelsLink00));
+
+  auto nestedModelsLink01 = nestedModel01.LinkByName(*this->ecm, "link_01");
+  ASSERT_NE(nestedModelsLink01, kNullEntity);
+
+  ignition::math::Pose3d nestedModelsLink01ExpectedPose(20, 21, 22, 0, 0, 0);
+  EXPECT_EQ(nestedModelsLink01ExpectedPose, this->GetPose(nestedModelsLink01));
+
+  this->server->Run(true, 1, false);
+
+  EXPECT_EQ(link01ExpectedPose, this->GetPose(link01));
+  EXPECT_EQ(link00ExpectedPose, this->GetPose(link00));
+  EXPECT_EQ(nestedModelsLink00ExpectedPose, this->GetPose(nestedModelsLink00));
+  EXPECT_EQ(nestedModelsLink01ExpectedPose, this->GetPose(nestedModelsLink01));
+}
