@@ -17,33 +17,27 @@
 
 #include <gtest/gtest.h>
 #include <sdf/sdf.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/fuel_tools.hh>
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include <ignition/common/Filesystem.hh>
+#include <ignition/fuel_tools.hh>
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-#include "../helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
-
-class SdfInclude : public InternalFixture<::testing::Test>
-{
-};
+using namespace ignition;
+using namespace gazebo;
 
 /////////////////////////////////////////////////
-TEST_F(SdfInclude, DownloadFromFuel)
+TEST(SdfInclude, DownloadFromFuel)
 {
   std::string path = common::cwd() + "/test_cache";
 
   // Configure the gazebo server, which will cause a model to be downloaded.
-  ServerConfig serverConfig;
+  gazebo::ServerConfig serverConfig;
   serverConfig.SetResourceCache(path);
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
     "/test/worlds/include.sdf");
-  Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   EXPECT_TRUE(common::exists(path +
-        "/fuel.gazebosim.org/openrobotics/models/ground plane" +
+        "/fuel.ignitionrobotics.org/openrobotics/models/ground plane" +
         "/1/model.sdf"));
 }
