@@ -24,48 +24,50 @@
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/transport/Node.hh>
+#include <ignition/utilities/ExtraTestMacros.hh>
 
-#include "gz/sim/EntityComponentManager.hh"
-#include "gz/sim/EventManager.hh"
-#include "gz/sim/SdfEntityCreator.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/Types.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/EntityComponentManager.hh"
+#include "ignition/gazebo/EventManager.hh"
+#include "ignition/gazebo/SdfEntityCreator.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/Types.hh"
+#include "ignition/gazebo/test_config.hh"
 
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/World.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/World.hh"
 
 #include "plugins/MockSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace std::chrono_literals;
-namespace components = gz::sim::components;
+namespace components = ignition::gazebo::components;
 
 //////////////////////////////////////////////////
-class SensorsFixture : public InternalFixture<InternalFixture<::testing::Test>>
+class SensorsFixture : public ::testing::Test
 {
   protected: void SetUp() override
   {
-    InternalFixture::SetUp();
+    common::Console::SetVerbosity(4);
+    // Augment the system plugin path.  In SetUp to avoid test order issues.
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+      (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
 
     auto plugin = sm.LoadPlugin("libMockSystem.so",
-                                "gz::sim::MockSystem",
+                                "ignition::gazebo::MockSystem",
                                 nullptr);
     EXPECT_TRUE(plugin.has_value());
     this->systemPtr = plugin.value();
-    this->mockSystem = static_cast<sim::MockSystem *>(
-        systemPtr->QueryInterface<sim::System>());
+    this->mockSystem = static_cast<gazebo::MockSystem *>(
+        systemPtr->QueryInterface<gazebo::System>());
   }
 
-  public: gz::sim::SystemPluginPtr systemPtr;
-  public: gz::sim::MockSystem *mockSystem;
+  public: ignition::gazebo::SystemPluginPtr systemPtr;
+  public: gazebo::MockSystem *mockSystem;
 
-  private: gz::sim::SystemLoader sm;
+  private: gazebo::SystemLoader sm;
 };
 
 //////////////////////////////////////////////////
@@ -87,17 +89,6 @@ void testDefaultTopics()
   std::vector<transport::MessagePublisher> publishers;
   transport::Node node;
 
-  // Sensors are created in a separate thread, so we sleep here to give them
-  // time
-  int sleep{0};
-  int maxSleep{30};
-  for (; sleep < maxSleep && !node.TopicInfo(topics.front(), publishers);
-      ++sleep)
-  {
-    std::this_thread::sleep_for(std::chrono::milliseconds(100));
-  }
-  ASSERT_LT(sleep, maxSleep);
-
   for (const std::string &topic : topics)
   {
     bool result = node.TopicInfo(topic, publishers);
@@ -113,7 +104,7 @@ void testDefaultTopics()
 /// are removed and then added back
 TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
 {
-  gz::sim::ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
 
   const std::string sdfFile = std::string(PROJECT_SOURCE_PATH) +
     "/test/worlds/sensor.sdf";
@@ -125,12 +116,12 @@ TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
   const sdf::World *sdfWorld = root.WorldByIndex(0);
   const sdf::Model *sdfModel = sdfWorld->ModelByIndex(0);
 
-  gz::sim::Server server(serverConfig);
+  gazebo::Server server(serverConfig);
 
   // A pointer to the ecm. This will be valid once we run the mock system
-  gz::sim::EntityComponentManager *ecm = nullptr;
+  gazebo::EntityComponentManager *ecm = nullptr;
   this->mockSystem->preUpdateCallback =
-    [&ecm](const gz::sim::UpdateInfo &, gz::sim::EntityComponentManager &_ecm)
+    [&ecm](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
     {
       ecm = &_ecm;
     };
@@ -143,8 +134,8 @@ TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
 
   // We won't use the event manager but it's required to create an
   // SdfEntityCreator
-  gz::sim::EventManager dummyEventMgr;
-  gz::sim::SdfEntityCreator creator(*ecm, dummyEventMgr);
+  gazebo::EventManager dummyEventMgr;
+  gazebo::SdfEntityCreator creator(*ecm, dummyEventMgr);
 
   unsigned int runs = 100;
   unsigned int runIterations = 2;
@@ -153,7 +144,7 @@ TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
     {
       auto modelEntity = ecm->EntityByComponents(
           components::Model(), components::Name(sdfModel->Name()));
-      EXPECT_NE(gz::sim::kNullEntity, modelEntity);
+      EXPECT_NE(gazebo::kNullEntity, modelEntity);
 
       // Remove the first model in the world
       creator.RequestRemoveEntity(modelEntity, true);
@@ -166,7 +157,7 @@ TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
           components::Name(sdfModel->Name()));
 
       // Since the model is removed, we should get a null entity
-      EXPECT_EQ(gz::sim::kNullEntity, modelEntity);
+      EXPECT_EQ(gazebo::kNullEntity, modelEntity);
     }
 
     // Create the model again
@@ -181,7 +172,7 @@ TEST_F(SensorsFixture, IGN_UTILS_TEST_DISABLED_ON_MAC(HandleRemovedEntities))
     {
       auto modelEntity = ecm->EntityByComponents(components::Model(),
           components::Name(sdfModel->Name()));
-      EXPECT_NE(gz::sim::kNullEntity, modelEntity);
+      EXPECT_NE(gazebo::kNullEntity, modelEntity);
     }
   }
 }
