@@ -16,22 +16,27 @@
  */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/transport/Node.hh>
-#include <gz/utilities/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/test_config.hh"
 
-#include "../helpers/EnvTestFixture.hh"
-
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test TouchPlugin system
-class TouchPluginTest : public InternalFixture<::testing::Test>
+class TouchPluginTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
+
   public: void StartServer(const std::string &_sdfFile)
   {
     ServerConfig serverConfig;
@@ -99,7 +104,7 @@ TEST_F(TouchPluginTest, OneLink)
     std::this_thread::sleep_for(std::chrono::milliseconds(30));
   }
 // Known to fail on OSX, see
-// https://github.com/gazebosim/gz-sim/issues/22
+// https://github.com/ignitionrobotics/ign-gazebo/issues/22
 #if !defined (__APPLE__)
   EXPECT_TRUE(whiteTouched);
 #endif
@@ -179,15 +184,14 @@ TEST_F(TouchPluginTest, StartDisabled)
     std::this_thread::sleep_for(std::chrono::milliseconds(30));
   }
 // Known to fail on OSX, see
-// https://github.com/gazebosm/gz-sim/issues/22
+// https://github.com/ignitionrobotics/ign-gazebo/issues/22
 #if !defined (__APPLE__)
   EXPECT_TRUE(blueTouched);
 #endif
 }
 
 //////////////////////////////////////////////////
-// See: https://github.com/gazebosim/gz-sim/issues/630
-TEST_F(TouchPluginTest, IGN_UTILS_TEST_DISABLED_ON_MAC(RemovalOfParentModel))
+TEST_F(TouchPluginTest, RemovalOfParentModel)
 {
   this->StartServer("/test/worlds/touch_plugin.sdf");
 
@@ -249,7 +253,7 @@ TEST_F(TouchPluginTest, SpawnedEntities)
         </link>
         <plugin
           filename="libignition-gazebo-touchplugin-system.so"
-          name="gz::sim::systems::TouchPlugin">
+          name="ignition::gazebo::systems::TouchPlugin">
           <target>green_box_for_white</target>
           <time>0.2</time>
           <namespace>white_touches_only_green</namespace>
@@ -298,7 +302,7 @@ TEST_F(TouchPluginTest, SpawnedEntities)
   auto testFunc = [&](const std::string &_box1, const std::string &_box2)
   {
     this->server.reset();
-    this->StartServer("/test/worlds/empty.sdf");
+    this->StartServer("/examples/worlds/empty.sdf");
 
     whiteTouched = false;
     req.set_sdf(_box1);
