@@ -17,33 +17,41 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/entity_factory.pb.h>
+#include <ignition/msgs/entity_factory.pb.h>
+#include <ignition/msgs/light.pb.h>
+#include <ignition/msgs/physics.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Physics.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Physics.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 //////////////////////////////////////////////////
-class UserCommandsTest : public InternalFixture<::testing::Test>
+class UserCommandsTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    ignition::common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
 };
 
 /////////////////////////////////////////////////
@@ -52,7 +60,7 @@ TEST_F(UserCommandsTest, Create)
   // Start server
   ServerConfig serverConfig;
   const auto sdfFile = std::string(PROJECT_SOURCE_PATH) +
-    "/test/worlds/empty.sdf";
+    "/examples/worlds/empty.sdf";
   serverConfig.SetSdfFile(sdfFile);
 
   Server server(serverConfig);
@@ -66,8 +74,8 @@ TEST_F(UserCommandsTest, Create)
   // shared pointer owned by the SimulationRunner.
   EntityComponentManager *ecm{nullptr};
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-                             EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+                             gazebo::EntityComponentManager &_ecm)
       {
         ecm = &_ecm;
       });
@@ -220,6 +228,25 @@ TEST_F(UserCommandsTest, Create)
 
   EXPECT_NE(nullptr, ecm->Component<components::Light>(light));
 
+  // Request entity spawn
+  req.Clear();
+  req.mutable_light()->set_name("light_test");
+  req.mutable_light()->set_parent_id(1);
+  EXPECT_TRUE(node.Request(service, req, timeout, res, result));
+  EXPECT_TRUE(result);
+  EXPECT_TRUE(res.data());
+
+  // Run an iteration and check it was created
+  server.Run(true, 1, false);
+
+  EXPECT_EQ(entityCount + 1, ecm->EntityCount());
+  entityCount = ecm->EntityCount();
+
+  light = ecm->EntityByComponents(components::Name("light_test"));
+  EXPECT_NE(kNullEntity, light);
+
+  EXPECT_NE(nullptr, ecm->Component<components::Light>(light));
+
   // Queue commands and check they're all executed in the same iteration
   req.Clear();
   req.set_sdf(modelStr);
@@ -328,8 +355,8 @@ TEST_F(UserCommandsTest, Remove)
   // shared pointer owned by the SimulationRunner.
   EntityComponentManager *ecm{nullptr};
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-                             EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+                             gazebo::EntityComponentManager &_ecm)
       {
         ecm = &_ecm;
       });
@@ -342,9 +369,9 @@ TEST_F(UserCommandsTest, Remove)
   EXPECT_NE(nullptr, ecm);
 
   // Check entities
-  // 1 x world + 1 x (default) level + 1 x wind + 3 x model + 3 x link + 3 x
-  // collision + 3 x visual + 1 x light
-  EXPECT_EQ(16u, ecm->EntityCount());
+  // 1 x world + 1 x (default) level + 1 x wind + 5 x model + 5 x link + 5 x
+  // collision + 5 x visual + 1 x light
+  EXPECT_EQ(24u, ecm->EntityCount());
 
   // Entity remove by name
   msgs::Entity req;
@@ -367,7 +394,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check it was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(12u, ecm->EntityCount());
+  EXPECT_EQ(20u, ecm->EntityCount());
 
   EXPECT_EQ(kNullEntity, ecm->EntityByComponents(components::Model(),
       components::Name("box")));
@@ -390,7 +417,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check it was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(8u, ecm->EntityCount());
+  EXPECT_EQ(16u, ecm->EntityCount());
 
   EXPECT_EQ(kNullEntity, ecm->EntityByComponents(components::Model(),
       components::Name("sphere")));
@@ -409,7 +436,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check it was not removed
   server.Run(true, 1, false);
-  EXPECT_EQ(8u, ecm->EntityCount());
+  EXPECT_EQ(16u, ecm->EntityCount());
 
   EXPECT_NE(kNullEntity, ecm->EntityByComponents(components::Link(),
       components::Name("cylinder_link")));
@@ -430,7 +457,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check cylinder was removed and light wasn't
   server.Run(true, 1, false);
-  EXPECT_EQ(4u, ecm->EntityCount());
+  EXPECT_EQ(12u, ecm->EntityCount());
 
   EXPECT_EQ(kNullEntity, ecm->EntityByComponents(components::Model(),
       components::Name("cylinder")));
@@ -449,7 +476,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check nothing was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(4u, ecm->EntityCount());
+  EXPECT_EQ(12u, ecm->EntityCount());
 
   EXPECT_NE(kNullEntity, ecm->EntityByComponents(components::Name("sun")));
 
@@ -463,7 +490,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check nothing was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(4u, ecm->EntityCount());
+  EXPECT_EQ(12u, ecm->EntityCount());
 
   // Unsupported type - fails to remove
   req.Clear();
@@ -476,7 +503,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check nothing was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(4u, ecm->EntityCount());
+  EXPECT_EQ(12u, ecm->EntityCount());
 
   EXPECT_NE(kNullEntity, ecm->EntityByComponents(components::Name("sun")));
 
@@ -491,7 +518,7 @@ TEST_F(UserCommandsTest, Remove)
 
   // Run an iteration and check it was removed
   server.Run(true, 1, false);
-  EXPECT_EQ(3u, ecm->EntityCount());
+  EXPECT_EQ(11u, ecm->EntityCount());
 
   EXPECT_EQ(kNullEntity, ecm->EntityByComponents(components::Name("sun")));
 }
@@ -512,8 +539,8 @@ TEST_F(UserCommandsTest, Pose)
   // Create a system just to get the ECM
   EntityComponentManager *ecm{nullptr};
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-                             EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+                             gazebo::EntityComponentManager &_ecm)
       {
         ecm = &_ecm;
       });
@@ -669,14 +696,13 @@ TEST_F(UserCommandsTest, Pose)
   EXPECT_NEAR(500.0, poseComp->Data().Pos().Y(), 0.2);
 }
 
-
 /////////////////////////////////////////////////
-TEST_F(UserCommandsTest, PoseVector)
+TEST_F(UserCommandsTest, Light)
 {
   // Start server
   ServerConfig serverConfig;
-  const auto sdfFile = std::string(PROJECT_SOURCE_PATH) +
-    "/test/worlds/shapes.sdf";
+  const auto sdfFile = ignition::common::joinPaths(
+    std::string(PROJECT_SOURCE_PATH), "test", "worlds", "lights_render.sdf");
   serverConfig.SetSdfFile(sdfFile);
 
   Server server(serverConfig);
@@ -686,8 +712,8 @@ TEST_F(UserCommandsTest, PoseVector)
   // Create a system just to get the ECM
   EntityComponentManager *ecm{nullptr};
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-                             EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+                             gazebo::EntityComponentManager &_ecm)
       {
         ecm = &_ecm;
       });
@@ -699,49 +725,201 @@ TEST_F(UserCommandsTest, PoseVector)
   server.Run(true, 1, false);
   EXPECT_NE(nullptr, ecm);
 
-  // Entity move by name
-  msgs::Pose_V req;
-
-  auto poseBoxMsg = req.add_pose();
-  poseBoxMsg->set_name("box");
-  poseBoxMsg->mutable_position()->set_y(123.0);
-
-  auto poseSphereMsg = req.add_pose();
-  poseSphereMsg->set_name("sphere");
-  poseSphereMsg->mutable_position()->set_y(456.0);
-
+  msgs::Light req;
   msgs::Boolean res;
-  bool result;
-  unsigned int timeout = 5000;
-  std::string service{"/world/default/set_pose_vector"};
-
   transport::Node node;
+  bool result;
+  unsigned int timeout = 1000;
+  std::string service{"/world/lights_command/light_config"};
+
+  // Point light
+  auto pointLightEntity = ecm->EntityByComponents(components::Name("point"));
+  EXPECT_NE(kNullEntity, pointLightEntity);
+
+  // Check point light entity has not been edited yet - Initial values
+  auto pointLightComp = ecm->Component<components::Light>(pointLightEntity);
+  ASSERT_NE(nullptr, pointLightComp);
+  EXPECT_EQ(
+    math::Pose3d(0, -1.5, 3, 0, 0, 0), pointLightComp->Data().RawPose());
+  EXPECT_EQ(math::Color(1, 0, 0, 1), pointLightComp->Data().Diffuse());
+  EXPECT_EQ(math::Color(0.1, 0.1, 0.1, 1), pointLightComp->Data().Specular());
+  EXPECT_NEAR(4.0, pointLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(0.5, pointLightComp->Data().LinearAttenuationFactor(), 0.1);
+  EXPECT_NEAR(0.2, pointLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(0.01, pointLightComp->Data().QuadraticAttenuationFactor(), 0.1);
+  EXPECT_FALSE(pointLightComp->Data().CastShadows());
+
+  req.Clear();
+  ignition::msgs::Set(req.mutable_diffuse(),
+    ignition::math::Color(0, 1, 1, 0));
+  ignition::msgs::Set(req.mutable_specular(),
+    ignition::math::Color(0.2, 0.2, 0.2, 0.2));
+  req.set_range(2.6);
+  req.set_name("point");
+  req.set_type(ignition::msgs::Light::POINT);
+  req.set_attenuation_linear(0.7);
+  req.set_attenuation_constant(0.6);
+  req.set_attenuation_quadratic(0.001);
+  req.set_cast_shadows(true);
   EXPECT_TRUE(node.Request(service, req, timeout, res, result));
   EXPECT_TRUE(result);
   EXPECT_TRUE(res.data());
 
-  // Box entity
-  auto boxEntity = ecm->EntityByComponents(components::Name("box"));
-  EXPECT_NE(kNullEntity, boxEntity);
+  server.Run(true, 100, false);
+  // Sleep for a small duration to allow Run thread to start
+  IGN_SLEEP_MS(10);
 
-  // Check entity has not been moved yet
-  auto poseComp = ecm->Component<components::Pose>(boxEntity);
-  ASSERT_NE(nullptr, poseComp);
-  EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 1), poseComp->Data());
+  // Check point light entity has been edited using the service
+  pointLightComp = ecm->Component<components::Light>(pointLightEntity);
+  ASSERT_NE(nullptr, pointLightComp);
 
-  // Run an iteration and check it was moved
-  server.Run(true, 1, false);
+  EXPECT_EQ(math::Color(0, 1, 1, 0), pointLightComp->Data().Diffuse());
+  EXPECT_EQ(math::Color(0.2, 0.2, 0.2, 0.2),
+    pointLightComp->Data().Specular());
+  EXPECT_NEAR(2.6, pointLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(0.7, pointLightComp->Data().LinearAttenuationFactor(), 0.1);
+  EXPECT_NEAR(0.6, pointLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(0.001, pointLightComp->Data().QuadraticAttenuationFactor(), 0.1);
+  EXPECT_TRUE(pointLightComp->Data().CastShadows());
+  EXPECT_EQ(sdf::LightType::POINT, pointLightComp->Data().Type());
 
-  poseComp = ecm->Component<components::Pose>(boxEntity);
-  ASSERT_NE(nullptr, poseComp);
-  EXPECT_NEAR(123.0, poseComp->Data().Pos().Y(), 0.2);
+  // Check directional light entity has not been edited yet - Initial values
+  auto directionalLightEntity = ecm->EntityByComponents(
+      components::Name("directional"));
+  EXPECT_NE(kNullEntity, directionalLightEntity);
 
-  auto sphereEntity = ecm->EntityByComponents(components::Name("sphere"));
-  EXPECT_NE(kNullEntity, sphereEntity);
+  auto directionalLightComp =
+    ecm->Component<components::Light>(directionalLightEntity);
+  ASSERT_NE(nullptr, directionalLightComp);
 
-  poseComp = ecm->Component<components::Pose>(sphereEntity);
-  ASSERT_NE(nullptr, poseComp);
-  EXPECT_NEAR(456, poseComp->Data().Pos().Y(), 0.2);
+  EXPECT_EQ(
+    math::Pose3d(0, 0, 10, 0, 0, 0), directionalLightComp->Data().RawPose());
+  EXPECT_EQ(
+    math::Color(0.8, 0.8, 0.8, 1), directionalLightComp->Data().Diffuse());
+  EXPECT_EQ(
+    math::Color(0.2, 0.2, 0.2, 1), directionalLightComp->Data().Specular());
+  EXPECT_NEAR(100, directionalLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(
+    0.01, directionalLightComp->Data().LinearAttenuationFactor(), 0.01);
+  EXPECT_NEAR(
+    0.9, directionalLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(
+    0.001, directionalLightComp->Data().QuadraticAttenuationFactor(), 0.001);
+  EXPECT_EQ(
+    math::Vector3d(0.5, 0.2, -0.9), directionalLightComp->Data().Direction());
+  EXPECT_TRUE(directionalLightComp->Data().CastShadows());
+  EXPECT_EQ(sdf::LightType::POINT, pointLightComp->Data().Type());
+
+  req.Clear();
+  ignition::msgs::Set(req.mutable_diffuse(),
+    ignition::math::Color(0, 1, 1, 0));
+  ignition::msgs::Set(req.mutable_specular(),
+    ignition::math::Color(0.3, 0.3, 0.3, 0.3));
+  req.set_range(2.6);
+  req.set_name("directional");
+  req.set_type(ignition::msgs::Light::DIRECTIONAL);
+  req.set_attenuation_linear(0.7);
+  req.set_attenuation_constant(0.6);
+  req.set_attenuation_quadratic(1);
+  req.set_cast_shadows(false);
+  ignition::msgs::Set(req.mutable_direction(),
+    ignition::math::Vector3d(1, 2, 3));
+  EXPECT_TRUE(node.Request(service, req, timeout, res, result));
+  EXPECT_TRUE(result);
+  EXPECT_TRUE(res.data());
+
+  server.Run(true, 100, false);
+  // Sleep for a small duration to allow Run thread to start
+  IGN_SLEEP_MS(10);
+
+  // Check directional light entity has been edited using the service
+  directionalLightComp =
+    ecm->Component<components::Light>(directionalLightEntity);
+  ASSERT_NE(nullptr, directionalLightComp);
+
+  EXPECT_EQ(math::Color(0, 1, 1, 0), directionalLightComp->Data().Diffuse());
+  EXPECT_EQ(math::Color(0.3, 0.3, 0.3, 0.3),
+    directionalLightComp->Data().Specular());
+  EXPECT_NEAR(2.6, directionalLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(
+    0.7, directionalLightComp->Data().LinearAttenuationFactor(), 0.1);
+  EXPECT_NEAR(
+    0.6, directionalLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(
+    1, directionalLightComp->Data().QuadraticAttenuationFactor(), 0.1);
+  EXPECT_EQ(math::Vector3d(1, 2, 3), directionalLightComp->Data().Direction());
+  EXPECT_FALSE(directionalLightComp->Data().CastShadows());
+  EXPECT_EQ(sdf::LightType::DIRECTIONAL,
+    directionalLightComp->Data().Type());
+
+  // spot light
+  auto spotLightEntity = ecm->EntityByComponents(
+      components::Name("spot"));
+  EXPECT_NE(kNullEntity, spotLightEntity);
+
+  // Check spot light entity has not been edited yet - Initial values
+  auto spotLightComp =
+    ecm->Component<components::Light>(spotLightEntity);
+  ASSERT_NE(nullptr, spotLightComp);
+
+  EXPECT_EQ(math::Pose3d(0, 1.5, 3, 0, 0, 0), spotLightComp->Data().RawPose());
+  EXPECT_EQ(math::Color(0, 1, 0, 1), spotLightComp->Data().Diffuse());
+  EXPECT_EQ(math::Color(0.2, 0.2, 0.2, 1), spotLightComp->Data().Specular());
+  EXPECT_NEAR(5, spotLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(0.4, spotLightComp->Data().LinearAttenuationFactor(), 0.01);
+  EXPECT_NEAR(0.3, spotLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(
+    0.001, spotLightComp->Data().QuadraticAttenuationFactor(), 0.001);
+  EXPECT_EQ(math::Vector3d(0, 0, -1), spotLightComp->Data().Direction());
+  EXPECT_FALSE(spotLightComp->Data().CastShadows());
+  EXPECT_EQ(sdf::LightType::SPOT, spotLightComp->Data().Type());
+  EXPECT_NEAR(0.1, spotLightComp->Data().SpotInnerAngle().Radian(), 0.1);
+  EXPECT_NEAR(0.5, spotLightComp->Data().SpotOuterAngle().Radian(), 0.1);
+  EXPECT_NEAR(0.8, spotLightComp->Data().SpotFalloff(), 0.1);
+
+  req.Clear();
+  ignition::msgs::Set(req.mutable_diffuse(),
+    ignition::math::Color(1, 0, 1, 0));
+  ignition::msgs::Set(req.mutable_specular(),
+    ignition::math::Color(0.3, 0.3, 0.3, 0.3));
+  req.set_range(2.6);
+  req.set_name("spot");
+  req.set_type(ignition::msgs::Light::SPOT);
+  req.set_attenuation_linear(0.7);
+  req.set_attenuation_constant(0.6);
+  req.set_attenuation_quadratic(1);
+  req.set_cast_shadows(true);
+  ignition::msgs::Set(req.mutable_direction(),
+    ignition::math::Vector3d(1, 2, 3));
+  req.set_spot_inner_angle(1.5);
+  req.set_spot_outer_angle(0.3);
+  req.set_spot_falloff(0.9);
+
+  EXPECT_TRUE(node.Request(service, req, timeout, res, result));
+  EXPECT_TRUE(result);
+  EXPECT_TRUE(res.data());
+
+  server.Run(true, 100, false);
+  // Sleep for a small duration to allow Run thread to start
+  IGN_SLEEP_MS(10);
+
+  // Check spot light entity has been edited using the service
+  spotLightComp = ecm->Component<components::Light>(spotLightEntity);
+  ASSERT_NE(nullptr, spotLightComp);
+
+  EXPECT_EQ(math::Color(1, 0, 1, 0), spotLightComp->Data().Diffuse());
+  EXPECT_EQ(math::Color(0.3, 0.3, 0.3, 0.3),
+    spotLightComp->Data().Specular());
+  EXPECT_NEAR(2.6, spotLightComp->Data().AttenuationRange(), 0.1);
+  EXPECT_NEAR(0.7, spotLightComp->Data().LinearAttenuationFactor(), 0.1);
+  EXPECT_NEAR(0.6, spotLightComp->Data().ConstantAttenuationFactor(), 0.1);
+  EXPECT_NEAR(1, spotLightComp->Data().QuadraticAttenuationFactor(), 0.1);
+  EXPECT_EQ(math::Vector3d(1, 2, 3), spotLightComp->Data().Direction());
+  EXPECT_TRUE(spotLightComp->Data().CastShadows());
+  EXPECT_EQ(sdf::LightType::SPOT, spotLightComp->Data().Type());
+  EXPECT_NEAR(1.5, spotLightComp->Data().SpotInnerAngle().Radian(), 0.1);
+  EXPECT_NEAR(0.3, spotLightComp->Data().SpotOuterAngle().Radian(), 0.1);
+  EXPECT_NEAR(0.9, spotLightComp->Data().SpotFalloff(), 0.1);
 }
 
 /////////////////////////////////////////////////
@@ -760,8 +938,8 @@ TEST_F(UserCommandsTest, Physics)
   // Create a system just to get the ECM
   EntityComponentManager *ecm{nullptr};
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-                             EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+                             gazebo::EntityComponentManager &_ecm)
       {
         ecm = &_ecm;
       });
@@ -779,7 +957,7 @@ TEST_F(UserCommandsTest, Physics)
   auto physicsComp = ecm->Component<components::Physics>(worldEntity);
   ASSERT_NE(nullptr, physicsComp);
   EXPECT_DOUBLE_EQ(0.001, physicsComp->Data().MaxStepSize());
-  EXPECT_DOUBLE_EQ(0.0, physicsComp->Data().RealTimeFactor());
+  EXPECT_DOUBLE_EQ(1.0, physicsComp->Data().RealTimeFactor());
 
   // Set physics properties
   msgs::Physics req;
