@@ -17,46 +17,52 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/msgs/entity_factory.pb.h>
+#include <ignition/msgs/entity_factory.pb.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/math/Pose3.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/math/Pose3.hh>
+#include <ignition/transport/Node.hh>
 
 #include <sdf/Sphere.hh>
 #include <sdf/Cylinder.hh>
 
-#include "gz/sim/components/Collision.hh"
-#include "gz/sim/components/Geometry.hh"
-#include "gz/sim/components/Gravity.hh"
-#include "gz/sim/components/Inertial.hh"
-#include "gz/sim/components/Joint.hh"
-#include "gz/sim/components/JointVelocity.hh"
-#include "gz/sim/components/JointVelocityCmd.hh"
-#include "gz/sim/components/Light.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Model.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/ParentEntity.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/SlipComplianceCmd.hh"
-#include "gz/sim/components/World.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/components/Collision.hh"
+#include "ignition/gazebo/components/Geometry.hh"
+#include "ignition/gazebo/components/Gravity.hh"
+#include "ignition/gazebo/components/Inertial.hh"
+#include "ignition/gazebo/components/Joint.hh"
+#include "ignition/gazebo/components/JointVelocity.hh"
+#include "ignition/gazebo/components/JointVelocityCmd.hh"
+#include "ignition/gazebo/components/Light.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Model.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/ParentEntity.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/SlipComplianceCmd.hh"
+#include "ignition/gazebo/components/World.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/Relay.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test DiffDrive system
-class WheelSlipTest : public InternalFixture<::testing::Test>
+class WheelSlipTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+             {
+               common::Console::SetVerbosity(4);
+               ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+                   (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+             }
   /// \brief Class to hold parameters for tire tests.
   public: class WheelSlipState
   {
@@ -81,7 +87,7 @@ class WheelSlipTest : public InternalFixture<::testing::Test>
     public: double drumSpeed = 0.0;
 
     /// \brief Steer angle to apply.
-    public: math::Angle steer;
+    public: ignition::math::Angle steer;
 
     /// \brief Suspension force to apply in N.
     public: double suspForce = 0.0;
@@ -118,10 +124,10 @@ TEST_F(WheelSlipTest, TireDrum)
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
 
-  EntityComponentManager *ecm = nullptr;
+  gazebo::EntityComponentManager *ecm = nullptr;
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-        EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+        gazebo::EntityComponentManager &_ecm)
       {
       ecm = &_ecm;
       });
@@ -139,7 +145,7 @@ TEST_F(WheelSlipTest, TireDrum)
   Entity worldEntity =
     ecm->EntityByComponents(components::World());
 
-  EXPECT_NE(kNullEntity, worldEntity);
+  EXPECT_NE(gazebo::kNullEntity, worldEntity);
 
   // Get both models
   Entity tireEntity =
@@ -150,8 +156,8 @@ TEST_F(WheelSlipTest, TireDrum)
     ecm->EntityByComponents(components::Model(),
         components::Name("drum"));
 
-  EXPECT_NE(kNullEntity, tireEntity);
-  EXPECT_NE(kNullEntity, drumEntity);
+  EXPECT_NE(gazebo::kNullEntity, tireEntity);
+  EXPECT_NE(gazebo::kNullEntity, drumEntity);
 
   Entity wheelLinkEntity = ecm->EntityByComponents(
       components::ParentEntity(tireEntity),
@@ -163,8 +169,8 @@ TEST_F(WheelSlipTest, TireDrum)
       components::Name("link"),
       components::Link());
 
-  EXPECT_NE(kNullEntity, wheelLinkEntity);
-  EXPECT_NE(kNullEntity, drumLinkEntity);
+  EXPECT_NE(gazebo::kNullEntity, wheelLinkEntity);
+  EXPECT_NE(gazebo::kNullEntity, drumLinkEntity);
 
   auto wheelInertialComp =
     ecm->Component<components::Inertial>(wheelLinkEntity);
@@ -191,8 +197,8 @@ TEST_F(WheelSlipTest, TireDrum)
       components::Name("collision"),
       components::Collision());
 
-  EXPECT_NE(kNullEntity, collisionWheelLinkEntity);
-  EXPECT_NE(kNullEntity, collisionDrumLinkEntity);
+  EXPECT_NE(gazebo::kNullEntity, collisionWheelLinkEntity);
+  EXPECT_NE(gazebo::kNullEntity, collisionDrumLinkEntity);
 
   auto wheelCollisionComp =
     ecm->Component<components::CollisionElement>(collisionWheelLinkEntity);
@@ -238,16 +244,19 @@ TEST_F(WheelSlipTest, TireDrum)
   // const double kp = surfaceContactOde->GetElement("kp")->Get<double>();
   // ASSERT_EQ(kp, 250e3);
 
+  double modelMass = 0.0;
   for (const auto &linkName : linksToCheck)
   {
     Entity linkEntity = ecm->EntityByComponents(
         components::ParentEntity(tireEntity),
         components::Name(linkName),
         components::Link());
-    EXPECT_NE(kNullEntity, linkEntity);
+    EXPECT_NE(gazebo::kNullEntity, linkEntity);
     auto inertialComp = ecm->Component<components::Inertial>(linkEntity);
 
     EXPECT_NE(nullptr, inertialComp);
+
+    modelMass += inertialComp->Data().MassMatrix().Mass();
   }
 
   // Get axle wheel and steer joint of wheel model
@@ -256,14 +265,14 @@ TEST_F(WheelSlipTest, TireDrum)
       components::Name("axle_wheel"),
       components::Joint());
 
-  ASSERT_NE(kNullEntity, wheelAxleJointEntity);
+  ASSERT_NE(gazebo::kNullEntity, wheelAxleJointEntity);
 
   Entity wheelSteerJointEntity = ecm->EntityByComponents(
       components::ParentEntity(tireEntity),
       components::Name("steer"),
       components::Joint());
 
-  ASSERT_NE(kNullEntity, wheelSteerJointEntity);
+  ASSERT_NE(gazebo::kNullEntity, wheelSteerJointEntity);
 
   const double wheelSpeed =
     -25.0 * metersPerMile / secondsPerHour / wheelRadius;
@@ -377,10 +386,10 @@ TEST_F(WheelSlipTest, TricyclesUphill)
   EXPECT_FALSE(server.Running());
   EXPECT_FALSE(*server.Running(0));
 
-  EntityComponentManager *ecm = nullptr;
+  gazebo::EntityComponentManager *ecm = nullptr;
   test::Relay testSystem;
-  testSystem.OnPreUpdate([&](const UpdateInfo &,
-        EntityComponentManager &_ecm)
+  testSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+        gazebo::EntityComponentManager &_ecm)
       {
       ecm = &_ecm;
       });
@@ -398,7 +407,7 @@ TEST_F(WheelSlipTest, TricyclesUphill)
   Entity worldEntity =
     ecm->EntityByComponents(components::World());
 
-  EXPECT_NE(kNullEntity, worldEntity);
+  EXPECT_NE(gazebo::kNullEntity, worldEntity);
 
   auto gravity = ecm->Component<components::Gravity>(worldEntity);
 
@@ -410,14 +419,14 @@ TEST_F(WheelSlipTest, TricyclesUphill)
     ecm->EntityByComponents(components::Model(),
         components::Name("trisphere_cycle0"));
 
-  EXPECT_NE(kNullEntity, trisphereCycle0Entity);
+  EXPECT_NE(gazebo::kNullEntity, trisphereCycle0Entity);
 
 
   Entity trisphereCycle1Entity =
     ecm->EntityByComponents(components::Model(),
         components::Name("trisphere_cycle1"));
 
-  EXPECT_NE(kNullEntity, trisphereCycle1Entity);
+  EXPECT_NE(gazebo::kNullEntity, trisphereCycle1Entity);
 
   // Check rear left wheel of first model
   Entity wheelRearLeftEntity = ecm->EntityByComponents(
@@ -425,7 +434,7 @@ TEST_F(WheelSlipTest, TricyclesUphill)
       components::Name("wheel_rear_left"),
       components::Link());
 
-  EXPECT_NE(kNullEntity, wheelRearLeftEntity);
+  EXPECT_NE(gazebo::kNullEntity, wheelRearLeftEntity);
 
   Entity wheelRearLeftCollisionEntity = ecm->EntityByComponents(
       components::ParentEntity(wheelRearLeftEntity),
@@ -445,28 +454,28 @@ TEST_F(WheelSlipTest, TricyclesUphill)
       components::Name("wheel_rear_left_spin"),
       components::Joint());
 
-  EXPECT_NE(kNullEntity, wheelRearLeftSpin0Entity);
+  EXPECT_NE(gazebo::kNullEntity, wheelRearLeftSpin0Entity);
 
   Entity wheelRearRightSpin0Entity = ecm->EntityByComponents(
       components::ParentEntity(trisphereCycle0Entity),
       components::Name("wheel_rear_right_spin"),
       components::Joint());
 
-  EXPECT_NE(kNullEntity, wheelRearRightSpin0Entity);
+  EXPECT_NE(gazebo::kNullEntity, wheelRearRightSpin0Entity);
 
   Entity wheelRearLeftSpin1Entity = ecm->EntityByComponents(
       components::ParentEntity(trisphereCycle1Entity),
       components::Name("wheel_rear_left_spin"),
       components::Joint());
 
-  EXPECT_NE(kNullEntity, wheelRearLeftSpin1Entity);
+  EXPECT_NE(gazebo::kNullEntity, wheelRearLeftSpin1Entity);
 
   Entity wheelRearRightSpin1Entity = ecm->EntityByComponents(
       components::ParentEntity(trisphereCycle1Entity),
       components::Name("wheel_rear_right_spin"),
       components::Joint());
 
-  EXPECT_NE(kNullEntity, wheelRearRightSpin1Entity);
+  EXPECT_NE(gazebo::kNullEntity, wheelRearRightSpin1Entity);
 
   // Set speed of both models
   const double angularSpeed = 6.0;
@@ -521,8 +530,8 @@ TEST_F(WheelSlipTest, TricyclesUphill)
   }
 
   test::Relay testSlipSystem;
-  testSlipSystem.OnPreUpdate([&](const UpdateInfo &,
-        EntityComponentManager &)
+  testSlipSystem.OnPreUpdate([&](const gazebo::UpdateInfo &,
+        gazebo::EntityComponentManager &)
       {
       auto wheelRearLeftVelocity0Cmd =
         ecm->Component<components::JointVelocityCmd>(wheelRearLeftSpin0Entity);
@@ -545,15 +554,12 @@ TEST_F(WheelSlipTest, TricyclesUphill)
   server.AddSystem(testSlipSystem.systemPtr);
   server.Run(true, 2000, false);
 
-  // Slip works on DART>=6.10, which isn't available on Ubuntu Focal
-#ifndef __linux__
   // compute expected slip
   // normal force as passed to Wheel Slip in test world
   const double wheelNormalForce = 32;
   const double mass = 14.5;
   const double forceRatio =
     (mass/2) * std::abs(gravity->Data().X()) / wheelNormalForce;
-#endif
   const double noSlipLinearSpeed = wheelRadius * angularSpeed;
 
   auto wheelRearLeftVelocity =
@@ -584,9 +590,6 @@ TEST_F(WheelSlipTest, TricyclesUphill)
 
   EXPECT_NEAR(angularSpeed, wheelRearLeftVelocity->Data()[0], 3e-3);
   EXPECT_NEAR(angularSpeed, wheelRearRightVelocity->Data()[0], 3e-3);
-  // Slip works on DART>=6.10, which isn't available on Ubuntu Focal
-#ifndef __linux__
   EXPECT_NEAR(noSlipLinearSpeed - worldVelTrisphere1->Data()[0],
       noSlipLinearSpeed * forceRatio, 5e-3);
-#endif
 }
