@@ -16,32 +16,39 @@
  */
 
 #include <gtest/gtest.h>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
-#include <gz/msgs/Utility.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
+#include <ignition/msgs/Utility.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sim/Link.hh"
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"
+#include "ignition/gazebo/Link.hh"
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"
 
-#include "gz/sim/components/LinearAcceleration.hh"
-#include "gz/sim/components/LinearVelocity.hh"
-#include "gz/sim/components/Link.hh"
-#include "gz/sim/components/Name.hh"
-#include "gz/sim/components/Pose.hh"
-#include "gz/sim/components/WindMode.hh"
+#include "ignition/gazebo/components/LinearAcceleration.hh"
+#include "ignition/gazebo/components/LinearVelocity.hh"
+#include "ignition/gazebo/components/Link.hh"
+#include "ignition/gazebo/components/Name.hh"
+#include "ignition/gazebo/components/Pose.hh"
+#include "ignition/gazebo/components/WindMode.hh"
 
 #include "plugins/MockSystem.hh"
-#include "../helpers/EnvTestFixture.hh"
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 /// \brief Test WindEffects system
-class WindEffectsTest : public InternalFixture<::testing::Test>
+class WindEffectsTest : public ::testing::Test
 {
+  // Documentation inherited
+  protected: void SetUp() override
+  {
+    common::Console::SetVerbosity(4);
+    ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+           (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
+  }
+
   public: void StartServer(const std::string &_sdfFile)
   {
     ServerConfig serverConfig;
@@ -70,7 +77,7 @@ class LinkComponentRecorder
       : linkName(std::move(_linkName))
   {
     auto plugin = loader.LoadPlugin("libMockSystem.so",
-                                    "gz::sim::MockSystem", nullptr);
+                                    "ignition::gazebo::MockSystem", nullptr);
     EXPECT_TRUE(plugin.has_value());
 
     this->systemPtr = plugin.value();
@@ -82,7 +89,7 @@ class LinkComponentRecorder
     if (_createComp)
     {
       this->mockSystem->preUpdateCallback =
-        [this](const UpdateInfo &, EntityComponentManager &_ecm)
+        [this](const gazebo::UpdateInfo &, gazebo::EntityComponentManager &_ecm)
         {
           auto linkEntity = _ecm.EntityByComponents(
               components::Link(), components::Name(this->linkName));
@@ -98,8 +105,8 @@ class LinkComponentRecorder
     }
 
     this->mockSystem->postUpdateCallback =
-        [this](const UpdateInfo &,
-              const EntityComponentManager &_ecm)
+        [this](const gazebo::UpdateInfo &,
+              const gazebo::EntityComponentManager &_ecm)
         {
           auto linkEntity = _ecm.EntityByComponents(
               components::Link(), components::Name(this->linkName));
@@ -319,55 +326,3 @@ TEST_F(WindEffectsTest , TopicsAndServices)
     lastVelMagnitude = velMagnitude;
   }
 }
-
-/// Test if adding a link with wind after first iteration adds
-/// WorldLinearVelocity component properly
-TEST_F(WindEffectsTest, WindEntityAddedAfterStart)
-{
-  const std::string windBox = R"EOF(
-  <?xml version="1.0" ?>
-  <sdf version="1.6">
-      <model name="box_wind">
-        <pose>5 5 5 0 0 0</pose>
-        <enable_wind>true</enable_wind>
-        <link name="test_link_wind">
-          <collision name="collision">
-            <geometry>
-              <box>
-                <size>1 1 1</size>
-              </box>
-            </geometry>
-          </collision>
-        </link>
-      </model>
-  </sdf>)EOF";
-
-  this->StartServer("/test/worlds/wind_effects.sdf");
-
-  LinkComponentRecorder<components::WorldLinearVelocity>
-    linkVelocityComponent("test_link_wind");
-  this->server->AddSystem(linkVelocityComponent.systemPtr);
-  EXPECT_TRUE(linkVelocityComponent.values.empty());
-
-  // Run the logger for a time, check it is still empty
-  this->server->Run(true, 10, false);
-  EXPECT_TRUE(linkVelocityComponent.values.empty());
-
-  // Add the box to be logged via the command system
-  // and check that is not empty
-  transport::Node node;
-  msgs::EntityFactory req;
-  unsigned int timeout = 5000;
-  std::string service{"/world/wind_demo/create"};
-  msgs::Boolean res;
-  bool result;
-
-  req.set_sdf(windBox);
-  EXPECT_TRUE(node.Request(service, req, timeout, res, result));
-  EXPECT_TRUE(result);
-  EXPECT_TRUE(res.data());
-
-  // Now box_wind WorldLinearVelocity component should be added
-  this->server->Run(true, 10, false);
-  ASSERT_FALSE(linkVelocityComponent.values.empty());
-}
