@@ -19,16 +19,16 @@
 #include <gtest/gtest.h>
 #include <array>
 
-#include <gz/math/Stopwatch.hh>
-#include <gz/common/Console.hh>
-#include <gz/common/Util.hh>
+#include <ignition/math/Stopwatch.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Util.hh>
 
-#include "gz/sim/Server.hh"
-#include "gz/sim/SystemLoader.hh"
-#include "gz/sim/test_config.hh"  // NOLINT(build/include)
+#include "ignition/gazebo/Server.hh"
+#include "ignition/gazebo/SystemLoader.hh"
+#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
 
-using namespace gz;
-using namespace gz::sim;
+using namespace ignition;
+using namespace gazebo;
 
 TEST(LevelManagerPerfrormance, LevelVsNoLevel)
 {
@@ -36,31 +36,20 @@ TEST(LevelManagerPerfrormance, LevelVsNoLevel)
 
   common::Console::SetVerbosity(4);
 
-  common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
+  ignition::common::setenv("IGN_GAZEBO_SYSTEM_PLUGIN_PATH",
          (std::string(PROJECT_BINARY_PATH) + "/lib").c_str());
 
-  ServerConfig serverConfig;
+  ignition::gazebo::ServerConfig serverConfig;
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
                           "/test/worlds/level_performance.sdf");
   math::Stopwatch watch;
 
   const std::size_t iters = 5000;
 
-
-  // Reduce potential startup costs by running the server once before
-  // measuring time differences between levels and no levels.
-  {
-    serverConfig.SetUseLevels(true);
-    Server server(serverConfig);
-    server.SetUpdatePeriod(1ns);
-
-    server.Run(true, 1, false);
-  }
-
   // Server with levels
   {
     serverConfig.SetUseLevels(true);
-    Server server(serverConfig);
+    gazebo::Server server(serverConfig);
     server.SetUpdatePeriod(1ns);
 
     watch.Start(true);
@@ -72,7 +61,7 @@ TEST(LevelManagerPerfrormance, LevelVsNoLevel)
   // Server without levels
   {
     serverConfig.SetUseLevels(false);
-    Server serverNoLevels(serverConfig);
+    gazebo::Server serverNoLevels(serverConfig);
     serverNoLevels.SetUpdatePeriod(1ns);
 
     watch.Start(true);
